import random

from h_common import *
from h_items import *
from h_troops import *
from h_skills import *
from ID_factions import *
from ID_items import *
from ID_scenes import *

####################################################################################################################
#  Each troop contains the following fields:
#  1) Troop id (string): Used for referencing troops in other files. The prefix trp_ is automatically added before each troop-ID .
#  2) Troop name (string).
#  3) Plural troop name (string).
#  4) Troop flags (int). See h_troops.py for a list of available flags.
#  5) Scene (int) (only applicable to heroes) For example: scn_reyvadin_castle|entry(1) puts troop in Reyvadin castle's first entry point.
#  6) Reserved (int). Put constant "reserved" or "0".
#  7) Faction (int).
#  8) Inventory (list): Must be a list of items.
#  9) Attributes (int): Example usage:
#     str_6|agi_6|int_4|cha_5|level(5)
# 10) Weapon proficiencies (int): Example usage:
#     wp_one_handed(55)|wp_two_handed(90)|wp_polearm(36)|wp_archery(80)|wp_crossbow(24)|wp_throwing(45)
#     The function wp(X) will create random weapon proficiencies close to value X.
#     To make an expert archer with other weapon proficiencies close to 60 you can use something like:
#     wp_archery(160)|wp(60)
# 11) Skills (int): See h_skills.py to see a list of skills. Example:
#     knows_ironflesh_3|knows_power_strike_2|knows_athletics_2|knows_riding_2
# 12) Face code (int): You can obtain the face code by pressing Ctrl+E in face generator screen.
# 13) Face code (int)(2) (only applicable to regular troops, can be omitted for heroes):
#     The game will create random faces between Face code 1 and face code 2 for generated troops.
# 14) Troop image (string): If this variable is set, the troop will use an image rather than its 3D visual during the conversations.
###############################################################################################

# Some constant and function declarations to be used below: 
# wp_one_handed () | wp_two_handed () | wp_polearm () | wp_archery () | wp_crossbow () | wp_throwing ()
def wp(x):
  n = 0
  r = 10 + int(x / 10)
#  n |= wp_one_handed(x + random.randrange(r))
#  n |= wp_two_handed(x + random.randrange(r))
#  n |= wp_polearm(x + random.randrange(r))
#  n |= wp_archery(x + random.randrange(r))
#  n |= wp_crossbow(x + random.randrange(r))
#  n |= wp_throwing(x + random.randrange(r))
  n |= wp_one_handed(x)
  n |= wp_two_handed(x)
  n |= wp_polearm(x)
  n |= wp_archery(x)
  n |= wp_crossbow(x)
  n |= wp_throwing(x)
  return n

def wpe(m,a,c,t):
   n = 0
   n |= wp_one_handed(m)
   n |= wp_two_handed(m)
   n |= wp_polearm(m)
   n |= wp_archery(a)
   n |= wp_crossbow(c)
   n |= wp_throwing(t)
   return n

def wpex(o,w,p,a,c,t):
   n = 0
   n |= wp_one_handed(o)
   n |= wp_two_handed(w)
   n |= wp_polearm(p)
   n |= wp_archery(a)
   n |= wp_crossbow(c)
   n |= wp_throwing(t)
   return n
   
def wp_melee(x):
  n = 0
  r = 10 + int(x / 10)
#  n |= wp_one_handed(x + random.randrange(r))
#  n |= wp_two_handed(x + random.randrange(r))
#  n |= wp_polearm(x + random.randrange(r))
  n |= wp_one_handed(x + 20)
  n |= wp_two_handed(x)
  n |= wp_polearm(x + 10)
  return n

def attrlev(s,a,i,c,l):
 n = bignum | s
 n |= (bignum | (a << 8))
 n |= (bignum | (i << 16))
 n |= (bignum | (c << 24))
 n |= level(l)
 return n
 
def strsk(i,ps,pt,pd):
 n = 0
 n |= (int(hex(i),16) << (skl_ironflesh << 2))
 n |= (int(hex(ps),16) << (skl_power_strike << 2))
 n |= (int(hex(pt),16) << (skl_power_throw << 2))
 n |= (int(hex(pd),16) << (skl_power_draw << 2))
 return n
 
def agisk(wm,sh,ath,ri,ha):
 n = 0
 n |= (int(hex(wm),16) << (skl_weapon_master << 2))
 n |= (int(hex(sh),16) << (skl_shield << 2))
 n |= (int(hex(ath),16) << (skl_athletics << 2))
 n |= (int(hex(ri),16) << (skl_riding << 2))
 n |= (int(hex(ha),16) << (skl_horse_archery << 2))
 return n
 
def lordsk1(loo,forag,train,track,tct,pf,spt,inv):
 n = 0
 n |= (int(hex(loo),16) << (skl_looting << 2))
 n |= (int(hex(forag),16) << (skl_foraging << 2))
 n |= (int(hex(train),16) << (skl_trainer << 2))
 n |= (int(hex(track),16) << (skl_tracking << 2))
 n |= (int(hex(tct),16) << (skl_tactics << 2))
 n |= (int(hex(pf),16) << (skl_pathfinding << 2))
 n |= (int(hex(spt),16) << (skl_spotting << 2))
 n |= (int(hex(inv),16) << (skl_inventory_management << 2))
 return n
 
def lordsk2(wt,sur,fa,eng,pers,prm,lead,trd):
 n = 0
 n |= (int(hex(wt),16) << (skl_wound_treatment << 2))
 n |= (int(hex(sur),16) << (skl_surgery << 2))
 n |= (int(hex(fa),16) << (skl_first_aid << 2))
 n |= (int(hex(eng),16) << (skl_engineer << 2))
 n |= (int(hex(pers),16) << (skl_persuasion << 2))
 n |= (int(hex(prm),16) << (skl_prisoner_management << 2))
 n |= (int(hex(lead),16) << (skl_leadership << 2))
 n |= (int(hex(trd),16) << (skl_trade << 2))
 return n
  
#Skills
knows_common = knows_riding_1|knows_trade_2|knows_inventory_management_2|knows_prisoner_management_1|knows_leadership_1
def_attrib = str_20 | agi_7 | int_6 | cha_6
def_attrib_multiplayer = str_14 | agi_14 | int_4 | cha_4

#Silber Balance as follows: Average troop begins with hero stats minus 1/3. All troops also upgrade in all stats with 2/3 compared to a hero!
# GS adds back 25% ...

#Stats related to this are attributes and weapon proficiencies. Skills are excepted so far as many skills are not needed for certain troops
#but are considered chosen by them nevertheless.
#NOTES: "plus20"-"plus70" means +20% to +70% in respect to their main weapon proficiency and the "average" troop!
#All factions have troops that together have plus100 not more or less.
#EXCEPTION: Minor factions with limited trooptrees might have hybrids marked "(hybrid)"

#ALL Household- and Noble Troops are always plus70, Faction Mercenaries are plus50!

#Silber Skill Definitions Begin
#Silber Skill Definition Recruit
knows_recruit = knows_ironflesh_1|knows_power_strike_1|knows_shield_1|knows_athletics_1
#Silber Skill Definition Militia
knows_militia = knows_ironflesh_1|knows_power_strike_2|knows_shield_2|knows_athletics_2|knows_power_throw_1

#Silber Skill Definitions Remnants
knows_average_inf_plus30_lvl4 = knows_ironflesh_5|knows_power_strike_7|knows_shield_4|knows_athletics_5|knows_power_throw_3
knows_average_inf_plus40_lvl3 = knows_ironflesh_5|knows_power_strike_7|knows_shield_4|knows_athletics_4|knows_power_throw_3
knows_average_inf_plus40_lvl4 = knows_ironflesh_6|knows_power_strike_8|knows_shield_5|knows_athletics_5|knows_power_throw_3
knows_average_inf_plus50_lvl3 = knows_ironflesh_5|knows_power_strike_8|knows_shield_4|knows_athletics_4|knows_power_throw_3
knows_average_inf_plus50_lvl4 = knows_ironflesh_6|knows_power_strike_8|knows_shield_5|knows_athletics_5|knows_power_throw_4
knows_average_cav_plus70_lvl4 = knows_ironflesh_6|knows_power_strike_6|knows_power_throw_5|knows_horse_archery_5|knows_shield_7|knows_athletics_7|knows_riding_8

#Silber Skill Definitions Common Skills
knows_common_wild_lvl1 = knows_tracking_1|knows_pathfinding_1|knows_spotting_1|knows_wound_treatment_1|knows_first_aid_1
knows_common_wild_lvl2 = knows_tracking_2|knows_pathfinding_2|knows_spotting_2|knows_wound_treatment_1|knows_first_aid_1
knows_common_wild_lvl3 = knows_tracking_2|knows_pathfinding_2|knows_spotting_2|knows_wound_treatment_2|knows_first_aid_2
knows_common_wild_lvl4 = knows_tracking_3|knows_pathfinding_3|knows_spotting_3|knows_wound_treatment_3|knows_first_aid_3
knows_common_wild_lvl5 = knows_tracking_4|knows_pathfinding_4|knows_spotting_3|knows_wound_treatment_3|knows_first_aid_3
knows_common_wild_lvl6 = knows_tracking_4|knows_pathfinding_4|knows_spotting_4|knows_wound_treatment_4|knows_first_aid_4
knows_common_civc_lvl1 = knows_tactics_1|knows_trade_1|knows_leadership_1|knows_surgery_1
knows_common_civc_lvl2 = knows_tactics_1|knows_trade_2|knows_leadership_1|knows_surgery_1
knows_common_civc_lvl3 = knows_tactics_2|knows_trade_2|knows_leadership_2|knows_surgery_2
knows_common_civc_lvl4 = knows_tactics_3|knows_trade_3|knows_leadership_3|knows_surgery_3
knows_common_civc_lvl5 = knows_tactics_3|knows_trade_3|knows_leadership_4|knows_surgery_4
knows_common_civc_lvl6 = knows_tactics_4|knows_trade_4|knows_leadership_4|knows_surgery_4

#Silber Attribute Definitions Begin
#Silber Attribute Definition Recruit
recruit_attrib = str_9|agi_8|int_8|cha_6|level(4)
#Silber Attribute Definition Militia
militia_attrib = str_10|agi_9|int_8|cha_6|level(7)

#Silber Attribute Definitions Archer&Infantry
# NOTE: Archers and Infantry both require the same attributes for their respective main skills and are therefore not differing in attributes! OLD
# With the new system, Infantry has more Str for less penalty.
average_archinf_attrib_plus30_lvl4 = str_23|agi_15|int_10|cha_6|level(42)
average_archinf_attrib_plus40_lvl3 = str_22|agi_13|int_8|cha_6|level(35)
average_archinf_attrib_plus40_lvl4 = str_25|agi_15|int_8|cha_6|level(43)
average_archinf_attrib_plus50_lvl3 = str_21|agi_13|int_9|cha_6|level(36)
average_cav_attrib_plus70_lvl4 = str_30|agi_24|int_9|cha_11|level(48)
hacker_attrib_lv14 = str_30|agi_18|int_9|cha_12|level(50)

#Silber Weapon Proficiency Definitions 
def_wpex_average_inf_plus30_lvl4 = wpex(255,230,60,50,60,175)
def_wpex_average_inf_plus40_lvl3 = wpex(235,200,60,50,60,150)
def_wpex_average_inf_plus50_lvl3 = wpex(240,225,60,50,70,180)
def_wpex_average_spear_plus40_lvl4 = wpex(196,126,252,50,60,140)
def_wpex_average_spear_plus50_lvl3 = wpex(180,120,225,50,60,131)
def_wpex_average_lcav_plus70_lvl4 = wpex(255,238,272,40,40,40)
def_wpex_hacker_lv14 = wpex(289,323,238,70,70,70)


tf_guarantee_all = tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_horse|tf_guarantee_shield|tf_guarantee_ranged
#Silber tf Guarantees Begin
tf_guarantee_allnoranged = tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_horse|tf_guarantee_shield
tf_guarantee_inf = tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_shield
tf_guarantee_archer = tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_shield|tf_guarantee_ranged
#Silber tf Guarantees End

#nurses
novicenurse_skills = knows_weapon_master_1|knows_athletics_1|knows_spotting_1|knows_first_aid_3|knows_wound_treatment_3|knows_surgery_3
companionnurse_skills = knows_weapon_master_1|knows_athletics_3|knows_spotting_3|knows_first_aid_5|knows_wound_treatment_5|knows_surgery_5
masternurse_skills = knows_weapon_master_1|knows_athletics_5|knows_spotting_5|knows_first_aid_7|knows_wound_treatment_7|knows_surgery_7
# Rigale but also used for Priestess/Priest buffs GS

lord_attrib = str_20|agi_20|int_20|cha_20|level(38)
#SU. Attrib
knight_attrib_7 = str_30|agi_30|int_21|cha_29|level(60)
#SU. Attrib End
knight_attrib_1 = str_25|agi_14|int_8|cha_16|level(22)
knight_attrib_2 = str_26|agi_16|int_10|cha_18|level(26)
knight_attrib_4 = str_27|agi_17|int_12|cha_20|level(30)
knight_attrib_5 = str_28|agi_19|int_13|cha_22|level(35)
knight_attrib_6 = str_29|agi_20|int_15|cha_25|level(41)
knight_attrib_7 = str_30|agi_20|int_15|cha_25|level(45)
knight_skills_1 = knows_riding_3|knows_ironflesh_2|knows_power_strike_3|knows_athletics_1|knows_tactics_2|knows_prisoner_management_1|knows_leadership_3
#SU. Skill End
#These face codes are generated by the in-game face generator.
#Enable edit mode and press Ctrl+E in face generator screen to obtain face codes.

#Races +  Defined in  h_troops.py
# tf_male           = 0
# tf_female         = 1
# tf_elven_male     = 2
# tf_elven_female   = 3
# tf_dwarf_male     = 4 
# tf_dwarf_female   = 5
# tf_giant          = 6
# tf_giant_female   = 7   # GS not sure if this was Coulton's use
# tf_undead         = 8
# tf_skeleton       = 9
## orc	      = 12  ## GS seems to be a soft cut-off here in what Warband engine allows
## goblin     = 13	# implicit "female" Orc
#Races -

reserved = 0
no_scene = 0

swadian_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
swadian_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
swadian_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
swadian_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
swadian_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

swadian_face_younger_2 = 0x00000000000062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_young_2   = 0x00000003c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_middle_2  = 0x00000007c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_old_2     = 0x0000000bc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_older_2   = 0x0000000fc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000

vaegir_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
vaegir_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
vaegir_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
vaegir_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
vaegir_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

vaegir_face_younger_2 = 0x000000003f00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_young_2   = 0x00000003bf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_middle_2  = 0x00000007bf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_old_2     = 0x0000000cbf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_older_2   = 0x0000000ff100230c4deeffffffffffff00000000001efff90000000000000000

khergit_face_younger_1 = 0x0000000009003109207000000000000000000000001c80470000000000000000
khergit_face_young_1   = 0x00000003c9003109207000000000000000000000001c80470000000000000000
khergit_face_middle_1  = 0x00000007c9003109207000000000000000000000001c80470000000000000000
khergit_face_old_1     = 0x0000000b89003109207000000000000000000000001c80470000000000000000
khergit_face_older_1   = 0x0000000fc9003109207000000000000000000000001c80470000000000000000

khergit_face_younger_2 = 0x000000003f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_young_2   = 0x00000003bf0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_middle_2  = 0x000000077f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_old_2     = 0x0000000b3f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_older_2   = 0x0000000fff0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000

rhodok_face_younger_1 = 0x0000000009002003140000000000000000000000001c80400000000000000000
rhodok_face_young_1   = 0x0000000449002003140000000000000000000000001c80400000000000000000
rhodok_face_middle_1  = 0x0000000849002003140000000000000000000000001c80400000000000000000
rhodok_face_old_1     = 0x0000000cc9002003140000000000000000000000001c80400000000000000000
rhodok_face_older_1   = 0x0000000fc9002003140000000000000000000000001c80400000000000000000

sarranid_face_younger_1 = 0x000000003f0065c036db6e36db6db6c000000000001db7d30000000000000000
sarranid_face_older_2   = 0x0000000e7f006013769b6e3adbd1f6c000000000001db7db0000000000000000

aroulo_face_younger_1 = 0x000000000000d007120000800100020000000000001c80400000000000000000
aroulo_face_older_2   = 0x0000000fff00e00b6dffffffffffffff00000000001f7dbf0000000000000000

aroulo_face_woman_younger_1 = 0x0000000000003016000000000000000000000000001c00000000000000000000
aroulo_face_woman_older_2   = 0x0000000fff0040187fffffffffffffff00000000001fffff0000000000000000

rhodok_face_younger_2 = 0x00000000000062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_young_2   = 0x00000003c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_middle_2  = 0x00000007c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_old_2     = 0x0000000bc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_older_2   = 0x0000000fc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000


#habeo's Redwood faces, prior to change if elven skin is implemented. - OLD
elintoran_face_1 = 0x000000000000200736db6db6db6db6db00000000001db6db0000000000000000
elintoran_face_2 = 0x000000000000000736db6db6db6db6db00000000001db6db0000000000000000
elintoran_face_3 = 0x000000000000200936db6db6db6db6db00000000001db6db0000000000000000
elintoran_face_4 = 0x000000000000000f36db6db6db6db6db00000000001db6db0000000000000000
#habeo end - OLD
#Michadr Elven Faces (v0.7)
elintoran_face_young_1 = 0x000000000900000536db6db6db6db6db00000000001dc6f20000000000000000
elintoran_face_young_2 = 0x000000001e00101636db6db6db6db6db00000000001dc6f20000000000000000
elintoran_face_young_3 = 0x000000003f00301536db6db6db6db6db00000000001dc6f20000000000000000
elintoran_face_middle_1 = 0x00000001a400014326db6db6db6db6db00000000001db6eb0000000000000000
elintoran_face_middle_2 = 0x00000001800015d122db6db6db6db75b00000000001da6eb0000000000000000
elintoran_face_middle_3 = 0x00000001a6000254289b51b74caa371300000000001e36da0000000000000000
elintoran_face_old_1 = 0x0000000c5900124538ac72a64c6a28d400000000001e34d40000000000000000
elintoran_face_old_2 = 0x0000000c71003305070d95266b699acc00000000001cbb340000000000000000
elintoran_face_old_3 = 0x0000000eb4000591475b3559916d991b00000000001dd6e20000000000000000
#Elintor

#old faces
#0x000000000000000136db6db6db6db6db00000000001db6db0000000000000000 0x000000003f00000636db6db6db6db6db00000000001db6db0000000000000000
#0x000000028000100136db6db6db6db6db00000000001db6db0000000000000000 0x00000002b100100636db6db6db6db6db00000000001db6db0000000000000000
#0x000000070000201636db6db6db6db6db00000000001db6db0000000000000000 0x000000072100201736db6db6db6db6db00000000001db6db0000000000000000
#0x0000000d1800001236db6db6db6db6db00000000001db6db0000000000000000 0x0000000d3f00001736db6db6db6db6db00000000001db6db0000000000000000
#0x00000007c000300136db6db6db6db6db00000000001db6db0000000000000000 0x00000007d800300636db6db6db6db6db00000000001db6db0000000000000000
#0x0000000d0000000136db6db6db6db6db00000000001db6db0000000000000000 0x0000000dff00000636db6db6db6db6db00000000001db6db0000000000000000

#Female
redwood_women_young_1 = 0x00000000001010083add69969bcd952500000000001d36e90000000000000000
redwood_women_young_2 = 0x000000000004200858c3b9549339c6a000000000001d292b0000000000000000
redwood_women_young_3 = 0x000000003b00100365a48cb514362a7600000000001d354c0000000000000000
redwood_women_middle_1 = 0x000000054008400a32e352bae3b1ccd500000000001d2aca0000000000000000
redwood_women_middle_2 = 0x000000057f105001534b72492334c4d500000000001e42e40000000000000000
redwood_women_middle_3 = 0x000000060a10300a5523c3c6a355a69c00000000001eee5d0000000000000000
redwood_women_old_1 = 0x0000000e7f1030035523c3c6a355a69c00000000001eee5d0000000000000000
redwood_women_old_2 = 0x0000000e64044009392472535c59b81c0000000000123b6a0000000000000000
#Michadr Elven Faces (v0.7) End
#Dwarf Faces
dwarf_face_young_1 = 0x00000000190011c4692ecdc29a2ccaa400000000001ec4e30000000000000000
dwarf_face_young_2 = 0x000000000000504518deaccab4892a6200000000001e390a0000000000000000
dwarf_face_young_3 = 0x00000000220002052c546dd71b8e22e300000000001e666d0000000000000000
dwarf_face_young_4 = 0x00000000300011c436dc4d971b8bc6db00000000001d37540000000000000000
dwarf_face_middle_1 = 0x00000006190011475b138a250d3dd49100000000001ce8d90000000000000000
dwarf_face_middle_2 = 0x00000006310002055b6b8b46ac9698db000000000010d3610000000000000000
dwarf_face_middle_3 = 0x000000063b005044432c75b89a6e56eb00000000000a4b2b0000000000000000
dwarf_face_old_1 = 0x0000000db60041c14b25a8aaea6ed89e000000000011bc9c0000000000000000
dwarf_face_old_2 = 0x0000000d80000043629693c55576c44d00000000001ebd1b0000000000000000
dwarf_face_old_3 = 0x0000000d8f0030c5351bc9a30351c6a400000000001c93350000000000000000
dwarf_face_old_4 = 0x0000000da6000184226075c89d2dd6ad00000000001c989d0000000000000000
dwarf_face_older_1 = 0x0000000ff100514127138e429baf20c2000000000005a7550000000000000000
dwarf_face_older_2 = 0x0000000ffe0021c431134ec4d0d12ac6000000000009b7200000000000000000
#Dwarf Faces End
#Mosoru Face Begin 
mosoru_face_1 = 0x000000003f0494c838896a4ae99256cc00000000001d69340000000000000000
mosoru_face_2 = 0x000000003f04734938896a4ae99256cc00000000001d69340000000000000000
mosoru_face_3 = 0x000000013f04834a3889aa4aec9256cc00000000001d68b40000000000000000
mosoru_face_4 = 0x000000013f0493493889aa4aec9256cc00000000001d68b40000000000000000
mosoru_face_5 = 0x000000013f04810c3889aa4aec9256cc00000000001d68b40000000000000000
mosoru_face_6 = 0x000000013f0471c92889a24a6c9216cc00000000001de8b40000000000000000
#Mosoru Face END






woman_face_1    = 0x0000000000000001000000000000000000000000001c00000000000000000000
woman_face_2    = 0x00000003bf0030067ff7fbffefff6dff00000000001f6dbf0000000000000000

swadian_woman_face_1 = 0x0000000180102006124925124928924900000000001c92890000000000000000
swadian_woman_face_2 = 0x00000001bf1000061db6d75db6b6dbad00000000001c92890000000000000000

khergit_woman_face_1 = 0x0000000180103006124925124928924900000000001c92890000000000000000
khergit_woman_face_2 = 0x00000001af1030025b6eb6dd6db6dd6d00000000001eedae0000000000000000

refugee_face1 = 0x000000000000000106994480c90982b400000000001cc4530000000000000000
refugee_face2 = 0x0000000bff00301429acef17b5eea53f00000000001df8bf0000000000000000
girl_face1    = woman_face_1
girl_face2    = woman_face_2

vaegir_face1  = vaegir_face_young_1
vaegir_face2  = vaegir_face_older_2

undead_face1  = 0x0000000000000000000000000000000000000000000000000000000000000000
undead_face2  = 0x000000003f000493000000000000000000000000000000000000000000000000

skeleton_face1  = 0xffffffff00000000000000000000000000000000000000000000000000000000
skeleton_face2  = 0xffffffff00000000000000000000000000000000000000000000000000000000


##+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#Revised faces by leo
man_face_young_1   = 0x0000000030000001124924924924924900000000001db4490000000000000000
man_face_young_2   = 0x00000007bf00648a5db7db6bb5d6ddb400000000001db9be0000000000000000
mfy1 = man_face_young_1
mfy2 = man_face_young_2
man_face_old_1  = 0x00000008b0000001124924924924924900000000001db4490000000000000000
man_face_old_2  = 0x0000000dbf00648a5db7db6bb5d6ddb400000000001db9be0000000000000000
mfo1 = man_face_old_1
mfo2 = man_face_old_2

bandit_face1  = man_face_young_1
bandit_face2  = man_face_old_2
merchant_face_1    = man_face_young_1
merchant_face_2    = man_face_old_2

nord_face_1 = 0x0000000030000201124924924924924900000000001db4490000000000000000
nord_face_2 = 0x0000000dbf00634a5db7db6bb5d6ddb400000000001db9be0000000000000000
nofa1 = nord_face_1
nofa2 =nord_face_2

mercenary_face_1 = 0x0000000000000081124824924924920900000000001d94490000000000000000 #both - revised by leo
mercenary_face_2 = 0x000000083f00640a6dbfdffb76becdb600000000001e39be0000000000000000

draharan_faces_black_begin = 0x0000000000013003245229144925144900000000001d24490000000000000000
draharan_faces_black_end = 0x0000000cff0141cb6d76db69369b3db600000000001e596d0000000000000000
draharan_faces_arab_begin = 0x000000002400a003245229144925144900000000001d24490000000000000000
draharan_faces_arab_end = 0x0000000cff00c1cb6d76db69369b3db600000000001e596d0000000000000000 #change C skin in 00c1 part to A if look to much like hakkon people (they also use skins B and C)

elintoran_face_young_begin = 0x00000000c1000001128924924924924900000000001c94490000000000000000
elintoran_face_young_end = 0x00000008bf00604d55b6db48f59a3da900000000001e69360000000000000000
elintoran_face_old_begin = 0x0000000940000003128924924924924900000000001c94490000000000000000
elintoran_face_old_end = 0x0000000fff00605055b6db48f59a3da900000000001e69360000000000000000
elintoran_face_female_start = 0x0000000000000001124924924924924100000000001d12490000000000000000
elintoran_face_female_end = 0x0000000b250020145b76d76db6cf68ea00000000001e6d760000000000000000

kaikoth_male_faces_begin = 0x0000000027040041124c24924924928a00000000001c92520000000000000000
kaikoth_male_faces_end = 0x0000000abf04d30c4db4d349aedb6d3600000000001f67b60000000000000000
kaikoth_male_faces_safebeard_begin = 0x00000000270400c1124c24924924928a00000000001c92520000000000000000
kaikoth_male_faces_safebeard_end = 0x0000000abf04d20c4db4d349aedb6d3600000000001f67b60000000000000000

kuulan_face_young_to_old_begin = 0x0000000080007381244a44944928949400000000001c92490000000000000000
kuulan_face_young_to_old_end = 0x0000000d7f00810b5b76d6ebb59a3b6e00000000001e596d0000000000000000

zann_face_young_to_middle_begin = 0x0000000000107381124929224925225100000000001d94480000000000000000
zann_face_young_to_middle_end = 0x000000083e1095c66dacdeecf69a4dad00000000001eebae0000000000000000
zann_face_middle_to_old_begin = 0x0000000800109050144924a44928a44900000000001da2490000000000000000
zann_face_middle_to_old_end = 0x0000000dbe1091d46dacdeecf69a4dad00000000001eebae0000000000000000

giant_face_female_start = 0x000000000104701212492492492492490000000000e412490000000000000000
giant_face_female_end = 0x0000000fff04d0196db6db6db6db6db60000000000f66db60000000000000000
##+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


troops = [
["player", "Player", "Player", tf_hero|tf_unmoveable_in_party_window, 0, 0, fac_player_faction, [], 
str_8|agi_8|int_8|cha_8, wpex(50,50,50,40,40,40),0, 0x00000001b500000436db6db6db6db75c00000000001db6db0000000000000000], 
["multiplayer_profile_troop_male", "multiplayer_profile_troop_male", "multiplayer_profile_troop_male", tf_hero|tf_guarantee_all, 0, 0, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 0, 0,0, 0x00000001b500000436db6db6db6db75c00000000001db6db0000000000000000], #human male
["multiplayer_profile_troop_female", "multiplayer_profile_troop_female", "multiplayer_profile_troop_female", tf_hero|tf_female|tf_guarantee_all, 0, 0, fac_commoners, [itm_tribal_warrior_outfit, itm_leather_boots], 0, 0,0, 0x00000001b500400b76db6db6db6db75c00000000000000000000000000000000], #human female
["temp_troop", "Temp Troop", "Temp Troop", tf_hero, 0, 0, fac_commoners, [], def_attrib,0, knows_common|knows_inventory_management_10, 0x000000018000201036db6db69b6d36da00000000001ca6db0000000000000000, 0x00000001b60c21ca265b75250a4932d80000000000ea16d20000000000000000], #elven default facecodes
#  ["game", "Game", "Game", tf_hero, 0, 0, fac_commoners, [], def_attrib,0, knows_common,0], 
#  ["unarmed_troop", "Unarmed Troop", "Unarmed Troops", tf_hero, 0, 0, fac_commoners, [itm_arrows, itm_short_bow], def_attrib|str_14,0, knows_common|knows_power_draw_2,0], 

####################################################################################################################
# Troops before this point are hardwired into the game and their order should not be changed!
####################################################################################################################
["find_item_cheat","find_item_cheat","find_item_cheat",tf_hero|tf_is_merchant,0,0,fac_commoners, [], def_attrib,0,knows_common|knows_inventory_management_10, 0x00000001b20020c134dba5991c9a66dc00000000001e9a5b0000000000000000, 0x00000001ad0c004f551c71caf2ca2cca0000000000f603240000000000000000], #dwarven default facecodes; stats are used to back up player's stats during custom troops' re-equipment
["globals_troop","globals_troop","globals_troop",tf_hero|tf_is_merchant,0,0,fac_commoners, [], 
def_attrib,0,knows_common|knows_inventory_management_10,0x000000063510308a70dc75b66c91aca500000000001c27530000000000000000, 0x000000018004030736a3db151a11c8e200000000001e2ac40000000000000000], #his facecode 0 is a real face of King Bullius (facecode 1 is default giant male face), STATS ARE USED TO BACK UP THE STATS OF HUMAN Household Guards
["tournament_participants","Tournament Participants","Tournament Participants",tf_hero,0,0,fac_commoners, [], def_attrib,0,knows_common|knows_inventory_management_10,0], 
["tutorial_maceman","Maceman","Maceman",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_tutorial_club, itm_leather_jerkin, itm_hunter_boots], str_6|agi_6|level(1),wp(50),knows_common,mercenary_face_1,mercenary_face_2], 
["tutorial_archer","Archer","Archer",tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_ranged,0,0,fac_commoners, [itm_tutorial_short_bow, itm_tutorial_arrows, itm_rough_tunic_mailed, itm_hunter_boots], str_6|agi_6|level(5),wp(100),knows_common|knows_power_draw_4,mercenary_face_1,mercenary_face_2], 
["tutorial_swordsman","Swordsman","Swordsman",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_tutorial_sword, itm_leather_vest, itm_hunter_boots], str_6|agi_6|level(5),wp(80),knows_common,mercenary_face_1,mercenary_face_2], 

["novice_fighter","Novice Fighter","Novice Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], 
attrlev(8,8,4,4,6), wpex(80,80,80,80,80,80), strsk(2,2,2,2)|agisk(2,2,2,2,2),mercenary_face_1,mercenary_face_2], #Titus/Vitus father
["regular_fighter","Regular Fighter","Regular Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], 
attrlev(12,12,6,6,12), wpex(150,150,150,150,150,150), strsk(3,3,3,3)|agisk(3,3,3,3,3),mercenary_face_1,mercenary_face_2], 
["veteran_fighter","Veteran Fighter","Veteran Fighters",tf_guarantee_boots|tf_guarantee_armor,no_scene,0,fac_commoners, [itm_hunter_boots], 
attrlev(18,18,8,8,20), wpex(220,220,220,220,220,220), strsk(6,5,5,5)|agisk(5,5,5,5,5),mercenary_face_1,mercenary_face_2], 
["champion_fighter","Champion Fighter","Champion Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], 
attrlev(24,24,14,14,35), wpex(300,300,300,300,300,300), strsk(8,7,7,7)|agisk(7,7,7,7,7),mercenary_face_1,mercenary_face_2], 

["giant_novice_fighter","Novice Fighter","Novice Fighters",tf_giant_male|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [], 
attrlev(26,7,4,4,8), wpex(100,100,100,70,70,70), strsk(3,3,3,3)|agisk(2,2,2,2,2),mercenary_face_1,mercenary_face_2], 
["giant_regular_fighter","Regular Fighter","Regular Fighters",tf_giant_male|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [], 
attrlev(32,10,5,5,15), wpex(200,200,200,120,120,120), strsk(5,5,5,5)|agisk(3,3,3,3,3),mercenary_face_1,mercenary_face_2], 
["giant_veteran_fighter","Veteran Fighter","Veteran Fighters",tf_giant_male|tf_guarantee_boots|tf_guarantee_armor,no_scene,0,fac_commoners, [], 
attrlev(38,13,6,6,23), wpex(250,250,250,170,170,170), strsk(7,6,6,6)|agisk(5,5,5,4,4),mercenary_face_1,mercenary_face_2], 
["giant_champion_fighter","Champion Fighter","Champion Fighters",tf_giant_male|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [], 
attrlev(45,15,10,10,40), wpex(350,350,350,220,220,220), strsk(10,8,8,8)|agisk(7,7,7,5,5),mercenary_face_1,mercenary_face_2], 
["dwarf_champion_fighter","Dwarf Fighter","Dwarf Fighters",tf_dwarf_male|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_leather_boots], 
attrlev(30,18,14,14,35), wpex(350,350,350,300,300,300), strsk(10,8,6,6)|agisk(8,8,6,6,6),mercenary_face_1,mercenary_face_2], 
["elf_champion_fighter","Elven Fighter","Elven Fighters",tf_elven_male|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_light_leather_boots], 
attrlev(22,25,20,20,40), wpex(300,250,300,350,250,250), strsk(7,7,6,9)|agisk(8,5,7,7,8),mercenary_face_1,mercenary_face_2], 

["arena_training_fighter_1","Novice Fighter","Novice Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_6|agi_6|level(5),wp(60),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_2","Novice Fighter","Novice Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_7|agi_6|level(7),wp(70),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_3","Regular Fighter","Regular Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_8|agi_7|level(9),wp(80),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_4","Regular Fighter","Regular Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_8|agi_8|level(11),wp(90),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_5","Regular Fighter","Regular Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_9|agi_8|level(13),wp(100),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_6","Veteran Fighter","Veteran Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_10|agi_9|level(15),wp(110),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_7","Veteran Fighter","Veteran Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_10|agi_10|level(17),wp(120),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_8","Veteran Fighter","Veteran Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_11|agi_10|level(19),wp(130),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_9","Champion Fighter","Champion Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_12|agi_11|level(21),wp(140),knows_common,mercenary_face_1,mercenary_face_2], 
["arena_training_fighter_10","Champion Fighter","Champion Fighters",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_hunter_boots], str_12|agi_12|level(23),wp(150),knows_common,mercenary_face_1,mercenary_face_2], 

["cattle","Cattle","Cattle",0,0,0,fac_neutral, [], def_attrib|level(1),wp(60),0,mercenary_face_1, mercenary_face_2], 


#soldiers:
#This troop is the troop marked as soldiers_begin
["farmer","Farmer","Farmers",tf_guarantee_armor|tf_guarantee_boots,0,0,fac_commoners, [itm_scythe, itm_knife, itm_military_fork, itm_sickle, itm_rrr_club1, itm_stones, itm_leather_cap, itm_felt_hat, itm_coarse_tunic, itm_pelt_coat, itm_nomad_boots], 
attrlev(9,5,5,5,1), wp(50), strsk(1,1,0,0)|agisk(0,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,1), mfy1, mfo2], 
["townsman","Townsman","Townsmen",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_sword_medieval_b_small, itm_knife, itm_rrr_club1, itm_shortened_military_scythe, itm_dagger, itm_stones, itm_woolen_cap, itm_tabard, itm_coarse_tunic, itm_novici_templar, itm_nomad_boots, itm_rus_shoes], 
attrlev(8,6,6,6,2), wp(75), strsk(1,1,0,0)|agisk(1,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,1)|lordsk2(0,0,0,0,0,0,0,1), mercenary_face_1,mercenary_face_2], 



#Tolrania (given Heraldic Armor by Mel)
["k01_tol_recruit", "Tolranian Recruit", "Tolranian Recruits", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_tabard, itm_sword_medieval_c_small, itm_tab_shield_round_a, itm_hide_boots, itm_leather_cap], 
attrlev(8,5,6,5,3), wpex(60,60,60,50,50,50), strsk(1,1,0,0)|agisk(1,1,2,0,0)|lordsk1(0,0,0,0,0,0,0,1), mfy1, mfy2], 
["k01_tol_footman", "Tolranian Footman", "Tolranian Footmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_padded_cloth, itm_leather_boots, itm_mace_3, itm_rrr_mace4, itm_tab_shield_kite_b, itm_leather_gloves, itm_footman_helmet], 
attrlev(10,6,6,6,6), wpex(90,75,75,80,70,70), strsk(2,2,1,1)|agisk(2,2,4,0,0)|lordsk1(1,0,0,0,0,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), mfy1, mfy2], 
["k01_tol_bowman", "Tolranian Bowman", "Tolranian Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tunic_b, itm_mail_coif, itm_leather_gloves, itm_rus_cav_boots, itm_new_shortbow, itm_bodkin_arrows, itm_rrr_mace4, itm_sword_medieval_b, itm_tab_shield_kite_c], 
attrlev(11,9,7,6,9), wpex(120,100,100,130,90,90), strsk(3,2,1,3)|agisk(3,2,5,0,0)|lordsk1(1,1,0,0,0,0,2,1)|lordsk2(0,0,0,0,0,1,0,0), mfy1, mfy2], 
["k01_tol_longbowman", "Tolranian Longbowman", "Tolranian Longbowmen", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tabard, itm_ak_bascinet_avt_a, itm_mail_mittens, itm_splinted_leather_greaves, itm_long_bow, itm_bodkin_arrows, itm_spak_bow8_arrow, itm_longsword_b], 
attrlev(14,12,8,7,15), wpex(160,160,130,200,120,120), strsk(3,3,1,4)|agisk(5,2,6,0,0)|lordsk1(2,3,0,2,1,1,3,2)|lordsk2(0,0,0,1,0,1,0,0), mfy1, mfy2], 
["k01_tol_vetlongbowman", "Tolranian Veteran Longbowman", "Tolranian Veteran Longbowmen", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_cuir_bouilli, itm_ak_bascinet_new_a, itm_new_lamellar_gauntlets, itm_mail_boots, itm_new_warbow_b, itm_sword_medieval_d_long, itm_tab_shield_kite_d, itm_spak_bow8_arrow], 
attrlev(17,15,9,8,22), wpex(220,220,180,270,150,150), strsk(5,4,2,5)|agisk(6,4,7,2,3)|lordsk1(2,4,2,3,2,2,4,2)|lordsk2(0,0,0,1,0,1,0,0), mfy1, mfy2], 
["k01_tol_archer", "Tolranian Archer", "Tolranian Archers", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_surcoat, itm_new_lamellar_gauntlets, itm_iron_greaves, itm_danish_greatsword, itm_ak_bascinet_new_b, itm_new_warbow_a, itm_spak_bow8_arrow, itm_gromitearrow], 
attrlev(22,18,10,9,33), wpex(270,270,250,350,200,200), strsk(6,5,3,7)|agisk(7,5,8,3,4)|lordsk1(2,6,4,4,2,4,4,2)|lordsk2(0,0,0,2,0,2,0,0), mfo1, mfo2], 
["k01_tol_headhunter", "Tolranian Headhunter", "Tolranian Headhunters", tf_guarantee_all, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tunic, itm_tolrania_kettlehat, itm_wisby_gauntlets_red, itm_splinted_greaves_spurs, itm_horse1, itm_winged_mace_no1, itm_tab_shield_kite_cav_b, itm_fire_nomad_bow, itm_1steel_arrow], 
attrlev(21,19,11,9,31), wpex(290,290,275,320,225,225), strsk(6,6,3,6)|agisk(7,6,7,6,7)|lordsk1(2,4,3,6,3,4,4,2)|lordsk2(0,0,0,1,0,4,0,2), mfy1, mfy2], 
["k01_tol_trainedfootman", "Tolranian Trained Footman", "Tolranian Trained Footmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tunic_b, itm_mail_mittens, itm_ak_reinf_helmet_a, itm_splinted_leather_greaves, itm_awlpike, itm_tab_shield_pavise_c, itm_sword_medieval_c], 
attrlev(13,9,7,7,12), wpex(145,145,145,100,100,100), strsk(4,3,2,2)|agisk(4,3,5,0,0)|lordsk1(2,0,0,0,0,0,2,1)|lordsk2(0,0,0,0,0,2,0,0), mfy1, mfy2], 
["k01_tol_vetfootman", "Tolranian Veteran Footman", "Tolranian Veteran Footmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_tabard_heavy, itm_new_lamellar_gauntlets, itm_ak_flattop_helmet_b, itm_mail_boots, itm_tab_shield_pavise_d, itm_morningstar_no1, itm_poleaxe_a], 
attrlev(18,12,7,8,20), wpex(180,180,180,120,120,120), strsk(5,5,3,3)|agisk(5,5,6,0,0)|lordsk1(2,0,1,0,0,0,2,2)|lordsk2(0,0,0,0,0,2,0,0),mfy1, mfy2], 
["k01_tol_hacker", "Tolranian Hacker", "Tolranian Hackers", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tunic, itm_pigface_klappvisor, itm_sword_two_handed_a, itm_wisby_gauntlets_black, itm_leather_boots, itm_luc_serrated_sword_v2, itm_danish_greatsword], 
attrlev(23,15,8,9,30), wpex(280,280,280,180,180,180), strsk(8,7,4,4)|agisk(8,5,8,0,0)|lordsk1(2,0,2,0,2,2,4,2)|lordsk2(0,0,0,0,0,2,0,0), mfy1, mfy2], 
["k01_tol_masterhacker", "Tolranian Master Hacker", "Tolranian Master Hackers", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_brigandine_b_heraldic, itm_pigface_klappvisor, itm_iron_greaves, itm_hourglass_gauntlets, itm_luc_serrated_sword_v2, itm_sword_of_war, itm_danish_greatsword], 
attrlev(30,20,9,12,40), wpex(400,400,400,250,250,250), strsk(10,9,6,6)|agisk(10,5,10,0,0)|lordsk1(2,0,4,0,3,2,4,2)|lordsk2(0,0,0,0,0,3,1,1), mfy1, mfy2], 
["k01_tol_kingsguard", "Tolranian King's Guard", "Tolranian King's Guards", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_surcoat_plated, itm_ak_bascinet_new_b, itm_mail_mittens, itm_iron_greaves, itm_tab_shield_heater_d, itm_sword_medieval_d_long, itm_luc_morningstar_4, itm_sword_medieval_d_long], 
attrlev(21,14,8,14,28), wpex(250,250,250,180,180,180), strsk(7,7,5,5)|agisk(7,7,6,0,0)|lordsk1(1,0,3,0,1,0,4,2)|lordsk2(0,0,0,0,3,3,3,2), mfy1, mfy2], 
["k01_tol_kingsman", "Tolranian Kingsman", "Tolranian Kingsmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_churburg_13_brass, itm_steel_greaves, itm_wisby_gauntlets_red, itm_col1_madelnbucket1, itm_shb2, itm_luc_morningstar_4, itm_luc_morningstar_new], 
attrlev(28,18,14,24,38), wpex(350,350,350,250,250,250), strsk(8,9,6,6)|agisk(9,8,6,0,0)|lordsk1(0,0,4,0,3,0,4,3)|lordsk2(0,0,0,2,4,3,6,4), mfo1, mfo2], 
#Tolrania Extras
["k01_tol_messenger","Tolranian Messenger","Tolranian Messengers",tf_guarantee_all,0,0,fac_kingdom_1, [itm_sword_medieval_b_small, itm_light_shield, itm_heraldic_tabard, itm_leather_boots, itm_courser, itm_leather_gloves, itm_new_shortbow, itm_bodkin_arrows, itm_stark_hood], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), mfy1,mfy2], 
["k01_tol_pg","Prison Guard","Prison Guards",tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tabard, itm_ak_bascinet_new_a, itm_mail_boots, itm_tab_shield_heater_d, itm_hourglass_gauntlets_ornate, itm_sword_medieval_d_long], 
attrlev(18,12,12,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), mfy1, mfy2], 
["k01_tol_cg","Castle Guard","Castle Guards",tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_surcoat, itm_ak_bascinet_new_a, itm_plate_boots, itm_tab_shield_heater_d, itm_hourglass_gauntlets_ornate, itm_sword_medieval_d_long], 
attrlev(22,15,14,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), mfo1, mfo2], 
#Tolrania Nobles
["k01_tol_n_squire", "Tolranian Squire", "Tolranian Squires", tf_guarantee_allnoranged, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tabard, itm_mail_mittens, itm_tolrania_kettlehat, itm_mail_boots, itm_hunter, itm_lance_lev2, itm_crusader_sword_c, itm_tab_shield_kite_cav_a], 
attrlev(18,15,14,14,22), wpex(200,200,200,150,150,150), strsk(5,5,3,3)|agisk(6,5,4,6,0)|lordsk1(1,0,0,0,2,1,1,1)|lordsk2(0,0,0,1,1,1,1,1), mfy1, mfy2], 
["k01_tol_n_knight", "Tolranian Knight", "Tolranian Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_1, [itm_wisby_gauntlets_red, itm_plate_boots, itm_ak_great_helmet_a, itm_early_transitional_heraldic, itm_english_war_horse1, itm_war_horse1, itm_lance_3, itm_lance_lev4, itm_luc_morningstar_new, itm_tab_shield_heater_cav_b], 
attrlev(27,20,18,18,42), wpex(340,340,340,250,250,250), strsk(7,7,5,5)|agisk(8,7,5,8,0)|lordsk1(1,0,3,0,4,2,2,3)|lordsk2(0,0,0,2,3,1,3,3), mfo1, mfo2], 
["k01_tol_n_footknight", "Tolranian Foot Knight", "Tolranian Foot Knights", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_heraldic_tunic_new, itm_great_helmet, itm_ak_great_helmet_a, itm_shynbaulds, itm_plate_mittens, itm_milanese_polehammer_no1], 
attrlev(29,21,18,18,42), wpex(360,360,360,220,220,220), strsk(8,8,5,5)|agisk(8,6,6,6,0)|lordsk1(1,0,3,0,4,1,2,3)|lordsk2(0,0,0,3,2,3,2,2), mfo1, mfo2], 
#Tolrania Household
["k01_tol_n_champion", "Tolranian Champion", "Tolranian Champions", tf_guarantee_allnoranged, 0,0, fac_kingdom_1, [itm_kingsman_plate, itm_great_helmet, itm_west_man_at_arms_boots, itm_hourglass_gauntlets_ornate, itm_morningstar_2, itm_luc_morningstar_new, itm_charger, itm_steel_shield_heater, itm_lance_3, itm_lance_lev5], 
attrlev(40,25,22,35,60), wpex(500,500,500,350,350,350), strsk(10,10,8,8)|agisk(10,9,6,10,6)|lordsk1(2,2,4,2,8,2,4,4)|lordsk2(2,2,2,4,4,3,8,4), mfo1, mfo2], 
["k01_tol_n_lionkingsman", "Tolranian Lion Kingsman", "Tolranian Lion Kingsmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_coat_of_plates_red, itm_ak_great_helmet_a, itm_iron_greaves, itm_hourglass_gauntlets, itm_morgenstern_no2], 
attrlev(33,16,16,28,44), wpex(360,360,360,200,200,200), strsk(9,8,5,5)|agisk(10,5,8,5,0)|lordsk1(0,0,4,0,5,0,3,3)|lordsk2(0,0,0,1,4,2,4,3), mfy1, mfo2], 
["k01_tol_n_galweengineer", "Galwe Royal Engineer", "Galwe Royal Engineers", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_cuir_bouilli, itm_ak_bascinet_new_a, itm_gauntlets_arabs_b_l, itm_rus_splint_greaves, itm_cinthorc, itm_tab_shield_pavise_d, itm_rrr_mallet1, itm_sniper_crossbow, itm_bolts], 
attrlev(20,16,27,16,36), wpex(250,250,250,250,250,250), strsk(5,5,3,3)|agisk(6,6,6,4,0)|lordsk1(0,0,0,0,10,2,4,4)|lordsk2(4,4,4,8,4,1,1,4), mfy1, mfo2], 
["k01_tol_n_yeoman","Tolranian Yeoman","Tolranian Yeomen",tf_guarantee_archer,0,0,fac_kingdom_1, [itm_dethertir_armor_g, itm_balaclavacoif, itm_leather_gloves, itm_leather_boots_dark, itm_gondor_bow, itm_falchion, itm_spak_ar2], 
attrlev(18,22,12,8,26), wpex(240,200,200,280,200,200), strsk(6,6,3,6)|agisk(7,2,9,3,0)|lordsk1(2,4,0,4,6,6,4,2)|lordsk2(0,0,0,0,4,2,0,2), mfy1, mfy2], 
["k01_tol_n_calariuskingsman", "Calarius Kingsman", "Calarius Kingsmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_maximilian_armour, itm_plate_mittens, itm_visoredhelm, itm_shynbaulds, itm_steel_shield_herald02, itm_luc_flanged_mace_iron], 
attrlev(30,12,14,22,35), wpex(300,300,300,100,100,100), strsk(8,8,5,5)|agisk(7,6,4,0,0)|lordsk1(0,0,4,0,2,0,2,2)|lordsk2(0,0,0,0,2,2,0,0), mfo1, mfo2], 
["k01_tol_n_valorkingsman", "Tolranian Valor Kingsman", "Tolranian Valor Kingsmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_early_transitional_blue, itm_col1_madelnbucket1, itm_iron_greaves, itm_wisby_gauntlets_red, itm_2hand_swadian_regent], 
attrlev(34,24,15,28,44), wpex(410,410,410,205,205,205), strsk(10,10,6,6)|agisk(10,6,10,0,0)|lordsk1(0,0,4,0,5,1,3,4)|lordsk2(0,0,0,2,4,4,3,3), mfy1, mfo2], 
["k01_tol_n_crownsquire", "Tolranian Squire of The Crown", "Tolranian Squires of The Crown", tf_guarantee_allnoranged, 0,0, fac_kingdom_1, [itm_amored_tabard_red_crown, itm_open_salet_coif, itm_iron_greaves, itm_mail_mittens, itm_hospitaller_knight_horse_d, itm_war_sword_no1, itm_light_shield], 
attrlev(20,16,15,15,26), wpex(260,260,260,200,200,200), strsk(5,6,3,4)|agisk(6,5,4,6,0)|lordsk1(0,0,1,1,3,1,2,2)|lordsk2(0,0,0,1,1,2,1,1), mfy1, mfy2], 
["k01_tol_n_crownknight", "Tolranian Knight of The Crown", "Tolranian Knights of The Crown", tf_guarantee_allnoranged, 0,0, fac_kingdom_1, [itm_churburg_13_brass, itm_crownedhelm, itm_steel_greaves, itm_hourglass_gauntlets_ornate, itm_horse_master_order_hospitaller, itm_claymore_no1_v3, itm_saracin_shield_c], 
attrlev(30,21,19,25,44), wpex(380,380,380,250,250,250), strsk(8,8,6,6)|agisk(9,7,5,8,0)|lordsk1(1,0,3,1,5,2,3,4)|lordsk2(0,0,1,3,3,3,3,3),mfo1, mfo2], 
#Tolrania Mercenaries
["k01_tol_m_lancer", "Tolranian Mercenary Lancer", "Tolranian Mercenary Lancers", tf_guarantee_allnoranged|tf_guarantee_polearm, 0,0, fac_kingdom_1, [itm_capelina_crusader_b, itm_heraldic_cuir_bouilli, itm_wisby_gauntlets_red, itm_boot_average_crusader_b, itm_lance_4, itm_lance_5, itm_norman_shield_1, itm_winged_mace_no1, itm_war_horse4], 
attrlev(20,14,10,12,30), wpex(230,230,250,100,100,100), strsk(6,6,3,3)|agisk(7,6,3,6,0)|lordsk1(2,0,0,1,2,2,2,3)|lordsk2(0,0,0,0,2,2,0,2), mfy1, mfo2], 
#Tolrania fief guardsmen
["k01_tol_n_royalguardsman", "Tolranian Royal Guardsman", "Tolranian Royal Guardsmen", tf_guarantee_inf, 0,0, fac_kingdom_1, [itm_west_heraldic, itm_ak_great_helmet_a, itm_shynbaulds, itm_wisby_gauntlets_black, itm_luc_morningstar_4, itm_shb2, itm_sniper_crossbow, itm_steel_bolts], 
attrlev(33,22,16,24,46), wpex(420,420,400,240,350,300), strsk(10,10,7,7)|agisk(10,9,7,0,0)|lordsk1(1,0,4,0,6,0,4,4)|lordsk2(0,0,0,3,2,4,1,1), mfo1, mfo2], 
#fakes for custom templates
["k01_tol_enduinius_longbowman", "Tolranian Longbowman", "Tolranian Longbowmen", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_mail_with_tabard, itm_ak_bascinet_avt_a, itm_mail_mittens, itm_splinted_leather_greaves, itm_long_bow, itm_bodkin_arrows, itm_spak_bow8_arrow, itm_longsword_b], 
attrlev(14,12,8,7,15), wpex(160,160,130,200,120,120), strsk(3,3,1,4)|agisk(5,2,6,0,0)|lordsk1(2,3,0,2,1,1,3,2)|lordsk2(0,0,0,1,0,1,0,0), mfy1, mfy2], 
["k01_tol_enduinius_vetlongbowman", "Tolranian Veteran Longbowman", "Tolranian Veteran Longbowmen", tf_guarantee_archer, 0,0, fac_kingdom_1, [itm_heraldic_cuir_bouilli, itm_ak_bascinet_new_a, itm_new_lamellar_gauntlets, itm_mail_boots, itm_new_warbow_b, itm_sword_medieval_d_long, itm_tab_shield_kite_d, itm_spak_bow8_arrow], 
attrlev(17,15,9,8,22), wpex(220,220,180,270,150,150), strsk(5,4,2,5)|agisk(6,4,7,2,3)|lordsk1(2,4,2,3,2,2,4,2)|lordsk2(0,0,0,1,0,1,0,0), mfy1, mfy2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Reich des Drachen
["k02_rei_recruit", "Rekrut des Drache", "Rekruten des Drachen", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_saddle_horse, itm_rough_leather_fur, itm_rus_shoes, itm_leather_gloves, itm_leather_steppe_cap_b, itm_one_handed_battle_axe_a, itm_fur_covered_shield], 
attrlev(12,8,8,7,8), wpex(90,90,90,50,50,50), strsk(2,2,0,0)|agisk(3,2,2,2,0)|lordsk1(1,1,0,0,1,1,0,1)|lordsk2(0,0,0,0,0,1,0,0), mfy1, mfy2], 
["k02_rei_krieger", "Drachen Krieger", "Drachen Krieger", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_tribal_warrior_outfit, itm_leather_gloves, itm_light_crusader_helm_b, itm_splinted_greaves, itm_one_handed_battle_axe_c, itm_ad_viking_shield_round_06, itm_two_handed_battle_axe_2], 
attrlev(15,10,9,8,12), wpex(130,130,130,70,70,70), strsk(3,3,1,1)|agisk(4,3,3,2,0)|lordsk1(1,1,0,1,2,1,1,2)|lordsk2(0,0,0,1,0,2,0,1), mfy1, mfy2], 
["k02_rei_bogenschutze", "Drachen Bogenschutze", "Drachen Bogenschutzen", tf_guarantee_archer, 0,0, fac_kingdom_2, [itm_rough_tunic_mailed, itm_nasal_helmet, itm_leather_gloves, itm_splinted_greaves, itm_elven_bow, itm_barbed_arrows, itm_hide_covered_round_shield, itm_lui_knightaxeoneh], 
attrlev(16,13,10,9,14), wpex(150,150,140,140,80,80), strsk(3,3,1,3)|agisk(4,3,4,2,0)|lordsk1(1,2,0,1,2,1,2,2)|lordsk2(0,0,0,1,0,2,0,1), mfy1, mfy2], 
["k02_rei_scharfschutze", "Drachen Scharfschutze", "Drachen Scharfschutzen", tf_guarantee_archer, 0,0, fac_kingdom_2, [itm_kuyak_b, itm_crusader_helm_medium_b, itm_splinted_greaves, itm_mail_mittens, itm_gothic_horsemans_axe, itm_long_bow, itm_gromitearrow, itm_bodkin_arrows], 
attrlev(19,15,11,10,20), wpex(175,175,150,200,100,100), strsk(4,4,2,4)|agisk(5,4,5,3,0)|lordsk1(1,3,0,2,3,2,3,2)|lordsk2(0,0,0,2,0,2,0,1), mfy1, mfy2], 
["k02_rei_elitescharfschutze", "Elite Drachen Scharfschutze", "Elite Drachen Scharfschutzen", tf_guarantee_archer, 0,0, fac_kingdom_2, [itm_rus_lamellar_b, itm_tagancha_helm_b, itm_highlander_boots_2_2, itm_mail_mittens, itm_battle_axe_no4, itm_fire_war_bow, itm_gromitearrow, itm_gromitearrow], 
attrlev(22,17,12,12,32), wpex(235,235,235,275,125,125), strsk(5,5,3,6)|agisk(7,4,5,3,0)|lordsk1(1,3,0,3,4,3,4,3)|lordsk2(0,0,0,2,0,2,0,2), mfo1, mfo2], 
["k02_rei_kaiserlichecharfschutze", "Kaiserliche Drachen Scharfschutze", "Konigliche Drachen Scharfschutzen", tf_guarantee_archer, 0,0, fac_kingdom_2, [itm_novogrod_helm, itm_ghulam_heavy_cavalryman_1, itm_shadow_greaves, itm_scale_gauntlets, itm_war_bow, itm_ebonyornate_arrow, itm_ebonyornate_arrow, itm_luc_saxon_voulge_b], 
attrlev(26,20,14,16,44), wpex(275,275,275,360,150,150), strsk(6,6,4,8)|agisk(8,5,6,4,0)|lordsk1(1,4,2,4,5,4,5,3)|lordsk2(0,0,0,3,2,3,1,2), mfo1, mfo2], 
["k02_rei_fussoldat", "Drachen Fussoldat", "Drachen Fussoldaten", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_normanhelmet3, itm_black_tribal_outfit, itm_splinted_leather_greaves, itm_mail_mittens, itm_lui_knightaxeonehb, itm_throwing_spears, itm_heavy_shield2], 
attrlev(18,12,10,9,18), wpex(170,170,150,80,80,180), strsk(4,4,3,2)|agisk(5,5,4,3,0)|lordsk1(1,1,0,1,2,1,2,2)|lordsk2(0,0,0,1,0,2,0,1), mfy1, mfy2], 
["k02_rei_landsknecht", "Drachen Landsknecht", "Drachen Landsknecht", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_scalefur, itm_crusader_helm_1, itm_beargauntlets, itm_mail_boots, itm_throwing_spears, itm_throwing_spears, itm_lui_battleaxenewb, itm_spak_pavise_1], 
attrlev(22,15,12,11,26), wpex(210,210,200,100,100,200), strsk(6,6,5,3)|agisk(6,6,5,3,0)|lordsk1(2,1,2,1,3,1,2,2)|lordsk2(0,0,0,2,1,2,1,2), mfy1, mfy2], 
["k02_rei_speerkampfer", "Drachen Speerkampfer", "Drachen Speerkampfer", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_2, [itm_allmail, itm_iron_greaves, itm_crusader_hard_helm_f, itm_wisby_gauntlets_black, itm_pike, itm_steel_shield_herald01, itm_throwing_spears, itm_heavy_throwing_axes], 
attrlev(26,18,13,11,32), wpex(270,270,270,120,120,250), strsk(7,7,7,4)|agisk(7,6,6,4,0)|lordsk1(2,1,3,1,4,1,3,3)|lordsk2(0,0,0,2,1,2,1,2), mfo1, mfo2], 
["k02_rei_elitespeerkampfer", "Elite Drachen Speerkampfer", "Elite Drachen Speerkampfer", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_2, [itm_bear_warrior, itm_gotlandbucket, itm_plate_boots, itm_beargauntlets, itm_swiss_pike_2, itm_luc_germanic_battle_axe, itm_steel_shield_herald01, itm_heavy_throwing_axes], 
attrlev(32,22,14,12,38), wpex(340,340,340,150,150,350), strsk(9,8,8,5)|agisk(8,7,8,5,0)|lordsk1(2,1,5,1,5,1,4,3)|lordsk2(0,0,0,3,1,3,2,2), mfo1, mfo2], 
["k02_rei_reiter", "Drachen Reiter", "Drachen Reiter", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_kuyak_a, itm_conichelm, itm_rus_cav_boots, itm_mail_mittens, itm_northerner_horse_black, itm_light_lance, itm_reich_sword, itm_tab_shield_kite_cav_a], 
attrlev(21,15,11,11,24), wpex(220,220,220,100,100,150), strsk(5,6,3,2)|agisk(6,6,4,6,0)|lordsk1(1,1,1,1,3,2,2,3)|lordsk2(0,0,0,1,0,2,1,1), mfy1, mfy2], 
["k02_rei_kavallerie", "Drachen Kavallerie", "Drachen Kavallerien", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_early_transitional_white, itm_gnezdovo_helm_b, itm_shadow_greaves, itm_wisby_gauntlets_black, itm_luc_german_winged_mace, itm_tab_shield_small_round_b, itm_hospitaller_charger, itm_heavy_lance], 
attrlev(25,19,13,13,33), wpex(300,300,300,150,150,175), strsk(7,8,4,3)|agisk(8,7,5,7,0)|lordsk1(1,1,3,1,4,2,2,3)|lordsk2(0,0,0,1,1,2,2,2), mfy1, mfo2], 
["k02_rei_dragoner", "Drachen Dragoner", "Drachen Dragoner", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_coat_of_plates_steel, itm_maciejowski_helmet_new3, itm_steel_greaves, itm_plate_mittens, itm_plated_charger4, itm_luc_horsemans_axe, itm_lance_1, itm_steel_shield_heater], 
attrlev(30,23,15,15,44), wpex(360,360,360,200,200,200), strsk(8,9,5,4)|agisk(9,9,5,9,0)|lordsk1(1,1,6,2,6,3,3,3)|lordsk2(0,0,0,2,2,3,4,2), mfo1, mfo2], 
#Drachen Extras
["k02_rei_messenger","Drachen Messenger","Drachen Messengers",tf_guarantee_all,0,0,fac_kingdom_2, [itm_sword_viking_2_small, itm_rough_leather_fur, itm_leather_boots, itm_leather_warrior_cap, itm_european_horse_d, itm_leather_gloves, itm_light_shield], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), mfy1, mfy2], 
["k02_rei_pg","Prison Guard","Prison Guards", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_kuyak_b, itm_normanhelmcoif, itm_iron_greaves, itm_wisby_gauntlets_black, itm_reich_sword, itm_spak_pavise_1, itm_heavy_throwing_axes], 
attrlev(18,12,12,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), mfy1, mfo2], 
["k02_rei_cg","Castle Guard","Castle Guards", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_coat_of_plates_steel, itm_gotlandbucket, itm_iron_greaves, itm_wisby_gauntlets_black, itm_luc_germanic_battle_axe, itm_spak_pavise_1, itm_heavy_throwing_axes], 
attrlev(22,15,14,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), mfo1, mfo2], 
#Drachen Nobles
["k02_rei_n_knappe", "Drachen Knappe", "Drachen Knappen", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_rough_smallring_fured, itm_frenchpepperpot3, itm_boot_average_crusader_b, itm_wisby_gauntlets_black, itm_northerner_horse_hunter, itm_round_dragon_shield2, itm_luc_english_horseman_axe], 
attrlev(24,18,14,16,30), wpex(270,270,270,100,100,150), strsk(6,7,4,3)|agisk(7,7,5,7,3)|lordsk1(1,0,3,1,4,2,2,3)|lordsk2(1,1,1,2,3,2,2,2), mfy1, mfy2], 
["k02_rei_n_drachenritter", "Drachenritter", "Drachenrittern", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_bronzeplate, itm_bronzeshynald, itm_maciejowski_helmet5b_bronze, itm_col2_madelnbucket2, itm_bronzeplatemitten, itm_plated_charger8, itm_lui_knightbastardaxea, itm_round_dragon_shield], 
attrlev(36,27,17,24,52), wpex(400,400,400,200,200,300), strsk(9,9,6,5)|agisk(10,10,5,10,6)|lordsk1(1,0,7,2,7,2,4,4)|lordsk2(1,1,1,3,3,3,4,3), mfo1, mfo2], 
#Drachen Houshold
["k02_rei_n_kaiserlichedragoner", "Kaiserliche Dragoner", "Kaiserliche Dragoner", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_knight_of_the_wall_plate, itm_madelnbucket1, itm_black_boot_salad_of, itm_dark_mail_mittens, itm_plated_charger5, itm_sw_warhammer_steel, itm_lance_lev5, itm_lance_1, itm_steel_heater1_dark], 
attrlev(34,24,20,30,60), wpex(440,440,440,300,300,300), strsk(10,10,6,6)|agisk(10,10,5,9,0)|lordsk1(1,0,4,3,8,2,4,4)|lordsk2(2,2,2,3,4,3,4,3), mfo1, mfo2], 
["k02_rei_n_graugardist", "Drachen Graugardist", "Drachen Graugardisten", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_luc_sugarloaf_helm_v1, itm_corrazina_grey, itm_hourglass_gauntlets, itm_mail_boots, itm_elegant_poleaxe, itm_plate_covered_round_shield], 
attrlev(27,20,14,10,35), wpex(300,300,340,100,100,100), strsk(8,7,4,4)|agisk(7,4,5,0,0)|lordsk1(1,0,2,0,4,0,4,2)|lordsk2(0,0,0,0,2,4,0,0), mfy1, mfo2], 
["k02_rei_n_klingendragoner", "Klingen Dragoner", "Klingen Dragoner", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_cyc_plate_armor, itm_maciejowski_helmet5b, itm_shynbaulds, itm_bnw_gauntlets, itm_luc_iron_hand_axe_g, itm_dal_muslimf, itm_luc_iron_morningstar], 
attrlev(34,16,16,18,45), wpex(420,420,420,200,200,200), strsk(9,8,5,5)|agisk(9,8,6,4,0)|lordsk1(2,0,4,0,6,2,3,3)|lordsk2(0,0,0,4,3,2,3,2), mfo1, mfo2], 
["k02_rei_n_wyverndragoner", "Wyvern Dragoner", "Wyvern Dragoner", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_plated_armor1, itm_new_helm1, itm_plate_boots, itm_gauntlets, itm_wyvern, itm_bastard_iron_war_axe, itm_great_lance, itm_dal_muslimf], 
attrlev(38,28,20,28,60), wpex(480,480,480,240,240,240), strsk(10,9,6,5)|agisk(10,9,6,10,4)|lordsk1(1,2,4,4,8,3,4,4)|lordsk2(0,0,0,2,4,2,5,3), mfo1, mfo2], 
["k02_rei_n_drachenmeister", "Drachenmeister", "Drachenmeister", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_narf_gothic_plate_black, itm_weimarhelm, itm_black_boot_salad_of, itm_blackplatemitty, itm_ice_dragon, itm_fire_dragon, itm_luc_spiked_mace_5p, itm_luc_knights_warhammer, itm_lance_1, itm_round_dragon_shield, itm_round_dragon_shield2], 
attrlev(50,35,27,40,70), wpex(525,525,525,400,400,400), strsk(10,10,8,6)|agisk(10,10,8,10,8)|lordsk1(1,3,4,4,10,4,4,4)|lordsk2(3,3,3,3,4,2,8,4), mfo1, mfo2], 
["k02_rei_n_drachenherzritter","Drachenherz Ritter","Drachenherz Ritter",tf_guarantee_allnoranged,0,0,fac_kingdom_2, [itm_ghulam_heavy_cavalryman_1, itm_bolzanobucket, itm_black_greaves, itm_scale_gauntlets, itm_whg2, itm_luc_hache_darmes, itm_round_dragon_shield, itm_heavy_lance], 
attrlev(30,24,16,19,42), wpex(400,400,400,180,180,180), strsk(9,9,7,7)|agisk(9,7,5,9,0)|lordsk1(4,0,4,4,5,2,3,4)|lordsk2(2,0,3,4,4,4,2,0), mfy1, mfo2], 
["k02_rei_n_raubritter","Raubritter","Raubritter",tf_guarantee_allnoranged,0,0,fac_kingdom_2, [itm_early_transitional_black, itm_munitionshelm1, itm_black_greaves, itm_scale_gauntlets, itm_hospitaller_knight_horse_a, itm_crusader_long_sword_c, itm_saracin_shield_t, itm_luc_horsemans_axe, itm_military_pick], 
attrlev(28,23,14,18,42), wpex(340,340,300,160,160,160), strsk(8,8,6,6)|agisk(8,6,5,8,5)|lordsk1(6,3,2,4,5,2,4,4)|lordsk2(2,1,2,0,2,4,1,0), mfy1, mfy2], 
["k02_rei_n_wyvernrider", "Wyvern Rider", "Wyvern Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_2, [itm_heraldic_tunic_new, itm_gotlandbucket, itm_plate_boots, itm_plate_mittens, itm_wyvern, itm_reich_sword, itm_luc_english_horseman_axe, itm_round_dragon_shield2], 
attrlev(32,25,18,22,48), wpex(380,380,380,240,240,240), strsk(9,8,7,6)|agisk(8,7,4,9,0)|lordsk1(1,3,3,4,6,4,4,3)|lordsk2(0,0,0,2,2,3,2,2), mfy1, mfo2], 
#Drachen Mercenaries
["k02_rei_m_landsknecht", "Drachen Elite Landsknecht", "Drachen Elite Landsknechte", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_claymore_no1, itm_xenoargh_metal_leather01, itm_lamellar_gauntlets, itm_chapel_de_fer, itm_shynbaulds], 
attrlev(28,18,13,13,36), wpex(200,400,200,100,100,100), strsk(8,8,4,4)|agisk(8,5,8,0,0)|lordsk1(2,0,3,0,4,2,2,3)|lordsk2(1,1,1,3,3,2,2,3), mfy1,mfo2], 
#Drachen fief guardsmen
["k02_rei_n_stadtwache", "Drachen Stadtwache", "Drachen Stadtwachen", tf_guarantee_archer, 0,0, fac_kingdom_2, [itm_knights_armor, itm_guard_knight_helm, itm_knights_boot, itm_dorn_knight_gant, itm_lui_knightbastardaxea, itm_round_dragon_shield, itm_round_dragon_shield2, itm_heavy_throwing_axes, itm_heavy_throwing_axes], 
attrlev(33,21,13,15,46), wpex(400,400,400,200,200,400), strsk(10,10,9,7)|agisk(10,9,8,4,0)|lordsk1(0,0,4,0,5,0,6,3)|lordsk2(0,0,1,0,2,4,1,1), mfy1, mfo2], 
#fakes for custom templates
["k02_rei_fridl_krieger", "Drachen Krieger", "Drachen Krieger", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_tribal_warrior_outfit, itm_leather_gloves, itm_light_crusader_helm_b, itm_splinted_greaves, itm_one_handed_battle_axe_c, itm_ad_viking_shield_round_06, itm_two_handed_battle_axe_2], 
attrlev(15,10,9,8,12), wpex(130,130,130,70,70,70), strsk(3,3,1,1)|agisk(4,3,3,2,0)|lordsk1(1,1,0,1,2,1,1,2)|lordsk2(0,0,0,1,0,2,0,1), mfy1, mfy2], 
["k02_rei_fridl_fussoldat", "Drachen Fussoldat", "Drachen Fussoldaten", tf_guarantee_inf, 0,0, fac_kingdom_2, [itm_normanhelmet3, itm_black_tribal_outfit, itm_splinted_leather_greaves, itm_mail_mittens, itm_lui_knightaxeonehb, itm_throwing_spears, itm_heavy_shield2], 
attrlev(18,12,10,9,18), wpex(170,170,150,80,80,180), strsk(4,4,3,2)|agisk(5,5,4,3,0)|lordsk1(1,1,0,1,2,1,2,2)|lordsk2(0,0,0,1,0,2,0,1), mfy1, mfy2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Drahara
["k03_dra_tribesman", "Draharan Tribesman", "Draharan Tribesmen", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_beduin_armor_c, itm_beduin_turban_a_mark, itm_ankle_boots, itm_sword_khergit_3, itm_spear, itm_dal_muslimh, itm_darts], 
attrlev(8,8,6,6,4), wpex(75,50,75,75,50,75), strsk(0,1,2,1)|agisk(1,0,2,1,1)|lordsk1(1,1,0,1,0,1,0,1)|lordsk2(1,1,1,0,0,1,0,1), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_spearman", "Draharan Spearman", "Draharan Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_3, [itm_arabian_light_armor_a, itm_saracin_turban_c, itm_hide_boots, itm_german_hunting_spear, itm_scimitar, itm_dal_muslimb, itm_darts, itm_war_darts], 
attrlev(10,12,7,7,8), wpex(110,60,110,110,60,110), strsk(1,1,3,2)|agisk(2,1,4,2,2)|lordsk1(2,2,0,1,0,1,1,1)|lordsk2(1,1,1,0,1,1,0,1), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_desertbowman", "Draharan Desert Bowman", "Draharan Desert Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_3, [itm_armor_archer_saracin_5, itm_desert_turban, itm_khergit_leather_boots, itm_leather_gloves, itm_nomad_bow, itm_scimitar, itm_dal_muslimc, itm_khergit_arrows], 
attrlev(12,15,8,8,13), wpex(150,70,140,170,70,160), strsk(1,2,4,4)|agisk(4,2,6,4,3)|lordsk1(2,3,0,2,1,1,2,2)|lordsk2(2,2,2,0,1,2,0,2), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_desertarcher", "Draharan Desert Archer", "Draharan Desert Archers", tf_guarantee_all, 0,0, fac_kingdom_3, [itm_heavy_armor_arabs_a, itm_sarranid_helmet1_black, itm_civil_rich_boots_b, itm_gauntlets_arabs_a_l, itm_tribal5, itm_khergit_bow, itm_sword_khergit_2, itm_khergit_arrows, itm_dal_muslimd], 
attrlev(15,19,9,9,21), wpex(200,80,180,240,80,200), strsk(2,4,5,6)|agisk(6,3,7,7,7)|lordsk1(2,4,0,3,1,2,3,2)|lordsk2(2,2,2,0,2,2,0,3), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_windarcher", "Draharan Wind Archer ", "Draharan Wind Archers ", tf_guarantee_all, 0,0, fac_kingdom_3, [itm_wei_xiadi_lamellar_armor02, itm_gulam_helm_f_market, itm_brass_lamellar_gauntlets, itm_mail_boots_brass, itm_tribal2, itm_dal_muslima, itm_new_strongbow, itm_scimitar_b, itm_bronze_arrow], 
attrlev(18,23,10,10,28), wpex(260,100,240,300,100,250), strsk(3,5,5,7)|agisk(8,5,8,8,8)|lordsk1(3,7,0,4,2,4,4,3)|lordsk2(3,3,3,0,3,3,0,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_vetspearman", "Draharan Veteran Spearman", "Draharan Veteran Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_3, [itm_armor_archer_saracin_4, itm_helm_saracin_b, itm_gauntlets_arabs_a_l, itm_civil_rich_boots_b, itm_dal_muslime, itm_luc_long_war_spear, itm_saracin_sword_e, itm_war_darts], 
attrlev(13,14,8,8,14), wpex(170,120,170,120,70,170), strsk(2,3,4,3)|agisk(4,3,6,3,3)|lordsk1(2,2,0,1,1,1,2,2)|lordsk2(2,1,2,0,1,2,0,2), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_desertwarrior", "Draharan Desert Warrior", "Draharan Desert Warriors", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_heavy_armor_arabs_f, itm_rus_splint_greaves, itm_wisby_gauntlets_black, itm_sarranid_veiled_helmet, itm_arabian_sword_d, itm_great_long_bardiche, itm_dal_muslime, itm_jarid, itm_war_darts], 
attrlev(16,18,9,9,22), wpex(240,200,240,150,80,240), strsk(4,5,6,4)|agisk(6,4,7,4,4)|lordsk1(2,2,1,2,1,2,3,2)|lordsk2(2,2,2,0,2,2,0,2), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_shadowwarrior", "Draharan Shadow Warrior", "Draharan Shadow Warriors", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_wei_xiadi_samurai_armor02, itm_facecovermail_turban_black, itm_wisby_gauntlets_black, itm_shadow_greaves, itm_sabre_black, itm_jarid, itm_jarid], 
attrlev(20,23,12,10,33), wpex(320,320,320,200,160,320), strsk(6,7,7,5)|agisk(8,5,9,5,5)|lordsk1(2,2,3,3,3,2,4,3)|lordsk2(3,3,3,0,3,3,0,3), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_desertassassin", "Draharan Desert Assassin", "Draharan Desert Assassins", tf_guarantee_archer, 0,0, fac_kingdom_3, [itm_youhou_assassin_armor, itm_youhou_assassin_hood, itm_gondor_bracer_l, itm_sarranid_boots_black, itm_youhou_assassin_sword, itm_assassin_throwing_daggers, itm_assassin_throwing_daggers], 
attrlev(27,30,21,18,44), wpex(440,440,440,400,400,440), strsk(9,9,10,9)|agisk(10,8,10,7,7)|lordsk1(2,3,7,4,8,4,4,4)|lordsk2(4,4,4,2,4,4,1,4), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_lightrider", "Draharan Light Rider", "Draharan Light Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_arabian_light_armor_c, itm_facecovermail_turban_red, itm_gloves_lord_l, itm_civil_rich_boots_a, itm_dal_hindud, itm_tribal2, itm_khergit_sword_two_handed_a, itm_war_darts, itm_lance], 
attrlev(19,21,10,12,27), wpex(280,280,280,180,90,300), strsk(4,6,7,5)|agisk(7,4,8,6,6)|lordsk1(2,2,1,2,2,3,3,3)|lordsk2(3,2,2,0,2,2,0,2), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_warrider", "Draharan War Rider", "Draharan War Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_heavy_armor_arabs_b, itm_helm_tyrk_heavi_c, itm_mail_boots_brass, itm_hourglass_gauntlets_ornate, itm_saracin_hard_horses_c, itm_khopesh_1, itm_lance_5, itm_saracin_shield_g], 
attrlev(23,25,12,14,37), wpex(360,360,360,200,100,330), strsk(6,7,7,6)|agisk(8,6,8,8,7)|lordsk1(2,2,2,2,4,3,3,4)|lordsk2(3,3,3,0,3,2,2,3), draharan_faces_arab_begin, draharan_faces_arab_end], 
#Drahara Extras
["k03_dra_messenger","Draharan Messenger","Draharan Messengers",tf_guarantee_all,0,0,fac_kingdom_3, [itm_saracin_turban_c, itm_arabian_light_armor_a, itm_leather_boots, itm_tribal5, itm_leather_gloves, itm_sword_khergit_2, itm_nomad_bow, itm_bodkin_arrows, itm_war_darts], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), draharan_faces_arab_begin,draharan_faces_arab_end], 
["k03_dra_pg","Prison Guard","Prison Guards", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_arabian_armor_b, itm_sarranid_veiled_helmet, itm_scimitar, itm_mail_mittens, itm_mail_boots, itm_dal_muslime], 
attrlev(14,14,12,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,2,5,0,2), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_cg","Castle Guard","Castle Guards", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_wei_xiadi_samurai_armor02, itm_sarranid_veiled_helmet, itm_scimitar_b, itm_mail_mittens, itm_shadow_greaves, itm_dal_muslime], 
attrlev(18,18,14,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,3,5,0,3), draharan_faces_arab_begin, draharan_faces_arab_end], 
#Drahara Nobles
["k03_dra_n_dunerider", "Draharan Dune Rider", "Draharan Dune Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_armor_medium_tyrk_a, itm_sarranid_royal_helmet, itm_mail_boots_brass, itm_brass_lamellar_gauntlets, itm_saracin_hard_horses_c_v1, itm_dal_hinduh, itm_arabian_sword_b], 
attrlev(20,22,13,13,29), wpex(300,300,300,200,200,200), strsk(4,5,5,4)|agisk(6,4,6,7,5)|lordsk1(1,1,1,1,2,1,2,2)|lordsk2(1,1,1,0,3,2,2,3), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_royalrider", "Draharan Royal Rider", "Draharan Royal Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_brass_mamluke_mail, itm_brass_veiled_helmet, itm_bronzeplatemitten, itm_bronzeshynald, itm_luc_sarranid_falchion_m2, itm_brass_shield1, itm_warhorse_brass], 
attrlev(27,30,15,22,48), wpex(430,430,430,300,150,300), strsk(8,8,7,7)|agisk(9,7,7,9,7)|lordsk1(1,1,3,2,5,2,3,4)|lordsk2(2,2,2,0,4,2,5,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_duneguardian", "Draharan Dune Guardian", "Draharan Dune Guardians", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_aqs_merchant_outf, itm_dwarvenforged_helm_2, itm_shadow_greaves, itm_gauntlets_arabs_b_l, itm_warblade_darkwoodgold, itm_saracin_shield_p], 
attrlev(29,29,15,21,45), wpex(460,460,400,300,150,300), strsk(8,8,7,7)|agisk(10,8,8,7,6)|lordsk1(0,1,3,2,6,1,4,4)|lordsk2(3,1,3,0,4,4,3,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_herbalist", "Draharan Herbalist", "Draharan Herbalists", tf_guarantee_inf, 0,0, fac_kingdom_3, [itm_beduin_turban_b_mark, itm_caravan_armor_a, itm_leather_gloves, itm_civil_rich_boots_b, itm_luc_sarranid_dagger, itm_luc_sarranid_dagger, itm_luc_sarranid_dagger, itm_assassin_throwing_daggers, itm_assassin_throwing_daggers, itm_youhou_assassin_sword], 
attrlev(30,30,24,10,40), wpex(400,400,400,200,200,500), strsk(10,9,10,9)|agisk(10,5,10,5,5)|lordsk1(3,2,2,4,8,4,4,4)|lordsk2(6,6,6,0,4,2,0,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
#Drahara Household
["k03_dra_n_ghareebiancavalry", "Draharan Ghareebian Cavalry", "Draharan Ghareebian Cavalry", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_crusaderbucket_yellow_1, itm_mamluke_mail, itm_mail_mittens, itm_black_greaves, itm_warhorse_sarranid, itm_luc_iron_hand_axe_h, itm_steel_shield, itm_great_lance, itm_lance_4], 
attrlev(30,27,13,13,43), wpex(425,425,425,150,150,150), strsk(9,9,6,6)|agisk(9,8,6,8,0)|lordsk1(1,1,4,1,3,1,2,2)|lordsk2(0,0,0,0,2,1,2,2), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_garuda", "Draharan Garuda", "Draharan Garudas", tf_guarantee_all, 0,0, fac_kingdom_3, [itm_armor_medium_tyrk_d, itm_gulam_helm_f_market, itm_dorn_sand_snakes_boots, itm_gauntlets_arabs_a_l, itm_saracin_hard_horses_d, itm_sword_khergit_4, itm_new_strongbow, itm_brown_arrow, itm_song_arrows], 
attrlev(22,25,15,12,38), wpex(350,350,250,400,200,250), strsk(7,7,7,8)|agisk(8,4,6,9,9)|lordsk1(2,4,2,4,4,4,4,4)|lordsk2(3,3,3,0,4,2,0,3), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_warrider", "Barakat's War Rider", "Barakat's War Riders", tf_guarantee_all, 0,0, fac_kingdom_3, [itm_j_surcoat_orn_13b, itm_sarranid_horseman_helmet_brass, itm_plate_boots, itm_brass_mail_mittens, itm_saracin_hard_horses_c, itm_saracin_sword_d, itm_saracin_shield_v, itm_throwing_spears], 
attrlev(23,25,12,17,44), wpex(360,360,360,200,100,330), strsk(6,7,7,6)|agisk(8,6,8,8,7)|lordsk1(2,2,2,2,4,3,3,4)|lordsk2(3,3,3,0,3,2,2,3), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_n_camelrider", "Draharan Camel Rider", "Draharan Camel Riders", tf_guarantee_all, 0,0, fac_kingdom_3, [itm_sarranid_elite_armor, itm_helm_saracin_j, itm_dorn_sand_snakes_boots, itm_brass_scale_gauntlets, itm_bedyin_camel_a, itm_khopesh_1, itm_dal_hindud, itm_lance, itm_jarid, itm_jarid, itm_gromitearrow, itm_khergit_bow], 
attrlev(22,25,15,15,33), wpex(250,200,250,300,200,300), strsk(7,7,7,7)|agisk(8,6,6,7,7)|lordsk1(1,2,0,3,4,3,3,4)|lordsk2(2,2,2,0,3,2,0,4), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_n_ihabbodyguard", "Ihab's Bodyguard", "Ihab's Bodyguards", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_sarranid_elite_armor, itm_vaegir_war_helmet, itm_bronzeshynald, itm_brass_scale_gauntlets, itm_dorn_horse_lamellar_c, itm_arabian_sword_b, itm_saracin_shield_v], 
attrlev(24,26,10,16,38), wpex(300,300,200,100,100,100), strsk(7,7,5,5)|agisk(7,6,7,7,0)|lordsk1(1,0,1,1,3,1,4,3)|lordsk2(0,0,3,0,1,4,0,1), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_shadowassassin", "Draharan Shadow Assassin", "Draharan Shadow Assassins", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_dorn_assasin_armor, itm_assassin_helmet2, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_perisno_purebred, itm_youhou_assassin_sword, itm_roman_shield_velite], 
attrlev(34,38,25,25,66), wpex(540,540,540,520,520,520), strsk(10,10,10,10)|agisk(10,9,10,10,8)|lordsk1(3,4,8,4,10,4,4,4)|lordsk2(4,4,4,3,4,4,1,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k03_dra_n_shadowassassin_dism", "Draharan Shadow Assassin", "Draharan Shadow Assassins", tf_guarantee_archer, 0,0, fac_kingdom_3, [itm_dorn_assasin_armor, itm_assassin_helmet2, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_youhou_assassin_sword, itm_roman_shield_velite, itm_ebonybow, itm_spak_ar2], 
attrlev(34,38,25,25,60), wpex(540,540,540,520,520,520), strsk(10,10,10,10)|agisk(10,9,10,10,8)|lordsk1(3,4,8,4,10,4,4,4)|lordsk2(4,4,4,3,4,4,1,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
#Drahara Mercenaries
["k03_dra_m_shadowguard", "Draharan Mercenary Shadowguard", "Draharan Mercenary Shadowguards", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_shadow_outfit_b, itm_assassin_helmet, itm_shadow_greaves, itm_gondor_bracer_l, itm_european_horse_d, itm_scimitar_b, itm_war_darts, itm_assassin_throwing_daggers, itm_throwing_daggers], 
attrlev(16,19,15,10,28), wpex(260,220,220,200,200,280), strsk(5,6,7,4)|agisk(6,0,4,6,6)|lordsk1(0,1,1,2,2,4,6,2)|lordsk2(2,1,2,0,3,3,0,2), draharan_faces_black_begin, draharan_faces_black_end], 
["k03_dra_m_duskguard", "Draharan Duskguard", "Draharan Duskguards", tf_guarantee_allnoranged, 0,0, fac_kingdom_3, [itm_wei_xiadi_sarranid_mamluk_armor, itm_dwarvenforged_helm_2, itm_shadow_greaves, itm_glovesblack, itm_hospitaller_knight_horse_a, itm_scimitar_b, itm_roman_shield_velite], 
attrlev(21,26,17,14,38), wpex(360,320,320,250,250,300), strsk(7,7,7,5)|agisk(7,4,6,8,6)|lordsk1(1,1,2,4,4,4,8,3)|lordsk2(3,2,3,0,4,4,0,4), draharan_faces_black_begin, draharan_faces_black_end], 
#Drahara fief guardsmen
["k03_dra_n_stormarcher", "Draharan Storm Archer", "Draharan Storm Archers", tf_guarantee_archer, 0,0, fac_kingdom_3, [itm_vaegir_elite_armor, itm_vaegir_war_helmet, itm_saracin_hard_boot_b, itm_gauntlets_arabs_a_l, itm_2scimitar_darkwood, itm_dwarf_horn_bow, itm_scull_arrow, itm_khergit_arrows], 
attrlev(24,30,13,13,44), wpex(300,350,300,420,150,300), strsk(6,6,7,8)|agisk(9,3,9,7,7)|lordsk1(3,4,2,4,4,4,6,4)|lordsk2(3,3,4,1,4,3,1,4),draharan_faces_arab_begin, draharan_faces_arab_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Maccavia
["k04_mac_freeman", "Maccavian Freeman", "Maccavian Freemen", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_blue_gambeson, itm_nordic_veteran_archer_helmet, itm_rus_shoes, itm_leather_gloves, itm_mace_1, itm_one_handed_war_axe_b, itm_ad_viking_shield_round_05], 
attrlev(10,5,8,5,5), wpex(80,60,40,40,40,40), strsk(1,2,1,1)|agisk(1,1,2,0,0)|lordsk1(1,0,0,0,0,0,0,2)|lordsk2(0,0,0,0,0,1,0,0), nofa1, nofa2], 
["k04_mac_axeman", "Maccavian Axeman", "Maccavian Axemen", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_peasant_leather_scale_2, itm_skullcap, itm_light_leather_boots, itm_leather_gloves, itm_lui_vaegiraxe, itm_throwing_axes, itm_luc_heavy_wooden_shield], 
attrlev(12,7,9,6,9), wpex(100,80,50,50,50,80), strsk(2,3,3,2)|agisk(2,3,3,0,0)|lordsk1(1,0,0,0,1,0,0,2)|lordsk2(0,0,0,0,0,1,0,1), nofa1, nofa2], 
["k04_mac_crossbowman", "Maccavian Crossbowman", "Maccavian Crossbowmen", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_rough_spiked_fur, itm_leather_warrior_cap, itm_rus_shoes, itm_leather_gloves, itm_lui_vikingaxeonehb, itm_kite_shield_3, itm_light_crossbow, itm_bolts], 
attrlev(13,9,10,7,14), wpex(120,100,60,60,140,80), strsk(2,3,3,3)|agisk(3,3,4,0,0)|lordsk1(1,1,0,1,2,1,2,2)|lordsk2(0,0,0,0,0,1,0,1), nofa1, nofa2], 
["k04_mac_heavycrossbowman", "Maccavian Heavy Crossbowman", "Maccavian Heavy Crossbowmen", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_rough_ring_leather, itm_archer_t2, itm_highlander_boots_2_2, itm_mail_mittens, itm_2shield, itm_lui_vikingaxebastard, itm_crossbow, itm_steel_bolts], 
attrlev(15,11,12,8,22), wpex(150,130,70,70,180,90), strsk(4,4,3,4)|agisk(5,4,4,0,0)|lordsk1(1,2,0,2,3,2,3,3)|lordsk2(0,0,0,2,0,2,0,1), nofa1, nofa2], 
["k04_mac_marksman", "Maccavian Marksman", "Maccavian Marksmen", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_highlander_3_1, itm_archer_t1, itm_highlander_boots_2_2, itm_scale_gauntlets, itm_luc_war_axe_2, itm_norman_shield_1, itm_heavy_crossbow, itm_steel_bolts], 
attrlev(19,13,14,9,31), wpex(200,190,80,80,240,100), strsk(5,5,4,5)|agisk(6,5,5,2,0)|lordsk1(1,2,2,3,5,3,4,3)|lordsk2(0,0,0,3,0,2,0,2), nofa1, nofa2], 
["k04_mac_heavymarksman", "Maccavian Heavy Marksman", "Maccavian Heavy Marksmen", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_huscarl_armour, itm_barbuta1, itm_iron_greaves, itm_wisby_gauntlets_red, itm_luc_battle_axe, itm_crossbow_axe, itm_axe_a, itm_steel_bolts], 
attrlev(24,15,18,11,42), wpex(275,275,100,100,300,130), strsk(7,6,5,6)|agisk(8,5,6,3,0)|lordsk1(1,3,4,4,7,4,6,4)|lordsk2(0,0,0,4,0,2,0,2), nofa1, nofa2], 
["k04_mac_mtdmarksman", "Maccavian Mounted Marksman", "Maccavian Mounted Marksmen", tf_guarantee_all, 0,0, fac_kingdom_4, [itm_giap_viet2_l, itm_rathos_fluted_helmet, itm_iron_greaves, itm_hourglass_gauntlets, itm_northerner_horse_white, itm_luc_spiked_mace, itm_luc_cavalry_shield_z, itm_steel_bolts, itm_new_sniper_crossbow], 
attrlev(18,15,15,10,30), wpex(230,150,80,80,250,100), strsk(5,5,3,5)|agisk(7,5,5,5,6)|lordsk1(1,4,0,5,5,4,4,3)|lordsk2(0,0,0,2,0,2,0,2), nofa1, nofa2], 
["k04_mac_footman", "Maccavian Footman", "Maccavian Footmen", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_rough_mail_coat_2, itm_crusader_helm_medium_c, itm_splinted_greaves, itm_mail_mittens, itm_sword_medieval_d_long, itm_war_spear, itm_tab_shield_round_d, itm_throwing_axes, itm_throwing_axes], 
attrlev(15,8,10,7,15), wpex(150,120,120,60,60,140), strsk(4,4,4,3)|agisk(4,4,4,0,0)|lordsk1(1,0,0,0,2,0,0,2)|lordsk2(0,0,0,0,0,2,0,1), nofa1, nofa2], 
["k04_mac_swordsman", "Maccavian Swordsman", "Maccavian Swordsmen", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_wei_xiadi_surcoat_rhodok02, itm_crusader_hard_helm_ord, itm_splinted_greaves_spurs, itm_hourglass_gauntlets, itm_bastard_sword_a, itm_steel_shield, itm_heavy_throwing_axes, itm_hurlbat_1], 
attrlev(19,11,13,8,22), wpex(220,200,180,70,70,200), strsk(5,6,5,3)|agisk(6,6,4,0,0)|lordsk1(1,0,1,0,4,0,0,3)|lordsk2(0,0,0,1,0,2,0,1), nofa1, nofa2], 
["k04_mac_spearman", "Maccavian Spearman", "Maccavian Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_4, [itm_dorn_spearbearer_armor, itm_salet_new, itm_shynbaulds, itm_hourglass_gauntlets_ornate, itm_ashwood_pike, itm_steel_shield, itm_heavy_throwing_axes, itm_throwing_axes], 
attrlev(24,14,14,9,28), wpex(250,220,270,80,80,250), strsk(8,8,6,4)|agisk(7,6,5,0,0)|lordsk1(1,0,2,0,4,0,0,3)|lordsk2(0,0,0,1,0,2,0,1), nofa1, nofa2], 
["k04_mac_halberdier", "Maccavian Halberdier", "Maccavian Halberdiers", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_milanese_armour, itm_klappvisier, itm_simple_poleaxe, itm_plate_mittens, itm_steel_greaves, itm_luc_polish_bardiche], 
attrlev(30,18,16,10,42), wpex(300,300,350,90,90,270), strsk(9,9,6,5)|agisk(8,6,6,0,0)|lordsk1(1,0,3,0,5,0,0,3)|lordsk2(0,0,0,2,0,3,0,2), nofa1, nofa2], 
["k04_mac_swordsmaster", "Maccavian Swordsmaster", "Maccavian Swordsmasters", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_wei_xiadi_nord_spiked_mail, itm_crusader_hard_helm_a, itm_hourglass_gauntlets, itm_dorn_spearbearer_boots, itm_saracin_shield_s, itm_trust, itm_greatsword, itm_hurlbat_1, itm_hurlbat_1], 
attrlev(22,15,15,11,30), wpex(270,270,200,80,80,250), strsk(7,7,7,4)|agisk(7,7,5,0,0)|lordsk1(1,0,4,0,6,0,2,3)|lordsk2(0,0,0,2,0,3,0,2), nofa1, nofa2], 
["k04_mac_northguard", "Maccavian Northguard", "Maccavian Northguards", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_blacky_platey_salad, itm_black_greaves, itm_black_helmet, itm_glovesblack, itm_frostfang, itm_crude_warhammer, itm_axe_crusader_1, itm_saracin_shield_t, itm_hurlbat_1], 
attrlev(30,21,18,12,40), wpex(360,360,300,100,100,360), strsk(8,9,9,5)|agisk(9,8,6,0,0)|lordsk1(1,0,4,0,8,0,4,3)|lordsk2(0,0,0,3,0,3,2,2), nofa1, nofa2], 
#Maccavia Extras
["k04_mac_messenger", "Maccavian Messenger", "Maccavian Messengers", tf_guarantee_all, 0,0, fac_kingdom_4, [itm_sword_medieval_c_small, itm_light_shield, itm_rough_leatherplate_spiked, itm_leather_boots, itm_courser, itm_leather_gloves, itm_hunting_crossbow, itm_bolts, itm_stark_hood], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), nofa1, nofa2], 
["k04_mac_pg", "Prison Guard", "Prison Guards", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_rough_mail_coat_2, itm_crusader_hard_helm_ord, itm_splinted_greaves_spurs, itm_mail_mittens, itm_bastard_sword_b, itm_steel_shield], 
attrlev(18,14,14,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), nofa1, nofa2], 
["k04_mac_cg", "Castle Guard", "Castle Guards", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_wei_xiadi_surcoat_rhodok02, itm_crusaderbucket1, itm_iron_greaves, itm_hourglass_gauntlets, itm_bastard_sword_b, itm_steel_shield], 
attrlev(22,16,16,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), nofa1, nofa2], 
#Maccavia Nobles
["k04_mac_n_squire", "Maccavian Squire", "Maccavian Squires", tf_guarantee_allnoranged, 0,0, fac_kingdom_4, [itm_rus_scale, itm_mail_mittens, itm_boot_average_crusader_b, itm_oniontop_bascinet, itm_plate_covered_round_shield, itm_mace_2, itm_northerner_horse, itm_hurlbat_1, itm_hurlbat_2], 
attrlev(21,17,16,14,27), wpex(250,230,230,150,150,220), strsk(6,6,6,3)|agisk(7,6,4,6,6)|lordsk1(1,0,3,2,6,3,1,3)|lordsk2(1,1,1,3,3,3,2,3), nofa1, nofa2], 
["k04_mac_n_blackknight", "Maccavian Black Knight", "Maccavian Black Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_4, [itm_dk_armour_charger, itm_plate_armor1, itm_black_greaves, itm_barbuta2_black, itm_dark_mail_mittens, itm_luc_kriegshammer, itm_sp_newsh], 
attrlev(32,22,20,18,44), wpex(400,350,350,200,200,300), strsk(9,8,7,5)|agisk(10,8,6,8,8)|lordsk1(1,0,4,3,8,4,3,4)|lordsk2(2,2,2,4,4,3,4,4), nofa1, nofa2], 
["k04_mac_n_steelknight", "Maccavian Knight of Steel", "Maccavian Knights of Steel", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_steel_greaves, itm_gothic_armour, itm_crusader_hard_helm_d, itm_new_sniper_crossbow, itm_steel_bolts, itm_executer, itm_hourglass_gauntlets_ornate, itm_steel_bolts], 
attrlev(35,24,21,20,50), wpex(350,400,350,200,400,200), strsk(10,9,7,8)|agisk(10,7,7,0,0)|lordsk1(1,0,8,2,8,1,4,4)|lordsk2(2,2,2,4,4,3,4,4), nofa1, nofa2], 
#Maccavia Household
["k04_mac_n_myrmidon", "Maccavian Myrmidon", "Maccavian Myrmidons", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_bnw_gauntlets, itm_halfj6, itm_jarid, itm_bnw_armour1, itm_splinted_greaves_spurs, itm_crusader_knight_helm_c], 
attrlev(26,24,16,14,35), wpex(350,350,400,100,100,350), strsk(9,8,8,7)|agisk(8,5,9,0,0)|lordsk1(1,0,1,3,5,3,4,2)|lordsk2(0,0,0,0,1,2,0,2), nofa1, nofa2], 
["k04_mac_n_kiarjanmauler", "Kiarjan Mauler", "Kiarjan Maulers", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_pigface_klappvisor, itm_armor_35, itm_bnw_gauntlets, itm_splinted_greaves_spurs, itm_morningstar_no1, itm_dec_steel_shield], 
attrlev(27,18,13,11,30), wpex(300,250,200,150,150,150), strsk(8,8,5,5)|agisk(7,6,6,0,0)|lordsk1(2,0,2,2,4,0,2,2)|lordsk2(0,0,0,0,0,3,0,1), nofa1, nofa2], 
["k04_mac_n_kiarjaninterceptor", "Kiarjan Interceptor", "Kiarjan Interceptors", tf_guarantee_allnoranged, 0,0, fac_kingdom_4, [itm_frenchpepperpot2, itm_armor_35, itm_bnw_gauntlets, itm_splinted_greaves_spurs, itm_lance_lev3, itm_spiked_mace, itm_kite_shield_6, itm_european_horse_d], 
attrlev(25,17,14,10,30), wpex(300,200,300,150,150,150), strsk(7,7,4,4)|agisk(7,5,5,7,0)|lordsk1(3,1,0,4,5,4,2,3)|lordsk2(0,0,0,0,0,2,0,3), nofa1, nofa2], 
["k04_mac_n_kijinwatcher", "Kijin Watcher", "Kijin Watchers",tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_barbuta1, itm_brigandine_black, itm_bnw_gauntlets, itm_splinted_greaves, itm_new_sniper_crossbow, itm_steel_bolts, itm_great_axe_no2], 
attrlev(24,20,15,10,30), wpex(250,250,225,150,275,150), strsk(7,6,5,6)|agisk(7,5,7,0,0)|lordsk1(1,2,0,4,5,3,6,2)|lordsk2(0,0,0,3,0,3,0,2), nofa1, nofa2], 
["k04_mac_n_kijincorpsman", "Kijin Corpsman", "Kijin Corpsmen", tf_guarantee_archer, 0,0, fac_kingdom_4, [itm_nikolskoe_helm, itm_giap_viet3, itm_gloves_lord_l, itm_civil_rich_boots_b, itm_jack_sting, itm_battle_axe_no3, itm_luc_knightly_hammer, itm_throwing_daggers], 
attrlev(21,18,21,15,30), wpex(250,250,200,100,100,250), strsk(8,6,7,3)|agisk(7,3,8,0,0)|lordsk1(0,0,0,1,3,0,2,4)|lordsk2(5,6,6,0,3,0,0,2), nofa1, nofa2], 
["k04_mac_n_wolfrider", "Maccavian Wolf Rider", "Maccavian Wolf Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_4, [itm_armour_temeria, itm_rathos_12thcent_faceplate, itm_iron_greaves, itm_gauntlets, itm_armor_wolf_black, itm_luc_baronaxeoneh, itm_norman_shield_3], 
attrlev(28,24,18,18,38), wpex(360,360,300,140,140,260), strsk(8,8,6,5)|agisk(8,6,5,9,0)|lordsk1(2,2,3,7,6,4,3,4)|lordsk2(1,0,3,0,2,4,2,0), nofa1, nofa2], 
["k04_mac_n_losthopeknight", "Knight of the Lost Hope", "Knights of the Lost Hope", tf_guarantee_allnoranged, 0,0, fac_kingdom_4, [itm_armor_baratheon, itm_helm_baratheon, itm_boots_baratheon, itm_dorn_knight_gant, itm_plated_charger9, itm_bastard_sword_b, itm_tab_shield_heater_cav_b], 
attrlev(30,24,19,15,50), wpex(400,400,380,280,280,280), strsk(9,8,7,7)|agisk(9,7,7,9,6)|lordsk1(2,2,4,1,8,3,3,4)|lordsk2(3,2,3,3,4,4,3,3), nofa1, nofa2], 
#Maccavia Mercenaries
["k04_mac_m_volheerewarlord", "Volheere Mercenary Warlord", "Volheere Mercenary Warlords", tf_guarantee_inf, 0,0, fac_kingdom_4, [itm_nordic_warlord_helmet, itm_bear_warrior, itm_shynbaulds, itm_gauntlets, itm_ad_viking_shield_round_11, itm_lui_knightbattleaxenew, itm_battle_ax_aa, itm_heavy_throwing_axes], 
attrlev(33,15,8,20,42), wpex(300,350,100,100,100,250), strsk(9,8,8,5)|agisk(8,6,6,0,0)|lordsk1(4,2,4,3,3,2,3,3)|lordsk2(0,0,0,0,0,3,4,1), nofa1, nofa2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Elintoran Nation
["k05_eli_hunter", "Elintoran Hunter", "Elintoran Hunters", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_tunic_with_green_cape, itm_stark_hood, itm_stark_hanter_boots, itm_leather_gloves, itm_wood_elven_knife, itm_dale_bow, itm_arrows], 
attrlev(10,12,11,11,6), wpex(125,100,100,150,75,75), strsk(1,2,1,3)|agisk(3,1,3,0,0)|lordsk1(1,1,0,1,0,1,1,1)|lordsk2(1,0,0,0,1,1,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_scout", "Elintoran Scout", "Elintoran Scouts", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_bronn_armor, itm_soldiers_ench, itm_civil_rich_boots_b, itm_gondor_bracer_l, itm_lorien_sword_b, itm_short_bow, itm_arrows], 
attrlev(14,15,13,12,13), wpex(160,130,130,200,90,90), strsk(2,3,2,4)|agisk(4,2,4,1,1)|lordsk1(1,2,0,2,0,2,2,1)|lordsk2(2,0,1,0,1,1,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_bowman", "Elintoran Bowman", "Elintoran Bowmen", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_lorien_archer, itm_fine_ench, itm_boot_average_crusader_c, itm_gondor_bracer_l, itm_wood_elven_blade, itm_lorien_bow_reward, itm_elven_arrows, itm_arrows], 
attrlev(18,18,16,14,23), wpex(220,200,180,270,100,100), strsk(3,5,3,5)|agisk(6,3,5,2,2)|lordsk1(1,3,0,3,1,3,3,2)|lordsk2(2,1,2,0,2,1,0,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_archer", "Elintoran Archer", "Elintoran Archers", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_lorien_armor_e, itm_mirk_helmet_2, itm_lorien_boots, itm_gondor_bracer_l, itm_sabre_black, itm_gondor_bow, itm_elven_arrows, itm_spak_bow8_arrow], 
attrlev(22,21,18,16,34), wpex(280,280,250,340,125,125), strsk(4,6,4,7)|agisk(8,4,6,3,3)|lordsk1(1,4,0,3,2,4,4,2)|lordsk2(3,2,3,0,2,2,1,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_ranger", "Elintoran Ranger", "Elintoran Rangers", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_lorien_armor_c, itm_elfhelm_grey, itm_rus_splint_greaves, itm_gauntlets_arabs_a_l, itm_lorien_sword_hand_and_half, itm_ivorybow, itm_elven_arrows, itm_elven_arrows], 
attrlev(25,24,21,20,45), wpex(360,360,350,420,150,150), strsk(5,7,5,9)|agisk(9,5,7,4,4)|lordsk1(1,6,2,4,3,5,6,3)|lordsk2(4,3,3,1,3,2,2,2), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_crimsonranger","Elintoran Crimson Ranger","Elintoran Crimson Rangers", tf_elven_male|tf_guarantee_archer,0,0,fac_kingdom_5, [itm_elf_armor, itm_elfhelm, itm_gondor_bracer_l, itm_shadow_greaves, itm_sabre_brightwood, itm_redwoodbow, itm_simpletreequiver_arrow, itm_simpletreequiver_arrow], 
attrlev(30,27,26,26,60), wpex(440,440,440,500,200,200), strsk(7,9,6,10)|agisk(10,6,8,5,5)|lordsk1(1,8,4,4,4,6,7,3)|lordsk2(4,4,4,2,4,2,3,3), elintoran_face_old_begin,elintoran_face_old_end], 
["k05_eli_rider", "Elintoran Rider", "Elintoran Riders", tf_elven_male|tf_guarantee_all, 0,0, fac_kingdom_5, [itm_cuir_bouilli_whitegold, itm_normanhelmet4_eli, itm_lorien_boots, itm_gondor_bracer_l, itm_horse_tyrk_b, itm_sabre_hithlain, itm_hermitage_shield_1, itm_whitewoodbow, itm_whiteleatherquiver_arrow], 
attrlev(21,19,17,17,31), wpex(300,275,250,325,125,125), strsk(4,6,4,6)|agisk(7,5,5,5,6)|lordsk1(1,4,0,4,2,4,3,2)|lordsk2(2,2,3,0,2,1,0,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_sunriserider", "Elintoran Sunrise Rider", "Elintoran Sunrise Riders", tf_elven_male|tf_guarantee_all, 0,0, fac_kingdom_5, [itm_j_knight_surcoat_01, itm_dorn_knight_helmet_a, itm_dorn_spearbearer_boots, itm_lamellar_gauntlets, itm_horse_tyrk_e, itm_ivorybow, itm_ivorygoldquiver_arrow, itm_lorien_sword_a, itm_lorien_round_shield], 
attrlev(26,22,20,20,44), wpex(375,350,350,400,150,150), strsk(6,8,5,7)|agisk(8,6,6,7,7)|lordsk1(1,5,1,6,3,5,4,2)|lordsk2(3,2,4,0,3,2,2,2), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_knight","Elintoran Knight","Elintoran Knights", tf_elven_male|tf_guarantee_all,0,0,fac_kingdom_5, [itm_j_knight_surcoat_01_with_mantle, itm_dorn_knight_helmet, itm_dorn_knight_boots, itm_cwe_king_gloves, itm_elvarie_spirit_horse, itm_warblade_ivorygold, itm_rivend_shield_2a, itm_elmwoodbow, itm_lonely_ar], 
attrlev(33,26,25,30,60), wpex(450,450,450,450,200,200), strsk(8,9,6,9)|agisk(10,8,6,9,9)|lordsk1(1,6,3,7,4,7,4,3)|lordsk2(3,3,4,0,4,2,4,3), elintoran_face_old_begin, elintoran_face_old_end], 
#Elintoran Extras
["k05_eli_messenger","Elintoran Messenger","Elintoran Messengers", tf_elven_male|tf_guarantee_all,0,0,fac_kingdom_5, [itm_tunic_with_green_cape, itm_leather_boots, itm_stark_hood, itm_leather_gloves, itm_courser, itm_lorien_sword_b, itm_short_bow, itm_arrows], 
attrlev(16,18,12,6,20), wp(200), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), elintoran_face_young_begin,elintoran_face_young_end], 
["k05_eli_pg","Prison Guard","Prison Guards", tf_elven_male|tf_guarantee_archer, 0, 0, fac_kingdom_5, [itm_lorien_armor_e, itm_mirk_helmet_2, itm_rus_splint_greaves, itm_gauntlets_arabs_a_l, itm_sabre_hithlain, itm_gondor_bow, itm_elven_arrows, itm_elven_arrows, itm_lorien_round_shield], 
attrlev(22,16,18,14,30), wp(275), strsk(5,5,0,6)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_cg","Castle Guard","Castle Guards", tf_elven_male|tf_guarantee_archer, 0, 0, fac_kingdom_5, [itm_lorien_armor_c, itm_elfhelm_gold, itm_rus_splint_greaves, itm_gauntlets_arabs_a_l, itm_lorien_sword_a, itm_lorien_round_shield, itm_elmwoodbow, itm_elven_arrows], 
attrlev(27,19,20,18,40), wp(320), strsk(6,6,0,8)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
#Elintoran Nobles
["k05_eli_n_hisentinel", "Elintoran Highelf Sentinel", "Elintoran Highelf Sentinels", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_j_knight_surcoat_02, itm_dorn_knight_helm_wh_a, itm_lorien_boots, itm_gauntlets_arabs_a_l, itm_lorien_sword_a, itm_lorien_round_shield, itm_gondor_bow, itm_spak_bow8_arrow], 
attrlev(22,20,21,15,33), wpex(300,250,250,330,150,150), strsk(5,6,3,6)|agisk(7,5,5,4,4)|lordsk1(1,3,1,3,2,3,4,2)|lordsk2(3,2,3,1,2,3,1,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_n_hiwarden", "Elintoran Highelf Warden", "Elintoran Highelf Wardens", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_j_knight_surcoat_02_with_mantle, itm_dorn_knight_helm_wh, itm_dorn_knight_boots, itm_gauntlets_arabs_a_l, itm_courtblades_ebony, itm_rivend_shield_2a, itm_ebonybow, itm_elven_arrows], 
attrlev(32,25,27,21,55), wpex(475,475,475,475,250,250), strsk(8,9,5,9)|agisk(10,9,8,6,6)|lordsk1(1,4,2,4,4,4,8,3)|lordsk2(5,5,5,3,3,4,2,3), elintoran_face_old_begin, elintoran_face_old_end], 
#Elintoran Household
["k05_eli_n_guardian", "Elintoran Guardian", "Elintoran Guardians", tf_elven_male|tf_guarantee_inf, 0,0, fac_kingdom_5, [itm_lorien_royal, itm_elfhelm_gold, itm_mail_chausses_shin_guard, itm_hourglass_gauntlets_ornate, itm_winged_sword, itm_citadel_guard_spear], 
attrlev(36,30,25,25,60), wpex(550,550,550,450,250,250), strsk(10,10,6,8)|agisk(10,6,8,5,5)|lordsk1(1,2,4,2,6,2,7,3)|lordsk2(4,4,4,1,2,4,2,2), elintoran_face_old_begin, elintoran_face_old_end], 
["k05_eli_n_elite","Elintoran Elite","Elintoran Elites",tf_elven_male|tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_horse,0,0,fac_kingdom_5, [itm_armour_tyrell_rider, itm_mirk_helmet_1, itm_mirk_boots_1, itm_gondor_bracer_l, itm_forest_mount, itm_ranger_blade, itm_saracin_shield_h, itm_elmwoodbow, itm_blackarrow, itm_blackarrow], 
attrlev(35,30,27,30,64), wpex(500,500,480,500,300,300), strsk(9,9,7,10)|agisk(10,8,9,10,10)|lordsk1(1,4,2,3,6,4,4,4)|lordsk2(4,4,4,1,4,4,5,3), elintoran_face_young_begin,elintoran_face_young_end], 
["k05_eli_n_moonknight", "Elintoran Moon Knight", "Elintoran Moon Knights", tf_elven_male|tf_guarantee_all,0,0,fac_kingdom_5, [itm_mirk_armor_1a, itm_gondor_helmet, itm_plate_boots2, itm_plate_mittens, itm_plated_charger7, itm_courtblades_ebony, itm_dec_steel_shield], 
attrlev(33,28,26,32,65), wpex(520,520,500,360,200,200), strsk(9,9,7,8)|agisk(10,8,6,10,6)|lordsk1(0,3,4,3,5,3,4,4)|lordsk2(4,3,4,0,4,3,4,3), elintoran_face_young_begin, elintoran_face_young_end], 
["k05_eli_n_masterscout", "Elintoran Master Scout", "Elintoran Master Scouts", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_5, [itm_mirk_armor_2, itm_mirk_helmet_1, itm_lorien_boots, itm_gondor_bracer_l, itm_wood_elven_knife, itm_gondor_bow, itm_elven_arrows], 
attrlev(24,28,25,18,36), wpex(330,250,250,380,130,130), strsk(5,6,4,7)|agisk(7,2,8,0,0)|lordsk1(1,4,0,7,4,7,7,3)|lordsk2(2,0,2,0,1,2,0,2), elintoran_face_young_begin, elintoran_face_young_end], 
#Elintoran Mercenaries
["k05_eli_m_mercredguard","Elintoran Mercenary Redguard","Elintoran Mercenary Redguards",tf_guarantee_archer,0,0,fac_kingdom_5, [itm_elf_armor_fake, itm_elfhelm_fake, itm_gondor_bracer_l, itm_shadow_greaves, itm_sabre_brightwood_fake, itm_redwoodbow_fake, itm_simpletreequiver_arrow_fake, itm_simpletreequiver_arrow_fake], 
attrlev(18,16,12,15,25), wpex(300,300,250,330,150,150), strsk(4,5,2,5)|agisk(6,3,5,5,5)|lordsk1(2,3,0,2,2,3,2,2)|lordsk2(1,0,1,0,4,1,0,3), elintoran_face_young_begin,elintoran_face_young_end], 
#Elintoran fief guardsmen
["k05_eli_n_noblemaiden", "Elintoran Noble Maiden", "Elintoran Noble Maidens", tf_elven_female|tf_guarantee_inf, 0,0, fac_kingdom_5, [itm_rivend_rohir_armor_1b, itm_rivend_helmet_1c, itm_rivend_boots_1b, itm_cwe_king_gloves, itm_elvish_sword, itm_lorien_round_shield], 
attrlev(30,33,26,30,55), wpex(500,500,500,400,200,200), strsk(8,9,6,8)|agisk(10,8,8,7,7)|lordsk1(1,3,6,3,5,2,4,4)|lordsk2(4,4,4,1,4,4,3,3), elintoran_face_female_start, elintoran_face_female_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Hakkon Empire
["k06_hak_loyalrecruit", "Hakkon Loyal Recruit", "Hakkon Loyal Recruits", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_rough_paddedleather_spiked, itm_boot_average_crusader_c, itm_light_crusader_helm_c, itm_leather_gloves, itm_tab_shield_heater_a, itm_sword_medieval_b_small, itm_javelin], 
attrlev(11,9,6,5,6), wpex(110,90,90,50,50,90), strsk(1,1,1,1)|agisk(2,2,2,0,0)|lordsk1(0,0,0,0,1,0,0,1)|lordsk2(0,0,0,0,0,1,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_militia", "Hakkon Militia", "Hakkon Militia", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_turk_bandit_c, itm_sarranid_boots_black, itm_inf_t1, itm_mail_mittens, itm_tab_shield_heater_c, itm_mrmasters_leaf_blade, itm_javelin], 
attrlev(13,13,7,6,11), wpex(160,140,140,60,80,150), strsk(2,3,2,2)|agisk(4,3,3,0,0)|lordsk1(0,0,0,0,2,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_footman", "Hakkon Footman", "Hakkon Footmen", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_shirt_a_got_2, (itm_shirt_a_got_2, imod_reinforced), itm_argossky_helm_nothingy_br, itm_gauntlets_arabs_a_l, itm_splinted_greaves, itm_rus_splint_greaves, itm_broadsword, itm_dal_hinduk, itm_javelin, itm_javelin, itm_nowe_jarid], 
attrlev(15,13,7,7,16), wpex(220,180,180,70,120,200), strsk(4,4,3,3)|agisk(5,4,4,0,0)|lordsk1(0,0,1,0,3,0,1,1)|lordsk2(0,0,0,1,0,2,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_crossbowman", "Hakkon Crossbowman", "Hakkon Crossbowmen", tf_guarantee_archer, 0,0, fac_kingdom_6, [itm_haubergeon_brass, itm_light_capelina_crusader_a, itm_brass_mail_mittens, itm_sarranid_boots_black, itm_crossbow, itm_bolts, itm_bolts, itm_bardiche], 
attrlev(17,15,8,7,25), wpex(230,230,210,85,180,220), strsk(5,5,3,4)|agisk(6,4,5,0,0)|lordsk1(0,2,1,0,4,1,3,2)|lordsk2(0,0,0,2,0,2,0,1), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_sharpshooter", "Hakkon Sharpshooter", "Hakkon Sharpshooter", tf_guarantee_archer, 0,0, fac_kingdom_6, [itm_corrazina_grey, itm_kettlehat1, itm_mail_mittens, itm_mail_chausses_shin_guard, itm_strelet_bardiche, itm_heavy_crossbow, itm_steel_bolts, itm_steel_bolts], 
attrlev(20,17,10,9,37), wpex(250,250,240,100,250,230), strsk(6,6,4,5)|agisk(8,4,6,0,0)|lordsk1(0,3,2,0,6,2,5,2)|lordsk2(0,0,0,3,0,2,0,2), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_heavyfootman", "Hakkon Heavy Footman", "Hakkon Heavy Footmen", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_xenoargh_hard_leather01, itm_crete_helm_gold, itm_mail_boots_brass, itm_brass_mail_mittens, itm_arabian_sword_a, itm_brass_shield1, itm_jarid, itm_nowe_jarid, itm_throwing_spears], 
attrlev(19,15,9,7,24), wpex(280,250,250,80,140,280), strsk(6,6,5,3)|agisk(7,6,5,0,0)|lordsk1(0,0,3,0,5,0,2,2)|lordsk2(0,0,0,3,0,2,0,1), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_legionnaire", "Hakkon Legionnaire", "Hakkon Legionnaires", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_bronze_plate, itm_corintiah_helmet, itm_bronze_gauntlet, itm_bronze_greaves, itm_roman_gladius_3, itm_shield_7, itm_nowe_jarid], 
attrlev(25,19,11,9,37), wpex(360,310,310,100,150,360), strsk(8,8,7,4)|agisk(9,7,7,0,0)|lordsk1(0,0,5,0,7,0,2,2)|lordsk2(0,0,0,4,1,3,1,2), 0x000000068100b00436db6db6db6db64b00000000001db6d90000000000000000, 0x0000000aff00c00636db6db6db6db7b300000000001db6df0000000000000000], 
["k06_hak_spearman", "Hakkon Spearman", "Hakkon Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_6, [itm_j_surcoat_bur_03d, itm_argossky_helm_nothingy, itm_splinted_greaves, itm_mail_mittens, itm_swiss_pike_1, itm_italian_sword, itm_tab_shield_pavise_b], 
attrlev(16,14,8,7,16), wpex(200,180,220,75,85,175), strsk(4,4,3,2)|agisk(5,4,5,0,0)|lordsk1(0,0,0,0,3,0,2,1)|lordsk2(0,0,0,1,0,1,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_vetspearman", "Hakkon Veteran Spearman", "Hakkon Veteran Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_6, [itm_j_surcoat_bur_03d_4, itm_corintiah_helmet_steel, itm_mail_mittens, itm_rus_splint_greaves, itm_swiss_pike_3_v2, itm_nowe_jarid], 
attrlev(20,15,9,8,26), wpex(240,220,280,90,90,250), strsk(6,5,4,3)|agisk(7,5,6,0,0)|lordsk1(0,0,1,0,4,0,2,2)|lordsk2(0,0,0,2,0,2,0,1), 0x000000068100b00436db6db6db6db64b00000000001db6d90000000000000000, 0x0000000aff00c00636db6db6db6db7b300000000001db6df0000000000000000], 
["k06_hak_impspearman", "Hakkon Imperial Spearman", "Hakkon Imperial Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_6, [itm_amade_steel_plate, itm_corinthian, itm_hourglass_gauntlets_ornate, itm_amade_steel_greaves, itm_swiss_pike_3_v1, itm_nowe_jarid, itm_roman_pilum_1], 
attrlev(25,17,10,10,37), wpex(275,250,360,100,100,300), strsk(8,7,6,4)|agisk(9,5,7,0,0)|lordsk1(0,0,3,0,6,0,3,2)|lordsk2(0,0,0,3,0,2,0,1), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_lancer", "Hakkon Lancer", "Hakkon Lancers", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_gotkn_rom_br_pl_3, itm_barbuta2_greekish_grey, itm_brass_mail_mittens, itm_mail_chausses_shin_guard, itm_lance_2, itm_hermitage_shield_1, itm_lui_empirewarhammerc, itm_halfcata], 
attrlev(19,16,10,9,25), wpex(260,260,260,80,90,200), strsk(6,6,3,3)|agisk(6,6,5,5,0)|lordsk1(0,0,1,0,5,0,2,2)|lordsk2(0,0,0,1,0,1,1,1), 0x000000068100b00436db6db6db6db64b00000000001db6d90000000000000000, 0x0000000aff00c00636db6db6db6db7b300000000001db6df0000000000000000], 
["k06_hak_implancer", "Hakkon Imperial Lancer", "Hakkon Imperial Lancers", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_gotkn_rom_br_pl_4, itm_crete_helm, itm_west_man_at_arms_boots, itm_scale_gauntlets_b, itm_romanhalfcata, itm_saracin_shield_g, itm_lance_1, itm_lui_empirewarhammerb], 
attrlev(24,18,12,12,37), wpex(350,330,350,100,100,250), strsk(7,7,4,4)|agisk(8,7,5,7,0)|lordsk1(0,0,2,0,7,0,2,2)|lordsk2(0,0,0,1,1,1,2,2), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
#Hakkon Extras
["k06_hak_messenger", "Hakkon Messenger", "Hakkon Messengers", tf_guarantee_all, 0,0, fac_kingdom_6, [itm_rough_spiked_rings, itm_inf_t1, itm_leather_boots, itm_leather_gloves, itm_european_horse_a, itm_tab_shield_heater_a, itm_sword_medieval_b_small, itm_javelin], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_pg","Prison Guard","Prison Guards",tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_xenoargh_hard_leather01, itm_h_tribune2, itm_mail_boots_brass, itm_brass_mail_mittens, itm_arabian_sword_a, itm_brass_shield1, itm_throwing_spears], 
attrlev(18,15,12,10,25), wp(250), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_cg","Castle Guard","Castle Guards",tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_bronze_plate, itm_h_tribune, itm_bronze_gauntlet, itm_bronze_greaves, itm_roman_gladius_3, itm_shield_7, itm_nowe_jarid], 
attrlev(22,18,14,12,30), wp(300), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
#Hakkon Nobles
["k06_hak_n_cavalry", "Hakkon Noble Cavalry", "Hakkon Noble Cavalry", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_hakkon_noble_outfit, itm_crete_helm_br, itm_wisby_gauntlets_red, itm_rus_splint_greaves, itm_saracin_shield_r, itm_halfcata, itm_saracin_sword_b, itm_nowe_jarid], 
attrlev(19,16,15,13,26), wpex(275,275,275,100,150,300), strsk(5,5,5,3)|agisk(6,5,4,6,6)|lordsk1(0,0,3,0,5,2,2,3)|lordsk2(2,2,2,2,3,1,2,3), 0x000000054000b5c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000006bf00c5c636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_impknight", "Hakkon Imperial Knight", "Hakkon Imperial Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_amade_bronze_plate_champion, itm_corintiah_helmet_dark, itm_west_guardsman_gant, itm_bronzeshynald, itm_charger1, itm_saracin_shield_p, itm_imperial_cavalry_sword1h, itm_lui_manhunter_polehammer, itm_roman_pilum_1, itm_roman_pilum_1], 
attrlev(30,24,18,20,50), wpex(475,475,450,200,225,500), strsk(8,8,8,6)|agisk(10,8,6,9,9)|lordsk1(0,0,7,0,9,2,2,4)|lordsk2(2,2,2,2,4,2,4,3), 0x0000000b8000b55436db6db6db6db64300000000001db6d80000000000000000, 0x0000000e3f00c5d436db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_impcavalry", "Hakkon Imperial Cavalry", "Hakkon Imperial Cavalry", tf_guarantee_all, 0,0, fac_kingdom_6, [itm_aqs_gold_roman, itm_crete_helm_gold, itm_dorn_knight_boots, itm_gauntlets_arabs_b_l, itm_charger_bronze, itm_crusader_sword_b, itm_hermitage_shield_3, itm_heavy_crossbow, itm_steel_bolts], 
attrlev(30,26,19,20,45), wpex(450,450,400,225,325,325), strsk(8,8,7,7)|agisk(9,8,7,8,8)|lordsk1(0,0,4,0,9,2,3,4)|lordsk2(2,2,2,4,4,2,3,4), 0x0000000b8000b55436db6db6db6db64300000000001db6d80000000000000000, 0x0000000e3f00c5d436db6db6db6db7b300000000001db6de0000000000000000], 
#Hakkon Household
["k06_hak_n_impbodyguard", "Hakkon Imperial Bodyguard", "Hakkon Imperial Bodyguards", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_west_guardsman, itm_barbuta2_greekish_black, itm_black_boot_salad_of, itm_glovesblack, itm_plated_charger9, itm_sw_warhammer_steel, itm_imperial_cavalry_sword1h, itm_tab_shield_heater_cav_b, itm_roman_pilum_1], 
attrlev(33,28,20,25,60), wpex(520,520,500,240,240,500), strsk(10,9,9,7)|agisk(10,9,7,10,10)|lordsk1(0,0,4,3,10,2,4,4)|lordsk2(3,3,3,2,4,4,4,3), 0x0000000b8000b55436db6db6db6db64300000000001db6d80000000000000000, 0x0000000e3f00c5d436db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_royalsniper", "Hakkon Royal Sniper", "Hakkon Royal Snipers", tf_guarantee_archer, 0,0, fac_kingdom_6, [itm_churburg_13, itm_col1_kettlehat2, itm_mail_mittens, itm_shynbaulds, itm_lui_manhunter_polehammer, itm_sniper_crossbow, itm_steel_bolts, itm_steel_bolts], 
attrlev(25,20,14,16,50), wpex(300,330,300,200,400,200), strsk(7,7,4,6)|agisk(8,4,6,0,0)|lordsk1(0,3,3,2,8,3,7,2)|lordsk2(0,0,0,4,1,3,1,3), 0x0000000b8000b55436db6db6db6db64300000000001db6d80000000000000000, 0x0000000e3f00c5d436db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_lightlancer", "Hakkon Light Lancer", "Hakkon Light Lancers", tf_guarantee_allnoranged|tf_guarantee_polearm, 0,0, fac_kingdom_6, [itm_black_mail_armor, itm_kettlehat1, itm_mail_mittens, itm_rus_splint_greaves, itm_3lamellar_charger, itm_italian_sword, itm_light_lance, itm_kite_shield_8], 
attrlev(21,18,12,10,25), wpex(300,200,330,150,150,150), strsk(6,6,3,3)|agisk(7,5,4,7,0)|lordsk1(0,0,0,0,4,1,2,2)|lordsk2(0,0,0,0,1,1,0,1), 0x000000054000b5c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000006bf00c5c636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_royalguard", "Hakkon Royal Guard", "Hakkon Royal Guards", tf_guarantee_inf, 0,0, fac_kingdom_6, [itm_gotkn_rom_br_pl_1, itm_corintiah_helmet_steel, itm_west_man_at_arms_boots, itm_west_guardsman_gant, itm_german_poleaxe], 
attrlev(30,22,12,13,42), wpex(350,350,400,200,200,200), strsk(9,8,5,5)|agisk(9,4,5,0,0)|lordsk1(0,0,4,0,5,0,4,2)|lordsk2(0,0,0,0,3,6,0,2), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
["k06_hak_n_vetlegionnaire", "Hakkon Veteran Legionnaire", "Hakkon Veteran Legionnaires", tf_guarantee_archer, 0,0, fac_kingdom_6, [itm_gotkn_rom_br_pl_2, itm_corintiah_helmet_hakleg, itm_dorn_sand_snakes_gauntles, itm_west_man_at_arms_boots, itm_mrmasters_leaf_blade_got, itm_goplon8, itm_roman_pilum_1], 
attrlev(32,26,13,12,50), wpex(460,360,360,120,170,440), strsk(10,10,9,6)|agisk(10,9,8,0,0)|lordsk1(0,0,6,0,9,0,3,3)|lordsk2(0,0,1,4,1,4,2,2), 0x000000068100b00436db6db6db6db64b00000000001db6d90000000000000000, 0x0000000aff00c00636db6db6db6db7b300000000001db6df0000000000000000], 
["k06_hak_n_valereanknight", "Hakkon Valerean Knight", "Hakkon Valerean Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_early_transitional_gold, itm_barbuta2_greekish_gold, itm_steel_greaves, itm_brass_lamellar_gauntlets, itm_romanhalfcata2, itm_crusader_long_sword_a, itm_sh_golden,  itm_roman_pilum_1], 
attrlev(29,24,15,24,46), wpex(400,380,380,130,150,400), strsk(7,8,8,6)|agisk(9,6,4,8,9)|lordsk1(3,0,3,1,6,1,2,3)|lordsk2(0,0,1,2,3,4,4,1), 0x0000000b8000b55436db6db6db6db64300000000001db6d80000000000000000, 0x0000000e3f00c5d436db6db6db6db7b300000000001db6de0000000000000000], 
#Hakkon Mercenaries
["k06_hak_m_merccataphract", "Hakkon Mercenary Cataphract", "Hakkon Mercenary Cataphracts", tf_guarantee_allnoranged, 0,0, fac_kingdom_6, [itm_wei_xiadi_cataphract_armor, itm_crete_helm_br, itm_brass_mail_mittens, itm_black_greaves, itm_3lamellar_charger, itm_brass_shield, itm_light_lance, itm_lui_knighthammer], 
attrlev(21,15,10,15,34), wpex(300,280,300,150,150,150), strsk(7,6,4,3)|agisk(6,5,4,6,0)|lordsk1(1,0,0,0,4,0,2,2)|lordsk2(0,0,0,0,2,2,0,2), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000,0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#The Zann Empire
["k07_zan_peasant", "Zann Peasant", "Zann Peasants", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_steppe_armor, itm_nomad_cap_b, itm_ankle_boots, itm_military_fork, itm_scythe], 
attrlev(7,6,4,4,2), wpex(65,65,65,50,50,50), strsk(0,0,0,0)|agisk(1,0,1,0,0)|lordsk1(1,0,0,0,0,0,0,1)|lordsk2(0,0,0,0,0,0,0,1), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_militia", "Zann Militia", "Zann Militia", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_black_steppe_armor, itm_steppe_cap, itm_leather_gloves, itm_nomad_boots, itm_hafted_blade_b, itm_darts], 
attrlev(9,8,5,5,4), wpex(100,100,110,80,55,80), strsk(0,1,1,0)|agisk(2,0,2,0,0)|lordsk1(1,0,0,0,0,0,1,1)|lordsk2(0,0,0,0,0,1,0,1), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_bowman", "Zann Bowman", "Zann Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_7, [itm_nomad_armor, itm_nomad_cap, itm_leather_gloves, itm_hide_boots, itm_hafted_blade_a, itm_nomad_bow, itm_barbed_arrows, itm_barbed_arrows], 
attrlev(11,11,6,5,7), wpex(130,130,150,140,70,95), strsk(1,2,1,2)|agisk(3,0,3,0,0)|lordsk1(2,1,0,1,0,1,1,2)|lordsk2(0,0,0,0,0,1,0,1), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_trainedbowman", "Zann Trained Bowman", "Zann Trained Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_7, [itm_black_nomad_armor, itm_vaegir_fur_cap, itm_leather_gloves, itm_khergit_leather_boots, itm_luc_swiss_voulge, itm_bogmir_yumi, itm_bodkin_arrows, itm_bodkin_arrows], 
attrlev(14,14,7,6,15), wpex(170,160,190,200,90,110), strsk(2,3,2,4)|agisk(5,0,4,0,0)|lordsk1(2,2,0,1,1,2,2,2)|lordsk2(0,0,0,0,0,1,0,2), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_vetbowman", "Zann Veteran Bowman", "Zann Veteran Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_7, [itm_arabian_armor_b, itm_vaegir_lamellar_helmet, itm_leather_gloves, itm_sarranid_boots_black, itm_halfj4, itm_longest_bow, itm_bodkin_arrows, itm_samurai_arrow_a], 
attrlev(17,17,8,7,24), wpex(230,200,250,280,110,140), strsk(3,4,2,5)|agisk(7,0,5,0,0)|lordsk1(3,3,0,2,3,3,3,3)|lordsk2(0,0,0,1,0,2,0,2), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_longbowman", "Zann Longbowman", "Zann Longbowmen", tf_guarantee_archer, 0,0, fac_kingdom_7, [itm_wei_xiadi_lamellar_armor01, itm_gulam_helm_a, itm_dorn_spearbearer_boots, itm_gauntlets_arabs_a_l, itm_yari_spear_b, itm_longest_bow_3, itm_samurai_arrow_a, itm_bronze_arrow], 
attrlev(21,21,10,9,36), wpex(280,240,350,400,140,170), strsk(4,5,4,7)|agisk(9,0,7,0,0)|lordsk1(3,5,0,3,5,4,4,3)|lordsk2(0,0,0,2,0,2,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_mtdarcher", "Zann Mounted Archer", "Zann Mounted Archers", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_giap_viet3, itm_vaegir_fur_helmet, itm_gauntlets_arabs_a_l, itm_sarranid_boots_black, itm_xenoargh_baydark, itm_naginata, itm_new_strong_bow, itm_samurai_arrow_a, itm_samurai_arrow_a], 
attrlev(17,16,9,7,23), wpex(240,210,270,270,120,140), strsk(3,5,2,5)|agisk(7,0,4,5,5)|lordsk1(3,3,0,3,3,3,3,3)|lordsk2(0,0,0,0,0,1,0,2), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_swifthunter", "Zann Swifthunter", "Zann Swifthunters", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_heavy_lamellar_armor, itm_gulam_helm_a, itm_gauntlets_arabs_a_l, itm_dorn_spearbearer_boots, itm_warhorse_steppe, itm_luc_hafted_blade_1, itm_longest_bow, itm_bronze_arrow, itm_bronze_arrow], 
attrlev(21,20,11,9,35), wpex(300,260,370,380,150,180), strsk(4,6,3,6)|agisk(9,0,5,7,7)|lordsk1(3,4,0,5,5,5,4,3)|lordsk2(0,0,0,0,0,2,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_heavyrider", "Zann Heavy Rider", "Zann Heavy Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_7, [itm_song_armor_ca, itm_song_helm_b, itm_mail_chausses_shin_guard, itm_gondor_bracer_l, itm_warhorse_sarranid, itm_warhorse_steppe, itm_luc_hafted_blade_2], 
attrlev(26,26,12,12,50), wpex(350,350,450,400,160,200), strsk(6,7,5,6)|agisk(10,0,6,9,7)|lordsk1(3,4,2,4,6,4,4,4)|lordsk2(0,0,0,0,1,3,1,4), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_swordsman", "Zann Swordsman", "Zann Swordsmen", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_black_lamellar_armor_light, itm_khergit_guard_helmet, itm_new_lamellar_gauntlets, itm_splinted_leather_greaves, itm_painted_brass_shield5, itm_sword_khergit_3], 
attrlev(13,12,6,6,9), wpex(160,160,160,90,70,100), strsk(2,3,2,1)|agisk(4,1,3,0,0)|lordsk1(2,0,0,0,1,0,1,2)|lordsk2(0,0,0,1,0,1,0,1), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_trainedswordsman", "Zann Trained Swordsman", "Zann Trained Swordsmen", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_lamellar_armor_f, itm_vaegir_spiked_helmet, itm_splinted_greaves_spurs, itm_new_lamellar_gauntlets, itm_sword_khergit_2, itm_brass_shield1], 
attrlev(16,15,7,7,17), wpex(220,220,220,110,85,130), strsk(3,4,2,2)|agisk(5,3,4,0,0)|lordsk1(2,0,1,1,2,0,1,2)|lordsk2(0,0,0,1,0,2,0,2), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_vetswordsman", "Zann Veteran Swordsman", "Zann Veteran Swordsmen", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_lamellar_armor, itm_vaegir_noble_helmet, itm_dorn_spearbearer_boots, itm_wisby_gauntlets_black, itm_sword_khergit_1, itm_dal_muslimf, itm_halfj], 
attrlev(19,18,8,9,26), wpex(290,290,290,130,110,160), strsk(4,5,3,3)|agisk(7,4,5,0,0)|lordsk1(3,0,2,1,3,0,2,2)|lordsk2(0,0,0,2,0,2,0,2), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_spearman", "Zann Spearman", "Zann Spearmen", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_7, [itm_wei_xiadi_lamellar_armor01, itm_helm_tyrk_d_market, itm_brass_scale_gauntlets, itm_shadow_greaves, itm_halfj4], 
attrlev(23,21,10,10,33), wpex(360,360,380,160,120,200), strsk(6,6,3,4)|agisk(9,4,6,0,0)|lordsk1(3,0,3,2,4,1,2,3)|lordsk2(0,0,0,2,0,3,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_spearmaster", "Zann Spearmaster", "Zann Spearmasters", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_7, [itm_ghulam_heavy_cavalryman_3, itm_helm_tyrk_a_market, itm_hourglass_gauntlets_ornate, itm_shadow_greaves, itm_halfj3, itm_halfj1], 
attrlev(27,25,12,12,45), wpex(450,450,500,200,150,250), strsk(8,8,4,5)|agisk(10,5,7,0,0)|lordsk1(3,0,5,2,6,1,3,3)|lordsk2(0,0,0,2,0,4,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
#Zann Extras 
["k07_zan_messenger", "Zann Messenger", "Zann Messengers", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_black_steppe_armor, itm_nomad_cap, itm_leather_gloves, itm_leather_boots, itm_european_horse_a, itm_sword_khergit_3, itm_nomad_bow, itm_barbed_arrows], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_pg","Prison Guard","Prison Guards", tf_guarantee_inf, 0, 0, fac_kingdom_7, [itm_giap_viet3, itm_vaegir_lamellar_helmet, itm_shadow_greaves, itm_gauntlets_arabs_a_l, itm_naginata], 
attrlev(14,14,12,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,2,5,0,2), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k07_zan_cg","Castle Guard","Castle Guards", tf_guarantee_inf, 0, 0, fac_kingdom_7, [itm_ghulam_heavy_cavalryman_3, itm_helm_tyrk_d_market, itm_shadow_greaves, itm_mail_mittens, itm_sword_khergit_1, itm_dal_hinduh], 
attrlev(18,18,14,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,3,5,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
#Zann Nobles
["k07_zan_n_kamikaze","Zann Kamikaze Warrior","Zann Kamikaze Warriors",tf_guarantee_inf,0,0,fac_kingdom_7, [itm_redyoroi, itm_redkabuto, itm_redkote, itm_redsuneate, itm_samurai_sword], 
attrlev(26,25,14,14,35), wpex(400,400,400,200,100,200), strsk(8,7,4,4)|agisk(8,4,8,0,0)|lordsk1(2,0,3,3,8,2,4,3)|lordsk2(0,0,0,3,3,3,1,3), zann_face_young_to_middle_begin,zann_face_young_to_middle_end], 
#Zann Household
["k07_zan_n_emperorsguardian", "Zann Emperor's Guardian", "Zann Emperor's Guardians", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_dorn_immortal_armor, itm_dorn_immortal_helmet, itm_suneate, itm_dorn_knight_gant, itm_two_handed_katana, itm_luc_hafted_blade_2], 
attrlev(32,28,16,22,60), wpex(540,540,540,350,180,350), strsk(10,10,8,8)|agisk(10,5,8,0,0)|lordsk1(1,0,6,2,9,3,4,4)|lordsk2(2,0,4,2,2,4,2,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_n_monk", "Zann Monk", "Zann Monks", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_robe, itm_assassin_helmet, itm_gondor_bracer_l, itm_civil_rich_boots_b, itm_naginata, itm_shinobi_bite_throw, itm_shinobi_bite_throw], 
attrlev(18,16,21,10,35), wpex(200,200,300,100,100,300), strsk(6,5,6,3)|agisk(6,0,7,0,0)|lordsk1(0,0,0,0,2,2,2,3)|lordsk2(6,6,6,2,3,1,0,2), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_n_blackwarrior", "Black Warrior", "Black Warriors", tf_male|tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_yoroi, itm_kabuto, itm_suneate, itm_kote, itm_roman_shield_velite, itm_strange_short_sword, itm_strange_great_sword, itm_shinobi_bite_throw], 
attrlev(27,24,13,15,38), wpex(440,440,400,200,150,400), strsk(8,8,7,4)|agisk(9,6,7,0,0)|lordsk1(2,0,4,2,5,2,4,3)|lordsk2(0,0,0,3,2,3,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_n_kheshig", "Zann Kheshig", "Zann Kheshigs", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_ghulam_heavy_cavalryman_3, itm_helm_saracin_b_zann, itm_shadow_greaves, itm_gauntlets_arabs_a_l, itm_warhorse_sarranid, itm_samurai_sword, itm_imperial_bow_2, itm_samurai_arrow_a, itm_samurai_arrow_a], 
attrlev(25,23,12,16,42), wpex(400,400,350,420,100,100), strsk(7,7,5,7)|agisk(9,0,5,8,8)|lordsk1(3,4,0,4,7,4,6,3)|lordsk2(0,0,0,0,3,2,0,4), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_n_yumimaster", "Zann Yumi Master", "Zann Yumi Masters", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_giap_viet1_d, itm_redkabuto, itm_redkote, itm_redsuneate, itm_halfj, itm_longest_bow_2, itm_samurai_arrow_a, itm_samurai_arrow_a], 
attrlev(24,24,15,15,42), wpex(350,350,400,450,200,200), strsk(7,7,5,8)|agisk(10,0,7,0,0)|lordsk1(2,4,4,3,6,4,4,3)|lordsk2(0,0,0,3,3,2,2,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["k07_zan_n_mtdberserker","Zann Mounted Berserker","Zann Mounted Berserkers",tf_guarantee_allnoranged,0,0,fac_kingdom_7, [itm_kabuto, itm_suneate, itm_kote, itm_yoroi, itm_horse_bandits_b, itm_mongol_heavy_sword], 
attrlev(26,24,11,11,42), wpex(380,380,340,120,120,120), strsk(8,8,5,5)|agisk(9,4,6,6,0)|lordsk1(4,0,2,2,4,2,3,3)|lordsk2(0,0,0,1,1,3,0,2), zann_face_young_to_middle_begin,zann_face_young_to_middle_end], 
#Thuro Imperial Scouts
["imperial_scout", "Imperial Scout", "Imperial Scouts", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_khergit_armor, itm_vaegir_fur_cap, itm_splinted_greaves, itm_lamellar_gauntlets, itm_european_horse_a, itm_steppe_horse, itm_strange_short_sword, itm_painted_brass_shield5, itm_short_imperial_bow, itm_samurai_arrow_a], 
attrlev(15,16,9,10,16), wpex(160,160,160,180,100,100), strsk(4,4,3,5)|agisk(5,3,4,6,6)|lordsk1(2,2,0,1,2,3,3,2)|lordsk2(0,0,1,0,2,1,0,2), khergit_face_younger_1, khergit_face_older_2], 
["seasoned_imperial_scout", "Seasoned Imperial Scout", "Seasoned Imperial Scouts", tf_guarantee_all, 0,0, fac_kingdom_7, [itm_giap_viet4, itm_vaegir_lamellar_helmet, itm_vaegir_fur_helmet, itm_shadow_greaves, itm_new_lamellar_gauntlets, itm_steppe_paint1, itm_steppe_paint1, itm_sword_khergit_1, itm_brass_shield, itm_imperial_bow_2, itm_samurai_arrow_a], 
attrlev(19,21,12,12,30), wpex(260,260,260,280,150,150), strsk(5,6,4,7)|agisk(7,5,6,8,8)|lordsk1(3,4,0,3,4,4,7,3)|lordsk2(1,0,2,0,4,2,0,4), khergit_face_younger_1, khergit_face_older_2], 
#Zann Mercenaries
["k07_zan_m_ronin", "Zann Ronin", "Zann Ronins", tf_guarantee_inf, 0,0, fac_kingdom_7, [itm_giap_viet1_d, itm_redkote, itm_suneate, itm_strange_sword], 
attrlev(21,18,13,14,28), wpex(300,300,250,70,70,70), strsk(7,6,3,4)|agisk(7,0,6,4,4)|lordsk1(3,0,3,0,4,2,3,3)|lordsk2(0,0,0,2,3,2,0,3), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Realm Of The Falcon (Michadr/Silberfalke)
["k08_fal_cav01", "Aepele Fealcan", "Aepele Fealcen", tf_guarantee_all, 0,0, fac_kingdom_8, [itm_knight_armor_templar_a, itm_rus_helm, itm_mail_mittens, itm_mail_boots, itm_tribal4, itm_tribal4, itm_mace_2, itm_gondor_shield_d, itm_lorien_bow_reward, itm_ebonyornate_arrow], 
attrlev(24,20,18,20,26), wpex(265,265,250,250,165,165), strsk(6,5,4,5)|agisk(6,5,5,6,6)|lordsk1(0,3,1,1,4,2,3,3)|lordsk2(2,2,2,1,2,2,0,1), elintoran_face_1, elintoran_face_4], 
["k08_fal_cav02", "Light Renweard", "Light Renweards", tf_guarantee_allnoranged, 0,0, fac_kingdom_8, [itm_west_guardsman_heavy_1, itm_fountain_guard_helmet, itm_shynbaulds, itm_iron_greaves, itm_wisby_gauntlets_black, itm_falconian_warhorse, itm_wlong24, itm_knights_winged_mace_1h, itm_gondor_shield_b], 
attrlev(30,24,21,26,45), wpex(415,415,415,300,200,200), strsk(8,8,6,6)|agisk(8,7,7,8,7)|lordsk1(0,3,4,2,6,3,4,3)|lordsk2(3,3,3,2,3,3,1,2), elintoran_face_1, elintoran_face_4], 
["k08_fal_cav03", "Renweard", "Renweards", tf_guarantee_allnoranged, 0,0, fac_kingdom_8, [itm_citadel_guard_armor, itm_fountain_guard_helmet_mask, itm_twilight_boots, itm_hourglass_gauntlets_ornate, itm_plated_charger7, itm_plated_charger7, itm_luc_flanged_mace_iron, itm_wardens_shield], 
attrlev(35,28,25,32,65), wpex(520,520,520,400,280,280), strsk(10,10,8,8)|agisk(10,9,8,10,8)|lordsk1(0,4,7,3,8,4,4,4)|lordsk2(4,4,4,3,4,3,3,3), elintoran_face_1, elintoran_face_4], 
["k08_fal_cavar02", "Sceotend Fealcan", "Sceotend Fealcen", tf_guarantee_all, 0,0, fac_kingdom_8, [itm_knight_armor_templar_a_1, itm_gondor_helmet, itm_steel_greaves, itm_gauntlets, itm_falconian_warhorse, itm_falconian_warhorse, itm_warblade_black01, itm_gondor_shield_d, itm_whitewoodbow, itm_yinjian], 
attrlev(28,25,22,25,45), wpex(400,380,380,400,200,200), strsk(8,7,6,8)|agisk(8,7,6,8,8)|lordsk1(0,4,2,2,6,3,4,4)|lordsk2(3,3,3,3,3,3,1,2), elintoran_face_1, elintoran_face_4], 
["k08_fal_cavar03", "Frod Sceotend Fealcan", "Frod Sceotend Fealcen", tf_guarantee_boots|tf_guarantee_all, 0,0, fac_kingdom_8, [itm_early_transitional_pearl, itm_citadel_guard_helmet, itm_plate_boots2, itm_hourglass_gauntlets_ornate, itm_mail_armour_charger1, itm_wlong24, itm_warblade_black02, itm_gondor_shield_c, itm_guizugong, itm_yinjian], 
attrlev(33,30,26,30,65), wpex(500,450,450,500,300,300), strsk(10,10,8,10)|agisk(10,8,8,10,10)|lordsk1(0,6,3,3,8,4,6,4)|lordsk2(4,4,4,4,4,3,2,3), elintoran_face_1, elintoran_face_4], 
#
["k08_fal_inf01", "Widumann", "Widumenn", tf_guarantee_inf, 0,0, fac_kingdom_8, [itm_knight_armor_templar_a_1, itm_fountain_guard_helmet, itm_mail_mittens, itm_mail_boots, itm_knights_warhammer_no1, itm_gondor_shield_b, itm_greatsword], 
attrlev(20,15,16,17,24), wpex(245,245,220,140,140,140), strsk(4,4,3,3)|agisk(5,5,4,0,0)|lordsk1(0,0,1,0,2,0,1,2)|lordsk2(1,1,1,1,1,2,0,1), elintoran_face_1, elintoran_face_4], 
["k08_fal_inf02", "Bearwesmann", "Bearwesmenn", tf_guarantee_inf, 0,0, fac_kingdom_8, [itm_early_transitional_pearl, itm_citadel_guard_helmet, itm_iron_greaves, itm_hourglass_gauntlets, itm_warblade_black02, itm_gondor_shield_a, itm_luc_iron_war_axe], 
attrlev(25,20,18,20,33), wpex(350,350,300,180,180,180), strsk(6,6,4,4)|agisk(7,6,6,0,0)|lordsk1(0,0,2,0,4,1,3,3)|lordsk2(2,2,2,3,2,3,0,2), elintoran_face_1, elintoran_face_4], 
["k08_fal_inf03", "Frod Bearwesmann", "Frod Bearwesmenn", tf_guarantee_inf, 0,0, fac_kingdom_8, [itm_west_guardsman_heavy_1, itm_fountain_guard_helmet_mask, itm_shynbaulds, itm_plate_mittens, itm_gothic_hammer, itm_wardens_shield, itm_luc_knights_warhammer], 
attrlev(30,25,21,25,46), wpex(450,450,420,240,240,240), strsk(8,8,6,9)|agisk(9,8,7,0,0)|lordsk1(0,0,4,0,6,2,4,3)|lordsk2(3,3,3,4,3,4,1,3), elintoran_face_1, elintoran_face_4], 
#
["k08_fal_arch01", "Geong Scytta Fealcan", "Geong Scytta Fealcen", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_8, [itm_knight_armor_templar_a, itm_tagancha_helm_a, itm_mail_mittens, itm_mail_boots, itm_italian_sword, itm_gondor_shield_d, itm_lorien_bow_reward, itm_yinjian], 
attrlev(18,15,15,16,24), wpex(220,200,200,240,150,150), strsk(4,4,2,5)|agisk(5,4,4,0,0)|lordsk1(0,2,1,0,3,1,3,2)|lordsk2(1,1,1,2,1,2,0,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k08_fal_arch02", "Scytta Fealcan", "Scytta Fealcen", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_8, [itm_knight_armor_templar_a_1, itm_rus_helm, itm_shynbaulds, itm_mail_mittens, itm_crusaders_swords_a, itm_gondor_shield_b, itm_whitewoodbow, itm_yinjian], 
attrlev(23,19,18,21,33), wpex(325,300,300,350,200,200), strsk(6,6,4,7)|agisk(7,6,6,0,0)|lordsk1(0,3,2,1,5,2,4,3)|lordsk2(2,2,2,3,2,2,0,2), elintoran_face_young_begin, elintoran_face_young_end], 
["k08_fal_arch03", "Scytere Fealcan", "Scytere Fealcan", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_8, [itm_armor_master_order_tevton, itm_gondor_helmet, itm_iron_greaves, itm_mail_mittens, itm_saracin_sword_b, itm_gondor_shield_a, itm_guizugong, itm_yinjian], 
attrlev(28,24,22,26,46), wpex(425,400,400,450,260,260), strsk(8,8,6,9)|agisk(9,8,8,0,0)|lordsk1(0,4,3,1,7,3,7,3)|lordsk2(3,3,3,4,3,3,1,3), elintoran_face_young_begin, elintoran_face_young_end], 
#Falcon Extras
["k08_fal_messenger","Falcon Messenger","Falcon Messengers",tf_guarantee_all,0,0,fac_kingdom_8, [itm_knight_armor_templar_a, itm_rus_helm, itm_mail_boots, itm_mail_mittens, itm_tribal4, itm_italian_sword, itm_gondor_shield_d, itm_lorien_bow_reward, itm_yinjian], 
attrlev(20,21,16,9,30), wp(250), strsk(5,5,4,4)|agisk(5,4,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), rhodok_face_middle_1,rhodok_face_older_2], 
["k08_fal_pg","Prison Guard","Prison Guards", tf_guarantee_archer, 0, 0, fac_kingdom_8, [itm_early_transitional_pearl, itm_gondor_helmet, itm_shynbaulds, itm_mail_mittens, itm_lorien_sword_hand_and_half, itm_whitewoodbow, itm_yinjian], 
attrlev(27,18,20,15,38), wp(315), strsk(6,6,0,6)|agisk(7,6,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_1, elintoran_face_2], 
["k08_fal_cg", "Castle Guard", "Castle Guards", tf_guarantee_inf, 0,0, fac_kingdom_8, [itm_west_guardsman_heavy_1, itm_citadel_guard_helmet, itm_shadow_greaves, itm_hourglass_gauntlets_ornate, itm_knights_mace_no1, itm_gondor_shield_a], 
attrlev(32,22,24,20,45), wp(380), strsk(8,8,0,8)|agisk(8,8,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_1, elintoran_face_2], 
#Falcon Nobles
["k08_fal_n_cav01", "Ridere Fealcan", "Ridereas Fealcen", tf_guarantee_allnoranged, 0,0, fac_kingdom_8, [itm_armor_master_order_tevton, itm_winged_helm_new, itm_lorien_boots, itm_mail_mittens, itm_falcon_horse, itm_falconian_warhorse, itm_sabre_elmwood, itm_dal_hindub], 
attrlev(26,22,24,26,38), wpex(285,285,285,250,200,200), strsk(6,6,5,5)|agisk(6,6,5,7,7)|lordsk1(0,2,2,1,5,2,2,3)|lordsk2(3,3,3,3,3,2,2,3), elintoran_face_1, elintoran_face_4], 
["k08_fal_n_cav02", "Frod Ridere Fealcan", "Frod Ridereas Fealcen", tf_guarantee_boots|tf_guarantee_allnoranged, 0,0, fac_kingdom_8, [itm_citadel_guard_armor, itm_maciejowski_helmet_new5, itm_bronzeshynald, itm_hourglass_gauntlets_ornate, itm_charger_bronze, itm_charger_bronze, itm_jack_faramir, itm_saracin_shield_s, itm_jack_anduril], 
attrlev(36,30,30,35,68), wpex(540,540,500,500,350,350), strsk(10,10,8,8)|agisk(10,10,7,10,9)|lordsk1(0,3,4,2,8,3,4,4)|lordsk2(4,4,4,4,4,3,4,4), elintoran_face_1, elintoran_face_4], 
#Falcon Household
["k08_fal_n_healer", "Gehorsod Helend", "Gehorsod Helends", tf_guarantee_all, 0,0, fac_kingdom_8, [itm_rathos_surcoat_white, itm_winged_helm_new, itm_boot_average_crusader_b, itm_gondor_bracer_l, itm_falcon_horse, itm_wlong24, itm_horsemans_axe_no2, itm_dal_hindub, itm_guizugong, itm_yinjian], 
attrlev(25,25,30,25,44), wpex(300,270,270,300,150,150), strsk(8,6,4,8)|agisk(7,5,9,9,7)|lordsk1(0,1,0,1,5,3,4,4)|lordsk2(8,8,8,2,4,1,0,3), elintoran_face_1, elintoran_face_4], 
["k08_fal_n_guard", "Seleweard Fealcan", "Seleweard Fealcen", tf_guarantee_inf, 0,0, fac_kingdom_8, [itm_west_guardsman_heavy_2, itm_winged_helmet, itm_dorn_knight_boots, itm_dorn_squire_gauntles, itm_gondor_spear, itm_steel_shield_kite, itm_schlachtschwert], 
attrlev(35,28,25,30,55), wpex(520,520,520,260,260,260), strsk(10,10,8,8)|agisk(10,10,8,0,0)|lordsk1(0,0,4,2,9,3,4,4)|lordsk2(3,3,4,4,4,4,2,3), elintoran_face_1, elintoran_face_4], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Valahir Clan
["k09_val_thrall", "Valahir Thrall", "Valahir Thralls", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_rawhide_coat, itm_nordic_archer_helmet, itm_hide_boots, itm_leather_gloves, itm_two_handed_axe], 
attrlev(13,8,5,5,7), wpex(90,90,60,50,50,60), strsk(2,2,1,1)|agisk(2,1,1,0,0)|lordsk1(2,1,0,0,0,1,0,0)|lordsk2(0,0,0,0,0,1,0,0), nofa1, nofa2], 
["k09_val_landi", "Valahir Landi", "Valahir Landir", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_rough_mail_spiked, itm_nordic_fighter_helmet, itm_leather_gloves, itm_leather_boots, itm_mackie_varangian_axe, itm_ad_viking_shield_round_07, itm_luc_two_handed_axe_1], 
attrlev(16,10,5,6,11), wpex(135,135,90,80,60,100), strsk(4,3,2,2)|agisk(4,3,2,0,0)|lordsk1(2,1,1,1,0,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), nofa1, nofa2], 
["k09_val_drengr", "Valahir Drengr", "Valahir Drengar", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_byrnie, itm_nordic_helmet, itm_splinted_leather_greaves, itm_mail_mittens, itm_ad_viking_shield_round_04, itm_ad_viking_shield_round_08, itm_great_axe, itm_throwing_axes], 
attrlev(20,12,6,6,16), wpex(185,185,130,90,70,160), strsk(5,4,4,3)|agisk(5,5,3,0,0)|lordsk1(3,1,1,1,0,2,2,2)|lordsk2(0,0,0,1,0,2,0,0), nofa1, nofa2], 
["k09_val_harddrengr", "Valahir Hardened Drengr", "Valahir Hardened Drengar", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_mail_hauberk, itm_helmet_w_eyeguard_new_alt, itm_mail_boots, itm_wisby_gauntlets_black, itm_long_axe_c_alt], 
attrlev(24,15,6,7,24), wpex(245,245,220,100,80,220), strsk(7,6,5,4)|agisk(7,6,4,0,0)|lordsk1(3,2,2,2,0,2,2,2)|lordsk2(0,0,0,2,0,3,1,1), nofa1, nofa2], 
["k09_val_seggr", "Valahir Seggr", "Valahir Seggar", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_brigandine_black, itm_nordic_huscarl_helmet, itm_iron_greaves, itm_mail_mittens, itm_rohirrim_long_hafted_axe, itm_heavy_throwing_axes, itm_ad_viking_shield_round_14], 
attrlev(29,17,7,8,31), wpex(315,315,300,125,90,280), strsk(9,8,7,5)|agisk(8,8,5,5,5)|lordsk1(4,2,3,2,1,3,3,3)|lordsk2(0,0,0,2,0,3,1,1), nofa1, nofa2], 
["k09_val_huscarl", "Valahir Huskarl", "Valahir Huskarle", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_dejawolf_vikingbyrnie, itm_nordic_huscarl_helmet, itm_gauntlets, itm_iron_greaves, itm_lui_baronaxeoneh, itm_battle_axe_no3, itm_ad_viking_shield_round_12, itm_rohirrim_throwing_axe], 
attrlev(34,20,8,9,40), wpex(400,400,350,150,100,400), strsk(10,9,9,6)|agisk(9,9,6,0,0)|lordsk1(4,2,4,3,1,3,4,3)|lordsk2(0,0,0,3,0,4,2,1), nofa1, nofa2], 
["k09_val_vassargl", "Valahir Vassargl", "Valahir Vassargle", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_plate_etched, itm_maciejowski_helmet5b_black, itm_plate_boots, itm_gauntlets, itm_rohan_axe_reward, itm_tab_shield_round_e], 
attrlev(40,22,9,10,52), wpex(500,500,450,200,120,450), strsk(10,10,9,7)|agisk(10,10,8,0,0)|lordsk1(4,2,7,3,3,3,4,4)|lordsk2(0,0,0,3,1,4,3,2), nofa1, nofa2], 
["k09_val_hersir", "Valahir Hersir", "Valahir Hersirs", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_brig_plate_black, itm_nordic_warlord_helmet, itm_iron_greaves, itm_plate_mittens, itm_great_hammer], 
attrlev(35,19,9,12,40), wpex(370,400,370,150,100,350), strsk(10,10,8,6)|agisk(9,8,7,0,0)|lordsk1(4,2,4,4,2,3,3,3)|lordsk2(0,0,0,3,2,4,5,2), nofa1, nofa2], 
["k09_val_hiligord", "Valahir Hiligord", "Valahir Hiligords", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_plate_etched, itm_otk_shlem, itm_shadow_greaves, itm_gauntlets, itm_luc_great_long_axe, itm_luc_knightly_axe_two_handed, itm_luc_maciejowski_axe], 
attrlev(42,25,10,16,54), wpex(450,500,500,200,120,400), strsk(10,10,9,8)|agisk(10,8,10,0,0)|lordsk1(4,2,4,4,4,3,4,4)|lordsk2(0,0,0,3,3,4,6,3), nofa1, nofa2], 
["k09_val_bogisveinn", "Valahir Bogisveinn", "Valahir Bogisveinnen", tf_guarantee_archer, 0,0, fac_kingdom_9, [itm_rough_spiked_rings, itm_nordic_helmet, itm_mail_mittens, itm_light_leather_boots, itm_axe, itm_noldor_bow, itm_bodkin_arrows], 
attrlev(18,12,7,6,15), wpex(170,170,140,150,70,120), strsk(5,4,2,4)|agisk(5,3,4,0,0)|lordsk1(2,2,1,2,0,2,2,2)|lordsk2(0,0,0,1,0,2,0,1), nofa1, nofa2], 
["k09_val_bogirre", "Valahir Bogirre", "Valahir Bogirren", tf_guarantee_archer, 0,0, fac_kingdom_9, [itm_cuir_bouilli, itm_mail_mittens, itm_mail_boots, itm_nordhelm_coif, itm_long_axe, itm_short_imperial_bow, itm_spak_bow8_arrow, itm_bodkin_arrows], 
attrlev(21,15,8,6,23), wpex(220,220,220,210,80,140), strsk(6,5,3,6)|agisk(6,4,6,0,0)|lordsk1(3,3,1,2,0,3,3,2)|lordsk2(0,0,0,1,0,2,0,1), nofa1, nofa2], 
["k09_val_heavybogirre", "Valahir Heavy Bogirre", "Valahir Heavy Bogirre", tf_guarantee_archer, 0,0, fac_kingdom_9, [itm_banded_armor, itm_nordic_huscarl_helmet, itm_splinted_greaves_spurs, itm_wisby_gauntlets_black, itm_varangian_axe, itm_imperial_bow_3, itm_spak_bow8_arrow, itm_bodkin_arrows], 
attrlev(25,18,9,7,30), wpex(280,280,280,270,90,155), strsk(7,7,4,7)|agisk(7,4,7,0,0)|lordsk1(3,4,2,3,1,3,4,3)|lordsk2(0,0,0,2,0,2,0,1), nofa1, nofa2], 
["k09_val_ullr", "Valahir Ullr", "Valahir Ullar", tf_guarantee_archer, 0,0, fac_kingdom_9, [itm_armor_23, itm_nordic_warlord_helmet, itm_mail_mittens, itm_mail_boots, itm_battle_axe_c, itm_imperial_bow_1, itm_1steel_arrow, itm_3steel_arrow], 
attrlev(30,21,10,8,40), wpex(350,350,350,350,100,175), strsk(9,8,5,8)|agisk(8,5,8,0,0)|lordsk1(3,5,2,4,1,4,4,3)|lordsk2(0,0,0,2,0,3,0,2), nofa1, nofa2], 
#Valahir Extras
["k09_val_messenger","Valahir Messenger","Valahir Messengers",tf_guarantee_all,0,0,fac_kingdom_9, [itm_rough_mail_spiked, itm_nordic_archer_helmet, itm_leather_gloves, itm_leather_boots, itm_courser, itm_ad_viking_shield_round_07, itm_sword_viking_1], 
attrlev(20,18,9,6,20), wp(150), strsk(4,4,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), nofa1, nofa2], 
["k09_val_pg","Prison Guard", "Prison Guards", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_cuir_bouilli, itm_nordic_helmet, itm_splinted_leather_greaves, itm_mail_mittens, itm_ad_viking_shield_round_08, itm_mackie_varangian_axe, itm_throwing_axes], 
attrlev(25,13,8,8,25), wp(240), strsk(7,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), nofa1, nofa2], 
["k09_val_cg","Castle Guard", "Castle Guards", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_dejawolf_vikingbyrnie, itm_nordic_huscarl_helmet, itm_mail_mittens, itm_iron_greaves, itm_rohirrim_long_hafted_axe, itm_ad_viking_shield_round_10, itm_rohirrim_throwing_axe], 
attrlev(28,14,10,8,30), wp(280), strsk(8,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), nofa1, nofa2], 
#Valahir Nobles
["k09_val_n_thegn", "Valahir Thegn", "Valahir Thegns", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_new_cuir_bouilli, itm_iron_greaves, itm_helmet_w_eyeguard_new_alt, itm_mail_mittens, itm_sword_viking_3_small, itm_ad_viking_shield_round_10, itm_rohirrim_throwing_axe], 
attrlev(25,19,11,11,27), wpex(260,260,240,200,100,240), strsk(8,7,6,5)|agisk(7,7,4,2,0)|lordsk1(3,1,4,2,1,2,2,2)|lordsk2(0,0,0,2,1,2,2,1), nofa1, nofa2], 
["k09_val_n_jarl", "Valahir Jarl", "Valahir Jarls", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_marmont_armor, itm_nordic_warlord_helmet, itm_dorn_spearbearer_boots, itm_dark_mail_mittens, itm_sword_viking_a_long, itm_tab_shield_round_d, itm_rohirrim_throwing_axe, itm_imperial_bow_1, itm_1steel_arrow], 
attrlev(33,24,13,13,38), wpex(400,400,380,350,150,380), strsk(10,10,9,9)|agisk(10,9,6,3,0)|lordsk1(4,2,6,3,3,3,4,4)|lordsk2(0,0,0,3,2,4,3,2), nofa1, nofa2], 
["k09_val_n_asbjarl", "Valahir Asbjarl", "Valahir Asbjarls", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_huscarl_armour_dark, itm_otk_shlem, itm_west_pikeman_boots, itm_gauntlets, itm_sword_valirian_a, itm_tab_shield_round_e, itm_rohirrim_throwing_axe, itm_imperial_bow, itm_scull_arrow, itm_scull_arrow], 
attrlev(42,31,16,21,56), wpex(520,520,520,450,250,500), strsk(10,10,10,10)|agisk(10,10,9,5,0)|lordsk1(4,4,6,4,6,4,4,4)|lordsk2(0,0,0,4,4,4,6,4), nofa1, nofa2], 
#Valahir Household
["k09_val_n_vanadis", "Valahir Vanadis", "Valahir Vanadis", tf_female|tf_guarantee_allnoranged, 0,0, fac_kingdom_9, [itm_xenoargh_new_female_armor_blue04, itm_dejawolf_valgarde_helm, itm_splinted_greaves_spurs, itm_mail_mittens, itm_boar_rideable, itm_ad_viking_shield_round_14, itm_ad_viking_shield_round_12, itm_lui_knightaxeonehe], 
attrlev(30,25,12,10,40), wpex(400,400,350,100,100,100), strsk(8,9,3,3)|agisk(8,7,3,7,4)|lordsk1(2,2,3,5,1,3,2,2)|lordsk2(0,0,0,0,1,2,1,2), refugee_face1, refugee_face2], 
["k09_val_n_rekkr", "Valahir Rekkr", "Valahir Rekkrs", tf_guarantee_inf|tf_guarantee_polearm, 0,0, fac_kingdom_9, [itm_dejawolf_valgarde_helm, itm_dejawolf_vikingbyrnie, itm_mail_mittens, itm_mail_boots, itm_halfj9], 
attrlev(29,19,9,9,38), wpex(325,325,375,150,75,150), strsk(9,8,5,5)|agisk(8,0,7,0,0)|lordsk1(2,0,1,2,1,1,2,1)|lordsk2(0,0,0,0,0,2,0,1), nofa1, nofa2], 
["k09_val_n_berserker", "Valahir Berserker", "Valahir Berserkers", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_bers_armor, itm_bers_helm, itm_dorn_spearbearer_boots, itm_dorn_knight_gant, itm_sword_valirian_a], 
attrlev(44,28,8,14,60), wpex(480,500,480,160,120,300), strsk(10,10,8,7)|agisk(10,4,8,0,0)|lordsk1(4,1,4,1,1,2,4,3)|lordsk2(0,0,0,0,0,4,1,0), nofa1, nofa2], 
["k09_val_n_vethouscarl", "Valahir Veteran Huskarl", "Valahir Veteran Huskarle", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_heraldic_tunic_new, itm_2kettle_hat_new, itm_splinted_leather_greaves, itm_beargauntlets, itm_gothic_battle_axe_no1, itm_tab_shield_round_e], 
attrlev(38,22,9,11,46), wpex(480,480,400,180,120,450), strsk(10,10,9,7)|agisk(10,10,7,0,0)|lordsk1(4,2,6,3,3,3,4,4)|lordsk2(0,0,1,3,1,4,2,1), nofa1, nofa2], 
#Valahir Mercenaries
["k09_val_m_mercvarangian", "Valahir Mercenary Varangian", "Valahir Mercenary Varangians", tf_guarantee_inf, 0,0, fac_kingdom_9, [itm_novici_templar, itm_nordic_veteran_archer_helmet, itm_splinted_greaves, itm_leather_gloves, itm_varangian_axe, itm_mackie_varangian_axe, itm_leather_covered_round_shield], 
attrlev(27,19,7,7,24), wpex(290,290,150,100,100,150), strsk(8,7,4,3)|agisk(7,6,7,0,0)|lordsk1(3,1,2,2,0,2,2,1)|lordsk2(0,0,0,1,1,2,0,1), nofa1, nofa2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Kaikoth Confederation
["k10_kai_miner", "Kaikoth Miner", "Kaikoth Miners", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_civilian_2_red, itm_dwarf_civilian_2_blue, itm_dwarf_helm_l, itm_rus_shoes, itm_dark_mail_mittens, itm_dwarf_adz, itm_dwarf_shield_f, itm_dwarf_shield_d], 
attrlev(18,6,6,5,7), wpex(100,100,100,60,70,70), strsk(3,1,1,0)|agisk(2,2,2,0,0)|lordsk1(0,0,0,0,1,0,1,2)|lordsk2(0,0,0,1,0,0,0,1), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_clansman", "Kaikoth Clansman", "Kaikoth Clansmen", tf_dwarf_male|tf_guarantee_all, 0,0, fac_kingdom_10, [itm_dwarf_armor_1a, itm_dwarf_helm_c, itm_mail_boots, itm_dwarf_glove_2, itm_rrr_hammer1, itm_dwarf_shield_a], 
attrlev(21,9,8,8,15), wpex(140,140,140,90,100,100), strsk(4,3,2,1)|agisk(3,4,3,0,0)|lordsk1(0,0,0,0,2,0,1,3)|lordsk2(0,0,0,2,1,1,0,2), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_footman", "Kaikoth Footman", "Kaikoth Footmen", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_4_b, itm_dwarf_er_helm_4, itm_mail_boots, itm_dorn_knight_gant, itm_dwarf_hammer_4, itm_dwarf_shield_6c], 
attrlev(26,11,9,9,24), wpex(200,200,200,150,150,180), strsk(6,5,4,3)|agisk(5,6,5,0,0)|lordsk1(0,0,1,0,3,0,1,3)|lordsk2(0,0,0,3,1,2,0,2), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_halberdier", "Kaikoth Halberdier", "Kaikoth Halberdiers", tf_dwarf_male|tf_guarantee_all, 0,0, fac_kingdom_10, [itm_dwarf_armor_8_c, itm_dwarf_er_helm_4, itm_west_pikeman_boots, itm_dwarf_glove, itm_luc_english_polehammer, itm_luc_lucerne_hammer], 
attrlev(34,14,10,11,34), wpex(260,260,280,180,180,200), strsk(8,8,6,5)|agisk(7,7,7,0,0)|lordsk1(0,0,2,0,5,0,2,3)|lordsk2(0,0,0,3,2,2,0,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_elite_halberdier", "Kaikoth Elite Halberdier", "Kaikoth Elite Halberdiers", tf_dwarf_male|tf_guarantee_all, 0,0, fac_kingdom_10, [itm_j_surcoat_orn_13a_dwarf, itm_dwarf_helm_o, itm_west_pikeman_boots, itm_dorn_knight_gant, itm_luc_flemish_halberd, itm_luc_poleaxe_m], 
attrlev(41,16,11,14,46), wpex(320,320,360,200,200,240), strsk(10,9,7,6)|agisk(9,7,8,0,0)|lordsk1(0,0,3,0,7,1,3,4)|lordsk2(0,0,0,3,2,3,1,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_warrior", "Kaikoth Warrior", "Kaikoth Warriors", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_5, itm_dwarf_er_helm_2b, itm_iron_greaves, itm_dorn_knight_gant, itm_dwarf_hammer_3, itm_dwarf_shield_5a], 
attrlev(32,13,10,11,34), wpex(265,265,250,200,200,250), strsk(8,7,5,5)|agisk(7,8,7,0,0)|lordsk1(0,0,2,0,4,0,2,3)|lordsk2(0,0,0,3,2,2,0,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_mountainwarrior", "Kaikoth Mountain Warrior", "Kaikoth Mountain Warriors", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_6, itm_dwarf_helm_f, itm_west_pikeman_boots, itm_dwarf_glove, itm_dwarf_er_th_axe_1], 
attrlev(38,15,11,15,42), wpex(320,320,300,225,225,300), strsk(9,8,7,6)|agisk(8,8,8,0,0)|lordsk1(0,0,4,0,6,0,2,4)|lordsk2(0,0,0,4,2,3,1,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_mountainkeeper", "Kaikoth Mountain Keeper", "Kaikoth Mountain Keepers", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_west_guardsman_dark_dwarf, itm_inf_t4_dark, itm_black_boot_salad_of, itm_glovesblack, itm_nord_clan_axe], 
attrlev(46,18,13,22,58), wpex(400,420,400,250,250,400), strsk(11,11,9,7)|agisk(10,9,10,0,0)|lordsk1(0,0,7,0,9,0,2,4)|lordsk2(0,0,0,4,3,3,3,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_ironguardsman", "Kaikoth Iron Guardsman", "Kaikoth Iron Guardsmen", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarven_scalemail, itm_inf_t4, itm_west_pikeman_boots, itm_dorn_knight_gant, itm_dwarf_th_hammer_1, itm_gaap_heavy_shield2_dwarf, itm_luc_throwing_hammer, itm_luc_throwing_hammer, itm_luc_throwing_hammer], 
attrlev(45,17,12,20,55), wpex(420,400,400,250,250,420), strsk(12,11,10,7)|agisk(10,10,9,0,0)|lordsk1(0,0,4,0,7,0,4,4)|lordsk2(0,0,2,4,2,4,0,2), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_elitescout", "Kaikoth Elite Scout", "Kaikoth Elite Scouts", tf_dwarf_male|tf_guarantee_all, 0,0, fac_kingdom_10, [itm_dwarf_scalemail, itm_act_dwarven_archer_helmet_t2, itm_west_pikeman_boots, itm_mail_mittens, itm_arhar_1, itm_luc_horseman_pick, itm_dwarf_hammer_4, itm_dwarf_shield_g, itm_dwarf_horn_bow, itm_1steel_arrow], 
attrlev(34,19,14,13,42), wpex(310,300,300,310,250,250), strsk(8,8,6,8)|agisk(8,8,7,6,7)|lordsk1(1,5,2,3,7,3,4,4)|lordsk2(0,0,0,3,2,2,0,3), kaikoth_male_faces_safebeard_begin, kaikoth_male_faces_safebeard_end], 
["k10_kai_highlandcrossbowman", "Kaikoth Highland Crossbowman", "Kaikoth Highland Crossbowmen", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_kingdom_10, [itm_dwarf_armor_1b, itm_dwarf_helm_e, itm_splinted_leather_greaves, itm_dwarf_glove_2, itm_luc_knightaxeoneh, itm_dwarf_shield_d, itm_crossbow, itm_bolts], 
attrlev(25,12,9,10,23), wpex(180,180,180,130,180,140), strsk(5,5,3,3)|agisk(4,5,4,0,0)|lordsk1(0,1,0,1,3,1,2,3)|lordsk2(0,0,0,3,1,2,0,3), kaikoth_male_faces_safebeard_begin, kaikoth_male_faces_safebeard_end], 
["k10_kai_seeker", "Kaikoth Seeker", "Kaikoth Seekers", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_kingdom_10, [itm_dwarf_armor_4_c, itm_dwarf_helm_d, itm_mail_boots, itm_dwarf_glove_2, itm_knights_war_axe_1h, itm_dwarf_shield_k, itm_spak_crsb01, itm_steel_bolts], 
attrlev(30,15,11,13,33), wpex(250,230,230,170,260,170), strsk(7,6,5,5)|agisk(6,6,6,0,0)|lordsk1(0,2,0,3,4,2,3,3)|lordsk2(0,0,0,4,2,2,0,3), kaikoth_male_faces_safebeard_begin, kaikoth_male_faces_safebeard_end], 
["k10_kai_highseeker", "Kaikoth High Seeker", "Kaikoth High Seekers", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_kingdom_10, [itm_dwarf_armor_2, itm_dwarf_helm_p, itm_dorn_knight_boots, itm_dwarf_glove, itm_dwarf_axe_3, itm_dwarf_shield_4c, itm_sniper_crossbow, itm_akbolt_b], 
attrlev(36,19,14,18,44), wpex(320,280,280,220,350,220), strsk(9,8,6,6)|agisk(8,8,8,0,0)|lordsk1(0,2,2,4,6,3,5,4)|lordsk2(0,0,0,4,2,3,0,4), kaikoth_male_faces_safebeard_begin, kaikoth_male_faces_safebeard_end], 
#Kaikoth Extras
["k10_kai_messenger","Kaikoth Messenger","Kaikoth Messengers",tf_dwarf_male|tf_guarantee_all,0,0,fac_kingdom_10, [itm_dwarf_civilian_3_c, itm_leather_boots_dark, itm_gondor_bracer_l, itm_arhar_1, itm_dwarf_sword_red, itm_dwarf_shield_f], 
attrlev(18,6,6,5,8), wpex(100,100,100,60,70,70), strsk(3,1,1,0)|agisk(2,2,2,7,0)|lordsk2(0,0,0,0,4,0,0,0), kaikoth_male_faces_begin,kaikoth_male_faces_end], 
["k10_kai_pg", "Prison Guard", "Prison Guards", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_kingdom_10, [itm_dwarf_armor_4_b, itm_dwarf_er_helm_4, itm_mail_boots, itm_dorn_knight_gant, itm_dwarf_sword_red, itm_dwarf_shield_6c], 
attrlev(26,11,9,9,23), wpex(200,200,200,150,150,180), strsk(6,5,4,3)|agisk(5,6,5,0,0)|lordsk2(0,0,0,0,0,5,0,0), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_cg", "Castle Guard", "Castle Guards", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_kingdom_10, [itm_dwarf_armor_5, itm_dwarf_er_helm_2b, itm_iron_greaves, itm_dorn_knight_gant, itm_dwarf_hammer_3, itm_dwarf_shield_5a], 
attrlev(32,13,10,11,33), wpex(265,265,250,200,200,250), strsk(8,7,5,5)|agisk(7,8,7,0,0)|lordsk2(0,0,0,0,0,5,0,0), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
#Kaikoth Nobles
["k10_kai_n_ironfist", "Kaikoth Ironfist", "Kaikoth Ironfists", tf_dwarf_male|tf_guarantee_allnoranged, 0,0, fac_kingdom_10, [itm_dwarf_armor_8_a, itm_dwarf_er_helm_2b, itm_dorn_knight_boots, itm_dwarf_glove_2, itm_arhar_armor_2, itm_sarranid_two_handed_axe_b, itm_dwarf_shield_i, itm_lance_lev1], 
attrlev(33,18,14,20,33), wpex(250,250,250,160,180,200), strsk(7,6,5,5)|agisk(6,6,4,8,0)|lordsk1(0,0,2,0,5,0,1,3)|lordsk2(0,0,0,3,2,2,3,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_n_vanguard", "Kaikoth Vanguard", "Kaikoth Vanguards", tf_dwarf_male|tf_guarantee_allnoranged, 0,0, fac_kingdom_10, [itm_dwarf_armor_9b, itm_dwarf_ih_helm_3, itm_plate_boots2, itm_dwarf_glove, itm_arhar_armor_2, itm_dwarf_war_mattok_1, itm_dwarf_ih_shield_1c], 
attrlev(45,22,18,30,60), wpex(380,380,350,200,240,280), strsk(10,10,8,7)|agisk(10,10,6,10,0)|lordsk1(0,0,4,0,8,1,2,4)|lordsk2(0,0,0,4,3,3,6,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
#Kaikoth Household
["k10_kai_n_elderseeker", "Kaikoth Elder Seeker", "Kaikoth Elder Seekers", tf_dwarf_male|tf_guarantee_all, 0,0, fac_kingdom_10, [itm_dwarf_armor_9a, itm_dwarf_ih_helm_3, itm_plate_boots2, itm_dwarf_glove_2, itm_arhar_armor_2, itm_dwarf_axe_3, itm_dwarf_shield_4c, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt], 
attrlev(42,24,22,28,50), wpex(400,350,350,300,450,250), strsk(10,10,7,8)|agisk(10,9,8,10,10)|lordsk1(1,4,3,4,10,7,4,4)|lordsk2(0,0,0,3,3,2,4,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_n_steroid_dwarf", "Kaikoth Dreagrd", "Kaikoth Dreagrds", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_kuyak_a_dwarf, itm_dwarf_helm_h, itm_mail_chausses_shin_guard, itm_dorn_knight_gant, itm_mackie_pendulum], 
attrlev(48,25,10,16,58), wpex(350,400,400,100,100,250), strsk(13,12,10,7)|agisk(10,4,10,0,0)|lordsk1(0,0,0,0,0,0,2,1)|lordsk2(0,0,0,0,0,1,0,0), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_n_smith", "Kaikoth Smith", "Kaikoth Smiths", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_5_a, itm_dwarf_helm_i, itm_shadow_greaves, itm_dorn_knight_gant, itm_dwarf_th_hammer_1, itm_luc_throwing_hammer, itm_luc_throwing_hammer], 
attrlev(38,14,10,15,44), wpex(280,280,250,100,200,280), strsk(8,8,8,6)|agisk(6,5,4,0,0)|lordsk1(0,0,1,0,4,0,0,4)|lordsk2(0,0,0,8,0,1,0,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k10_kai_n_master_miner", "Kaikoth Master Miner", "Kaikoth Master Miner", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_rough_ring_leather_dwarf, itm_pino_tunic_mail_spiked_dwarf, itm_dwarf_helm_m, itm_dwarf_helm_g, itm_splinted_leather_greaves, itm_dark_mail_mittens, itm_dwarf_great_mattock, itm_dwarf_shield_l], 
attrlev(28,10,9,8,20), wpex(180,180,180,90,100,130), strsk(6,6,5,3)|agisk(4,4,4,0,0)|lordsk1(0,0,1,0,2,0,2,3)|lordsk2(0,0,0,3,1,1,1,3), kaikoth_male_faces_safebeard_begin, kaikoth_male_faces_safebeard_end], 
["k10_kai_n_foreman", "Kaikoth Foreman", "Kaikoth Foremen", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_5, itm_dwarf_helm_n, itm_west_pikeman_boots, itm_mail_mittens, itm_dwarf_great_pick, itm_dwarf_war_pick], 
attrlev(37,14,14,15,40), wpex(300,300,300,120,160,200), strsk(9,9,8,5)|agisk(6,5,6,0,0)|lordsk1(0,0,2,0,4,0,3,4)|lordsk2(0,0,0,4,3,2,5,4), kaikoth_male_faces_begin, kaikoth_male_faces_end],  
#fakes for custom templates
["k10_kai_harunn_warrior", "Kaikoth Warrior", "Kaikoth Warriors", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_kingdom_10, [itm_dwarf_armor_5, itm_dwarf_er_helm_2b, itm_iron_greaves, itm_dorn_knight_gant, itm_dwarf_hammer_3, itm_dwarf_shield_5a], 
attrlev(32,13,10,11,32), wpex(265,265,250,200,200,250), strsk(8,7,5,5)|agisk(7,8,7,0,0)|lordsk1(0,0,2,0,4,0,2,3)|lordsk2(0,0,0,3,2,2,0,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Geldarin Elves
["k11_gel_recruit", "Geldarin Recruit", "Geldarin Recruits", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_ao_vai_2_x, itm_civil_rich_boots_b, itm_gondor_bracer_l, itm_shortened_military_scythe, itm_short_bow, itm_arrows], 
attrlev(11,13,11,13,8), wpex(140,140,120,160,70,70), strsk(2,2,1,3)|agisk(3,0,2,0,0)|lordsk1(0,1,0,0,0,1,1,1)|lordsk2(1,0,1,0,1,1,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_woodbowman", "Geldarin Woodland Bowman", "Geldarin Woodland Bowmen", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_arab_bandit_c, itm_civil_rich_boots_b, itm_gauntlets_arabs_a_l, itm_simple_ench, itm_wood_elven_blade, itm_lorien_sword_b, itm_riv_bow, itm_spak_arrow], 
attrlev(14,16,13,15,16), wpex(190,190,180,210,75,75), strsk(3,3,2,4)|agisk(5,1,3,1,1)|lordsk1(1,2,0,1,1,2,2,2)|lordsk2(2,0,1,0,1,2,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_woodarcher", "Geldarin Woodland Archer", "Geldarin Woodland Archers", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_armour_vale, itm_civil_rich_boots_b, itm_gondor_bracer_l, itm_soldiers_ench, itm_2scimitar_bluesilver, itm_warblade_black01, itm_whitewoodbow, itm_spak_arrow], 
attrlev(18,19,15,16,24), wpex(240,240,220,260,80,80), strsk(4,5,3,5)|agisk(6,2,4,2,2)|lordsk1(1,2,1,2,2,2,3,2)|lordsk2(2,1,2,0,2,2,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_bordersentinel", "Geldarin Border Sentinel", "Geldarin Border Sentinels", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_riverlands_freylight, itm_civil_rich_boots_b, itm_stark_hood, itm_gondor_bracer_l, itm_wood_elven_knife, itm_riv_bow, itm_blackarrow], 
attrlev(22,23,16,16,30), wpex(360,330,330,360,100,100), strsk(5,6,3,7)|agisk(7,2,7,4,4)|lordsk1(1,3,1,4,5,4,6,2)|lordsk2(2,3,3,0,2,3,0,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_sergeant","Geldarin Sergeant","Geldarin Sergeants", tf_elven_male|tf_guarantee_archer,0,0,fac_kingdom_11, [itm_riv_armor_m_archer, itm_rus_splint_greaves, itm_gauntlets_arabs_a_l, itm_fine_ench, itm_lorien_sword_hand_and_half, itm_skywoodbow, itm_spak_arrow], 
attrlev(23,22,17,18,33), wpex(320,320,300,330,85,85), strsk(6,6,4,6)|agisk(7,3,5,3,3)|lordsk1(2,3,2,2,3,3,3,3)|lordsk2(3,1,3,1,2,3,0,0), elintoran_face_young_begin,elintoran_face_young_end], 
["k11_gel_blademaster", "Geldarin Blademaster", "Geldarin Blademasters", tf_elven_male|tf_guarantee_inf, 0,0, fac_kingdom_11, [itm_rivend_rohir_armor_1a, itm_rivend_helmet_2a, itm_riv_boots, itm_cwe_king_gloves, itm_sabre_cloud, itm_rivend_shield_1], 
attrlev(28,25,18,21,40), wpex(425,425,400,380,90,100), strsk(7,8,5,7)|agisk(9,7,7,3,3)|lordsk1(2,3,5,2,4,3,4,3)|lordsk2(3,1,3,2,3,4,1,1), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_ranger", "Geldarin Ranger", "Geldarin Rangers", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_riv_armor_h_archer, itm_mail_chausses_shin_guard, itm_gondor_bracer_l, itm_noble_ench, itm_sabre_cloud, itm_skywoodbow, itm_spak_arrow], 
attrlev(27,24,19,21,42), wpex(400,400,380,400,90,90), strsk(7,7,5,8)|agisk(8,3,6,4,4)|lordsk1(2,4,3,3,4,3,4,3)|lordsk2(3,2,4,1,3,3,1,1), elintoran_face_young_begin,elintoran_face_young_end], 
["k11_gel_forestwarden","Geldarin Forest Warden","Geldarin Forest Wardens", tf_elven_male|tf_guarantee_all,0,0,fac_kingdom_11, [itm_riv_armor_leader, itm_barbuta2_1, itm_gondor_bracer_l, itm_riv_boots, itm_blue_warhorse, itm_elvish_sword, itm_saracin_shield_d, itm_imperial_bow, itm_blackarrow], 
attrlev(32,26,22,26,60), wpex(470,470,450,470,100,100), strsk(8,9,6,9)|agisk(10,6,6,8,8)|lordsk1(2,4,3,7,6,7,7,3)|lordsk2(4,2,4,1,3,3,1,1), elintoran_face_old_begin,elintoran_face_old_end], 
["k11_gel_footknight", "Geldarin Foot Knight", "Geldarin Foot Knights", tf_elven_male|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_riv_armor_leader, itm_shadow_greaves, itm_wisby_gauntlets_black, itm_royal_ench, itm_sabre_ebony, itm_ebonybow, itm_spak_arrow], 
attrlev(34,27,21,25,56), wpex(500,500,500,480,100,100), strsk(9,9,6,10)|agisk(10,4,7,5,5)|lordsk1(2,6,4,4,6,4,6,4)|lordsk2(4,3,4,2,3,3,3,1), elintoran_face_old_begin, elintoran_face_old_end], 
#Geldarin Extras
["k11_gel_messenger","Geldarin Messenger","Geldarin Messengers", tf_elven_male|tf_guarantee_all,0,0,fac_kingdom_11, [itm_lorien_archer, itm_leather_boots, itm_leather_gloves, itm_courser, itm_lorien_sword_b, itm_short_bow, itm_arrows], 
attrlev(16,18,12,6,20), wp(200), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), elintoran_face_young_begin,elintoran_face_young_end], 
["k11_gel_pg","Prison Guard","Prison Guards", tf_elven_male|tf_guarantee_archer, 0, 0, fac_kingdom_11, [itm_riv_armor_h_archer, itm_rus_splint_greaves, itm_gondor_bracer_l, itm_soldiers_ench, itm_2scimitar_bluesilver, itm_riv_bow, itm_spak_arrow], 
attrlev(22,16,18,14,30), wp(275), strsk(5,5,0,6)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_young_begin, elintoran_face_young_end], 
["k11_gel_cg","Castle Guard","Castle Guards", tf_elven_male|tf_guarantee_archer, 0, 0, fac_kingdom_11, [itm_riv_armor_leader, itm_riv_boots, itm_wisby_gauntlets_black, itm_noble_ench, itm_sabre_cloud, itm_skywoodbow, itm_spak_arrow], 
attrlev(27,19,20,18,40), wp(320), strsk(6,6,0,8)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), elintoran_face_old_begin, elintoran_face_old_end], 
#Geldarin Nobles
["k11_gel_n_noble","Geldarin Noble","Geldarin Nobles", tf_elven_male|tf_guarantee_allnoranged,0,0,fac_kingdom_11, [itm_mail_and_plate, itm_shadow_greaves, itm_gondor_bracer_l, itm_noble_ench, itm_lorien_sword_a, itm_lorien_round_shield, itm_horse_tyrk_e], 
attrlev(22,18,20,24,32), wpex(300,300,250,270,80,80), strsk(6,6,3,6)|agisk(7,6,4,6,6)|lordsk1(1,3,2,2,4,3,3,3)|lordsk2(3,3,3,1,3,1,4,1), elintoran_face_young_begin,elintoran_face_young_end], 
["k11_gel_n_duke", "Geldarin Duke", "Geldarin Dukes", tf_guarantee_allnoranged|tf_elven_male, 0,0, fac_kingdom_11, [itm_rivendellrewardarmour, itm_dorn_knight_boots, itm_new_gauntlets_b, itm_royal_ench, itm_saracin_shield_d, itm_elvish_sword, itm_blue_warhorse], 
attrlev(33,26,30,35,65), wpex(520,520,500,500,100,100), strsk(9,9,5,9)|agisk(10,9,5,9,9)|lordsk1(1,4,4,3,7,4,4,4)|lordsk2(4,4,4,2,4,2,7,2), elintoran_face_old_begin, elintoran_face_old_end], 
#Geldarin Household
["k11_gel_n_honorguard", "Geldarin Honor Guard", "Geldarin Honor Guards", tf_elven_male|tf_guarantee_inf, 0,0, fac_kingdom_11, [itm_rivendellrewardarmour, itm_crusader_knight_helm_f, itm_new_gauntlets_b, itm_riv_boots, itm_winged_sword], 
attrlev(36,28,20,24,60), wpex(530,530,500,400,150,150), strsk(10,9,6,9)|agisk(10,5,6,0,0)|lordsk1(1,2,6,3,6,3,4,3)|lordsk2(3,3,3,1,3,4,2,0), elintoran_face_old_begin, elintoran_face_old_end], 
["k11_gel_n_silverwidow", "Geldarin Silver Widow", "Geldarin Silver Widows", tf_elven_female|tf_guarantee_archer, 0,0, fac_kingdom_11, [itm_cuir_bouilli_sil, itm_rivend_helmet_2a, itm_riv_boots, itm_cwe_king_gloves, itm_sabre_val_1, itm_rivend_shield_1, itm_skywoodbow, itm_spak_arrow], 
attrlev(25,32,21,27,45), wpex(425,380,380,450,125,125), strsk(5,7,5,8)|agisk(9,8,8,6,6)|lordsk1(0,4,1,4,7,4,4,4)|lordsk2(6,3,6,2,4,3,1,4), elintoran_face_female_start, elintoran_face_female_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Cretas
["k12_cre_rabble", "Cretasan Rabble", "Cretasan Rabble", tf_guarantee_armor|tf_guarantee_helmet, 0, 0, fac_kingdom_12, [itm_padded_cloth, itm_linen_tunic, itm_padded_jack, itm_woolen_hose, itm_white_hose, itm_hide_boots, itm_shortened_spear, itm_h_spear, itm_spear], 
attrlev(9,6,7,6,4), wpex(60,60,105,60,60,70), strsk(2,2,1,1)|agisk(1,1,2,0,0)|lordsk1(2,1,0,0,1,1,0,0)|lordsk2(0,0,0,0,0,1,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k12_cre_levy", "Cretasan Levy", "Cretasan Levies", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_shield|tf_guarantee_helmet, 0, 0, fac_kingdom_12, [itm_aketon_green, itm_white_hose, itm_leather_gloves, itm_arming_cap, itm_spear, itm_h_spear], 
attrlev(12,9,8,6,9), wpex(75,75,155,75,75,90), strsk(3,4,2,2)|agisk(2,2,2,0,0)|lordsk1(2,1,1,1,2,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_old_2], 
["k12_cre_vigil", "Cretasan Vigil", "Cretasan Vigils", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_shield|tf_guarantee_helmet|tf_guarantee_gloves, 0, 0, fac_kingdom_12, [itm_norman_helmet, itm_lamellar_vest, itm_leather_gloves, itm_leather_boots, itm_war_spear], 
attrlev(16,12,9,7,16), wpex(100,100,240,80,80,90), strsk(4,6,3,3)|agisk(4,3,3,0,0)|lordsk1(2,1,1,1,3,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_old_2], 
["k12_cre_defender", "Cretasan Defender", "Cretasan Defenders", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_shield|tf_guarantee_gloves, 0, 0, fac_kingdom_12, [itm_rathos_fluted_helmet, itm_early_transitional_white, itm_splinted_greaves_spurs, itm_mail_mittens, itm_awlpike], 
attrlev(20,15,10,8,26), wpex(125,125,320,100,100,175), strsk(5,7,4,4)|agisk(6,4,4,0,0)|lordsk1(2,1,1,1,4,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_young_2], 
["k12_cre_custodian", "Cretasan Custodian", "Cretasan Custodians", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_rathos_11thcent_conicalhelm_store, itm_rathos_surcoat_white, itm_mail_boots, itm_mail_mittens, itm_sword_spear], 
attrlev(25,18,11,10,35), wpex(175,175,400,150,150,250), strsk(7,9,5,5)|agisk(7,5,6,0,0)|lordsk1(2,1,1,1,6,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_young_2], 
["k12_cre_eidolon", "Cretasan Eidolon", "Cretasan Eidolons", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_cretas_full_helm, itm_cretas_brig, itm_plate_boots2, itm_bnw_gauntlets, itm_waorstaffb], 
attrlev(32,21,12,12,42), wpex(230,230,485,180,180,300), strsk(8,10,6,6)|agisk(9,6,7,0,0)|lordsk1(2,1,1,1,8,1,1,1)|lordsk2(0,0,0,1,0,2,6,0), swadian_face_young_1, swadian_face_young_2], 
["k12_cre_warden", "Cretasan Warden", "Cretasan Wardens", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_maciejowski_helmet_new3, itm_early_transitional_white, itm_splinted_greaves_spurs, itm_mail_mittens, itm_german_morningstar, itm_spak_knightsh], 
attrlev(23,13,10,8,24), wpex(280,120,120,100,100,150), strsk(9,5,3,3)|agisk(5,9,3,0,0)|lordsk1(2,1,1,1,4,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_middle_1, swadian_face_old_2], 
["k12_cre_ironclad", "Cretasan Ironclad", "Cretasan Ironclads", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_bolzanobucket, itm_coat_of_plates, itm_black_greaves, itm_bnw_gauntlets, itm_luc_spiked_mace_b, itm_sh_snake], 
attrlev(30,15,11,10,35), wpex(325,150,150,120,120,175), strsk(10,6,4,4)|agisk(6,10,4,0,0)|lordsk1(2,1,1,1,5,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_middle_1, swadian_face_old_2], 
["k12_cre_cavalry", "Cretasan Cavalry", "Cretasan Cavalry", tf_mounted|tf_guarantee_horse|tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_helmet|tf_guarantee_gloves, 0, 0, fac_kingdom_12, [itm_sumpter_horse, itm_rathos_11thcent_conicalhelm_store, itm_mail_mittens, itm_rathos_surcoat_white, itm_mail_boots, itm_heavy_lance, itm_spak_knightsh, itm_german_morningstar], 
attrlev(24,18,11,10,30), wpex(330,300,375,130,130,200), strsk(5,6,4,4)|agisk(7,5,5,4,4)|lordsk1(2,1,1,1,7,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_old_2], 
["k12_cre_eidolonknight", "Cretasan Eidolon Knight", "Cretasan Eidolon Knights", tf_mounted|tf_guarantee_all, 0, 0, fac_kingdom_12, [itm_cretas_brig, itm_plate_boots2, itm_bnw_gauntlets, itm_cretas_full_helm, itm_waorstaffb, itm_tribal4], 
attrlev(28,21,12,12,42), wpex(400,360,450,180,180,300), strsk(7,8,5,5)|agisk(9,6,6,6,6)|lordsk1(2,1,1,1,8,1,1,1)|lordsk2(0,0,0,1,0,2,6,0), swadian_face_middle_1, swadian_face_older_2], 
["k12_cre_huntsman", "Cretasan Huntsman", "Cretasan Huntsman", tf_guarantee_ranged|tf_guarantee_gloves|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_kingdom_12, [itm_spak_bow6, itm_brown_arrow, itm_brown_arrow, itm_lamellar_vest, itm_leather_boots, itm_leather_gloves, itm_shortened_spear], 
attrlev(14,12,9,8,13), wpex(100,100,150,200,100,125), strsk(3,4,2,5)|agisk(6,2,5,0,1)|lordsk1(2,1,1,1,3,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_middle_1, swadian_face_older_2], 
["k12_cre_skilledhuntsman", "Cretasan Skilled Huntsman", "Cretasan Skilled Huntsman", tf_guarantee_ranged|tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_12, [itm_spak_bow6, itm_brown_arrow, itm_brown_arrow, itm_lamellar_vest, itm_leather_boots, itm_leather_gloves, itm_shortened_spear], 
attrlev(18,15,10,9,24), wpex(125,125,250,280,100,175), strsk(4,5,3,7)|agisk(8,2,6,0,2)|lordsk1(2,5,1,1,5,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_middle_2], 
["k12_cre_horsehunter", "Cretasan Horsehunter", "Cretasan Horsehunter", tf_guarantee_ranged|tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots, 0, 0, fac_kingdom_12, [itm_cretas_brig, itm_plate_boots2, itm_bnw_gauntlets, itm_sword_spear, itm_latticed_flatbow, itm_brown_arrow, itm_brown_arrow], 
attrlev(22,18,12,10,40), wpex(175,175,300,320,150,250), strsk(5,5,4,9)|agisk(9,3,7,0,3)|lordsk1(2,1,1,6,6,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_middle_1, swadian_face_older_2], 
#Cretas Extras
["k12_cre_messenger", "Cretasan Messenger", "Cretasan Messengers", tf_mounted|tf_guarantee_ranged|tf_guarantee_horse|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots, 0, 0, fac_kingdom_12, [itm_shortened_spear, itm_padded_jack, itm_leather_boots, itm_courser, itm_leather_gloves, itm_new_shortbow, itm_brown_arrow], 
attrlev(12,9,8,6,9), wpex(75,75,155,145,75,90), strsk(3,4,0,3)|agisk(2,2,2,0,0)|lordsk1(2,1,1,1,0,1,1,1)|lordsk2(0,0,0,1,0,2,0,0),swadian_face_young_1,swadian_face_old_2], 
["k12_cre_pg", "Prison Guard", "Prison Guards", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_bolzanobucket, itm_coat_of_plates, itm_black_greaves, itm_bnw_gauntlets, itm_luc_spiked_mace_b, itm_sh_snake], 
attrlev(18,14,14,10,25), wpex(150,150,150,150,150,150), strsk(7,4,3,3)|agisk(3,3,3,0,0)|lordsk1(2,1,1,1,0,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_young_2], 
["k12_cre_cg", "Castle Guard", "Castle Guards", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_12, [itm_cretas_full_helm, itm_cretas_brig, itm_plate_boots2, itm_bnw_gauntlets, itm_waorstaffb], 
attrlev(22,16,16,12,30), wpex(100,100,500,100,100,100), strsk(8,10,4,4)|agisk(9,6,7,0,0)|lordsk1(2,1,1,1,0,1,1,1)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_young_1, swadian_face_young_2], 
# Noble
["k12_cre_n_astylon", "Cretasan Astylon", "Cretasan Astylons", tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_horse|tf_guarantee_shield, 0,0, fac_kingdom_12, [itm_cretas_brig, itm_plate_boots2, itm_bnw_gauntlets, itm_sword_spear, itm_throwing_spears, itm_throwing_spears], 
attrlev(32,21,12,12,31), wpex(230,230,400,180,180,485), strsk(8,7,8,4)|agisk(9,6,7,0,0)|lordsk1(2,1,1,1,8,1,1,1)|lordsk2(0,0,0,1,0,2,6,0), swadian_face_young_1, swadian_face_young_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Kuu-lan
["k13_kuu_nomad", "Kuu-lan Nomad", "Kuu-lan Nomads", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_nomad_vest, itm_nomad_cap_b_dark, itm_nomad_boots, itm_sumpter_horse, itm_lucas_nomad_club, itm_nomad_bow, itm_ak_arrows_b], 
attrlev(10,9,6,6,5), wpex(70,90,90,100,30,70), strsk(0,0,1,2)|agisk(1,0,2,2,4)|lordsk1(0,1,0,0,0,0,1,1)|lordsk2(0,0,0,0,0,0,0,1), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_anshi", "Kuu-lan Anshi", "Kuu-lan Anshi", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_ped_padd_lamellar_whitel, itm_nomad_cap, itm_nomad_boots, itm_leather_gloves, itm_steppe_horse, itm_butchering_knife, itm_noldor_bow, itm_arrows, itm_arrows], 
attrlev(12,12,7,7,10), wpex(120,120,120,170,60,120), strsk(1,1,2,4)|agisk(3,0,4,4,6)|lordsk1(1,2,0,1,0,1,1,2)|lordsk2(1,0,0,0,0,1,0,1), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_sadak", "Kuu-lan Sadak", "Kuu-lan Sadaki", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_heavy_armor_arabs_d, itm_helm_saracin_b, itm_hide_boots, itm_leather_gloves, itm_steppe_horse, itm_horsemans_axe_no2, itm_tulgan_bow_kuulan, itm_ebonyornate_arrow, itm_ebonyornate_arrow], 
attrlev(14,16,7,8,18), wpex(180,160,160,250,80,70), strsk(1,2,3,5)|agisk(5,0,5,6,7)|lordsk1(2,3,0,2,1,2,2,2)|lordsk2(1,0,1,0,1,1,0,1), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_atkish", "Kuu-lan Atkish", "Kuu-lan Atkishi", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_lamellar_armor, itm_sarranid_horseman_helmet, itm_splinted_leather_greaves, itm_gondor_bracer_l, itm_horse_bandits_b, itm_horsemans_axe_no3, itm_tulgan_bow_kuulan, itm_ebonyornate_arrow, itm_ebonyornate_arrow], 
attrlev(17,21,8,9,29), wpex(250,220,220,330,120,250), strsk(2,4,5,7)|agisk(6,1,6,8,8)|lordsk1(2,4,0,3,2,3,3,3)|lordsk2(2,0,1,0,1,2,0,2), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_mergen", "Kuu-lan Mergen", "Kuu-lan Mergeni", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_armor_22, itm_vaegir_mask, itm_mail_boots, itm_gondor_bracer_l, itm_hospitaller_knight_horse_a, itm_luc_iron_hand_axe_h, itm_tulgan_bow_kuulan, itm_scull_arrow, itm_scull_arrow], 
attrlev(21,26,10,12,40), wpex(320,280,280,410,160,300), strsk(4,5,7,9)|agisk(8,2,6,9,9)|lordsk1(3,5,0,3,3,4,4,3)|lordsk2(2,0,2,1,2,3,1,3), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_kara_mergen", "Kuu-lan Kara-Mergen", "Kuu-lan Kara-Mergeni", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_wei_xiadi_sarranid_mamluk_armor, itm_litchina_helm, itm_dorn_spearbearer_boots, itm_twilight_gloves, itm_warhorse_sarranid_black, itm_luc_horsemans_axe, itm_imperial_bow_2, itm_scull_arrow, itm_scull_arrow], 
attrlev(26,32,12,17,52), wpex(380,330,330,500,200,360), strsk(6,6,8,10)|agisk(10,3,7,10,10)|lordsk1(4,7,2,4,4,4,6,4)|lordsk2(2,0,2,1,3,4,2,3), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_eren", "Kuu-lan Eren", "Kuu-lan Ereni", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_wei_xiadi_kher_lamellar_vest02, itm_steppe_cap, itm_khergit_leather_boots, itm_leather_gloves, itm_xenoargh_bayappy, itm_spear, itm_leather_covered_round_shield, itm_nomad_bow, itm_khergit_arrows], 
attrlev(13,12,7,7,11), wpex(140,140,160,160,40,120), strsk(1,2,2,4)|agisk(2,1,3,4,5)|lordsk1(0,1,0,1,0,0,1,1)|lordsk2(1,0,0,0,0,1,0,2), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_yasak", "Kuu-lan Yasak", "Kuu-lan Yasaki", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_wei_xiadi_kher_lamellar_vest01, itm_khergit_war_helmet, itm_rus_splint_greaves, itm_gauntlets_arabs_a_l, itm_horse5, itm_sword_khergit_3, itm_luc_cavalry_shield_z, itm_light_lance, itm_tulgan_bow_kuulan, itm_spak_bow8_arrow], 
attrlev(16,16,8,8,19), wpex(210,210,210,220,60,200), strsk(2,4,3,5)|agisk(4,2,4,6,6)|lordsk1(1,2,1,2,1,1,2,2)|lordsk2(1,0,2,0,1,2,0,2), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_aldaspan", "Kuu-lan Aldaspan", "Kuu-lan Aldaspani", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_dorn_heavy_cavalry_armor, itm_sarranid_horseman_helmet, itm_splinted_greaves_spurs, itm_gauntlets_arabs_a_l, itm_horse5, itm_sword_khergit_2, itm_dal_hindum, itm_tulgan_bow_kuulan, itm_spak_ar2], 
attrlev(20,20,9,9,30), wpex(290,290,290,290,100,280), strsk(4,6,5,6)|agisk(6,3,5,7,8)|lordsk1(2,3,1,3,2,2,3,3)|lordsk2(1,0,2,0,1,3,0,3), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_lankes", "Kuu-lan Lankes", "Kuu-lan Lankesi", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_ao_vai_1, itm_shadow_mask, itm_shadow_greaves, itm_gondor_bracer_l, itm_leather_armour_charger1, itm_hooksword_spak, itm_jarid, itm_throwing_spears, itm_war_darts], 
attrlev(24,26,11,9,35), wpex(360,360,350,350,200,400), strsk(5,7,7,7)|agisk(8,3,7,9,10)|lordsk1(2,3,1,5,5,3,4,4)|lordsk2(2,0,3,0,3,3,0,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_ulan", "Kuu-lan Ulan", "Kuu-lan Ulani", tf_guarantee_allnoranged|tf_guarantee_polearm, 0,0, fac_kingdom_13, [itm_wei_xiadi_samurai_armor01, itm_vaegir_mask, itm_dorn_spearbearer_boots, itm_brass_lamellar_gauntlets, itm_warhorse_steppe, itm_sword_khergit_1, itm_dal_hinduh, itm_heavy_lance, itm_heavy_lance, itm_tulgan_bow_kuulan, itm_bronze_arrow], 
attrlev(25,25,10,12,40), wpex(370,370,370,360,140,330), strsk(6,8,6,8)|agisk(8,4,6,9,9)|lordsk1(3,3,2,3,3,3,3,4)|lordsk2(2,0,2,0,2,3,1,3), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_baatur", "Kuu-lan Baatur", "Kuu-lan Baaturi", tf_guarantee_allnoranged, 0,0, fac_kingdom_13, [itm_zabadai_man_armor, itm_litchina_helm, itm_west_pikeman_boots, itm_gauntlets, itm_warhorse_sarranid, itm_luc_knightly_axe, itm_saracin_shield_s], 
attrlev(32,30,12,16,56), wpex(450,450,450,420,160,380), strsk(9,10,8,9)|agisk(10,6,6,10,9)|lordsk1(4,3,4,3,4,3,4,4)|lordsk2(2,0,3,1,3,4,5,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
#Kuu-lan Extras
["k13_kuu_messenger","Kuu-lan Messenger","Perisno Messengers",tf_guarantee_all,0,0,fac_kingdom_13, [itm_wei_xiadi_kher_lamellar_vest02, itm_steppe_cap, itm_khergit_leather_boots, itm_leather_gloves, itm_xenoargh_bayappy, itm_sword_khergit_3, itm_leather_covered_round_shield, itm_nomad_bow, itm_khergit_arrows],
attrlev(14,16,9,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_pg","Prison Guard", "Prison Guards", tf_guarantee_inf, 0, 0, fac_kingdom_13, [itm_lamellar_armor, itm_vaegir_mask, itm_mail_boots, itm_gondor_bracer_l, itm_luc_iron_hand_axe_h, itm_plate_covered_round_shield], 
attrlev(18,14,10,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_cg","Castle Guard", "Castle Guards", tf_guarantee_inf, 0, 0, fac_kingdom_13, [itm_zabadai_man_armor, itm_litchina_helm, itm_west_pikeman_boots, itm_gauntlets, itm_luc_strange_blade, itm_steel_shield], 
attrlev(24,18,12,12,40), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
#Kuu-lan Nobles
["k13_kuu_n_alaman", "Kuu-lan Alaman", "Kuu-lan Alamani", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_khergit_elite_armor, itm_dorn_sand_snakes_helm, itm_splinted_greaves, itm_gloves_lord_l, itm_spakhorse_03, itm_saracen_mace, itm_dal_hindub, itm_tulgan_bow_kuulan, itm_elmwoodquiver_arrow], 
attrlev(19,22,14,14,27), wpex(270,270,200,300,100,250), strsk(3,5,4,6)|agisk(6,4,4,7,8)|lordsk1(2,3,1,2,3,3,3,3)|lordsk2(2,1,2,2,3,2,2,3), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k13_kuu_n_ataman", "Kuu-lan Ataman", "Kuu-lan Atamani", tf_guarantee_all, 0,0, fac_kingdom_13, [itm_vaegir_elite_armor, itm_litchina_gold, itm_dorn_sand_snakes_boots, itm_brass_scale_gauntlets, itm_warhorse_sarranid_brass, itm_luc_bronze_mace, itm_saracin_shield_y, itm_hangong, itm_song_arrows], 
attrlev(29,32,16,23,54), wpex(400,400,340,440,180,340), strsk(7,8,7,9)|agisk(8,6,6,9,10)|lordsk1(4,4,3,4,5,4,4,4)|lordsk2(3,2,3,5,4,4,4,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
#Kuu-lan Household
["k13_kuu_n_manaatch", "Kuu-lan Manaatch", "Kuu-lan Manaatchi", tf_guarantee_all|tf_guarantee_polearm, 0,0, fac_kingdom_13, [itm_khergit_guard_armor, itm_dorn_sand_snakes_helm, itm_khergit_guard_boots, itm_brass_scale_gauntlets, itm_ak_warhorse_chain_a, itm_lui_knightaxeonehd, itm_dal_muslimj, itm_bamboo_lance], 
attrlev(27,30,13,15,40), wpex(380,340,380,300,140,300), strsk(8,8,7,7)|agisk(8,6,5,8,5)|lordsk1(2,2,1,3,3,3,4,4)|lordsk2(4,2,4,1,3,4,1,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Bakhal 
["k14_bak_villager", "Bakhal Villager", "Bakhal Villagers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giants_grey_pants, itm_club_with_spike_head, itm_smallaxe_marauder_recruit_b_01], 
attrlev(26,9,5,6,7), wpex(110,110,100,80,50,100), strsk(5,3,2,2)|agisk(2,1,3,0,0)|lordsk1(1,0,0,0,0,0,1,0)|lordsk2(0,0,0,0,0,1,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_footman", "Bakhal Footman", "Bakhal Footmen", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_in_karnoth_mine, itm_giant_helmet_bakhal, itm_giant_grey_boots, itm_two_handed_battle_axe_2, itm_javelin], 
attrlev(31,11,5,7,15), wpex(150,150,140,100,60,150), strsk(7,5,4,3)|agisk(4,2,4,0,0)|lordsk1(2,0,1,0,0,0,1,1)|lordsk2(0,0,0,0,0,2,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_soldier", "Bakhal Soldier", "Bakhal Soldiers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_plate_armor_bakhal, itm_spiked_bakhal_helmet, itm_giant_gr_boots_knee_01, itm_sut_two_handed_axe, itm_javelin, itm_jarid], 
attrlev(38,13,6,8,26), wpex(210,210,180,120,70,200), strsk(9,8,7,5)|agisk(6,3,6,0,0)|lordsk1(3,0,2,0,0,0,1,1)|lordsk2(0,0,0,1,0,3,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_warrior", "Bakhal Warrior", "Bakhal Warriors", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_armor_elite_berserker_a_01, itm_k14_bak_warrior_helmet, itm_giant_warrior_boots, itm_bigaxe_weathered_marauder_01, itm_jarid, itm_jarid], 
attrlev(44,15,6,10,35), wpex(260,260,200,130,80,270), strsk(11,10,9,6)|agisk(7,4,8,0,0)|lordsk1(3,0,2,1,0,0,2,2)|lordsk2(0,0,0,1,0,3,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_seasonedwarrior", "Bakhal Seasoned Warrior", "Bakhal Seasoned Warriors", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_warrior_armor_bakhal, itm_bakhal_guard_helmet, itm_giant_gloves_plus, itm_giant_warrior_boots, itm_axe_weathered_berserker_a_01, itm_jarid, itm_throwing_spears], 
attrlev(50,16,7,12,45), wpex(320,320,240,140,90,320), strsk(13,12,10,8)|agisk(8,5,9,0,0)|lordsk1(4,0,3,2,1,0,2,2)|lordsk2(0,0,0,2,0,4,1,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_champion", "Bakhal Champion", "Bakhal Champions", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_armor_elite_marauder_of_norsca_c_02, itm_giant_horned_helmet_bakhal, itm_giant_leather_boots, itm_giant_gloves_plus1, itm_axe_elite_raider_01, itm_throwing_spears], 
attrlev(60,18,8,15,60), wpex(400,400,280,150,100,400), strsk(14,13,12,10)|agisk(9,6,10,0,0)|lordsk1(4,0,4,2,2,0,3,3)|lordsk2(0,0,0,2,0,4,5,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_huntsman", "Bakhal Huntsman", "Bakhal Huntsmen", tf_giant_male|tf_guarantee_archer, 0, 0, fac_kingdom_14, [itm_giant_archer_armor_bakhal, itm_giant_helmet_karnoth, itm_giant_grey_boots, itm_axe_marauder_01, itm_bakhal_leather_shield, itm_practice_bow_2, itm_skeleton_archer_arrow], 
attrlev(30,11,6,6,11), wpex(140,140,120,120,60,120), strsk(6,4,4,5)|agisk(3,2,5,0,0)|lordsk1(1,1,0,1,0,1,2,1)|lordsk2(0,0,0,0,0,1,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_archer", "Bakhal Archer", "Bakhal Archers", tf_giant_male|tf_guarantee_archer, 0, 0, fac_kingdom_14, [itm_giant_archer_armor_bakhal_2, itm_giant_helmet_bakhal, itm_giant_br_boots_knee_02, itm_smallcrowbill_marauder_recruit_01, itm_bakhal_shield, itm_dale_bow, itm_skeleton_archer_arrow], 
attrlev(35,13,7,7,18), wpex(200,180,140,180,75,160), strsk(8,6,5,7)|agisk(5,4,7,0,0)|lordsk1(2,2,0,2,0,1,3,1)|lordsk2(0,0,0,0,0,2,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k14_bak_skullshooter", "Bakhal Skullshooter", "Bakhal Skullshooters", tf_giant_male|tf_guarantee_archer, 0, 0, fac_kingdom_14, [itm_giant_leather_armor_bakhal, itm_spiked_bakhal_helmet, itm_giant_gr_boots_knee_01, itm_crowbill_marauder_01, itm_bak_warrior_shield, itm_skeleton_archer_bow, itm_skeleton_archer_arrow], 
attrlev(40,16,8,8,30), wpex(260,240,200,250,90,200), strsk(10,9,7,9)|agisk(6,6,9,0,0)|lordsk1(3,4,0,3,1,2,4,2)|lordsk2(0,0,0,1,0,3,0,1), swadian_face_younger_1, swadian_face_middle_2], 
#Bakhal Extras
["k14_bak_messenger", "Bakhal Messenger", "Bakhal Messengers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_armor_marauder_recruit_c_01, itm_giant_helmet_karnoth, itm_giant_grey_boots, itm_crowbill_marauder_01], 
attrlev(28,18,9,9,16), wpex(130,130,100,100,80,100), strsk(5,5,4,4)|agisk(4,0,10,0,0)|lordsk1(1,0,0,2,0,4,3,3)|lordsk2(0,0,0,0,1,1,0,1), swadian_face_young_1,swadian_face_old_2], 
["k14_bak_pg", "Prison Guard", "Prison Guards", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_plate_armor_bakhal, itm_k14_bak_warrior_helmet, itm_giant_gr_boots_knee_01, itm_giant_gloves_plus1, itm_middleaxe_marauder_of_norsca_a_01, itm_bakhal_shield], 
attrlev(38,12,6,6,30), wpex(180,180,150,80,80,150), strsk(7,7,4,4)|agisk(6,6,5,0,0)|lordsk1(1,0,0,0,0,0,3,1)|lordsk2(0,0,0,0,1,4,0,0), swadian_face_young_1, swadian_face_young_2], 
["k14_bak_cg", "Castle Guard", "Castle Guards", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_plate_armor_bakhal, itm_bakhal_guard_helmet, itm_giant_warrior_boots, itm_giant_gloves_plus1, itm_axe_weathered_berserker_a_01], 
attrlev(46,14,7,10,40), wpex(245,245,170,100,100,200), strsk(9,9,6,6)|agisk(8,7,6,0,0)|lordsk1(1,0,0,0,0,0,4,2)|lordsk2(0,0,0,0,1,3,0,0), swadian_face_young_1, swadian_face_young_2], 
#Bakhal Slaves
["k14_bak_hslave1","Human Weakling Slave","Human Weakling Slaves",tf_allways_fall_dead,0,0,fac_kingdom_14, [itm_mace_1, itm_knife, itm_shortened_spear], 
attrlev(8,6,6,5,1), wpex(60,60,60,60,60,60), strsk(0,1,0,0)|agisk(1,0,2,0,0), mfy1, mfo2], 
["k14_bak_hslave2","Human Arrow Fodder","Human Arrow Fodder",tf_allways_fall_dead|tf_guarantee_armor,0,0,fac_kingdom_14, [itm_beduin_armor_a, itm_peasant_leather_ls, itm_ragged_outfit, itm_leather_jerkin, itm_ankle_boots, itm_rus_shoes, itm_spear], 
attrlev(10,7,6,5,3), wpex(80,80,80,80,80,80), strsk(1,1,0,0)|agisk(2,0,4,0,0), mfy1, mfo2], 
#Bakhal Nobles
["k14_bak_n_slaveherder", "Bakhal Slaveherder", "Bakhal Slaveherders", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_armor_weathered_berserker_b_01, itm_bakhal_guard_helmet, itm_giant_gloves_plus, itm_giant_br_boots_knee_02, itm_bakhal_spear], 
attrlev(48,18,7,9,36), wpex(250,250,300,100,100,100), strsk(10,9,6,6)|agisk(7,0,8,0,0)|lordsk1(3,0,1,4,0,1,4,3)|lordsk2(0,0,0,0,1,6,1,1), swadian_face_younger_1, swadian_face_middle_2], 
#Bakhal Household
["k14_bak_n_shaman", "Bakhal Blood Shaman", "Bakhal Blood Shamans", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_14, [itm_giant_guard_armor_bakhal, itm_giant_honor_helmet, itm_giant_leather_boots, itm_giant_gloves_plus, itm_axe_weathered_berserker_b_01], 
attrlev(54,15,10,15,48), wpex(370,370,370,150,150,150), strsk(11,10,7,7)|agisk(8,0,8,0,0)|lordsk1(2,0,0,3,0,0,2,2)|lordsk2(3,3,3,0,3,2,2,0), swadian_face_younger_1, swadian_face_middle_2], 
#Bakhal Warlords, Bakhal Tyrants
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Sut 
["k15_sut_giant", "Sut Giant", "Sut Giants", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_armor_marauder_recruit_b_01, itm_giant_helmet_karnoth, itm_giant_brown_boots, itm_smallaxe_marauder_recruit_a_01, itm_sut_giant_shield], 
attrlev(27,10,6,6,9), wpex(100,90,80,70,50,60), strsk(5,3,1,1)|agisk(2,2,2,0,0)|lordsk1(1,0,0,0,0,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_clansman", "Sut Clansman", "Sut Clansmen", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_giant_leather_armor_sut, itm_sut_horned_helmet, itm_giant_brown_boots, itm_greatsword_elite_marauder_of_norsca_01, itm_sut_leather_shield], 
attrlev(31,12,7,7,16), wpex(150,140,140,90,70,90), strsk(7,5,3,3)|agisk(3,4,3,0,0)|lordsk1(1,0,0,0,0,0,1,2)|lordsk2(0,0,0,1,0,2,0,1), swadian_face_middle_2], 
["k15_sut_fighter", "Sut Fighter", "Sut Fighters", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_giant_guard_armor_sut, itm_giant_helmet_sut, itm_giant_br_boots_knee_02, itm_giant_gloves, itm_axe_raider_01, itm_sut_shield, itm_axe_weathered_marauder_01], 
attrlev(37,14,8,8,24), wpex(220,190,190,100,80,120), strsk(9,7,4,4)|agisk(5,5,5,0,0)|lordsk1(2,0,0,1,1,1,2,2)|lordsk2(0,0,0,1,0,2,0,1), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_warrior", "Sut Warrior", "Sut Warriors", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_giant_guardsman_armor_sut, itm_k15_sut_warrior_helmet, itm_giant_furred_boots, itm_giant_gloves, itm_middleaxe_marauder_of_norsca_b_01, itm_sut_warrior_shield], 
attrlev(43,16,9,10,32), wpex(280,250,250,120,100,150), strsk(10,9,6,6)|agisk(6,6,6,0,0)|lordsk1(2,0,1,1,1,1,2,2)|lordsk2(0,0,0,1,0,3,0,1), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_chiefsguard", "Sut Chieftain's Guard", "Sut Chieftain's Guards", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_armor_weathered_marauder_of_norsca_b_01, itm_giant_horned_helmet_sut, itm_giant_furred_boots, itm_giant_gloves_plus1, itm_giant_axe_01, itm_sut_steel_shield], 
attrlev(48,18,10,14,42), wpex(350,330,330,150,120,200), strsk(12,11,8,8)|agisk(8,8,8,0,0)|lordsk1(2,0,2,1,2,1,5,3)|lordsk2(0,0,0,2,1,4,1,2), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_berserker", "Sut Berserker", "Sut Berserkers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_elite_marauder_armor2, itm_giant_bers_helmet, itm_giant_furred_boots_1, itm_giant_gloves, itm_giant_greatsword], 
attrlev(52,20,9,12,48), wpex(380,380,350,140,110,200), strsk(13,12,8,8)|agisk(8,7,10,0,0)|lordsk1(3,0,3,2,1,3,3,3)|lordsk2(0,0,0,2,0,3,0,1), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_huntsman", "Sut Huntsman", "Sut Huntsmen", tf_giant_male|tf_guarantee_archer, 0, 0, fac_kingdom_15, [itm_giant_archer_armor_sut, itm_sut_horned_helmet, itm_giant_brown_boots, itm_smallsword_marauder_recruit_01, itm_new_warbow_b, itm_arrows], 
attrlev(35,15,8,8,20), wpex(190,170,180,180,85,110), strsk(8,6,4,6)|agisk(4,4,6,0,0)|lordsk1(2,2,0,1,0,2,2,2)|lordsk2(0,0,0,1,0,2,0,1), swadian_face_middle_2], 
["k15_sut_bowman", "Sut Bowman", "Sut Bowmen", tf_giant_male|tf_guarantee_archer, 0, 0, fac_kingdom_15, [itm_giant_archer_armor_sut_2, itm_giant_helmet_sut, itm_giant_br_boots_knee_02, itm_giant_gloves_plus1, itm_giant_spear, itm_skeleton_archer_bow, itm_1steel_arrow, itm_1steel_arrow], 
attrlev(40,18,9,9,30), wpex(250,230,250,250,100,125), strsk(10,8,5,8)|agisk(6,5,9,0,0)|lordsk1(2,4,0,2,1,3,4,3)|lordsk2(0,0,0,2,0,2,0,1), swadian_face_younger_1, swadian_face_middle_2], 
#Sut Extras
["k15_sut_messenger", "Sut Messenger", "Sut Messengers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_armor_marauder_recruit_b_01, itm_giant_helmet_karnoth, itm_giant_brown_boots, itm_smallsword_marauder_recruit_01], 
attrlev(28,18,9,9,15), wpex(140,140,120,120,80,100), strsk(5,5,4,4)|agisk(4,0,10,0,0)|lordsk1(1,0,0,2,0,4,3,3)|lordsk2(0,0,0,0,1,1,0,1), swadian_face_young_1,swadian_face_old_2], 
["k15_sut_pg", "Prison Guard", "Prison Guards", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_giant_guardsman_armor_sut, itm_giant_helm_01, itm_giant_leather_boots, itm_giant_gloves_plus, itm_spear_weathered_raider_01], 
attrlev(36,12,7,7,30), wpex(200,180,200,150,80,150), strsk(7,7,5,5)|agisk(6,6,5,0,0)|lordsk1(1,0,0,0,0,0,3,1)|lordsk2(0,0,0,0,1,4,0,0), swadian_face_young_1, swadian_face_young_2], 
["k15_sut_cg", "Castle Guard", "Castle Guards", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_giant_guardsman_armor_sut_2, itm_giant_horned_helmet_sut, itm_giant_furred_boots, itm_giant_gloves_plus, itm_giant_greatsword], 
attrlev(45,14,9,12,40), wpex(260,260,260,200,100,200), strsk(9,9,7,7)|agisk(8,7,6,0,0)|lordsk1(1,0,0,0,0,0,4,2)|lordsk2(0,0,0,0,1,3,0,0), swadian_face_young_1, swadian_face_young_2], 
#Sut Nobles
["k15_sut_n_raider", "Sut Raider", "Sut Raiders", tf_giant_male|tf_guarantee_allnoranged, 0, 0, fac_kingdom_15, [itm_giant_plate_armor_sut, itm_giant_helm_01, itm_giant_leather_boots, itm_giant_gloves_plus, itm_northerner_horse, itm_sut_slasher, itm_sut_leather_shield], 
attrlev(42,17,9,10,30), wpex(250,240,240,160,130,160), strsk(9,8,5,5)|agisk(7,7,6,5,0)|lordsk1(3,0,0,3,1,2,3,3)|lordsk2(0,0,0,1,1,3,2,1), swadian_face_younger_1, swadian_face_middle_2], 
["k15_sut_n_chieftan", "Sut Chieftain", "Sut Chieftans", tf_giant_male|tf_guarantee_allnoranged, 0, 0, fac_kingdom_15, [itm_giant_guardsman_armor_sut_2, itm_giant_horned_chief_helmet_sut, itm_giant_plated_boots_sharp, itm_giant_gloves_plus1, itm_plate_charger_brown, itm_sut_elite_shield, itm_sut_one_handed_war_axe], 
attrlev(58,20,12,20,65), wpex(420,420,420,250,200,250), strsk(14,12,9,9)|agisk(9,9,8,9,0)|lordsk1(4,0,5,4,3,3,4,4)|lordsk2(0,0,0,3,3,4,6,3), swadian_face_younger_1, swadian_face_middle_2], 
#Sut Household
["k15_sut_n_bonebreaker", "Sut Bonebreaker", "Sut Bonebreakers", tf_giant_male|tf_guarantee_inf, 0, 0, fac_kingdom_15, [itm_armor_weathered_marauder_of_norsca_b_01, itm_full_sut_helmet, itm_giant_furred_boots_1, itm_giant_gloves_plus1, itm_polehammer], 
attrlev(50,15,8,10,48), wpex(260,320,320,80,80,80), strsk(13,9,6,6)|agisk(8,4,6,0,0)|lordsk1(2,0,0,0,0,0,0,2)|lordsk2(0,0,0,1,0,2,0,0), swadian_face_younger_1, swadian_face_middle_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Aroulo
["k16_aro_unproven", "Aroulo Unproven", "Aroulo Unproven", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_pelt_coat, itm_hunter_boots, itm_wooden_stick], 
attrlev(11,8,4,4,2), wpex(85,85,85,70,25,70), strsk(1,1,1,0)|agisk(1,0,3,0,0)|lordsk1(0,1,0,0,0,1,1,0)|lordsk2(0,0,0,0,0,1,0,0), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_tribesman", "Aroulo Tribesman", "Aroulo Tribesmen", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_rawhide_coat, itm_hunter_boots, itm_staff], 
attrlev(14,11,5,5,4), wpex(160,160,160,140,35,140), strsk(2,3,2,1)|agisk(2,0,4,0,0)|lordsk1(1,1,0,1,0,1,1,1)|lordsk2(1,0,0,0,0,1,0,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_woodsman", "Aroulo Woodsman", "Aroulo Woodsmen", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_woodman_tunic, itm_hunter_boots, itm_leather_gloves, itm_staff, itm_stones], #itm_rrr_club1, itm_hide_covered_round_shield
attrlev(18,14,5,6,8), wpex(230,230,230,220,40,220), strsk(3,4,3,3)|agisk(4,1,5,0,0)|lordsk1(1,2,0,1,0,2,2,1)|lordsk2(1,0,1,0,0,2,0,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_bowman", "Aroulo Bowman", "Aroulo Bowmen", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_woodman_scout, itm_hunter_boots, itm_leather_gloves, itm_woodman_staff, itm_strong_bow, itm_aroulo_arrows, itm_aroulo_arrows], 
attrlev(22,18,6,7,17), wpex(290,290,290,310,60,250), strsk(4,5,4,5)|agisk(6,1,7,0,0)|lordsk1(1,4,0,2,0,3,3,2)|lordsk2(2,0,2,0,0,2,0,2), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_bowmaster", "Aroulo Bowmaster", "Aroulo Bowmasters", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_leaf_armour, itm_hide_boots, itm_leather_gloves, itm_woodman_staff, itm_strong_bow, itm_spak_bow8_arrow, itm_spak_bow8_arrow], 
attrlev(27,23,8,10,27), wpex(350,350,350,400,80,300), strsk(6,6,5,7)|agisk(8,2,9,0,0)|lordsk1(2,6,0,3,0,4,4,3)|lordsk2(3,0,2,0,0,2,0,2), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_hurler", "Aroulo Hurler", "Aroulo Hurlers", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_woodman_tunic, itm_hunter_boots, itm_leather_gloves, itm_woodman_staff, itm_aroulo_throwing_wep], 
attrlev(23,18,6,9,18), wpex(290,290,290,250,50,300), strsk(5,5,5,4)|agisk(5,2,6,0,0)|lordsk1(2,2,0,2,0,3,2,2)|lordsk2(2,0,1,0,0,2,0,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_provenhurler", "Aroulo Proven Hurler", "Aroulo Proven Hurlers", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_woodman_scout, itm_aroulo_boots, itm_gloves_lord_l, itm_woodman_staff, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep], 
attrlev(28,22,7,12,32), wpex(340,340,340,280,60,360), strsk(6,6,7,5)|agisk(6,2,7,0,0)|lordsk1(2,2,0,2,1,3,3,2)|lordsk2(2,0,2,0,0,2,0,2), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_masterhurler", "Aroulo Master Hurler", "Aroulo Master Hurlers", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0, 0, fac_kingdom_16, [itm_woodman_chieftain, itm_aroulo_boots, itm_gloves_lord_l, itm_woodman_staff, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep], 
attrlev(32,25,8,16,48), wpex(380,380,380,320,70,440), strsk(7,7,9,6)|agisk(8,3,9,0,0)|lordsk1(2,3,0,3,2,3,3,3)|lordsk2(2,0,3,0,0,2,0,2), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_fighter", "Aroulo Fighter", "Aroulo Fighters", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_woodman_padded, itm_hunter_boots, itm_leather_gloves, itm_woodman_staff], #old weapon itm_two_handed_axe, replaced on request from cwr
attrlev(28,23,7,9,25), wpex(360,360,360,280,60,330), strsk(6,7,5,5)|agisk(7,2,7,0,0)|lordsk1(2,2,1,2,0,3,2,2)|lordsk2(2,0,1,0,0,3,0,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_warrior", "Aroulo Warrior", "Aroulo Warriors", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_leaf_armour, itm_hide_boots, itm_leather_gloves, itm_woodman_staff], #old weapon itm_axe, replaced on request from cwr
attrlev(33,28,7,10,32), wpex(430,430,430,300,70,360), strsk(8,9,6,6)|agisk(8,3,8,0,0)|lordsk1(3,2,2,2,0,3,3,2)|lordsk2(2,0,2,0,0,3,0,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_provenwarrior", "Aroulo Proven Warrior", "Aroulo Proven Warriors", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_armour_braided, itm_hide_boots, itm_gloves_lord_l, itm_woodman_staff], #old weapon itm_long_axe, replaced on request from cwr
attrlev(38,32,8,12,38), wpex(500,500,500,330,80,380), strsk(10,10,7,7)|agisk(10,3,9,0,0)|lordsk1(3,2,4,3,0,3,3,3)|lordsk2(2,0,2,0,0,4,1,2), aroulo_face_younger_1, aroulo_face_older_2], 
#Aroulo Extras
["k16_aro_messenger", "Aroulo Messenger", "Aroulo Messengers", tf_guarantee_ranged|tf_guarantee_horse|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots, 0, 0, fac_kingdom_16, [itm_woodman_tunic, itm_woodman_staff], 
attrlev(22,18,8,6,20), wp(150), strsk(4,4,4,4)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_pg", "Prison Guard", "Prison Guards", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_16, [itm_leaf_armour, itm_woodman_staff], 
attrlev(25,17,8,7,25), wp(290), strsk(6,6,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_cg", "Castle Guard", "Castle Guards", tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_boots|tf_guarantee_shield, 0, 0, fac_kingdom_16, [itm_armour_braided, itm_woodman_staff], 
attrlev(32,20,9,10,30), wp(380), strsk(7,7,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), aroulo_face_younger_1, aroulo_face_older_2], 
#Aroulo Nobles
["k16_aro_n_strongone", "Aroulo Strong One", "Aroulo Strong Ones", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves, 0, 0, fac_kingdom_16, [itm_leather_gloves, itm_aroulo_boots, itm_stonemaul_aroulo], 
attrlev(40,26,7,10,30), wpex(380,380,380,160,50,160), strsk(10,9,7,7)|agisk(8,0,7,0,0)|lordsk1(2,0,1,0,0,1,2,2)|lordsk2(0,0,1,0,1,2,2,1), aroulo_face_younger_1, aroulo_face_older_2], 
["k16_aro_n_beastslayer","Aroulo Beast Slayer","Aroulo Beast Slayers",tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves,0,0,fac_kingdom_16, [itm_woodman_chieftain, itm_ranger_helmet_tld, itm_aroulo_boots, itm_gloves_lord_l, itm_stonemaul_aroulo], 
attrlev(48,36,8,15,50), wpex(500,540,500,370,70,370), strsk(12,11,8,8)|agisk(10,0,10,0,0)|lordsk1(4,7,3,4,2,4,4,3)|lordsk2(3,2,4,0,0,3,3,3), aroulo_face_younger_1,aroulo_face_older_2], 
#Aroulo Beast Master

#Aroulo Special
["k16_aro_n_proven", "Aroulo Proven", "Aroulo Proven", tf_guarantee_armor|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_ranged, 0,0, fac_kingdom_16, [itm_woodman_padded, itm_aroulo_boots, itm_gloves_lord_l, itm_bamboo_spear, itm_aroulo_throwing_wep], 
attrlev(26,20,8,10,26), wpex(300,300,350,200,60,300), strsk(7,7,7,6)|agisk(7,0,7,0,0)|lordsk1(2,2,1,3,0,3,2,3)|lordsk2(2,1,2,0,0,3,0,2), aroulo_face_younger_1, aroulo_face_older_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#The 3rd Legion
["k17_ttl_compinfantry", "Third Companion Infantry", "Third Companion Infantry", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_shirt_a_got_1, itm_roman_helm_copper, itm_roman_greaves_caligea, itm_gauntlets_arabs_a_l, itm_roman_spear_1, itm_roman_shield_oval, itm_roman_javelin, itm_roman_javelin], 
attrlev(13,10,8,7,8), wpex(100,100,120,70,70,120), strsk(1,2,2,1)|agisk(3,2,3,1,0)|lordsk1(3,0,0,0,1,0,1,1)|lordsk2(0,0,0,1,0,1,0,0), 0x000000000001000436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff01200636db6db6db6db7b300000000001db6de0000000000000000], #10-12 skins
["k17_ttl_compcavalry", "Third Companion Cavalry", "Third Companion Cavalry", tf_guarantee_allnoranged, 0,0, fac_kingdom_17, [itm_roman_hamata, itm_h_tribune_steel, itm_roman_greaves_gutter, itm_gauntlets_arabs_a_l, itm_roman_courser, itm_roman_horse_1, itm_roman_cav_sword_3, itm_roman_shield_oval, itm_roman_spear_1, itm_roman_spear_2], 
attrlev(16,13,10,11,17), wpex(160,145,190,100,100,145), strsk(2,3,3,2)|agisk(4,4,4,4,3)|lordsk1(3,0,0,2,3,1,3,2)|lordsk2(0,0,1,1,0,2,0,0), 0x000000000001000436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff01200636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_compcavalryplus", "Third Equitata", "Third Equitatae", tf_guarantee_allnoranged, 0,0, fac_kingdom_17, [itm_roman_cent_hamata, itm_h_tribune_bronze_feathered, itm_roman_greaves_greek, itm_brass_lamellar_gauntlets, itm_roman_courser, itm_roman_horse_1, itm_roman_cav_sword_3, itm_roman_shield_cav, itm_bb_spathion_2, itm_roman_spear_2], 
attrlev(20,17,13,16,26), wpex(225,220,270,150,140,200), strsk(4,4,4,3)|agisk(6,5,5,6,6)|lordsk1(2,0,1,5,5,3,4,3)|lordsk2(0,0,2,2,0,3,0,1), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_compsoldier", "Third Companion Soldier", "Third Companion Soldiers", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_armor_cent, itm_roman_armor, itm_roman_helm_lego, itm_roman_greaves_gutter, itm_gauntlets_arabs_a_l, itm_roman_gladius_1, itm_roman_shield_oval, itm_roman_javelin, itm_roman_javelin], 
attrlev(17,13,10,10,16), wpex(175,160,175,135,100,175), strsk(3,3,3,3)|agisk(4,4,5,2,0)|lordsk1(3,0,0,0,2,0,1,1)|lordsk2(0,0,0,1,0,2,0,0), 0x000000000001000436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff01200636db6db6db6db7b300000000001db6de0000000000000000], #10-12 skins
["k17_ttl_comparcher", "Third Companion Archer", "Third Companion Archers", tf_guarantee_archer, 0,0, fac_kingdom_17, [itm_roman_squamata, itm_h_tribune, itm_roman_greaves_caligea, itm_roman_greaves_gutter_single, itm_gauntlets_arabs_a_l, itm_roman_spear_2, itm_lav_cubow_1, itm_bronze_arrow, itm_bronze_arrow], 
attrlev(20,17,12,14,24), wpex(220,220,250,250,150,220), strsk(4,4,4,5)|agisk(5,4,6,3,3)|lordsk1(2,2,1,0,4,1,3,2)|lordsk2(0,0,0,1,0,2,0,1), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_sagittarius", "Third Sagittarius", "Third Sagittarii", tf_guarantee_archer, 0,0, fac_kingdom_17, [itm_roman_catafract_heavy_2, itm_h_tribune2, itm_roman_greaves_gutter, itm_gauntlets_arabs_a_l, itm_roman_spear_3, itm_lav_cubow_2, itm_bronze_arrow, itm_bronze_arrow], 
attrlev(25,22,15,20,40), wpex(270,270,330,350,200,280), strsk(5,6,5,7)|agisk(7,5,8,4,4)|lordsk1(2,3,2,0,7,2,5,3)|lordsk2(0,0,0,2,1,3,0,2), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_legionary", "Third Legionary", "Third Legionaries", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_armor_red, itm_roman_armor_white, itm_roman_helm_lego, itm_catafract_helmet_1, itm_roman_greaves_greek, itm_gauntlets_arabs_a_l, itm_roman_gladius_2, itm_roman_shield_early, itm_roman_javelin, itm_roman_pilum_2], 
attrlev(22,17,12,15,26), wpex(270,230,240,175,120,260), strsk(5,5,5,4)|agisk(6,6,6,2,0)|lordsk1(3,0,1,0,4,0,1,2)|lordsk2(0,0,1,2,0,3,0,1), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_legionaryveteranus", "Third Legionary Veteranus", "Third Legionaries Veterani", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_catafract_heavy_2, itm_roman_helm_preator, itm_roman_greaves_greek, itm_gauntlets_arabs_a_l, itm_roman_gladius_3, itm_roman_shield_square, itm_roman_javelin, itm_roman_pilum_2], 
attrlev(26,21,14,20,36), wpex(375,330,350,225,150,360), strsk(7,7,7,5)|agisk(8,7,8,3,0)|lordsk1(2,0,3,0,6,0,2,3)|lordsk2(1,0,1,2,0,4,0,2), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_legionaryimperialis", "Third Legionary Imperialis", "Third Legionaries Imperiali", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_catafract_heavy, itm_roman_helm_cent, itm_roman_centurion_boots, itm_scale_gauntlets_b, itm_roman_gladius_2_gold, itm_roman_shield_square, itm_roman_pilum_2, itm_roman_pilum_2], 
attrlev(31,26,17,26,50), wpex(500,440,460,260,180,500), strsk(9,9,9,7)|agisk(10,9,10,4,0)|lordsk1(1,0,5,0,8,0,3,4)|lordsk2(1,0,2,2,1,4,2,3), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_praetorian", "Third Praetorian Guard", "Third Praetorian Guards", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_tribune_b_2, itm_roman_helm_preator_dark, itm_roman_centurion_boots, itm_dorn_squire_gauntles, itm_bb_spathion_lotr_1, itm_roman_shield_square, itm_roman_spear_3], 
attrlev(32,25,18,25,50), wpex(485,450,485,280,200,460), strsk(10,10,8,8)|agisk(9,10,9,4,0)|lordsk1(1,0,4,0,9,0,3,4)|lordsk2(1,0,2,2,1,5,0,3), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
#TTL Extras
["k17_ttl_messenger", "Third Legion Messenger", "Third Legion Messengers", tf_guarantee_all, 0,0, fac_kingdom_17, [itm_roman_hamata, itm_h_tribune_steel, itm_roman_greaves_gutter, itm_gauntlets_arabs_a_l, itm_roman_courser, itm_roman_horse_1, itm_roman_cav_sword_3], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), 0x000000000001000436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff01200636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_pg","Prison Guard","Prison Guards",tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_armor_red, itm_roman_helm_lego, itm_roman_greaves_greek, itm_gauntlets_arabs_a_l, itm_roman_gladius_2, itm_roman_shield_early], 
attrlev(18,15,12,10,25), wp(250), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_cg","Castle Guard","Castle Guards",tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_roman_catafract_heavy, itm_roman_helm_preator, itm_roman_centurion_boots, itm_gauntlets_arabs_a_l, itm_roman_gladius_3, itm_roman_shield_square], 
attrlev(22,18,14,12,30), wp(300), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
#TTL Nobles
["k17_ttl_n_optio", "Third Optio", "Third Optiones", tf_guarantee_all, 0,0, fac_kingdom_17, [itm_padded_cloth_got_1, itm_h_tribune_bronze_feathered, itm_west_arbalester_boots, itm_gloves_lord_l, itm_3lamellar_charger, itm_roman_cav_sword_1, itm_roman_shield_oval, itm_roman_javelin], 
attrlev(15,14,16,15,15), wpex(200,175,175,150,125,200), strsk(3,4,4,3)|agisk(4,3,3,4,5)|lordsk1(1,0,2,1,5,0,1,2)|lordsk2(1,0,1,2,2,2,2,2), 0x000000000001000436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff01200636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_n_kalero", "Third Kalero", "Third Kaleros", tf_guarantee_allnoranged, 0,0, fac_kingdom_17, [itm_a_roman_chain_2, itm_h_tribune2, itm_dorn_knight_boots, itm_gauntlets_arabs_b_l, itm_2lamellar_charger, itm_bb_spathion_2, itm_roman_cav_sword_2, itm_roman_shield_cav], 
attrlev(22,20,21,21,33), wpex(325,300,300,225,175,300), strsk(6,6,6,4)|agisk(7,6,5,6,6)|lordsk1(1,0,3,1,8,1,2,3)|lordsk2(2,0,2,4,3,4,4,3), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_n_visavo", "Third Visavo", "Third Visavos", tf_guarantee_allnoranged, 0,0, fac_kingdom_17, [itm_a_roman_chain_3, itm_catafract_helmet_2, itm_dorn_sand_snakes_boots, itm_hourglass_gauntlets_ornate, itm_2lamellar_charger, itm_luc_celtic_sword, itm_roman_shield_noble], 
attrlev(30,27,27,30,54), wpex(475,450,450,275,250,450), strsk(9,9,8,7)|agisk(9,9,7,8,8)|lordsk1(1,0,4,2,10,2,3,4)|lordsk2(3,0,3,6,4,4,6,4), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
#TTL Household
["k17_ttl_n_anvissarius", "Third Anvissarius", "Third Anvissarii", tf_guarantee_inf, 0,0, fac_kingdom_17, [itm_tribune_b_3, itm_catafract_helmet_2, itm_west_man_at_arms_boots, itm_hourglass_gauntlets_ornate, itm_luc_celtic_sword_cwe, itm_towershield_steel], 
attrlev(36,28,20,28,55), wpex(560,550,550,250,200,500), strsk(10,10,9,8)|agisk(10,10,9,5,0)|lordsk1(1,0,8,0,10,0,4,4)|lordsk2(2,0,4,4,2,4,3,3), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 
["k17_ttl_n_venator", "Third Venator", "Third Venatores", tf_guarantee_allnoranged, 0,0, fac_kingdom_17, [itm_west_swordsman, itm_h_tribune_bronze_feathered, itm_h_tribune_steel_dark, itm_roman_centurion_boots, itm_dorn_squire_gauntles, itm_twilight_horse_got, itm_luc_kriegshammer, itm_crude_warhammer, itm_saracin_shield_l], 
attrlev(28,24,19,21,40), wpex(390,330,330,230,100,230), strsk(8,8,6,6)|agisk(8,7,5,7,0)|lordsk1(2,0,1,4,6,2,4,3)|lordsk2(2,0,2,1,3,7,1,4), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
#TTL fief guardsmen
["k17_ttl_n_sagittariusplus", "Third Sagittaria Imperialia", "Third Sagittariae Imperialiae", tf_guarantee_archer|tf_female, 0,0, fac_kingdom_17, [itm_a_roman_chain_4, itm_h_tribune2_steel, itm_west_man_at_arms_boots, itm_gauntlets_arabs_a_l, itm_bb_spathion, itm_roman_shield_early, itm_lav_cubow_2, itm_bronze_arrow], 
attrlev(23,27,17,20,42), wpex(380,260,360,420,200,300), strsk(5,6,5,8)|agisk(8,6,8,3,0)|lordsk1(1,6,1,3,7,3,4,4)|lordsk2(3,0,3,2,2,4,0,3), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 
#TTL Special
["athanon_guard", "Third Atanon Guard", "Third Atanon Guards", tf_guarantee_inf, 0,0, fac_first_legion, [itm_tribune_b_4, itm_roman_helm_cent, itm_roman_greaves_greek, itm_dorn_squire_gauntles, itm_an_shortsword2, itm_roman_shield_square, itm_an_longsword], 
attrlev(35,32,16,18,52), wpex(480,480,440,200,200,450), strsk(10,10,10,8)|agisk(10,10,9,0,0)|lordsk1(3,0,8,1,7,1,2,3)|lordsk2(1,1,1,4,3,4,3,2), 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Perisno by michadr & su, reworked by habeo
["k00_per_recruit", "Perisno Recruit", "Perisno Recruits", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_green_tunic, itm_woolen_cap, itm_rus_shoes, itm_leather_gloves, itm_sword_medieval_c_small, itm_shortened_voulge], 
attrlev(8,7,7,5,3), wpex(75,75,70,70,70,70), strsk(0,1,0,0)|agisk(1,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,1)|lordsk2(0,0,0,0,0,1,0,0), mfy1, mfy2], 
["k00_per_militia", "Perisno Militia", "Perisno Militia", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_wei_xiadi_rod_padded_cloth, itm_segmented_helmet, itm_leather_boots, itm_leather_gloves, itm_nordic_halberd], 
attrlev(11,9,8,6,7), wpex(105,105,105,90,90,90), strsk(1,2,1,1)|agisk(2,1,3,0,0)|lordsk1(1,0,0,0,1,0,0,1)|lordsk2(0,0,1,1,0,2,0,1), mfy1, mfy2], 
["k00_per_bowman", "Perisno Bowman", "Perisno Bowmen", tf_guarantee_archer, 0,0, fac_kingdom_0, [itm_ao_vai_2_l, itm_helmet_with_neckguard, itm_boot_average_crusader_c, itm_leather_gloves, itm_spear, itm_dale_bow, itm_brown_arrow, itm_brown_arrow], 
attrlev(13,11,10,7,11), wpex(140,140,150,150,120,120), strsk(2,3,1,3)|agisk(3,1,4,0,0)|lordsk1(1,1,0,1,2,0,1,2)|lordsk2(1,0,1,1,0,2,0,1), mfy1, mfy2], 
["k00_per_archer", "Perisno Archer", "Perisno Archers", tf_guarantee_archer, 0,0, fac_kingdom_0, [itm_light_mail_and_plate_green, itm_bascinet_2, itm_splinted_greaves, itm_mail_mittens, itm_glaive, itm_spak_bow6, itm_brown_arrow, itm_bodkin_arrows], 
attrlev(16,13,12,8,17), wpex(185,185,200,210,140,140), strsk(3,4,2,4)|agisk(5,2,6,0,0)|lordsk1(1,2,0,1,3,1,2,2)|lordsk2(2,0,2,2,0,2,0,2), mfy1, mfy2], 
["k00_per_runearcher", "Perisno Rune Archer", "Perisno Rune Archers", tf_guarantee_archer, 0,0, fac_kingdom_0, [itm_armored_tabard_green, itm_rathos_11thcent_conicalhelm_rw_store, itm_mail_boots, itm_mail_mittens, itm_luc_saxon_voulge, itm_new_warbow_a, itm_3steel_arrow, itm_3steel_arrow], 
attrlev(20,16,15,10,28), wpex(240,240,250,280,160,160), strsk(4,5,3,5)|agisk(6,2,7,0,0)|lordsk1(1,4,1,2,5,2,3,3)|lordsk2(2,1,3,3,1,3,1,2), mfy1, mfo2], 
["k00_per_darkarcher", "Perisno Darkforest Archer", "Perisno Darkforest Archers", tf_guarantee_archer, 0,0, fac_kingdom_0, [itm_surcoat_over_mail, itm_dwarvenforged_helm_1, itm_mail_boots, itm_mail_mittens, itm_luc_saxon_voulge_b, itm_akwar_bow, itm_spak_ar2, itm_spak_ar2], 
attrlev(24,19,18,12,40), wpex(300,300,300,350,320,320), strsk(5,6,4,7)|agisk(8,3,8,0,0)|lordsk1(1,6,2,3,7,4,4,3)|lordsk2(3,2,4,4,2,3,1,3), mfo1, mfo2], 
["k00_per_footman", "Perisno Footman", "Perisno Footmen", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_rough_tunic_spiked, itm_light_crusader_helm_d, itm_boot_average_crusader_c, itm_mail_mittens, itm_luc_english_falchion, itm_ad_viking_shield_round_09], 
attrlev(14,11,9,7,12), wpex(150,150,150,105,105,105), strsk(3,3,2,2)|agisk(3,3,4,0,0)|lordsk1(1,0,0,0,2,0,1,2)|lordsk2(1,0,1,2,0,2,0,1), mfy1, mfy2], 
["k00_per_manatarms", "Perisno Man at Arms", "Perisno Men at Arms", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_mail_with_tunic_green, itm_flattop, itm_splinted_leather_greaves, itm_wisby_gauntlets_black, itm_luc_flemish_sword, itm_ad_viking_shield_round_09], 
attrlev(18,13,11,8,18), wpex(215,215,215,120,120,120), strsk(4,5,3,3)|agisk(5,4,5,0,0)|lordsk1(1,0,1,0,3,1,1,2)|lordsk2(1,0,2,3,0,3,0,2), mfy1, mfy2], 
["k00_per_warrior", "Perisno Warrior", "Perisno Warriors", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_new_banded_armor, itm_visored_salet, itm_mail_boots, itm_hourglass_gauntlets, itm_military_cleaver_c, itm_saracin_shield_h, itm_greatsword], 
attrlev(23,15,14,10,28), wpex(290,290,290,150,150,150), strsk(6,6,4,4)|agisk(6,6,6,0,0)|lordsk1(1,0,2,0,4,1,2,3)|lordsk2(2,1,2,4,1,3,0,2), mfy1, mfo2], 
["k00_per_champion", "Perisno Champion", "Perisno Champions", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_perisno_armour_1, itm_blacksale_salad, itm_shadow_greaves, itm_gondor_bracer_l, itm_jack_faramir, itm_sp_shr1, itm_schlachtschwert], 
attrlev(28,18,18,14,44), wpex(370,370,370,200,200,200), strsk(8,8,5,5)|agisk(8,7,7,4,0)|lordsk1(1,0,4,0,6,1,3,4)|lordsk2(2,2,3,5,3,3,3,3), mfo1, mfo2], 
["k00_per_guardsman", "Perisno Guardsman", "Perisno Guardsmen", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_perisno_heavy_armour_with_cape, itm_twilighthelm, itm_dorn_spearbearer_boots, itm_dark_mail_mittens, itm_sword_val_4, itm_steel_shield_kite], 
attrlev(29,18,17,14,40), wpex(370,350,330,200,200,200), strsk(9,8,5,5)|agisk(8,9,6,0,0)|lordsk1(1,0,3,0,5,1,4,4)|lordsk2(3,1,3,4,2,4,1,3), mfo1, mfo2], 
["k00_per_cavalry", "Perisno Cavalry", "Perisno Cavalry", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_corrazina_green, itm_rathos_11thcent_conicalhelm_rw_store, itm_mail_boots, itm_mail_mittens, itm_knight_horse_green, itm_swiss_falchion_v3, itm_shield_13, itm_light_lance], 
attrlev(21,16,13,11,27), wpex(280,280,280,145,145,145), strsk(5,6,3,3)|agisk(6,5,5,5,0)|lordsk1(1,0,1,1,5,2,2,3)|lordsk2(2,0,2,3,0,3,0,2), mfy1, mfo2], 
["k00_per_darkcavalry", "Perisno Darkforest Cavalry", "Perisno Darkforest Cavalry", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_xenoargh_metal_leather02, itm_gnezdovo_helm_a, itm_plate_boots, itm_hourglass_gauntlets_ornate, itm_forest_mount, itm_jack_herugrim, itm_heavy_lance, itm_steel_shield_herald03], 
attrlev(25,20,18,12,40), wpex(350,350,350,160,160,160), strsk(7,7,4,4)|agisk(7,6,6,7,0)|lordsk1(1,0,2,2,6,5,4,3)|lordsk2(2,1,2,3,1,3,1,3), mfo1, mfo2], 
#Perisno Extras
["k00_per_messenger","Perisno Messenger","Perisno Messengers",tf_guarantee_all,0,0,fac_kingdom_0, [itm_rough_tunic_spiked, itm_woolen_cap, itm_light_leather_boots, itm_leather_gloves, itm_courser, itm_luc_english_falchion, itm_norman_shield_2], 
attrlev(16,18,12,6,20), wp(150), strsk(3,3,3,3)|agisk(4,3,7,7,6)|lordsk1(0,1,0,2,0,4,4,3)|lordsk2(0,0,0,0,4,0,0,0), mfy1, mfy2], 
["k00_per_pg","Prison Guard", "Prison Guards", tf_guarantee_inf, 0, 0, fac_kingdom_0, [itm_mail_with_tunic_green, itm_kettlehat2, itm_splinted_leather_greaves, itm_mail_mittens, itm_luc_flemish_sword, itm_ad_viking_shield_round_09], 
attrlev(18,14,14,10,25), wp(240), strsk(5,5,5,5)|agisk(6,5,5,0,0)|lordsk1(0,0,2,0,3,0,5,2)|lordsk2(0,0,0,0,0,5,0,0), mfy1, mfo2], 
["k00_per_cg","Castle Guard", "Castle Guards", tf_guarantee_inf, 0, 0, fac_kingdom_0, [itm_perisno_armour_1, itm_barbuta1_black, itm_shadow_greaves, itm_gondor_bracer_l, itm_luc_saxon_voulge], 
attrlev(22,16,16,12,30), wp(280), strsk(6,6,6,6)|agisk(7,6,6,0,0)|lordsk1(0,0,4,0,4,0,6,3)|lordsk2(0,0,0,0,0,5,0,0), mfo1, mfo2], 
#Perisno Nobles
["k00_per_n_squire", "Perisno Squire", "Perisno Squires", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_armored_tabard_green, itm_capelina_crusader_b, itm_splinted_leather_greaves, itm_wisby_gauntlets_black, itm_knight_horse_green, itm_2scimitar_green, itm_norman_shield_2], 
attrlev(19,15,15,12,26), wpex(265,265,265,170,170,170), strsk(5,6,3,4)|agisk(6,5,4,5,4)|lordsk1(1,0,1,1,4,2,2,3)|lordsk2(3,2,3,2,2,2,2,2), mfy1, mfy2], 
["k00_per_n_rangerknight", "Perisno Ranger Knight", "Perisno Ranger Knights", tf_guarantee_all, 0,0, fac_kingdom_0, [itm_early_transitional_perisnified, itm_pigface_klappvisor_open, itm_shynbaulds, itm_gondor_bracer_l, itm_forest_mount, itm_ranger_blade, itm_saracin_shield_h, itm_ebonybow, itm_spak_ar2], 
attrlev(27,21,21,15,48), wpex(375,375,375,400,240,240), strsk(8,8,5,9)|agisk(8,7,6,8,8)|lordsk1(1,4,3,3,8,4,4,4)|lordsk2(4,4,4,3,4,3,4,4), mfo1, mfo2], 
["k00_per_n_greatknight", "Perisno Great Knight", "Perisno Great Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_perisno_heavy_armour, itm_barbuta2_black, itm_twilight_boots, itm_wisby_gauntlets_black, itm_plated_charger9, itm_crusader_long_sword_c, itm_sp_newsh], 
attrlev(30,22,20,16,50), wpex(410,410,410,280,280,280), strsk(9,8,6,7)|agisk(8,8,6,8,6)|lordsk1(1,0,6,1,8,2,3,4)|lordsk2(4,3,4,4,4,3,4,4), mfo1, mfo2], 
#Perisno Household
["aracanus_honor_guard", "Arcane Defender", "Arcane Defenders", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_dark_lord_armor, itm_barbuta2_purple, itm_black_boot_salad_of, itm_twilight_gloves, itm_twilight_horse, itm_jack_anduril, itm_sh_snake], 
attrlev(46,34,28,30,74), wpex(560,560,560,430,430,430), strsk(10,10,9,9)|agisk(10,10,6,10,7)|lordsk1(1,0,4,2,8,2,4,4)|lordsk2(3,3,3,4,3,4,7,3), mfo1, mfo2], 
["perisno_white_knight", "Perisno White Knight", "Perisno White Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_plate_armor3, itm_barbuta2_white, itm_plate_boots2, itm_hourglass_gauntlets, itm_plated_charger7, itm_rivend_sword_1, itm_spak_knightsh], 
attrlev(34,25,23,25,60), wpex(450,450,450,300,300,300), strsk(9,9,7,7)|agisk(10,8,6,9,0)|lordsk1(0,0,4,1,8,1,3,4)|lordsk2(4,2,4,3,4,4,7,3), mfy1, mfo2], 
["k00_per_n_sniper", "Perisno Darkforest Sniper", "Perisno Darkforest Snipers", tf_guarantee_archer, 0,0, fac_kingdom_0, [itm_coat_of_plates_green, itm_salet_new, itm_iron_greaves, itm_gauntlets_arabs_a_l, itm_swiss_voulge_no3, itm_spak_crsb01, itm_steel_bolts], 
attrlev(24,17,15,13,35), wpex(250,250,300,200,330,130), strsk(5,5,4,4)|agisk(8,0,6,0,0)|lordsk1(3,2,2,3,5,3,7,4)|lordsk2(0,0,2,4,2,3,1,2), mfy1, mfo2], 
["k00_per_n_eclipseknight", "Knight of Eclipse", "Knights of Eclipse", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_j_blacksmith_marinian_armor_d, itm_luc_sugarloaf_helm_v1, itm_west_pikeman_boots_dark, itm_scale_gauntlets, itm_twilight_horse_got, itm_faradon_handandahalf, itm_tab_shield_kite_cav_b], 
attrlev(28,23,14,19,42), wpex(420,420,350,150,150,150), strsk(8,8,6,6)|agisk(9,8,5,8,0)|lordsk1(4,0,3,1,5,1,3,4)|lordsk2(0,0,2,1,3,4,3,2), mfy1, mfo2], 
["k00_per_n_totaleclipseknight", "Knight of Total Eclipse", "Knights of Total Eclipse", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_blacky_platey_salad, itm_twilighthelm, itm_black_boot_salad_of, itm_glovesblack, itm_twilight_horse_got, itm_bastard_sword_b, itm_sh_snake], 
attrlev(33,26,16,26,62), wpex(500,500,450,200,200,200), strsk(10,9,7,7)|agisk(10,9,6,10,0)|lordsk1(4,0,4,1,8,2,4,4)|lordsk2(0,0,2,3,4,4,6,3), mfo1, mfo2], 
["k00_per_n_rhysrider", "Rhysian Rider", "Rhysian Riders", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_corrazina_green, itm_munitionshelm2, itm_rus_splint_greaves, itm_mail_mittens, itm_knight_horse_green, itm_luc_horsemans_hammer, itm_tab_shield_heater_d], 
attrlev(23,18,13,11,32), wpex(300,300,280,145,145,145), strsk(5,6,3,3)|agisk(6,5,5,5,0)|lordsk1(1,0,1,1,5,2,2,3)|lordsk2(2,0,2,3,0,3,0,2), mfy1, mfy2], #basically former perisno cavalry

#Perisno 1st Female Trooptree
["k00_per_f_recruit","Perisno Maiden Recruit","Perisno Maiden Recruits",tf_female|tf_guarantee_archer,0,0,fac_kingdom_0, [itm_tunic_with_green_cape, itm_leather_cap, itm_rus_shoes, itm_leather_gloves, itm_war_spear, itm_hunting_crossbow, itm_bolts], 
attrlev(10,9,6,5,5), wpex(80,80,80,70,80,70), strsk(1,1,0,0)|agisk(2,0,3,0,0)|lordsk1(1,1,0,0,0,0,1,2)|lordsk2(1,0,0,0,0,1,0,1), refugee_face1,refugee_face2], 
["k00_per_f_maiden","Perisno Maiden","Perisno Maidens",tf_female|tf_guarantee_archer,0,0,fac_kingdom_0, [itm_rough_tunic_spiked, itm_inf_t1, itm_stark_hanter_boots, itm_leather_gloves, itm_nordic_halberd, itm_light_crossbow, itm_bolts], 
attrlev(12,12,8,6,11), wpex(120,120,130,95,130,95), strsk(2,2,1,1)|agisk(3,1,4,2,2)|lordsk1(1,1,0,0,1,1,2,2)|lordsk2(2,0,1,1,0,1,0,2), refugee_face1,refugee_face2], 
["k00_per_f_rider","Perisno Maiden Rider","Perisno Maiden Riders",tf_female|tf_guarantee_all,0,0,fac_kingdom_0, [itm_rough_mail_coat, itm_light_crusader_helm_b, itm_splinted_greaves, itm_leather_gloves, itm_bandits_horse_a, itm_luc_hafted_blade_4, itm_light_crossbow, itm_steel_bolts], 
attrlev(15,15,11,8,17), wpex(185,185,200,130,200,130), strsk(3,3,2,2)|agisk(5,3,5,5,5)|lordsk1(2,2,0,1,2,2,3,3)|lordsk2(2,0,2,1,0,2,0,2), refugee_face1,refugee_face2], 
["k00_per_f_ranger","Perisno Maiden Ranger","Perisno Maiden Rangers",tf_female|tf_guarantee_all,0,0,fac_kingdom_0, [itm_xenoargh_new_female_armor_green01, itm_fine_ench, itm_mail_boots, itm_mail_mittens, itm_knight_horse_green, itm_luc_hafted_blade_1, itm_spak_crsb02, itm_steel_bolts], 
attrlev(18,19,14,10,28), wpex(260,260,290,180,280,180), strsk(4,4,2,3)|agisk(6,3,6,7,7)|lordsk1(2,3,0,2,4,3,4,3)|lordsk2(2,0,3,2,1,2,0,3), refugee_face1,refugee_face2], 
["k00_per_f_champion","Perisno Maiden Champion","Perisno Maiden Champions",tf_female|tf_guarantee_all,0,0,fac_kingdom_0, [itm_xenoargh_new_female_armor_green03, itm_barbuta2, itm_black_greaves, itm_twilight_gloves, itm_forest_mount, itm_glaive_xv, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt, itm_van_helsing_crossbow_bolt], 
attrlev(23,23,18,14,44), wpex(350,350,400,250,380,250), strsk(6,6,4,4)|agisk(8,5,7,8,8)|lordsk1(2,3,2,2,6,3,6,4)|lordsk2(3,1,3,3,3,3,3,4), refugee_face1,refugee_face2], 

#Perisno Pilgrims added by S.U. (thought it would be fun to add another special troop tree for the player to hire, these guys will become really strong and upgrade into Perisno Holy Champions. Upgrade tree is: k00_per_pm_pilgrim > Perisno Monk > Perisno Cleric splitting to either Perisno Crusader > Perisno Zealot OR Perisno Priest > Perisno Holy Champion  OR
["k00_per_pm_pilgrim", "Perisno Pilgrim", "Perisno Pilgrims", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_archer_tevton_armor_b, itm_padded_coif, itm_leather_boots, itm_lui_waronehandedaxec], 
attrlev(9,7,6,4,4), wpex(85,70,85,70,70,70), strsk(0,1,0,0)|agisk(1,0,3,0,0)|lordsk1(0,0,0,0,0,1,0,2)|lordsk2(1,0,1,0,1,0,0,1), mfy1, mfo2], 
["k00_per_pm_monk", "Perisno Monk", "Perisno Monks", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_armor_monie_tevton_b, itm_saracin_turban_c, itm_leather_boots, itm_staff], 
attrlev(12,10,9,5,7), wpex(115,115,130,90,90,90), strsk(1,2,1,0)|agisk(2,0,4,0,0)|lordsk1(0,0,0,0,0,2,1,2)|lordsk2(2,1,1,0,2,0,0,2), mfy1, mfo2], 
["k00_per_pm_cleric", "Perisno Cleric", "Perisno Clerics", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_sergeant_tevton_armor_b, itm_spiked_helmet, itm_splinted_leather_greaves, itm_mail_mittens, itm_german_morningstar, itm_kite_shield_6], 
attrlev(16,13,11,6,14), wpex(165,165,165,115,115,115), strsk(2,4,2,2)|agisk(4,2,5,0,0)|lordsk1(0,0,1,0,0,2,2,2)|lordsk2(3,2,2,0,3,1,0,2), mfy1, mfo2], 
["k00_per_pm_crusader", "Perisno Crusader", "Perisno Crusaders", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_knight_armor_templar_d, itm_normanhelmbalaclavacoif, itm_dorn_spearbearer_boots, itm_wisby_gauntlets_black, itm_templar_knight_horse_d, itm_spiked_mace, itm_shield_2], 
attrlev(21,15,13,11,24), wpex(235,235,235,130,130,130), strsk(4,5,3,3)|agisk(6,5,5,5,0)|lordsk1(2,0,2,2,1,2,3,3)|lordsk2(3,2,2,0,3,3,2,2), mfo1, mfo2], 
["k00_per_pm_zealot", "Perisno Zealot", "Perisno Zealots", tf_guarantee_all, 0,0, fac_kingdom_0, [itm_knight_armor_templar_d_cloak, itm_crusader_knight_helm_c, itm_black_greaves, itm_gauntlets, itm_whg2, itm_axe_crusader_1, itm_german_horsemans_axe_no1, itm_shields_archer_templar_a, itm_heavy_crossbow, itm_bolts], 
attrlev(28,18,15,18,40), wpex(340,340,340,150,250,150), strsk(7,7,4,4)|agisk(8,7,6,7,5)|lordsk1(4,0,3,4,3,3,4,3)|lordsk2(3,2,3,2,3,4,5,2), mfo1, mfo2], 
["k00_per_pm_priest", "Perisno Priest", "Perisno Priests", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_knight_armor_tevton_c, itm_flattop, itm_mail_boots, itm_hourglass_gauntlets, itm_german_bastard_sword], 
attrlev(22,16,15,7,24), wpex(220,220,220,140,140,140), strsk(5,5,3,3)|agisk(6,3,6,0,0)|lordsk1(0,0,1,0,0,3,3,3)|lordsk2(4,3,4,0,4,1,2,3), mfo1, mfo2], 
["k00_per_pm_holychampion", "Perisno Holy Champion", "Perisno Holy Champions", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_knight_armor_tevton_c_cloak, itm_maciejowski_helmet_new5, itm_plate_boots2, itm_plate_mittens, itm_perisno_king_sword], 
attrlev(30,21,19,10,42), wpex(300,350,300,200,200,200), strsk(8,7,5,5)|agisk(8,4,8,0,0)|lordsk1(0,0,3,0,2,3,4,4)|lordsk2(4,4,4,2,4,2,6,4), mfo1, mfo2], 

#Perisno Female Pilgrims added by Melanie (Yes, they use blunt weapons, but are rare compared to male pilgrims.  They also add a mounted element at high tier)
["k00_per_pf_initiate", "Perisno Initiate", "Perisno Initiates",tf_female|tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_sarranid_common_dress, itm_sarranid_felt_head_cloth_b, itm_rus_shoes, itm_cudgel], 
attrlev(9,10,7,5,3), wpex(100,100,100,75,75,75), strsk(0,1,0,0)|agisk(2,0,4,0,0)|lordsk1(0,0,0,0,0,1,1,2)|lordsk2(1,0,1,0,1,0,0,0), refugee_face1, refugee_face2], 
["k00_per_pf_novice", "Perisno Novice", "Perisno Novices", tf_female|tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_demonrobe, itm_simple_ench, itm_civil_rich_boots_b, itm_rrr_club1, itm_kite_shield_8], 
attrlev(11,13,9,6,7), wpex(150,150,150,90,90,90), strsk(1,2,0,0)|agisk(3,1,6,0,0)|lordsk1(0,0,0,0,1,2,2,2)|lordsk2(2,0,2,0,2,1,0,1), refugee_face1, refugee_face2], 
["k00_per_pf_nunfoot", "Perisno Nun", "Perisno Nuns", tf_female|tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_new_cuir_bouilli, itm_soldiers_ench, itm_shadow_greaves, itm_long_hafted_knobbed_mace], 
attrlev(14,16,12,8,16), wpex(210,210,210,110,110,110), strsk(2,3,1,1)|agisk(5,2,7,0,0)|lordsk1(0,0,0,0,2,3,2,3)|lordsk2(3,1,3,0,3,2,0,2), refugee_face1, refugee_face2], 
["k00_per_pf_nuncavalry", "Perisno Nun Cavalry", "Perisno Nun Cavalry", tf_female|tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_xenoargh_female_armor_sisters_of_mercy1, itm_fine_ench, itm_shadow_greaves, itm_wisby_gauntlets_black, itm_templar_knight_horse_c, itm_sarranid_mace_1, itm_shield_4], 
attrlev(18,20,15,10,29), wpex(290,290,290,130,130,130), strsk(4,5,3,2)|agisk(6,4,7,5,0)|lordsk1(0,0,0,0,3,3,3,3)|lordsk2(4,2,4,0,3,2,1,2), refugee_face1, refugee_face2], 
["k00_per_pf_priestess", "Perisno Priestess", "Perisno Priestesses", tf_female|tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_xenoargh_female_armor_sisters_of_mercy4, itm_noble_ench, itm_black_greaves, itm_glovesblack, itm_hospitaller_charger, itm_sw_pear_mace_steel, itm_shields_archer_templar_b], 
attrlev(22,25,18,14,42), wpex(370,370,370,150,150,150), strsk(5,6,4,4)|agisk(8,5,8,7,0)|lordsk1(0,0,2,0,4,3,3,4)|lordsk2(6,3,6,0,4,3,2,3), refugee_face1, refugee_face2], 

#fakes for custom templates
["k00_per_pm_good_pilgrim", "Perisno Pilgrim", "Perisno Pilgrims", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_archer_tevton_armor_b, itm_padded_coif, itm_leather_boots, itm_lui_waronehandedaxec], 
attrlev(9,7,6,4,4), wpex(85,70,85,70,70,70), strsk(0,1,0,0)|agisk(1,0,3,0,0)|lordsk1(0,0,0,0,0,1,0,2)|lordsk2(1,0,1,0,1,0,0,1), mfy1, mfo2], 
["k00_per_pm_good_monk", "Perisno Monk", "Perisno Monks", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_armor_monie_tevton_b, itm_saracin_turban_c, itm_leather_boots, itm_staff], 
attrlev(12,10,9,5,7), wpex(115,115,130,90,90,90), strsk(1,2,1,0)|agisk(2,0,4,0,0)|lordsk1(0,0,0,0,0,2,1,2)|lordsk2(2,1,1,0,2,0,0,2), mfy1, mfo2], 
["k00_per_pm_good_cleric", "Perisno Cleric", "Perisno Clerics", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_sergeant_tevton_armor_b, itm_spiked_helmet, itm_splinted_leather_greaves, itm_mail_mittens, itm_german_morningstar, itm_kite_shield_6], 
attrlev(16,13,11,6,14), wpex(165,165,165,115,115,115), strsk(2,4,2,2)|agisk(4,2,5,0,0)|lordsk1(0,0,1,0,0,2,2,2)|lordsk2(3,2,2,0,3,1,0,2), mfy1, mfo2], 
["k00_per_pm_bad_pilgrim", "Perisno Pilgrim", "Perisno Pilgrims", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_archer_tevton_armor_b, itm_padded_coif, itm_leather_boots, itm_lui_waronehandedaxec], 
attrlev(9,7,6,4,4), wpex(85,70,85,70,70,70), strsk(0,1,0,0)|agisk(1,0,3,0,0)|lordsk1(0,0,0,0,0,1,0,2)|lordsk2(1,0,1,0,1,0,0,1), mfy1, mfo2], 
["k00_per_pm_bad_monk", "Perisno Monk", "Perisno Monks", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_armor_monie_tevton_b, itm_saracin_turban_c, itm_leather_boots, itm_staff], 
attrlev(12,10,9,5,7), wpex(115,115,130,90,90,90), strsk(1,2,1,0)|agisk(2,0,4,0,0)|lordsk1(0,0,0,0,0,2,1,2)|lordsk2(2,1,1,0,2,0,0,2), mfy1, mfo2], 
["k00_per_pm_bad_cleric", "Perisno Cleric", "Perisno Clerics", tf_guarantee_inf, 0,0, fac_kingdom_0, [itm_sergeant_tevton_armor_b, itm_spiked_helmet, itm_splinted_leather_greaves, itm_mail_mittens, itm_german_morningstar, itm_kite_shield_6], 
attrlev(16,13,11,6,14), wpex(165,165,165,115,115,115), strsk(2,4,2,2)|agisk(4,2,5,0,0)|lordsk1(0,0,1,0,0,2,2,2)|lordsk2(3,2,2,0,3,1,0,2), mfy1, mfo2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#Bandits
["ou_looter","Robber","Robbers",0,0,0,fac_outlaw_union, [itm_leather_vest, itm_sarranid_cloth_robe_b, itm_ragged_outfit, itm_felt_hat, itm_ankle_boots, itm_rus_shoes, itm_knife, itm_wooden_stick, itm_h_spear, itm_stones, itm_throwing_knives], 
attrlev(9,6,5,4,2), wpex(55,55,55,45,45,50), strsk(0,1,0,0)|agisk(1,0,1,0,0)|lordsk1(3,0,0,0,0,0,0,1), bandit_face1, bandit_face2], 
["ou_bandit","Bandit","Bandits",tf_guarantee_inf,0,0,fac_outlaw_union, [itm_ragged_outfit, itm_leather_vest, itm_gambeson, itm_felt_hat, itm_leather_cap, itm_woolen_cap, itm_ankle_boots, itm_rus_shoes, itm_butchering_knife, itm_cleaver, itm_club2_v2, itm_cudgel, itm_practice_bow_2, itm_barbed_arrows, itm_hunting_crossbow, itm_bolts], 
attrlev(11,7,5,5,5), wpex(90,90,90,80,80,80), strsk(1,2,1,1)|agisk(2,0,2,0,0)|lordsk1(5,0,0,1,0,0,0,1)|lordsk2(0,0,0,0,0,1,0,0), bandit_face1, bandit_face2], 
["ou_wandering_criminal","Wandering Criminal","Wandering Criminals",tf_guarantee_inf,0,0,fac_outlaw_union, [itm_dethertir_armor_b, itm_gambeson, itm_rough_leather_6, itm_skullcap, itm_leather_warrior_cap, itm_hide_boots, itm_leather_boots, itm_saddle_horse, itm_horse_bandits_a, itm_voulge, itm_sledgehammer, itm_sword_medieval_b_small, itm_fur_covered_shield, itm_light_crossbow, itm_bolts], 
attrlev(14,9,6,6,11), wpex(140,140,140,100,120,100), strsk(3,3,2,2)|agisk(3,1,3,2,2)|lordsk1(5,1,0,1,0,0,1,2)|lordsk2(0,0,1,0,0,2,0,0), bandit_face1, bandit_face2], 
["ou_brigand","Brigand","Brigands",tf_guarantee_allnoranged,0,0,fac_outlaw_union, [itm_studded_leather_coat, itm_dethertir_armor_c, itm_spiked_helmet, itm_nasal_helmet, itm_mail_coif, itm_leather_boots, itm_leather_gloves, itm_horse_bandits_a, itm_sword_medieval_c_long, itm_kite_shield_4, itm_long_spiked_club, itm_light_crossbow, itm_steel_bolts], 
attrlev(17,11,7,7,17), wpex(190,190,190,145,160,145), strsk(4,5,3,3)|agisk(4,3,3,4,4)|lordsk1(6,1,0,2,1,0,2,2)|lordsk2(0,0,1,0,0,2,0,0), bandit_face1, bandit_face2], 
["ou_marauder","Marauder","Marauders",tf_guarantee_allnoranged,0,0,fac_outlaw_union, [itm_dethertir_armor_a, itm_dethertir_armor_e, itm_normanhelmet2, itm_normanhelmcoif, itm_leather_boots, itm_splinted_greaves, itm_splinted_leather_greaves, itm_mail_mittens, itm_xenoargh_bayappy, itm_european_horse_f, itm_luc_spiked_war_club, itm_great_axe, itm_heavy_shield2, itm_crossbow, itm_bolts, itm_steel_bolts], 
attrlev(21,13,8,8,27), wpex(250,250,250,190,210,190), strsk(6,6,4,4)|agisk(6,4,4,5,5)|lordsk1(6,2,0,2,2,1,2,3)|lordsk2(1,0,1,0,0,3,0,0), bandit_face1, bandit_face2], 
["ou_vanquisher","Vanquisher","Vanquishers",tf_guarantee_all,0,0,fac_outlaw_union, [itm_wei_xiadi_nord_spiked_mail, itm_coat_of_plates_a, itm_barbuta1_black, itm_facecovermail_kettlehat_s, itm_blacksale_salad, itm_dorn_spearbearer_boots, itm_mail_mittens, itm_northerner_horse_black, itm_military_cleaver_c, itm_military_cleaver_b, itm_plate_covered_round_shield, itm_heavy_crossbow, itm_bolts, itm_steel_bolts], 
attrlev(26,16,10,10,37), wpex(340,340,340,240,270,240), strsk(8,8,5,5)|agisk(8,6,5,7,7)|lordsk1(7,2,1,3,3,1,2,3)|lordsk2(1,0,1,0,1,4,0,0), bandit_face1, bandit_face2], 
["ou_knight_of_doom","Knight of Doom","Knights of Doom",tf_guarantee_allnoranged,0,0,fac_outlaw_union, [itm_coat_of_plates, itm_spak_helmet_k, itm_black_greaves, itm_scale_gauntlets, itm_charger_black, itm_whg2, itm_giant_cleaver, itm_sp_newsh, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt, itm_van_helsing_crossbow_bolt], 
attrlev(32,19,12,14,54), wpex(450,450,450,300,350,300), strsk(10,10,7,7)|agisk(10,8,6,9,9)|lordsk1(8,2,3,4,5,2,3,4)|lordsk2(1,0,1,2,2,4,2,0), bandit_face1, bandit_face2], 
#
["ou_dwarf", "Outlaw Dwarf", "Outlaw Dwarves", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_rough_leather_ringed_dwarf, itm_pino_tunic_spiked_rings_dwarf, itm_act_dwarven_inf_helmet_t1, itm_leather_boots_dark, itm_mail_mittens, itm_luc_waronehandedaxec, itm_one_handed_war_axe_no14, itm_dwarf_shield_f, itm_light_throwing_axes], 
attrlev(18,7,7,6,9), wpex(100,100,80,70,90,90), strsk(2,2,2,1)|agisk(2,2,3,0,0)|lordsk1(3,0,0,0,0,0,1,2)|lordsk2(0,0,0,1,0,1,0,0), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_dwarfaxeman", "Outlaw Dwarf Axeman", "Outlaw Dwarf Axemen", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_pino_tunic_mail_spiked_dwarf, itm_banded_armor_a_dwarf, itm_dwarf_helm_b, itm_b_h1, itm_dark_mail_mittens, itm_luc_knightaxeoneh, itm_one_handed_war_axe_no11, itm_dwarf_shield_j, itm_throwing_axes], 
attrlev(22,9,8,7,17), wpex(150,150,120,100,130,150), strsk(4,4,4,2)|agisk(3,4,4,0,0)|lordsk1(5,1,0,1,1,1,1,2)|lordsk2(0,0,0,1,0,2,0,1), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_dwarfinfantry", "Outlaw Dwarf Infantry", "Outlaw Dwarf Infantry", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_ak_long_surcoat_a1_dwarf, itm_inf_t3, itm_mail_chausses_shin_guard, itm_dorn_knight_gant, itm_sarranid_two_handed_axe_b, itm_tab_shield_round_d, itm_heavy_throwing_axes], 
attrlev(27,11,10,9,27), wpex(220,220,180,130,170,210), strsk(6,6,6,4)|agisk(5,6,5,0,0)|lordsk1(5,1,1,1,2,1,2,3)|lordsk2(0,0,0,2,0,2,0,1), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_dwarfaxemaster", "Outlaw Dwarf Axemaster", "Outlaw Dwarf Axemaster", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_got_orc_cuir_bouilli_dwarf, itm_dwarf_ih_helm_2, itm_west_pikeman_boots_dark, itm_glovesblack, itm_varangian_war_axe_no1, itm_german_horsemans_axe_no1, itm_dwarf_shield_6c], 
attrlev(33,13,11,12,37), wpex(300,300,260,160,210,280), strsk(8,8,7,6)|agisk(6,8,6,0,0)|lordsk1(6,1,2,2,4,1,2,3)|lordsk2(0,0,0,3,0,3,0,2), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_dwarfwhatever", "Dagrankhazdur", "Dagrankhazdar", tf_dwarf_male|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_et_black_dwarf, itm_dwarf_er_helm_1_dark, itm_west_pikeman_boots_dark, itm_glovesblack, itm_great_axe_no4, itm_sp_shr1], 
attrlev(40,16,13,15,47), wpex(380,380,350,200,250,350), strsk(10,10,9,8)|agisk(8,10,8,0,0)|lordsk1(7,1,3,2,6,1,3,4)|lordsk2(0,0,0,4,1,4,1,3), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
#
["ou_redinitiate", "Red Initiate", "Red Initiates", tf_elven_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_rough_padded_leather_3_red, itm_simple_ench, itm_rus_cav_boots, itm_gloves_lord_l, itm_luc_scramasax, itm_noldor_bow, itm_spak_bow8_arrow], 
attrlev(10,13,10,13,7), wpex(130,80,100,160,80,80), strsk(0,1,0,2)|agisk(2,0,2,0,0)|lordsk1(3,1,0,1,1,1,1,1)|lordsk2(1,0,0,0,1,0,0,1), elintoran_face_female_start, elintoran_face_female_end], 
["ou_scarletsnake", "Scarlet Snake", "Scarlet Snakes", tf_elven_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_j_surcoat_comp_1b, itm_soldiers_ench, itm_civil_rich_boots_a, itm_gloves_lord_l, itm_lorien_sword_b, itm_amazon_bow, itm_spak_bow8_arrow], 
attrlev(13,17,12,16,15), wpex(170,110,140,220,110,110), strsk(0,2,1,4)|agisk(4,0,4,0,0)|lordsk1(4,2,0,2,3,2,2,2)|lordsk2(1,0,1,0,2,1,0,2), elintoran_face_female_start, elintoran_face_female_end], 
["ou_redsnake", "Red Snake", "Red Snakes", tf_elven_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_wei_xiadi_mail_shirt02, itm_fine_ench, itm_rus_splint_greaves, itm_gondor_bracer_l, itm_faradon_onehanded, itm_spak_bow6, itm_spak_ar2], 
attrlev(15,20,14,18,22), wpex(220,160,90,290,140,140), strsk(2,4,2,6)|agisk(5,0,5,0,0)|lordsk1(5,2,0,3,4,3,3,2)|lordsk2(1,0,2,0,2,2,0,3), elintoran_face_female_start, elintoran_face_female_end], 
["ou_maroonsnake", "Maroon Snake", "Maroon Snakes", tf_elven_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_j_surcoat_comp_19c, itm_noble_ench, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_jack_herugrim, itm_lonely, itm_spak_ar2], 
attrlev(18,25,17,22,34), wpex(280,200,240,360,170,170), strsk(3,5,3,7)|agisk(7,0,7,0,0)|lordsk1(6,3,0,3,6,3,4,3)|lordsk2(2,0,2,0,3,3,0,3), elintoran_face_female_start, elintoran_face_female_end], 
["ou_maroonviper", "Maroon Viper", "Maroon Vipers", tf_elven_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_j_blacksmith_marinian_armor_c, itm_elfhelm_grey_full, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_sabre_val_1, itm_lonely, itm_spak_bow6_arrow, itm_scull_arrow], 
attrlev(22,31,20,27,47), wpex(350,250,300,440,200,200), strsk(4,7,5,8)|agisk(9,0,8,0,0)|lordsk1(7,4,2,4,8,4,4,4)|lordsk2(2,0,2,1,4,4,1,4), elintoran_face_female_start, elintoran_face_female_end], 
#
["ou_haderas_blackknight","Black Knight of Haderas","Black Knights of Haderas",tf_guarantee_allnoranged,0,0, fac_outlaw_union, [itm_west_heraldic, itm_sugarloaf_b, itm_west_pikeman_boots, itm_gauntlets, itm_charger_new_black_long, itm_razor_nema, itm_tab_shield_heater_cav_b], 
attrlev(36,21,14,24,66), wpex(520,520,500,330,400,400), strsk(10,10,8,8)|agisk(10,9,6,10,9)|lordsk1(9,2,4,4,7,2,4,4)|lordsk2(1,0,2,2,3,6,4,1), bandit_face1, bandit_face2], 
["ou_moonless_wind","Wind of Moonless Night","Winds of Moonless Night",tf_elven_male|tf_guarantee_allnoranged,0,0, fac_outlaw_union, [itm_mirk_armor_1c, itm_west_man_at_arms_closed, itm_rivend_boots_1c, itm_dorn_assasin_gant, itm_5warhorse_holy, itm_an_sword01b, itm_rivend_shield_2b], 
attrlev(35,30,24,24,76), wpex(550,550,500,500,400,400), strsk(9,10,9,9)|agisk(10,8,8,10,7)|lordsk1(4,4,8,4,10,4,8,4)|lordsk2(4,1,4,2,4,2,2,2), elintoran_face_old_begin, elintoran_face_old_end], 
["ou_moonless_whisper","Whisper of Moonless Night","Whispers of Moonless Night",tf_elven_female|tf_guarantee_archer,0,0, fac_outlaw_union, [itm_rivend_rohir_armor_1d, itm_dorn_knight_helmet_b, itm_rivend_boots_1c, itm_dorn_assasin_gant, itm_an_axe02, itm_ebonybow, itm_spak_bow6_arrow, itm_blackarrow], 
attrlev(27,35,26,29,60), wpex(450,450,450,550,300,300), strsk(6,9,6,9)|agisk(10,4,10,6,6)|lordsk1(4,4,4,8,10,6,8,6)|lordsk2(3,1,3,3,6,4,2,6), elintoran_face_female_start, elintoran_face_female_end], 
["ou_blackbolt", "Black Bolt", "Black Bolts", tf_dwarf_male|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_banded_armor_got_dwarf, itm_dwarvenforged_helm_noveil_dwarf, itm_west_pikeman_boots_dark, itm_dark_mail_mittens, itm_mackie_morning_star_cwe, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt, itm_van_helsing_crossbow_bolt], 
attrlev(36,18,13,17,48), wpex(280,280,320,230,350,230), strsk(7,7,6,6)|agisk(8,3,7,0,0)|lordsk1(6,2,2,1,4,1,4,4)|lordsk2(0,0,0,3,1,4,0,1), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_priestessofwar", "Priestess of War", "Priestesses of War", tf_giant_female|tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_medusa_armor, itm_barbuta_horny, itm_mail_boots, itm_scale_gauntlets_b, itm_an_bastardsword], 
attrlev(42,21,12,12,50), wpex(270,350,270,150,100,270), strsk(7,10,8,6)|agisk(8,0,8,0,0)|lordsk1(5,2,4,4,2,2,3,4)|lordsk2(0,0,3,0,2,4,4,2), giant_face_female_start, giant_face_female_end], 
["ou_rogue_maccknight","Renegade Maccavian Knight","Renegade Maccavian Knights", tf_guarantee_all,0,0, fac_outlaw_union, [itm_armour_vargo, itm_helmet_cof_1, itm_black_greaves, itm_dorn_assasin_gant, itm_2imperial_warhorse, itm_pappen2, itm_sp_newsh, itm_crossbow_axe, itm_steel_bolts], 
attrlev(32,23,19,20,56), wpex(380,350,350,200,300,300), strsk(8,8,7,5)|agisk(10,8,6,8,8)|lordsk1(7,0,4,3,7,3,4,4)|lordsk2(1,1,2,4,3,4,3,2), bandit_face1, bandit_face2], 
["ou_batman", "Batman", "Batmen", tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_dorn_wiper, itm_bolzanobucket, itm_dorn_spearbearer_boots, itm_glovesblack, itm_faradon_largeclub], 
attrlev(35,25,12,13,50), wpex(200,500,200,100,100,100), strsk(9,10,8,8)|agisk(10,0,7,0,0)|lordsk1(8,1,4,4,5,1,3,3)|lordsk2(0,0,2,0,2,6,0,3), bandit_face1, bandit_face2], 
["ou_giant_huntress", "Giant Huntress", "Giant Huntresses", tf_giant_female|tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_armour_north_clanman2, itm_barbuta_horny, itm_bear_boots, itm_beargauntlets, itm_medieval_axe_1, itm_dwarf_horn_bow, itm_1steel_arrow, itm_1steel_arrow], 
attrlev(38,24,10,10,40), wpex(250,280,250,280,150,200), strsk(9,9,8,9)|agisk(7,3,7,0,0)|lordsk1(5,5,0,4,0,3,3,3)|lordsk2(1,0,1,0,1,2,0,2), giant_face_female_start, giant_face_female_end], 
["ou_peacekeeper", "Peacekeeper", "Peacekeepers", tf_dwarf_male|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet, 0,0, fac_outlaw_union, [itm_et_pearl_dwarf, itm_dwarf_helm_o, itm_wp_boots_light, itm_dwarf_glove, itm_white_great_hammer, itm_dec_steel_shield, itm_luc_throwing_hammer, itm_luc_throwing_hammer, itm_luc_throwing_hammer], 
attrlev(38,16,11,16,48), wpex(330,330,250,150,200,400), strsk(11,10,10,8)|agisk(8,7,6,0,0)|lordsk1(6,0,1,3,2,1,4,4)|lordsk2(0,0,0,1,1,6,2,2), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["ou_nihonian_sharpshooter", "Nihonian Sharpshooter", "Nihonian Sharpshooters", tf_guarantee_archer, 0,0, fac_outlaw_union, [itm_wei_xiadi_scale_armor01, itm_vaeg_helmet5, itm_west_man_at_arms_boots, itm_scale_gauntlets_b, itm_warbrand_runico, itm_akwar_bow, itm_1steel_arrow, itm_1steel_arrow], 
attrlev(23,20,11,13,42), wpex(240,240,240,440,250,200), strsk(5,5,5,8)|agisk(9,2,5,0,0)|lordsk1(3,2,1,0,2,0,6,3)|lordsk2(0,0,0,1,1,2,0,2), 0x0000000800107050144924a44928a44900000000001da2490000000000000000, 0x0000000dbe1071d46dacdeecf69a4dad00000000001eebae0000000000000000], 
["ou_fiend", "Fiend", "Fiends", tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_coat_of_plates, itm_munitionshelm1, itm_west_pikeman_boots_dark, itm_scale_gauntlets, itm_unholy_trident], 
attrlev(28,25,12,13,46), wpex(280,280,450,150,150,150), strsk(8,9,6,6)|agisk(9,2,7,0,0)|lordsk1(6,1,3,0,8,0,3,3)|lordsk2(0,0,0,0,0,3,0,0), bandit_face1, bandit_face2], 
["ou_highlander", "Outlaw Highlander", "Outlaw Highlanders", tf_guarantee_inf, 0,0, fac_outlaw_union, [itm_a_h3, itm_skullcap, itm_b_h1, itm_mail_mittens, itm_2h_claymore], 
attrlev(31,22,10,12,39), wpex(400,440,400,180,180,180), strsk(10,10,6,6)|agisk(8,4,8,0,0)|lordsk1(7,2,5,0,2,1,2,3)|lordsk2(0,0,0,0,0,3,0,0), bandit_face1, bandit_face2], 
["ou_scorpion","Al-eaqarab Horse Archer","Al-eaqarab Horse Archers", tf_guarantee_all,0,0, fac_outlaw_union, [itm_j_surcoat_ssm_01d, itm_saracin_turban_c_eaqarab, itm_saracin_hard_boot_b, itm_gauntlets_arabs_b_l, itm_saracin_hard_horses_c, itm_luc_sarranid_falchion_m3, itm_brass_shield, itm_hangong, itm_song_arrows], 
attrlev(26,29,20,18,56), wpex(400,300,300,440,200,300), strsk(10,8,7,10)|agisk(9,7,8,9,10)|lordsk1(3,4,6,4,7,4,8,4)|lordsk2(3,0,4,2,4,4,2,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["ou_blackmarshal", "Black Marshal", "Black Marshals", tf_guarantee_allnoranged, 0,0, fac_outlaw_union, [itm_black_marshal_armor, itm_west_squire_helm, itm_black_boot_salad_of, itm_blackplatemitty, itm_plated_charger9, itm_stark_axe, itm_saracin_shield_t], 
attrlev(33,21,18,25,60), wpex(500,500,500,270,270,270), strsk(9,9,7,7)|agisk(10,8,5,9,0)|lordsk1(8,0,7,2,7,3,3,4)|lordsk2(0,0,0,3,4,4,7,3), mercenary_face_1, mercenary_face_2], 
#
["ou_mercgiantwarrior", "Mercenary Giant Warrior", "Mercenary Giant Warriors", tf_giant_male|tf_guarantee_inf, 0, 0, fac_outlaw_union, [itm_armor_elite_marauder_of_norsca_c_02, itm_giant_horned_skull_helmet_bakhal, itm_giant_plated_boots_sharp, itm_giant_gloves_plus, itm_crowbill_weathered_marauder_01, itm_bakhal_steel_shield, itm_throwing_spears, itm_throwing_spears], 
attrlev(52,16,8,12,48), wpex(300,300,250,200,100,300), strsk(11,11,10,8)|agisk(8,6,8,0,0)|lordsk1(7,1,4,2,1,0,4,2)|lordsk2(0,0,0,1,0,4,2,1), swadian_face_younger_1, swadian_face_middle_2], 

#################################################################################################################################################################################
##################################################################MINOR FACTIONS AND SPAWNS ALL MOVED HERE!######################################################################
#################################################################################################################################################################################

#Cavalry
["m01_mem_c_cavalryman", "Cavalryman", "Cavalrymen", tf_guarantee_allnoranged, 0,0, fac_commoners, [itm_leather_armor, itm_nordic_archer_helmet, itm_light_leather_boots, itm_leather_gloves, itm_saddle_horse, itm_sword_medieval_b, itm_leather_covered_round_shield, itm_shortened_spear, itm_light_throwing_axes], 
attrlev(10,7,6,7,5), wpex(100,100,100,90,90,90), strsk(1,1,1,0)|agisk(2,1,2,3,4)|lordsk1(1,0,0,0,0,1,1,1)|lordsk2(0,0,0,0,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m01_mem_c_caravanguard","Caravan Guard","Caravan Guards",tf_guarantee_allnoranged,no_scene,0,fac_commoners, [itm_heraldic_padded_cloth, itm_leather_steppe_cap_b, itm_nomad_cap, itm_saracin_turban_c, itm_light_leather_boots, itm_mail_mittens, itm_hunting_horse_four, itm_sword_medieval_c_long, itm_mace_3, itm_tab_shield_small_round_a, itm_double_sided_lance], 
attrlev(13,9,7,9,8), wpex(135,135,135,110,110,110), strsk(2,2,1,1)|agisk(3,2,2,4,4)|lordsk1(1,0,0,1,0,2,2,2)|lordsk2(0,0,0,0,1,2,0,1), mercenary_face_1,mercenary_face_2], 
["m01_mem_c_shockcavalry", "Mercenary Shock Cavalry", "Mercenary Shock Cavalry", tf_guarantee_allnoranged, 0,0, fac_commoners, [itm_rough_leather_ringed, itm_light_crusader_helm_d, itm_rus_cav_boots, itm_mail_mittens, itm_european_horse_a, itm_sword_medieval_c, itm_luc_spiked_mace_b, itm_2shield, itm_light_lance], 
attrlev(16,11,8,11,14), wpex(165,165,165,130,130,130), strsk(3,3,2,2)|agisk(4,3,3,5,5)|lordsk1(2,0,0,2,1,2,2,2)|lordsk2(0,0,0,0,2,2,0,1), mercenary_face_1, mercenary_face_2], 
["m01_mem_c_cavalry", "Mercenary Cavalry", "Mercenary Cavalry", tf_guarantee_allnoranged|tf_guarantee_polearm, 0,0, fac_commoners, [itm_cuir_bouilli, itm_flat_topped_helmet, itm_mail_boots, itm_new_lamellar_gauntlets, itm_leather_armour_charger1, itm_luc_flemish_sword, itm_war_axe, itm_luc_cavalry_shield_z, itm_lance], 
attrlev(19,13,9,14,22), wpex(205,205,205,150,150,150), strsk(4,5,3,3)|agisk(6,5,4,6,6)|lordsk1(3,0,0,2,1,2,3,3)|lordsk2(0,0,0,0,2,2,0,2), mercenary_face_1, mercenary_face_2], 
["m01_mem_c_lancer", "Mercenary Lancer", "Mercenary Lancers", tf_guarantee_allnoranged|tf_guarantee_polearm, 0,0, fac_commoners, [itm_banded_armor_common, itm_flattop, itm_crusader_hard_helm_ord, itm_iron_greaves, itm_gauntlets, itm_war_horse4, itm_war_horse1, itm_crusader_long_sword_a, itm_luc_horsemans_axe, itm_saracin_shield_s, itm_lance_2, itm_lance_3], 
attrlev(23,15,10,18,35), wpex(260,260,260,170,170,170), strsk(5,6,4,4)|agisk(7,6,4,7,7)|lordsk1(3,0,1,2,2,3,3,3)|lordsk2(0,0,0,1,3,3,1,2), mercenary_face_1, mercenary_face_2], 
#Infantry
["m01_mem_i_swordsman","Mercenary Swordsman","Mercenary Swordsmen",tf_guarantee_inf,0,0,fac_commoners, [itm_haubergeon, itm_guard_helmet, itm_mail_boots, itm_mail_mittens, itm_sword_viking_1, itm_norman_shield_5], 
attrlev(16,11,8,10,15), wpex(175,175,175,130,130,130), strsk(4,4,2,2)|agisk(4,3,4,4,4)|lordsk1(2,0,0,1,0,2,2,2)|lordsk2(0,0,0,0,1,2,0,1), mercenary_face_1,mercenary_face_2], 
["m01_mem_i_sellsword","Sellsword","Sellswords",tf_guarantee_inf,0,0,fac_commoners, [itm_mail_hauberk, itm_bascinet_3, itm_splinted_greaves_spurs, itm_mail_mittens, itm_crusaders_swords_a, itm_steel_shield, itm_sword_two_handed_a], 
attrlev(20,13,9,13,23), wpex(220,220,220,160,160,160), strsk(5,5,3,3)|agisk(5,5,5,4,4)|lordsk1(3,0,0,1,1,2,3,3)|lordsk2(0,0,0,0,2,3,0,2), mercenary_face_1,mercenary_face_2], 
["m01_mem_i_impknight", "Mercenary Impoverished Knight", "Mercenary Impoverished Knights", tf_guarantee_inf, 0,0, fac_commoners, [itm_wei_xiadi_surcoat_rhodok01, itm_crusaderbucket1, itm_iron_greaves, itm_gauntlets, itm_sword_medieval_a, itm_tab_shield_kite_d, itm_luc_zweihander], 
attrlev(25,16,12,18,40), wpex(300,300,300,200,200,200), strsk(7,7,4,4)|agisk(7,7,6,5,5)|lordsk1(4,0,2,2,3,3,3,4)|lordsk2(0,0,0,2,4,4,2,3), mercenary_face_1, mercenary_face_2], 
#Crossbows
["m01_mem_a_skirmisher", "Mercenary Skirmisher", "Mercenary Skirmishers", tf_guarantee_archer, 0,0, fac_commoners, [itm_peasant_leather_plate_b, itm_light_capelina_crusader_a, itm_splinted_greaves, itm_leather_gloves, itm_lui_vikingaxeonehb, itm_kite_shield_4, itm_hunting_crossbow, itm_bolts], 
attrlev(12,9,7,9,12), wpex(130,130,130,115,130,115), strsk(1,2,1,1)|agisk(3,1,4,0,0)|lordsk1(1,1,0,1,0,1,2,2)|lordsk2(0,0,0,0,1,1,0,1), mercenary_face_1, mercenary_face_2], 
["m01_mem_a_crossbowman", "Mercenary Crossbowman", "Mercenary Crossbowmen", tf_guarantee_archer, 0,0, fac_commoners, [itm_peasant_leather_mail_ls, itm_kettle_hat, itm_splinted_leather_greaves, itm_new_leather_gloves, itm_lui_knightaxeoneh, itm_tab_shield_pavise_a, itm_light_crossbow, itm_bolts], 
attrlev(15,12,8,11,19), wpex(160,160,160,130,170,130), strsk(2,3,2,2)|agisk(4,2,5,0,0)|lordsk1(2,2,0,1,0,2,3,2)|lordsk2(0,0,0,1,1,2,0,1), mercenary_face_1, mercenary_face_2], 
["m01_mem_a_vetcrossbowman", "Mercenary Veteran Crossbowman", "Mercenary Veteran Crossbowmen", tf_guarantee_archer, 0,0, fac_commoners, [itm_peasant_leather_ring_ls, itm_capelina_crusader_b, itm_mail_boots, itm_mail_mittens, itm_one_handed_war_axe_b, itm_tab_shield_pavise_b, itm_crossbow, itm_steel_bolts], 
attrlev(18,15,10,13,28), wpex(190,190,190,150,210,150), strsk(3,4,3,3)|agisk(5,4,6,0,0)|lordsk1(2,2,0,2,1,3,4,3)|lordsk2(0,0,0,1,2,2,0,2), mercenary_face_1, mercenary_face_2], 
["m01_mem_a_sniper", "Mercenary Sniper", "Mercenary Snipers", tf_guarantee_archer, 0,0, fac_commoners, [itm_leather_swordsman_2, itm_kettlehat2, itm_splinted_greaves_spurs, itm_mail_mittens, itm_lui_knightaxeonehb, itm_tab_shield_pavise_c, itm_heavy_crossbow, itm_steel_bolts], 
attrlev(21,18,11,17,38), wpex(240,240,240,175,275,175), strsk(5,5,3,4)|agisk(7,5,7,0,0)|lordsk1(3,3,0,2,2,3,5,4)|lordsk2(0,0,0,3,3,3,0,3), mercenary_face_1, mercenary_face_2], 
#Additional Mercenaries
["m01_mem_s_shieldsman","Mercenary Shieldman","Mercenary Shieldmen",tf_guarantee_inf,0,0,fac_commoners, [itm_dorn_spearbearer_armor, itm_facecovermail_kettlehat_s, itm_mail_boots, itm_mail_mittens, itm_bastard_sword_a, itm_spak_pavise_1], 
attrlev(21,14,9,14,20), wpex(185,185,185,90,90,90), strsk(6,5,3,3)|agisk(6,7,4,0,0)|lordsk1(1,0,1,0,2,0,1,2)|lordsk2(0,0,0,1,1,3,0,1), mercenary_face_1,mercenary_face_2], 
["m01_mem_s_jouster", "Mercenary Jouster", "Mercenary Jousters", tf_guarantee_allnoranged, 0,0, fac_commoners, [itm_mail_with_tunic_blue, itm_duelling_helmet_blue, itm_splinted_leather_greaves, itm_mail_mittens, itm_war_horse5, itm_mace_4, itm_arena_shield_blue, itm_jousting_lance], 
attrlev(18,16,8,14,22), wpex(200,200,250,160,160,160), strsk(6,6,4,4)|agisk(7,6,5,7,7)|lordsk1(1,0,1,1,1,0,1,2)|lordsk2(0,0,0,0,2,1,0,1), mercenary_face_1, mercenary_face_2], 
["m01_mem_s_masnerianknight", "Masnerian Knight", "Masnerian Knights", tf_guarantee_allnoranged, 0,0, fac_commoners, [itm_maximilian_armour, itm_full_helm, itm_shynbaulds, itm_gauntlets, itm_lamellar_armor_horse, itm_military_pick, itm_steel_shield, itm_lance_5], 
attrlev(26,16,12,21,40), wpex(300,250,330,150,150,150), strsk(7,7,4,4)|agisk(7,6,4,7,7)|lordsk1(4,0,2,2,3,1,2,3)|lordsk2(0,0,0,0,3,3,2,2), mercenary_face_1, mercenary_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Mel Female Mercs
["m02_mef_2_refugee","Refugee","Refugees",tf_female|tf_guarantee_inf,0,0,fac_commoners, [itm_woolen_dress, itm_dress, itm_wimple_a, itm_ankle_boots, itm_staff, itm_lui_waronehandedaxec], 
attrlev(7,7,6,4,1), wpex(70,70,70,60,60,60), strsk(0,0,0,0)|agisk(1,0,2,0,0)|lordsk1(0,0,0,0,0,1,0,2), refugee_face1,refugee_face2], 
["m02_mef_2_archer", "Mercenary Archer", "Mercenary Archers", tf_female|tf_guarantee_archer, 0,0, fac_mercenaries, [itm_rough_leather_6, itm_rus_shoes, itm_luc_italian_longsword, itm_practice_bow_2, itm_barbed_arrows], 
attrlev(10,9,7,6,5), wpex(90,90,90,100,80,80), strsk(0,1,0,2)|agisk(2,1,3,0,0)|lordsk1(1,1,0,1,0,1,1,2)|lordsk2(0,0,0,0,1,1,0,1), refugee_face1, refugee_face2], 
["m02_mef_2_tracker", "Mercenary Tracker", "Mercenary Trackers", tf_female|tf_guarantee_archer, 0,0, fac_mercenaries, [itm_banded_leather_a_spiked, itm_rus_shoes, itm_leather_gloves, itm_longsword_b, itm_hunting_bow, itm_bodkin_arrows], 
attrlev(13,12,8,9,10), wpex(130,130,130,150,110,110), strsk(2,2,1,3)|agisk(3,1,5,0,0)|lordsk1(2,2,0,3,1,2,2,2)|lordsk2(0,0,0,0,1,2,0,1), refugee_face1, refugee_face2], 
["m02_mef_2_huntress", "Mercenary Huntress", "Mercenary Huntresses", tf_female|tf_guarantee_archer, 0,0, fac_mercenaries, [itm_rough_leather_plates_ring, itm_splinted_greaves, itm_mail_mittens, itm_claymore_no1, itm_short_bow, itm_arrows], 
attrlev(16,16,9,11,16), wpex(180,180,180,200,140,140), strsk(3,3,2,4)|agisk(5,2,7,0,0)|lordsk1(3,4,0,3,1,3,3,3)|lordsk2(0,0,1,0,2,2,0,2), refugee_face1, refugee_face2], 
["m02_mef_2_masterhuntress", "Mercenary Master Huntress", "Mercenary Master Huntresses", tf_female|tf_guarantee_archer, 0,0, fac_mercenaries, [itm_banded_armor, itm_splinted_leather_greaves, itm_mail_mittens, itm_bastard_sword_a_fix, itm_short_imperial_bow, itm_spak_bow8_arrow], 
attrlev(20,19,10,13,25), wpex(240,240,240,265,170,170), strsk(4,4,3,6)|agisk(6,2,8,0,0)|lordsk1(3,6,0,4,2,3,4,3)|lordsk2(0,0,1,0,3,3,0,2), refugee_face1, refugee_face2], 
["m02_mef_2_stalker", "Mercenary Stalker", "Mercenary Stalkers", tf_female|tf_guarantee_archer, 0,0, fac_mercenaries, [itm_banded_armor_common, itm_splinted_greaves_spurs, itm_gondor_bracer_l, itm_german_bastard_sword, itm_fire_nomad_bow, itm_spak_bow8_arrow], 
attrlev(24,24,11,16,33), wpex(285,285,285,325,200,200), strsk(5,6,4,7)|agisk(7,3,9,0,0)|lordsk1(4,6,1,6,3,4,4,3)|lordsk2(1,0,1,0,3,4,0,3), refugee_face1, refugee_face2], 

#Main Female Merc Troop Tree
["m02_mef_1_peasantwoman","Peasant Woman","Peasant Women",tf_female|tf_guarantee_armor|tf_guarantee_helmet,0,0,fac_commoners, [itm_peasant_dress, itm_headcloth, itm_straw_hat, itm_ankle_boots, itm_scythe, itm_sickle, itm_wooden_stick, itm_luc_studded_club], 
attrlev(8,7,5,4,1), wpex(50,50,50,50,50,50), strsk(0,1,0,0)|agisk(1,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,2)|lordsk2(1,0,0,0,0,0,0,1), refugee_face1,refugee_face2], 
["m02_mef_1_campdefender","Camp Defender","Camp Defenders",tf_female|tf_guarantee_archer,0,0,fac_commoners, [itm_sarranid_common_dress_b, itm_dress, itm_woolen_dress, itm_leather_steppe_cap_b, itm_leather_cap, itm_hide_boots, itm_military_sickle_a, itm_wooden_shield2, itm_hunting_crossbow, itm_bolts], 
attrlev(10,9,6,5,7), wpex(85,85,85,65,85,65), strsk(1,1,0,0)|agisk(2,1,2,0,0)|lordsk1(1,0,0,0,1,0,1,2)|lordsk2(1,0,0,0,0,1,0,1), refugee_face1,refugee_face2], 
["m02_mef_1_scout", "Scout", "Scouts", tf_female|tf_guarantee_archer, 0,0, fac_commoners, [itm_light_leather, itm_skullcap, itm_hide_boots, itm_leather_gloves, itm_dagger, itm_light_crossbow, itm_steel_bolts, itm_bolts], 
attrlev(12,13,7,7,15), wpex(135,135,135,110,140,80), strsk(2,2,1,1)|agisk(3,1,4,0,0)|lordsk1(1,2,0,1,1,1,2,2)|lordsk2(1,0,1,0,0,1,0,2), refugee_face1, refugee_face2], 
["m02_mef_1_markswoman", "Markswoman", "Markswomen", tf_female|tf_guarantee_archer, 0,0, fac_commoners, [itm_ped_padd_lamellar_narrowd, itm_archer_t2, itm_leather_boots, itm_leather_gloves, itm_luc_war_axe_s, itm_heavy_crossbow, itm_steel_bolts, itm_bolts], 
attrlev(15,16,8,10,26), wpex(190,190,190,160,200,100), strsk(3,3,2,2)|agisk(5,2,5,0,0)|lordsk1(2,3,0,1,2,1,3,3)|lordsk2(1,0,1,1,1,2,0,2), refugee_face1, refugee_face2], 
["m02_mef_1_sharpshooter", "Maiden Sharpshooter", "Maiden Sharpshooters", tf_female|tf_guarantee_archer, 0,0, fac_commoners, [itm_heavy_lamellar_armor, itm_barbuta1_black, itm_boot_average_crusader_c, itm_leather_gloves, itm_two_handed_battle_axe_2, itm_heavy_crossbow, itm_steel_bolts, itm_steel_bolts], 
attrlev(19,20,10,13,36), wpex(250,250,250,230,270,125), strsk(4,5,3,3)|agisk(6,2,6,0,0)|lordsk1(3,4,1,1,3,2,4,3)|lordsk2(1,0,2,2,2,3,0,3), refugee_face1, refugee_face2], 
["m02_mef_1_femmefatale", "Femme Fatale", "Femme Fatales", tf_female|tf_guarantee_inf, 0,0, fac_commoners, [itm_wei_xiadi_scale_armor02, itm_ak_flattop_helmet_b, itm_leather_boots_dark, itm_new_lamellar_gauntlets, itm_luc_english_falchion, itm_dal_hinduf, itm_throwing_daggers], 
attrlev(14,13,7,7,12), wpex(140,140,140,115,115,115), strsk(2,3,2,1)|agisk(3,2,3,0,0)|lordsk1(1,0,0,0,1,0,1,2)|lordsk2(1,0,1,0,0,2,0,1), refugee_face1, refugee_face2], 
["m02_mef_1_vixenrider","Vixen Rider","Vixen Riders",tf_female|tf_guarantee_allnoranged|tf_guarantee_polearm,0,0,fac_commoners, [itm_brigandine_red, itm_rus_splint_greaves, itm_wisby_gauntlets_red, itm_steppe_paint1, itm_sword_medieval_a_long, itm_dal_hinduf, itm_lance], 
attrlev(17,17,10,10,18), wpex(240,240,240,140,140,140), strsk(3,4,2,2)|agisk(5,3,4,6,0)|lordsk1(3,0,0,2,3,2,3,3)|lordsk2(1,0,3,0,2,2,0,3), refugee_face1,refugee_face2], 
["m02_mef_1_swordsister", "Sword Sister", "Sword Sisters",tf_female|tf_guarantee_inf, 0,0, fac_commoners, [itm_mail_with_surcoat, itm_col1_kettlehat1, itm_splinted_leather_greaves, itm_mail_mittens, itm_sword_viking_3_small, itm_sword_medieval_d_long, itm_norman_shield_5], 
attrlev(18,17,8,9,18), wpex(220,220,220,180,180,180), strsk(4,4,2,3)|agisk(5,4,4,0,0)|lordsk1(2,0,0,0,2,0,2,3)|lordsk2(2,0,1,0,1,2,0,2), refugee_face1, refugee_face2], 
["m02_mef_1_swordmaiden", "Sword Maiden", "Sword Maidens", tf_female|tf_guarantee_inf, 0,0, fac_commoners, [itm_xenoargh_new_female_armor02, itm_crusader_knight_helm_c, itm_shadow_greaves, itm_wisby_gauntlets_red, itm_arabian_sword_c, itm_shields_archer_templar_b], 
attrlev(23,21,10,12,30), wpex(310,310,310,240,240,240), strsk(6,6,4,4)|agisk(7,6,5,0,0)|lordsk1(2,0,2,1,3,1,3,3)|lordsk2(2,1,2,1,2,3,0,3), refugee_face1, refugee_face2], 
["m02_mef_1_assassin", "Female Assassin", "Female Assassins", tf_female|tf_guarantee_inf, 0,0, fac_commoners, [itm_shadow_outfit_a, itm_saracin_turban_c, itm_sarranid_boots_black, itm_gondor_bracer_l, itm_youhou_assassin_sword, itm_roman_shield_velite], 
attrlev(27,26,12,15,44), wpex(440,440,440,375,375,375), strsk(8,8,6,6)|agisk(9,8,8,0,0)|lordsk1(3,0,6,4,5,3,4,4)|lordsk2(3,2,4,1,4,4,0,4), refugee_face1, refugee_face2], 
["m02_mef_1_footknight", "Maiden Foot Knight", "Maiden Foot Knights", tf_female|tf_guarantee_inf, 0,0, fac_commoners, [itm_xenoargh_new_female_armor04, itm_crusaderbucket_red, itm_black_greaves, itm_hourglass_gauntlets_ornate, itm_crusader_sword_b, itm_saracin_shield_c, itm_2hand_swadian_regent], 
attrlev(28,25,13,16,48), wpex(420,420,420,300,300,300), strsk(8,8,6,6)|agisk(8,8,6,0,0)|lordsk1(2,0,4,1,5,2,4,4)|lordsk2(3,1,2,3,3,4,2,4), refugee_face1, 0x0000000bff00201629acef17b5eea53f00000000001df8bf0000000000000000], 
["m02_mef_1_viragocav", "Virago", "Viragos", tf_female|tf_guarantee_all, 0,0, fac_commoners, [itm_corrazina_red, itm_crusader_hard_helm_f, itm_shynbaulds, itm_new_lamellar_gauntlets, itm_perisno_purebred, itm_sword_medieval_a, itm_sword_viking_3, itm_saracin_shield_r, itm_imperial_bow_3, itm_3steel_arrow], 
attrlev(22,21,10,13,30), wpex(290,290,290,290,200,200), strsk(5,5,3,5)|agisk(6,5,5,5,6)|lordsk1(2,2,0,0,3,1,3,3)|lordsk2(2,0,1,0,2,2,1,3), refugee_face1, refugee_face2], 
["m02_mef_1_viragoheroine", "Virago Heroine", "Virago Heroines", tf_female|tf_guarantee_all, 0,0, fac_commoners, [itm_perisnofemalearmor, itm_pigface_klappvisor_open, itm_black_greaves, itm_gauntlets_arabs_b_l, itm_wlong4, itm_sabre_ebony, itm_saracin_shield_c, itm_imperial_bow_2, itm_spak_bow6_arrow], 
attrlev(26,26,13,18,50), wpex(380,380,360,400,280,280), strsk(6,7,5,7)|agisk(8,6,6,8,8)|lordsk1(3,3,2,1,5,2,4,4)|lordsk2(2,0,2,1,4,3,5,4), refugee_face1, refugee_face2], 
["m02_mef_1_maidenofwar","Maiden of War","Maidens of War",tf_female|tf_guarantee_allnoranged,0,0,fac_commoners, [itm_gothic_plate_female, itm_flemish_armet, itm_plate_boots, itm_plate_mittens, itm_plated_charger6, itm_luc_iron_hand_axe_g, itm_lui_rangeraxe, itm_steel_shield_kite, itm_lance_lev5], 
attrlev(29,26,12,16,50), wpex(400,400,400,340,260,260), strsk(7,7,5,6)|agisk(8,7,6,8,8)|lordsk1(3,2,2,0,5,1,4,4)|lordsk2(2,0,2,0,3,3,3,3), refugee_face1,refugee_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Silberfalke - Changed Glory-Seeking Men
#Cavalry Branch
["m03_gsm_gloryseekingman", "Glory Seeking Man", "Glory Seeking Men", tf_guarantee_allnoranged, 0,0, fac_manhunters, [itm_nomad_vest, itm_light_leather, itm_fur_hat, itm_nordic_archer_helmet, itm_rus_shoes, itm_leather_gloves, itm_sumpter_horse, itm_goedendag_no1, itm_rrr_club1], 
attrlev(11,7,6,6,5), wpex(85,85,85,65,65,65), strsk(1,2,0,0)|agisk(2,0,2,2,0)|lordsk1(1,0,0,0,0,1,1,1)|lordsk2(0,0,0,0,0,1,0,0), bandit_face1, bandit_face2], 
["m03_gsm_volunteer", "Volunteer", "Volunteers", tf_guarantee_allnoranged, 0, 0, fac_manhunters, [itm_red_gambeson, itm_banded_leather_a_spiked, itm_peasant_leather_padded, itm_skullcap, itm_helmet_with_neckguard, itm_light_leather_boots, itm_leather_gloves, itm_xenoargh_bayappy, itm_mace_4, itm_kite_shield_3], 
attrlev(13,9,7,7,10), wpex(120,120,120,75,75,75), strsk(2,3,1,1)|agisk(3,1,3,3,0)|lordsk1(1,0,0,1,0,1,2,1)|lordsk2(0,0,0,0,0,1,0,0), bandit_face1, bandit_face2], 
["m03_gsm_bountyscout", "Bounty Scout", "Bounty Scouts", tf_guarantee_allnoranged, 0, 0, fac_slavers, [itm_rough_spiked_rings, itm_crusader_helm_1, itm_rus_cav_boots, itm_mail_mittens, itm_european_horse_a, itm_european_horse_f, itm_lui_mace, itm_kite_shield_5], 
attrlev(16,11,8,9,16), wpex(160,160,160,90,90,90), strsk(3,4,2,2)|agisk(4,2,4,5,0)|lordsk1(2,0,0,2,0,2,3,1)|lordsk2(0,0,0,0,1,2,0,1), bandit_face1, bandit_face2], 
["m03_gsm_bountyhunter", "Bounty Hunter", "Bounty Hunters", tf_guarantee_allnoranged, 0, 0, fac_slavers, [itm_rus_lamellar_a, itm_kettlehatfacebyrnie, itm_splinted_greaves_spurs, itm_mail_mittens, itm_rus_horse, itm_horse_bandits_b, itm_horse_bandits_b, itm_lui_mace, itm_lui_twohandedmace, itm_shield_heater_c], 
attrlev(19,14,10,11,26), wpex(215,215,215,110,110,110), strsk(4,5,3,3)|agisk(6,4,5,7,0)|lordsk1(2,0,0,4,1,3,3,2)|lordsk2(0,0,0,0,2,4,0,2), bandit_face1, bandit_face2], 
["m03_gsm_elitebountyhunter", "Elite Bounty Hunter", "Elite Bounty Hunters", tf_guarantee_allnoranged, 0, 0, fac_slavers, [itm_huscarl_armour, itm_nikolskoe_helm, itm_splinted_greaves_spurs, itm_mail_mittens, itm_rus_horse, itm_northerner_horse_hunter, itm_lui_mace, itm_lui_twohandedmace, itm_shield_8], 
attrlev(25,18,11,16,40), wpex(315,315,315,150,150,150), strsk(6,7,4,4)|agisk(7,6,6,9,0)|lordsk1(3,0,0,8,3,4,4,3)|lordsk2(0,0,0,0,3,8,0,4), bandit_face1, bandit_face2], 
["m03_gsm_inspector", "Inspector", "Inspectors", tf_guarantee_allnoranged, 0, 0, fac_manhunters, [itm_wei_xiadi_swa_surcoat_fancy02, itm_crusader_hard_helm_a, itm_mail_chausses_shin_guard, itm_scale_gauntlets, itm_dorn_horse_lamellar_c, itm_luc_warhammer_s, itm_shield_heater_c, itm_spiked_war_club_no1], 
attrlev(22,17,12,13,35), wpex(265,265,265,130,130,130), strsk(6,6,4,4)|agisk(7,5,6,8,0)|lordsk1(1,0,0,4,2,3,4,3)|lordsk2(0,0,1,0,3,4,1,3), bandit_face1, bandit_face2], 
["m03_gsm_sheriff", "Sheriff", "Sheriffs", tf_guarantee_all, 0, 0, fac_manhunters, [itm_tarth_armor, itm_crusaderbucket_orange, itm_bronzeshynald, itm_bronzeplatemitten, itm_dorn_horse_lamellar_b, itm_knights_mace_no1, itm_luc_morningstar_3, itm_shb1], 
attrlev(27,20,14,16,45), wpex(330,330,330,160,160,160), strsk(7,7,5,5)|agisk(8,6,7,9,0)|lordsk1(1,0,2,7,4,4,6,4)|lordsk2(0,0,3,0,4,4,3,4), bandit_face1, bandit_face2], 
#Infantry Branch
["m03_gsm_villageguard","Village Guard","Village Guards", tf_guarantee_inf,0,0,fac_manhunters, [itm_ped_padd_lamellar_grey2, itm_light_crusader_helm_e, itm_light_leather_boots, itm_mail_mittens, itm_bardiche, itm_luc_wooden_war_hammer], 
attrlev(14,9,7,8,10), wpex(130,130,130,80,80,80), strsk(2,3,1,1)|agisk(3,1,3,2,0)|lordsk1(0,0,0,0,0,1,2,2)|lordsk2(0,0,0,0,1,2,0,1), bandit_face1, bandit_face2], 
["m03_gsm_cityguard","City Guard","City Guards", tf_guarantee_inf,0,0,fac_manhunters, [itm_rough_leather_metal_plates, itm_flat_topped_helmet, itm_splinted_greaves, itm_brass_scale_gauntlets, itm_swiss_voulge_no1, itm_luc_great_hammer_a], 
attrlev(17,12,9,11,18), wpex(180,180,180,100,100,100), strsk(4,5,3,2)|agisk(5,3,4,3,0)|lordsk1(0,0,1,1,1,1,3,2)|lordsk2(0,0,0,0,2,3,0,2), bandit_face1, bandit_face2], 
["m03_gsm_sergeant","Sergeant of the Guard","Sergeants of the Guard", tf_guarantee_inf,0,0,fac_manhunters, [itm_leather_swordsman, itm_flattophelmet, itm_splinted_leather_greaves, itm_gondor_bracer_l, itm_swiss_voulge_no2, itm_warhammer_kn1], 
attrlev(21,15,11,14,26), wpex(250,250,250,125,125,125), strsk(6,6,4,4)|agisk(6,4,5,4,0)|lordsk1(0,0,3,2,3,2,4,2)|lordsk2(0,0,1,1,3,4,2,3), bandit_face1, bandit_face2], 
["m03_gsm_captain","Captain of the Guard","Captains of the Guard", tf_guarantee_inf,0,0,fac_manhunters, [itm_king_knight_armour, itm_great_helmet, itm_west_man_at_arms_boots, itm_dorn_squire_gauntles, itm_knights_mace_no1, itm_shb2, itm_luc_knightly_hammer], 
attrlev(30,21,15,18,45), wpex(380,380,380,180,180,180), strsk(8,8,6,6)|agisk(9,7,7,8,0)|lordsk1(0,0,7,4,5,3,4,4)|lordsk2(1,1,3,3,4,4,6,4), bandit_face1, bandit_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#SU. Freelancers
["m04_frg_i_recruit", "Freelancer Recruit", "Freelancer Recruits", tf_guarantee_inf, 0,0, fac_freelancer_guild, [itm_tabard_red, itm_norman_helmet, itm_leather_boots, itm_mail_mittens, itm_sword_viking_2_small, itm_tab_shield_heater_a], 
attrlev(10,7,6,6,5), wpex(115,115,115,100,100,100), strsk(1,1,0,0)|agisk(2,1,1,0,0)|lordsk1(1,0,0,0,1,0,0,1)|lordsk2(0,0,0,0,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m04_frg_i_soldier", "Freelancer Soldier", "Freelancer Soldiers", tf_guarantee_inf, 0,0, fac_freelancer_guild, [itm_sergeant_armor_antioh_a, itm_guard_helmet, itm_civil_rich_boots_b, itm_mail_mittens, itm_sword_viking_1, itm_tab_shield_heater_b], 
attrlev(14,9,7,9,12), wpex(180,180,180,140,140,140), strsk(2,2,1,1)|agisk(4,3,2,0,0)|lordsk1(2,0,0,0,2,0,0,1)|lordsk2(0,0,0,1,0,2,0,0), mercenary_face_1, mercenary_face_2], 
["m04_frg_i_infantry", "Freelancer Infantry", "Freelancer Infantry", tf_guarantee_inf, 0,0, fac_freelancer_guild, [itm_knight_armor_antioh_e, itm_frenchpepperpot3, itm_splinted_leather_greaves, itm_mail_mittens, itm_sword_viking_3_small, itm_tab_shield_heater_c], 
attrlev(18,12,9,12,20), wpex(255,255,255,180,180,180), strsk(3,4,3,2)|agisk(5,5,3,0,0)|lordsk1(2,0,1,0,3,0,1,2)|lordsk2(0,0,0,2,0,3,0,0), mercenary_face_1, mercenary_face_2], 
["m04_frg_i_swordsmaster", "Freelancer Swordsmaster", "Freelancer Swordsmasters", tf_guarantee_inf, 0,0, fac_freelancer_guild, [itm_knight_armor_antioh_b_cloak, itm_crusader_hard_helm_f, itm_mail_boots, itm_wisby_gauntlets_red, itm_sword_viking_3, itm_tab_shield_heater_d], 
attrlev(23,15,11,15,31), wpex(335,335,335,220,220,220), strsk(5,6,4,4)|agisk(7,6,4,0,0)|lordsk1(2,0,2,0,4,0,1,2)|lordsk2(0,0,0,3,1,4,0,1), mercenary_face_1, mercenary_face_2], 
["m04_frg_i_dismknight", "Freelancer Dismounted Knight", "Freelancer Dismounted Knights", tf_guarantee_inf, 0,0, fac_freelancer_guild, [itm_armor_master_order_antioh, itm_crusaderbucket_blue, itm_mail_chausses_shin_guard, itm_hourglass_gauntlets, itm_arabian_sword_c, itm_tab_shield_heater_cav_b, itm_viking_sword_a], 
attrlev(29,18,14,20,40), wpex(420,420,420,260,260,260), strsk(8,8,6,6)|agisk(9,8,5,0,0)|lordsk1(2,0,4,0,6,1,2,3)|lordsk2(0,0,0,4,3,4,2,3), mercenary_face_1, mercenary_face_2], 
#Freelancer Cavalry
["m04_frg_c_rider", "Freelancer Rider", "Freelancer Riders", tf_guarantee_allnoranged, 0,0, fac_freelancer_guild, [itm_west_heavy_footman_armor, itm_tolrania_kettlehat, itm_civil_rich_boots_b, itm_mail_mittens, itm_perisno_purebred, itm_trust, itm_tab_shield_small_round_a], 
attrlev(17,12,8,11,21), wpex(240,240,240,170,170,170), strsk(3,3,2,2)|agisk(5,4,3,4,0)|lordsk1(2,0,0,0,3,0,1,2)|lordsk2(0,0,0,1,1,2,0,0), mercenary_face_1, mercenary_face_2], 
["m04_frg_c_squire", "Freelancer Squire", "Freelancer Squires", tf_guarantee_allnoranged, 0,0, fac_freelancer_guild, [itm_west_rider_armor, itm_crusader_helm_1, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_dk_armour_charger, itm_frostfang, itm_tab_shield_kite_cav_a], 
attrlev(22,15,10,15,31), wpex(310,310,310,210,210,210), strsk(4,5,3,3)|agisk(6,5,3,6,0)|lordsk1(2,0,1,0,4,0,2,2)|lordsk2(0,0,0,2,2,3,0,1), mercenary_face_1, mercenary_face_2], 
["m04_frg_c_knight", "Freelancer Knight", "Freelancer Knights", tf_guarantee_allnoranged, 0,0, fac_freelancer_guild, [itm_west_halberdier, itm_barbuta2_purple, itm_black_greaves, itm_new_lamellar_gauntlets, itm_2imperial_warhorse, itm_great_axe_no1, itm_battle_axe_le_duc, itm_tab_shield_heater_cav_a], 
attrlev(28,18,13,20,40), wpex(400,400,400,250,250,250), strsk(7,7,5,4)|agisk(8,7,4,8,0)|lordsk1(2,0,3,1,6,1,2,3)|lordsk2(0,0,0,3,3,4,3,3), mercenary_face_1, mercenary_face_2], 
["m04_frg_c_marshal", "Freelancer Marshal", "Freelancer Marshals", tf_guarantee_allnoranged, 0,0, fac_freelancer_guild, [itm_west_man_at_arms_armor, itm_winged_great_helmet, itm_west_pikeman_boots, itm_plate_mittens, itm_plate_armour_charger2, itm_mackie_mangler_short, itm_tab_shield_small_round_c], 
attrlev(34,22,16,28,60), wpex(500,500,500,300,300,300), strsk(9,9,7,6)|agisk(10,9,5,10,0)|lordsk1(2,0,7,2,8,2,3,4)|lordsk2(0,0,0,4,4,4,7,4), mercenary_face_1, mercenary_face_2], 
#Freelancer Archers
["m04_frg_a_archer", "Freelancer Archer", "Freelancer Archers", tf_guarantee_archer, 0,0, fac_freelancer_guild, [itm_archer_ibelin_armor_a, itm_light_crusader_helm_c, itm_leather_boots, itm_leather_gloves, itm_sword_viking_2, itm_tab_shield_kite_a, itm_hunting_bow, itm_bodkin_arrows], 
attrlev(13,10,7,8,9), wpex(160,160,160,170,150,130), strsk(2,2,1,2)|agisk(3,2,2,0,0)|lordsk1(1,0,0,0,2,0,1,2)|lordsk2(0,0,0,1,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m04_frg_a_vetarcher", "Freelancer Veteran Archer", "Freelancer Veteran Archers", tf_guarantee_archer, 0,0, fac_freelancer_guild, [itm_sergeant_ibelin_armor, itm_kettle_hat, itm_civil_rich_boots_b, itm_leather_gloves, itm_sword_viking_1, itm_tab_shield_kite_b, itm_long_bow, itm_spak_bow8_arrow], 
attrlev(17,13,9,11,17), wpex(210,210,210,240,210,180), strsk(3,3,2,4)|agisk(4,3,4,0,0)|lordsk1(2,1,0,0,3,0,2,2)|lordsk2(0,0,0,2,0,2,0,1), mercenary_face_1, mercenary_face_2], 
["m04_frg_a_masterarcher", "Freelancer Master Archer", "Freelancer Master Archers", tf_guarantee_archer, 0,0, fac_freelancer_guild, [itm_knight_armor_ibelin_c, itm_ak_bascinet_new_a, itm_civil_rich_boots_b, itm_gauntlets_arabs_a_l, itm_luc_english_falchion, itm_tab_shield_kite_c, itm_new_warbow_b, itm_spak_bow8_arrow], 
attrlev(21,16,11,14,26), wpex(275,275,275,325,275,225), strsk(4,5,3,6)|agisk(6,5,5,0,0)|lordsk1(2,2,1,0,4,1,3,3)|lordsk2(0,0,0,3,1,3,0,1), mercenary_face_1, mercenary_face_2], 
["m04_frg_a_sharpshooter", "Freelancer Sharpshooter", "Freelancer Sharpshooters", tf_guarantee_archer, 0,0, fac_freelancer_guild, [itm_knight_armor_ibelin_b_cloak, itm_ak_bascinet_new_b, itm_civil_rich_boots_a, itm_gondor_bracer_l, itm_luc_flemish_sword, itm_tab_shield_kite_d, itm_fire_war_bow, itm_spak_bow8_arrow], 
attrlev(25,20,13,18,38), wpex(365,365,365,410,370,270), strsk(6,6,4,8)|agisk(8,6,6,0,0)|lordsk1(2,3,2,0,5,1,4,3)|lordsk2(0,0,0,4,2,3,0,2), mercenary_face_1, mercenary_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Perisno Pioneers
["settler", "Perisnoan Settler", "Perisnoan Settlers", tf_guarantee_allnoranged, 0,0, fac_pioneers, [itm_peasant_leather_mail_ls, itm_light_crusader_helm_c, itm_splinted_greaves, itm_leather_gloves, itm_military_sickle_a, itm_luc_wooden_shield_y, itm_two_handed_axe], 
attrlev(13,9,7,6,11), wpex(140,140,140,80,80,80), strsk(1,2,1,1)|agisk(2,1,4,1,0)|lordsk1(1,1,0,0,0,2,1,2)|lordsk2(1,0,1,0,0,1,0,1), mfy1, mfo2], 
["pioneer","Perisnoan Pioneer","Perisnoan Pioneers",tf_guarantee_inf,0,0,fac_pioneers, [itm_rathos_surcoat_halfred, itm_combed_morion_blued, itm_splinted_leather_greaves, itm_gauntlets, itm_epieu_de_guerre_no1, itm_gold_ore], 
attrlev(18,11,10,8,22), wpex(220,220,220,90,90,90), strsk(3,4,2,2)|agisk(4,2,6,3,0)|lordsk1(1,1,0,0,0,3,2,3)|lordsk2(2,1,2,0,1,2,0,3), mfy1, mfo2], 
["pioneer_adventurer","Perisnoan Adventurer","Perisnoan Adventurers",tf_guarantee_allnoranged,0,0,fac_pioneers, [itm_bnw_armour2, itm_combed_morion, itm_iron_greaves, itm_bnw_gauntlets, itm_dorn_horse_lamellar_a, itm_1hlongsword, itm_shield_5, itm_gold_ore], 
attrlev(24,15,13,10,33), wpex(300,300,300,100,100,100), strsk(5,5,3,3)|agisk(6,4,7,7,0)|lordsk1(2,1,0,1,0,4,4,4)|lordsk2(3,1,3,0,2,2,1,4), mfy1, mfo2], 

#SU. Slave Rebels (renamed to match Gladiatrixes)
["slave_male","Slave","Slaves",tf_guarantee_inf,0,0,fac_mercenaries, [itm_linen_tunic, itm_wrapping_boots, itm_leather_gloves, itm_bamboo_spear, itm_javelin], 
attrlev(10,7,5,4,2), wpex(75,75,80,50,50,80), strsk(0,1,1,0)|agisk(1,0,2,0,0)|lordsk1(1,0,0,0,0,0,0,0)|lordsk2(0,0,0,0,0,1,0,0), bandit_face1, bandit_face2], 
["trained_slave", "Gladiator", "Gladiators", tf_guarantee_inf, 0,0, fac_mercenaries, [itm_a_tribune, itm_roman_helm_copper, itm_inf_t1, itm_desert_turban, itm_leather_boots, itm_lamellar_gauntlets, itm_falchion, itm_painted_brass_shield5, itm_pike, itm_javelin], 
attrlev(14,10,7,6,10), wpex(140,140,150,120,120,150), strsk(2,3,3,2)|agisk(3,2,4,0,0)|lordsk1(1,0,1,0,1,0,1,1)|lordsk2(0,0,0,0,0,2,0,0), bandit_face1, bandit_face2], 
["veteran_slave", "Veteran Gladiator", "Veteran Gladiators", tf_guarantee_inf, 0,0, fac_mercenaries, [itm_tribune_b, itm_catafract_helmet_1, itm_crete_helm_gold, itm_boot_average_crusader_c, itm_brass_lamellar_gauntlets, itm_crusaders_swords_a, itm_painted_brass_shield, itm_halfj7, itm_throwing_spears], 
attrlev(19,15,9,9,22), wpex(230,230,230,200,200,250), strsk(5,5,5,3)|agisk(5,4,5,0,0)|lordsk1(2,0,3,0,3,0,1,2)|lordsk2(0,0,0,0,1,3,0,0), bandit_face1, bandit_face2], 
["gladiator", "Gladiator Champion", "Gladiator Champions", tf_guarantee_inf, 0,0, fac_mercenaries, [itm_a_roman_chain, itm_catafract_helmet_3, itm_saracin_hard_boot_b, itm_brass_scale_gauntlets, itm_viking_sword_a, itm_dal_hinduh, itm_luc_trident, itm_nowe_jarid], 
attrlev(26,22,11,12,38), wpex(350,350,350,300,300,350), strsk(8,8,8,6)|agisk(8,7,0,0,0)|lordsk1(2,0,4,0,5,0,2,3)|lordsk2(0,0,0,0,3,3,2,1), bandit_face1, bandit_face2], 
#Mel Gladiatrixes 
#["slave_fem","Female Slave","Female Slaves",tf_female|tf_guarantee_inf,0,0,fac_outlaws, [ itm_stones, itm_wooden_stick, itm_blue_hose], average_archinf_attrib_plus60_lvl1,wpex(73,73,40,40,40,101),knows_average_archer_plus50_lvl1|knows_common_wild_lvl1, refugee_face1, refugee_face2], 
#["gladiatrix", "Gladiatrix", "Gladiatrixes", tf_female|tf_guarantee_inf, 0,0, fac_outlaws, [itm_roman_gladius_2, itm_roman_javelin, itm_roman_shield_oval, itm_soldiers_ench, itm_roman_squamata, itm_roman_greaves_greek], average_archinf_attrib_plus60_lvl2,wpex(90,90,40,40,40,140),knows_average_archer_plus50_lvl2|knows_common_wild_lvl2, refugee_face1, refugee_face2], 
#["vet_gladiatrix", "Veteran Gladiatrix", "Veteran Gladiatrixes", tf_female|tf_guarantee_inf, 0,0, fac_outlaws, [itm_roman_gladius_2, itm_roman_pilum_1, itm_roman_javelin, itm_roman_shield_oval, itm_roman_hamata, itm_fine_ench, itm_leather_gloves, itm_mail_boots], average_archinf_attrib_plus60_lvl3,wpex(116,116,40,40,40,161),knows_average_archer_plus50_lvl3|knows_common_wild_lvl4, refugee_face1, refugee_face2], 
#["gladiatrix_champ", "Gladiatrix Champion", "Gladiatrix Champions", tf_female|tf_guarantee_inf, 0,0, fac_outlaws, [itm_roman_gladius_3, itm_roman_pilum_2, itm_roman_javelin, itm_roman_shield_oval, itm_imperial_armor_body_combined, itm_imperial_boots_female, itm_noble_ench], average_archinf_attrib_plus60_lvl4,wpex(140,140,40,40,40,166),knows_average_archer_plus50_lvl4|knows_common_wild_lvl6, refugee_face1, refugee_face2], 
#Mel Gladiatrixes END

#SU. Companion Household Troops
["tylen_kingsman", "Tylen Rogue Kingsman", "Tylen Rogue Kingsmen", tf_guarantee_allnoranged, 0,0, fac_player_supporters_faction, [itm_brigandine_b_heraldic, itm_pepperpothelm1, itm_iron_greaves, itm_hourglass_gauntlets, itm_barded_armour_charger2, itm_sword_val_2, itm_shield_11, itm_lance_3], 
attrlev(27,21,17,22,40), wpex(370,350,400,250,250,250), strsk(7,8,5,5)|agisk(8,7,5,8,0)|lordsk1(4,0,4,2,5,1,3,1)|lordsk2(1,0,2,1,4,3,4,1), mfy1, mfy2], 

#Jin troops (Shi Jin households)
["jin_swordmaster", "Jin Swordmaster", "Jin Swordmasters", tf_guarantee_inf, 0,0, fac_jin, [itm_song_armor_cb, itm_song_tiekui_b, itm_rus_splint_greaves, itm_gondor_bracer_l, itm_rivend_sword_1, itm_fhbs], 
attrlev(28,33,18,24,52), wpex(450,450,400,250,150,250), strsk(10,9,6,6)|agisk(10,5,8,3,0)|lordsk1(0,1,7,1,8,1,4,4)|lordsk2(2,0,2,4,3,4,4,4), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_guardsman", "Jin Guardsman", "Jin Guardsmen", tf_guarantee_inf, 0,0, fac_jin, [itm_songgeneral_a, itm_song_helm_kk, itm_rus_splint_greaves, itm_gauntlets_arabs_b_l, itm_sabre_val_2, itm_saracin_shield_r], 
attrlev(23,23,13,15,33), wpex(360,360,300,200,150,200), strsk(7,7,5,5)|agisk(7,7,7,0,0)|lordsk1(0,0,2,0,5,0,4,2)|lordsk2(0,0,0,2,3,4,0,2), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_impguardsman", "Jin Imperial Guardsman", "Jin Imperial Guardsmen", tf_guarantee_inf, 0,0, fac_jin, [itm_dorn_squire_armor, itm_kevin_song_helm_a, itm_west_man_at_arms_boots, itm_wisby_gauntlets_red, itm_bb_chineese_sword, itm_saracin_shield_c], 
attrlev(28,27,15,20,48), wpex(440,420,360,250,200,250), strsk(8,9,6,6)|agisk(9,9,8,0,0)|lordsk1(0,0,3,0,6,0,4,3)|lordsk2(0,0,0,2,3,6,1,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_crossbowman", "Jin Crossbowman", "Jin Crossbowmen", tf_guarantee_archer, 0,0, fac_jin, [itm_songgeneral_a, itm_song_tiekui, itm_rus_cav_boots, itm_gondor_bracer_l, itm_burgundian_glaive, itm_spak_crsb01, itm_steel_bolts], 
attrlev(19,21,13,14,33), wpex(250,250,300,250,300,200), strsk(5,5,4,4)|agisk(7,0,7,0,0)|lordsk1(0,3,1,1,5,1,4,3)|lordsk2(0,0,0,5,2,2,0,3), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_eagleeye", "Jin Eagle Eye", "Jin Eagle Eyes", tf_guarantee_all, 0,0, fac_jin, [itm_songgeneral_b, itm_song_helm_aa, itm_iron_greaves_a, itm_gondor_bracer_l, itm_song_charger_b, itm_bb_holed_blade_sword, itm_steel_shield_herald02, itm_imperial_bow, itm_spak_bow6_arrow], 
attrlev(24,28,18,22,50), wpex(380,380,380,450,300,300), strsk(7,7,5,9)|agisk(9,5,5,10,10)|lordsk1(0,4,3,4,7,4,8,4)|lordsk2(2,0,2,2,4,3,3,4), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_cataphract", "Jin Cataphract", "Jin Cataphracts", tf_guarantee_allnoranged, 0,0, fac_jin, [itm_song_pifeng_b, itm_red_song_helm_1, itm_dorn_spearbearer_boots, itm_scale_gauntlets, itm_song_horse_h, itm_song_ztswpodao, itm_saracin_shield_c, itm_heavy_lance], 
attrlev(28,28,16,24,54), wpex(420,420,450,150,150,150), strsk(8,8,6,6)|agisk(9,8,5,10,0)|lordsk1(0,0,3,0,6,0,2,3)|lordsk2(0,0,0,0,2,2,3,2), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 
["jin_halberdier", "Jin Halberdier", "Jin Halberdiers", tf_guarantee_inf, 0,0, fac_jin, [itm_song_pifeng_c, itm_kevin_song_helm_a, itm_dorn_spearbearer_boots, itm_scale_gauntlets, itm_luc_flemish_halberd], 
attrlev(29,29,15,18,44), wpex(330,330,400,100,100,100), strsk(9,9,6,6)|agisk(9,0,6,0,0)|lordsk1(0,0,1,0,5,0,2,3)|lordsk2(0,0,0,1,2,4,1,2), zann_face_middle_to_old_begin, zann_face_middle_to_old_end], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Desouk Slavers
["desouk_female_slave", "Slave Girl", "Slave Girls", tf_female|tf_guarantee_inf, 0,0, fac_desouk_slaver, [itm_xena_armor, itm_woolen_hose, itm_bamboo_spear], 
attrlev(9,7,5,4,3), wpex(65,65,70,50,50,50), strsk(0,0,0,0)|agisk(1,0,1,0,0)|lordsk1(1,0,0,0,0,0,0,0), refugee_face1, refugee_face2], 
["desouk_mounted_slaver","Desouk Slaver","Desouk Slavers",tf_guarantee_allnoranged,0,0,fac_desouk_slaver, [itm_early_transitional_slaverwhip, itm_ghulam_helm2, itm_rus_splint_greaves, itm_mail_mittens, itm_arab_war_horse2, itm_luc_wooden_war_hammer, itm_luc_knobbed_mace_b], 
attrlev(18,16,8,12,24), wpex(260,260,200,60,60,60), strsk(4,5,3,3)|agisk(5,3,3,6,0)|lordsk1(4,0,0,6,0,3,4,3)|lordsk2(0,0,0,0,1,4,0,3), draharan_faces_black_begin,draharan_faces_black_end], 
["desouk_slaver","Desouk Enforcer","Desouk Enforcers",tf_guarantee_inf,0,0,fac_desouk_slaver, [itm_early_transitional_slaverwhip, itm_ghulam_helm2, itm_splinted_greaves, itm_mail_mittens, itm_luc_long_hammer], 
attrlev(19,15,9,14,32), wpex(230,230,260,80,80,80), strsk(5,5,3,3)|agisk(5,3,5,3,0)|lordsk1(4,0,0,4,0,3,4,4)|lordsk2(0,0,0,0,3,6,0,4), draharan_faces_black_begin,draharan_faces_black_end], 

#Foreign Invaders
["foreign_grunt", "Ukundu Warrior", "Ukundu Warriors",tf_guarantee_inf, 0,0, fac_foreigners, [itm_wei_xiadi_samurai_armor01, itm_vaegir_war_helmet, itm_mail_boots_brass, itm_brass_mail_mittens, itm_great_bardiche, itm_long_hafted_spiked_mace], 
attrlev(19,16,9,10,28), wpex(300,300,300,130,130,130), strsk(6,6,3,3)|agisk(5,3,5,0,0)|lordsk1(3,0,0,1,0,0,0,2)|lordsk2(0,0,0,0,0,4,0,0), 0x00000001bf013000144a49249249b6db00000000001d12490000000000000000,0x00000001bf01305349249249249e492300000000001e49240000000000000000], 
["foreign_invader", "Ukundu Tigress", "Ukundu Tigresses", tf_female|tf_guarantee_all, 0,0, fac_foreigners, [itm_xenoargh_new_female_armor_orange03, itm_sarranid_boots_brass, itm_brass_mail_mittens, itm_tiger, itm_saracen_mace, itm_dal_muslimj, itm_bamboo_lance, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar], 
attrlev(18,20,12,18,30), wpex(310,310,310,150,150,330), strsk(5,6,6,3)|agisk(6,4,4,6,6)|lordsk1(4,1,0,3,2,2,3,3)|lordsk2(1,0,1,0,1,3,2,1), 0x000000018d004002000000000000700000000000000000000000000000000000,0x000000018d0040150000000000007b6d00000000000000000000000000000000], 
["foreign_warlord", "Ukundu Princess", "Ukundu Princesses", tf_female|tf_guarantee_all, 0,0, fac_foreigners, [itm_xenoargh_new_female_armor_orange04, itm_noble_ench, itm_sarranid_boots_brass, itm_brass_mail_mittens, itm_tigerwhite, itm_khopesh_1, itm_dal_muslimj, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar], 
attrlev(26,30,16,28,48), wpex(430,430,430,240,240,450), strsk(6,7,7,5)|agisk(9,6,5,8,8)|lordsk1(4,2,1,4,4,3,4,4)|lordsk2(2,0,1,0,3,4,5,2), 0x000000018d004002000000000000700000000000000000000000000000000000,0x000000018d0040150000000000007b6d00000000000000000000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Volheere Raiders
["volheere_raider", "Volheere Raider", "Volheere Raiders", tf_guarantee_inf, 0, 0, fac_volheere_raiders, [itm_rough_leatherplate_spiked, itm_nasal_helmet, itm_leather_boots, itm_leather_gloves, itm_sword_viking_2, itm_luc_wooden_shield_y, itm_light_throwing_axes, itm_javelin], 
attrlev(13,7,6,7,11), wpex(130,130,100,100,60,130), strsk(2,3,3,2)|agisk(3,2,3,0,0)|lordsk1(5,1,0,1,0,1,1,2)|lordsk2(0,0,0,0,0,2,0,0), nofa1, nofa2], 
["strong_volheere_raider", "Experienced Volheere Raider", "Experienced Volheere Raiders", tf_guarantee_inf, 0, 0, fac_volheere_raiders, [itm_black_tribal_outfit, itm_nordhelm_coif, itm_stark_hanter_boots, itm_mail_mittens, itm_one_handed_war_axe_no4, itm_2shield, itm_throwing_axes, itm_javelin], 
attrlev(17,9,7,8,18), wpex(200,200,150,130,75,200), strsk(5,5,5,4)|agisk(5,4,5,0,0)|lordsk1(6,1,0,2,1,1,2,3)|lordsk2(0,0,0,1,0,3,0,0), nofa1, nofa2], 
["sea_barbarian", "Volheere Barbarian", "Volheere Barbarians", tf_guarantee_inf, 0, 0, fac_volheere_raiders, [itm_tribal_warrior_outfit_b, itm_munitionshelm2, itm_splinted_leather_greaves, itm_beargauntlets, itm_long_axe_b_alt, itm_heavy_throwing_axes, itm_javelin], 
attrlev(23,12,8,10,30), wpex(290,290,240,150,90,290), strsk(7,7,7,5)|agisk(7,5,6,0,0)|lordsk1(7,1,1,2,2,2,3,3)|lordsk2(0,0,0,2,0,4,0,0), nofa1, nofa2], 
["sea_archer", "Volheere Raiding Archer", "Volheere Raiding Archers", tf_guarantee_archer, 0, 0, fac_volheere_raiders, [itm_rough_tunic_mailed, itm_nordic_helmet, itm_leather_boots, itm_leather_gloves, itm_sword_viking_2_small, itm_luc_heavy_wooden_shield, itm_noldor_bow, itm_arrows], 
attrlev(16,10,8,8,14), wpex(180,180,140,180,80,160), strsk(4,4,4,5)|agisk(4,2,5,0,0)|lordsk1(6,3,0,3,1,3,3,3)|lordsk2(0,0,0,1,0,2,0,1), nofa1, nofa2], 
#Ulfheonar
["volheere_berserker", "Volheere Berserker", "Volheere Berserkers", tf_guarantee_inf, 0,0, fac_volheere_raiders, [itm_kuyak_b, itm_2kettle_hat_new, itm_splinted_leather_greaves, itm_beargauntlets, itm_taleworlds_doubleaxe], 
attrlev(44,26,9,14,48), wpex(415,415,400,100,100,360), strsk(10,10,8,7)|agisk(10,5,8,0,0)|lordsk1(7,0,3,2,3,1,2,3)|lordsk2(0,0,0,2,0,4,1,0), nofa1, nofa2], 
#Illica Falki
["illica_hunter", "Illica Falki Hunter", "Illica Falki Hunters", tf_guarantee_all, 0,0, fac_illica, [itm_armor_17, itm_helm_tyrk_heavi_a, itm_boot_average_crusader_c, itm_leather_gloves, itm_horse_bandits_a, itm_one_handed_war_axe_no7, itm_dal_hindug, itm_new_shortbow, itm_brown_arrow], 
attrlev(15,12,9,8,12), wpex(160,160,140,180,80,100), strsk(4,4,2,5)|agisk(4,3,4,5,5)|lordsk1(3,3,0,1,1,2,2,3)|lordsk2(0,0,0,0,0,1,0,1), vaegir_face_young_1, vaegir_face_young_2], 
["illica_rider", "Illica Falki Rider", "Illica Falki Riders", tf_guarantee_all, 0,0, fac_illica, [itm_armor_18, itm_helm_tyrk_heavi_a, itm_boot_average_crusader_b, itm_gauntlets_arabs_a_l, itm_bandits_horse_a, itm_horsemans_axe_no3, itm_dal_hindug, itm_new_strong_bow, itm_brown_arrow], 
attrlev(20,16,12,10,23), wpex(270,270,230,270,100,150), strsk(5,6,4,6)|agisk(6,5,5,7,7)|lordsk1(5,3,0,2,3,2,3,3)|lordsk2(0,0,0,0,0,2,0,1), vaegir_face_young_1, vaegir_face_young_2], 
["illica_ranger", "Illica Falki Ranger", "Illica Falki Rangers", tf_guarantee_all, 0,0, fac_illica, [itm_armor_19, itm_helm_tyrk_heavi_a, itm_iron_greaves, itm_scale_gauntlets, itm_golden_deer, itm_one_handed_war_axe_no3, itm_dal_hindug, itm_imperial_bow_3, itm_spak_bow6_arrow], 
attrlev(25,20,14,13,36), wpex(370,370,300,400,150,200), strsk(7,8,4,8)|agisk(8,7,6,9,9)|lordsk1(5,4,1,3,5,3,4,3)|lordsk2(0,0,0,0,1,3,0,2), vaegir_face_middle_1, vaegir_face_middle_2], 
["illica_knight", "Illica Falki Knight", "Illica Falki Knights", tf_guarantee_allnoranged, 0,0, fac_illica, [itm_armor_19, itm_crusader_hard_helm_d, itm_plate_boots, itm_hourglass_gauntlets_ornate, itm_golden_deer, itm_luc_knightly_axe_one_handed, itm_lui_knightaxetwoha, itm_dal_hindug], 
attrlev(27,20,15,16,40), wpex(400,400,375,330,130,200), strsk(8,8,5,7)|agisk(8,8,6,9,8)|lordsk1(5,3,2,2,5,2,3,4)|lordsk2(0,0,0,0,1,4,1,1), vaegir_face_middle_1, vaegir_face_middle_2], 
["illican_hero", "Illican Hero", "Illican Heroes", tf_guarantee_all, 0,0, fac_illica, [itm_j_surcoat_dav_02b, itm_helm_tyrk_heavi_a, itm_bronzeshynald, itm_brass_lamellar_gauntlets, itm_golden_deer, itm_luc_knightly_axe_one_handed_b, itm_saracin_shield_g, itm_hangong, itm_scull_arrow], 
attrlev(32,28,17,21,58), wpex(500,450,450,500,180,300), strsk(9,9,7,9)|agisk(10,8,7,10,10)|lordsk1(6,4,3,4,6,4,6,4)|lordsk2(0,0,2,0,3,4,4,2), vaegir_face_middle_1, vaegir_face_middle_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#habeo Saccar Raiders
["saccar_raider","Saccar Raider","Saccar Raiders",tf_guarantee_all,0,0,fac_outlaws, [itm_heavy_armor_arabs_c_1, itm_khergit_war_helmet, itm_khergit_leather_boots, itm_leather_gloves, itm_tribal5, itm_tribal2, itm_sword_khergit_3, itm_dal_hindue, itm_double_sided_lance, itm_nomad_bow, itm_khergit_arrows], 
attrlev(13,12,7,7,10), wpex(130,100,130,140,70,100), strsk(1,3,2,3)|agisk(4,2,4,4,4)|lordsk1(5,2,0,2,0,1,2,2)|lordsk2(1,0,1,0,0,2,0,0), draharan_faces_arab_begin,draharan_faces_arab_end], 
["saccar_chieftain","Saccar Chieftain","Saccar Chieftains",tf_guarantee_all,0,0,fac_outlaws, [itm_heavy_armor_arabs_c, itm_khergit_cavalry_helmet, itm_khergit_leather_boots, itm_sarranid_boots_black, itm_gloves_lord_l, itm_saracin_hard_horses_b, itm_saracin_hard_horses_b, itm_hooksword_spak, itm_dal_hindue, itm_tulgan_bow, itm_khergit_arrows], 
attrlev(18,17,9,10,24), wpex(230,210,180,250,100,180), strsk(3,5,3,6)|agisk(6,3,7,7,7)|lordsk1(7,4,1,4,2,3,3,4)|lordsk2(1,0,2,0,2,3,1,1), draharan_faces_arab_begin,draharan_faces_arab_end], 
#habeo Sandwalkers
["desert_bandit","Sandwalker","Sandwalkers",tf_guarantee_archer,0,0,fac_outlaws, [itm_sarranid_cloth_robe, itm_beduin_armor_a, itm_turban, itm_desert_turban, itm_sarranid_warrior_cap, itm_ankle_boots, itm_scimitar, itm_khergit_sword_two_handed_b, itm_darts, itm_war_darts], 
attrlev(11,11,6,7,9), wpex(125,125,120,100,60,140), strsk(1,2,3,2)|agisk(3,0,4,0,0)|lordsk1(5,1,0,2,0,2,1,2)|lordsk2(1,0,1,0,0,2,0,1), draharan_faces_arab_begin,draharan_faces_arab_end], 
["sandstalker","Sandstalker","Sandstalkers",tf_guarantee_archer,0,0,fac_outlaws, [itm_sarranid_leather_armor, itm_sarranid_mail_shirt, itm_sarranid_warrior_cap_black, itm_sarranid_warrior_cap, itm_sarranid_mail_coif, itm_sarranid_boots_b, itm_brass_lamellar_gauntlets, itm_sword_khergit_2, itm_dal_muslimh, itm_khergit_sword_two_handed_a, itm_darts, itm_war_darts, itm_luc_throwing_scimitar, itm_throwing_spears], 
attrlev(15,16,8,8,18), wpex(190,190,190,140,70,200), strsk(3,4,5,3)|agisk(5,2,6,0,0)|lordsk1(6,2,0,4,0,3,2,3)|lordsk2(1,0,1,0,0,3,0,2), draharan_faces_arab_begin,draharan_faces_arab_end], 
#habeo Escaped Prisoners
["mountain_bandit","Slave Prisoner","Slave Prisoners",tf_guarantee_inf,0,0,fac_outlaws, [itm_ragged_outfit, itm_leather_jerkin, itm_padded_leather, itm_padded_coif, itm_fur_hat, itm_common_hood, itm_ankle_boots, itm_nomad_boots, itm_sword_medieval_b_small, itm_one_handed_battle_axe_a, itm_german_hunting_spear, itm_fur_covered_shield, itm_hide_covered_round_shield, itm_javelin], 
attrlev(11,6,6,5,5), wpex(80,80,80,65,65,80), strsk(0,2,2,1)|agisk(2,1,2,0,0)|lordsk1(3,0,0,0,0,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), rhodok_face_young_1,rhodok_face_old_2], 
["war_prisoner","War Prisoner","War Prisoners",tf_guarantee_inf,0,0,fac_outlaws, [itm_novici_templar, itm_rough_leatherplate_spiked, itm_dethertir_armor_c, itm_footman_helmet, itm_segmented_helmet, itm_leather_boots, itm_rus_shoes, itm_leather_gloves, itm_mail_mittens, itm_saddle_horse, itm_2shield, itm_kite_shield_3, itm_one_handed_battle_axe_c, itm_sword_two_handed_b, itm_crossbow, itm_bolts], 
attrlev(15,9,7,6,18), wpex(165,165,165,100,140,140), strsk(1,4,4,2)|agisk(4,3,3,3,0)|lordsk1(4,0,0,0,1,0,1,2)|lordsk2(0,0,0,1,0,3,0,0), rhodok_face_young_1,rhodok_face_old_2], 

#Nibor Hood
["nibor_honor_guard","Nibor's Brotherhood Marksman","Nibor's Brotherhood Marksmen",tf_guarantee_archer,0,0,fac_forest_bandits, [itm_leather_armor, itm_peasant_lamellar_ls, itm_woolen_cap, itm_stark_hanter_boots, itm_stark_hood, itm_falchion, itm_dagger, itm_rohirrim_short_axe, itm_nibor_hood_bow, itm_spak_ar2, itm_blackarrow], 
attrlev(21,27,8,12,38), wpex(280,280,280,460,320,100), strsk(5,5,2,8)|agisk(8,0,7,0,0)|lordsk1(7,7,0,4,2,4,4,3)|lordsk2(1,0,1,1,0,3,0,1), swadian_face_young_1,swadian_face_old_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Michadr Mosoru
["mosoru_rider", "Mosoru Rider", "Mosoru Riders", tf_guarantee_all, 0,0, fac_mosoru, [itm_black_lamellar_vest, itm_khergit_guard_helmet, itm_civil_rich_boots_b, itm_kote, itm_xenoargh_baydark, itm_strange_sword, itm_kite_shield_8, itm_javelin], 
attrlev(13,11,7,8,11), wpex(120,120,120,100,70,140), strsk(2,3,3,1)|agisk(3,1,2,4,4)|lordsk1(5,1,0,1,0,1,0,1)|lordsk2(0,0,0,0,0,2,0,1), mosoru_face_1, mosoru_face_2], 
["mosoru_battle_rider", "Mosoru Battle Rider", "Mosoru Battle Riders", tf_guarantee_all, 0,0, fac_mosoru, [itm_armor_medium_tyrk_b, itm_mosoru_song_helm, itm_splinted_leather_greaves, itm_kote, itm_horse_bandits_b, itm_steppe_paint1, itm_sword_khergit_4, itm_norman_shield_5, itm_throwing_spears], 
attrlev(17,14,9,10,22), wpex(190,190,190,140,80,200), strsk(4,5,5,2)|agisk(5,3,3,5,6)|lordsk1(6,1,0,2,1,2,1,2)|lordsk2(1,0,0,0,0,3,0,1), mosoru_face_3, mosoru_face_6], 
["mosoru_war_rider", "Mosoru War Rider", "Mosoru War Riders", tf_guarantee_all, 0,0, fac_mosoru, [itm_armor_medium_tyrk_c, itm_mosoru_song_qibing, itm_dorn_spearbearer_boots, itm_kote, itm_saracin_hard_horses_a_v1, itm_sword_khergit_1, itm_saracin_shield_k, itm_throwing_spears], 
attrlev(22,18,11,12,34), wpex(290,290,290,190,90,300), strsk(6,6,7,4)|agisk(7,5,4,7,8)|lordsk1(6,2,1,3,2,3,2,3)|lordsk2(1,0,1,0,0,3,0,1), mosoru_face_2, mosoru_face_4], 
["mosoru_warlord", "Mosoru Warlord", "Mosoru Warlords", tf_guarantee_all, 0,0, fac_mosoru, [itm_domaru_heraldic, itm_mosoru_song_qibing, itm_black_greaves, itm_glovesblack, itm_saracin_hard_horses_a, itm_two_handed_katana, itm_saracin_shield_t], 
attrlev(28,23,14,16,52), wpex(420,420,400,260,120,400), strsk(8,8,8,5)|agisk(9,7,5,9,9)|lordsk1(8,3,3,4,4,3,3,4)|lordsk2(2,0,1,1,2,4,2,2), mosoru_face_5, mosoru_face_6], 
# Female
["mosoru_maiden_rider", "Mosoru Maiden Rider", "Mosoru Maiden Riders", tf_female|tf_guarantee_all, 0,0, fac_mosoru, [itm_j_surcoat_dav_03d, itm_khergit_cavalry_helmet, itm_splinted_greaves_spurs, itm_gloves_lord_l, itm_european_horse_f, itm_khergit_sword_two_handed_b, itm_tulgan_bow, itm_ebonyornate_arrow], 
attrlev(15,14,8,10,13), wpex(170,170,130,200,100,130), strsk(3,3,2,4)|agisk(4,0,3,4,5)|lordsk1(5,1,0,2,0,2,2,2)|lordsk2(1,0,0,0,0,2,0,0), refugee_face1, refugee_face2], 
["mosoru_maiden_cavalry", "Mosoru Maiden Cavalry", "Mosoru Maiden Cavalry", tf_female|tf_guarantee_all, 0,0, fac_mosoru, [itm_dorn_heavy_cavalry_armor, itm_mosoru_song_helm, itm_mail_boots_brass, itm_redkote, itm_saracin_hard_horses_b, itm_sword_khergit_4, itm_tulgan_bow, itm_scull_arrow, itm_bronze_arrow], 
attrlev(21,22,10,13,28), wpex(270,270,230,300,130,160), strsk(4,5,3,6)|agisk(6,0,4,7,7)|lordsk1(6,3,0,3,0,3,3,3)|lordsk2(2,0,0,0,0,3,0,1), refugee_face1, refugee_face2], 
["mosoru_maroon_panther", "Maroon Panther", "Maroon Panthers", tf_female|tf_guarantee_all, 0,0, fac_mosoru, [itm_j_surcoat_bur_01c, itm_dorn_sand_snakes_helm_b, itm_west_man_at_arms_boots, itm_dorn_assasin_gant, itm_gauntlets_arabs_b_l, itm_saracin_hard_horses_a, itm_luc_strange_blade, itm_saracin_shield_k, itm_imperial_bow, itm_spak_bow6_arrow], 
attrlev(24,26,12,15,38), wpex(350,330,300,380,140,180), strsk(4,6,4,7)|agisk(8,4,5,8,9)|lordsk1(5,4,1,4,2,4,4,4)|lordsk2(2,0,0,0,1,3,1,3), refugee_face1, refugee_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Wolf Knights
["wolf_page", "Wolf Page", "Wolf Pages", tf_guarantee_inf, 0,0, fac_wolf_knights, [itm_wei_xiadi_mail_shirt02, itm_col1_gotlandbucket, itm_mail_boots, itm_wisby_gauntlets_black, itm_bastard_mace_no1, itm_luc_flanged_mace_s], 
attrlev(18,12,9,8,18), wpex(170,170,170,80,100,100), strsk(5,4,2,1)|agisk(3,1,2,1,0)|lordsk1(3,0,0,1,1,0,1,1)|lordsk2(0,0,0,0,0,2,0,0), mfy1, mfy2], 
["wolf_squire", "Wolf Squire", "Wolf Squires", tf_guarantee_allnoranged, 0,0, fac_wolf_knights, [itm_corrazina_red, itm_col1_gotlandbucket, itm_mail_boots, itm_iron_greaves, itm_wisby_gauntlets_red, itm_young_wolf_white_paint, itm_lui_knightaxeonehc, itm_luc_flanged_mace_s, itm_norman_shield_6], 
attrlev(25,18,12,12,28), wpex(250,250,250,110,160,160), strsk(7,7,4,3)|agisk(5,3,3,4,0)|lordsk1(5,2,1,3,3,2,2,2)|lordsk2(0,0,1,0,0,3,0,0), mfy1, mfo2], 
["wolf_knight", "Wolf Knight", "Wolf Knights", tf_guarantee_allnoranged, 0,0, fac_wolf_knights, [itm_early_transitional_black, itm_crusaderbucket_red, itm_black_greaves, itm_blackplatemitty, itm_young_wolf_blk_paint, itm_lui_knightaxeonehe, itm_luc_baronaxeoneh, itm_norman_shield_6], 
attrlev(33,23,15,17,40), wpex(340,340,340,160,200,200), strsk(9,9,6,5)|agisk(7,6,4,7,0)|lordsk1(6,3,3,4,5,4,3,3)|lordsk2(0,0,1,1,0,4,2,0), mfy1, mfo2], 
["wolf_elder", "Wolf Elder", "Wolf Elders", tf_guarantee_allnoranged, 0,0, fac_wolf_knights, [itm_maximilian_armour_1, itm_crusaderbucket_orange, itm_black_greaves, itm_blackplatemitty, itm_tamed_black_wolf, itm_stark_axe, itm_norman_shield_6], 
attrlev(42,28,20,23,58), wpex(440,440,440,220,250,260), strsk(10,10,7,6)|agisk(9,8,5,9,0)|lordsk1(7,4,4,6,7,6,4,4)|lordsk2(1,0,2,2,2,4,4,1), mfo1, mfo2], 
["wolf_constable", "Wolf Constable", "Wolf Constables", tf_guarantee_allnoranged|tf_allways_fall_dead, 0,0, fac_wolf_knights, [itm_armour_gothic, itm_great_helmet, itm_sugarloaf_b, itm_black_boot_salad_of, itm_blackplatemitty, itm_dreaded_wolf, itm_bleeding_killer, itm_sp_shr1], 
attrlev(66,36,30,30,85), wpex(580,580,580,400,400,400), strsk(12,11,9,9)|agisk(10,9,10,10,8)|lordsk1(8,7,7,8,10,8,7,4)|lordsk2(7,6,7,5,8,6,8,2), mfo1, mfo2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Assassins of Ral'Daiun
["cult_assassin", "Assassin of Ral'Daiun", "Assassins of Ral'Daiun", tf_guarantee_inf, 0,0, fac_outlaws, [itm_youhou_assassin_armor_red, itm_youhou_assassin_hood_red, itm_sarranid_boots_black, itm_gondor_bracer_l, itm_youhou_assassin_sword, itm_spak_crsb01, itm_steel_bolts], 
attrlev(30,30,24,24,46), wpex(500,500,500,400,440,400), strsk(10,9,9,9)|agisk(10,8,10,7,7)|lordsk1(4,3,4,4,8,4,4,4)|lordsk2(3,2,4,2,4,4,0,3), mercenary_face_1,mercenary_face_2], 

#Lymbard Knights
["lymbard_knight", "Lymbard Knight", "Lymbard Knights", tf_guarantee_allnoranged, 0,0, fac_lymbard, [itm_wei_xiadi_nord_cuir_bouilli, itm_crusaderbucket_purple, itm_steel_greaves, itm_hourglass_gauntlets_ornate, itm_war_horse5, itm_claymore_no1_v3, itm_norman_shield_8, itm_lance_6], 
attrlev(25,19,15,18,40), wpex(325,325,325,200,200,200), strsk(7,7,4,4)|agisk(7,7,3,7,0)|lordsk1(3,0,2,0,5,1,2,3)|lordsk2(0,0,1,2,2,3,2,2), mercenary_face_1,mercenary_face_2], 
["lymbard_dismounted_knight", "Dismounted Lymbard Knight", "Dismounted Lymbard Knights", tf_guarantee_inf, 0,0, fac_lymbard, [itm_wei_xiadi_nord_cuir_bouilli, itm_pigface_klappvisor, itm_iron_greaves, itm_plate_mittens, itm_sword_of_war], 
attrlev(26,20,15,18,40), wpex(340,340,340,200,200,200), strsk(8,8,4,4)|agisk(8,6,6,4,0)|lordsk1(3,0,3,2,5,1,1,3)|lordsk2(0,0,1,4,3,4,2,2), mercenary_face_1,mercenary_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#SU. Eagle Knights Begin
["eagle_pilgrim", "Eagle Pilgrim", "Eagle Pilgrims", tf_guarantee_inf, 0,0, fac_eagle_brotherhood, [itm_armor_14, itm_mail_coif, itm_splinted_greaves, itm_military_cleaver_short, itm_kite_shield_6, itm_awlpike, itm_rohirrim_throwing_axe], 
attrlev(14,13,10,7,12), wpex(145,145,150,80,80,150), strsk(3,3,4,2)|agisk(3,2,4,2,0)|lordsk1(0,0,0,1,1,1,1,2)|lordsk2(3,1,2,0,1,2,0,1), 0x000000018000618336db6db6db6db75c00000000001db6db0000000000000000,0x0000000d800062c736db6db6db6db75c00000000001db6db0000000000000000], 
["eagle_retainer", "Eagle Retainer", "Eagle Retainers", tf_guarantee_allnoranged, 0,0, fac_eagle_brotherhood, [itm_knight_armor_hospitaller_f, itm_gnezdovo_helm_a, itm_gnezdovo_helm_b, itm_mail_boots, itm_gauntlets, itm_tribal4, itm_bastard_sword_a, itm_military_cleaver_b, itm_shield_3, itm_lance_lev3], 
attrlev(20,17,12,10,26), wpex(310,310,310,180,180,180), strsk(6,6,4,4)|agisk(6,5,3,6,0)|lordsk1(2,0,0,2,3,1,2,2)|lordsk2(1,1,1,0,1,3,0,1), mfy1, mfy2], 
["eagle_knight", "Knight of the Eagle", "Knights of the Eagle", tf_guarantee_allnoranged, 0,0, fac_eagle_brotherhood, [itm_knight_armor_hospitaller_d_cloak, itm_crusader_knight_helm_b, itm_iron_greaves, itm_gauntlets, itm_wlong2, itm_sword_val_2, itm_shield_3, itm_luc_serrated_sword_v2, itm_lance_lev6], 
attrlev(27,21,15,16,42), wpex(410,410,410,220,220,220), strsk(8,8,6,6)|agisk(8,7,4,8,0)|lordsk1(3,0,2,3,4,2,2,3)|lordsk2(2,1,2,1,2,4,2,2), mfy1, mfo2], 
["eagle_lord", "Eagle Lord", "Eagle Lords", tf_guarantee_allnoranged, 0,0, fac_eagle_brotherhood, [itm_armor_master_order_hospitaller, itm_sugarloaf_a, itm_plate_boots2, itm_plate_mittens, itm_wlong2, itm_luc_hammer_spike, itm_shield_3, itm_lance_1], 
attrlev(35,24,20,26,62), wpex(530,530,530,300,300,300), strsk(10,10,8,8)|agisk(10,10,5,10,0)|lordsk1(4,0,4,3,6,2,3,4)|lordsk2(3,2,3,3,4,4,6,3), mfo1, mfo2], 

#Demon Worshippers
["demon_pilgrim", "Demon Pilgrim", "Demon Pilgrims", tf_guarantee_inf, 0,0, fac_demon_worshippers, [itm_pilgrim_disguise, itm_pilgrim_hood, itm_civil_rich_boots_b, itm_war_scythe_no1, itm_light_crossbow, itm_steel_bolts], 
attrlev(15,12,9,8,13), wpex(150,150,150,90,140,90), strsk(3,3,2,3)|agisk(3,0,4,0,0)|lordsk1(2,1,0,0,0,1,2,2)|lordsk2(0,0,0,1,1,2,0,0), 0x000000018000618336db6db6db6db75c00000000001db6db0000000000000000,0x0000000d800062c736db6db6db6db75c00000000001db6db0000000000000000], 
["demon_worshipper", "Demon Worshipper", "Demon Worshippers", tf_guarantee_allnoranged, 0,0, fac_demon_worshippers, [itm_shadow_outfit_c, itm_dragonrider_helmet, itm_dorn_spearbearer_boots, itm_scale_gauntlets, itm_hospitaller_knight_horse_a, itm_sarranid_two_handed_mace_1], 
attrlev(24,15,11,11,25), wpex(300,300,300,120,160,120), strsk(7,6,4,4)|agisk(6,4,4,5,0)|lordsk1(3,0,0,2,0,1,2,2)|lordsk2(0,0,0,1,2,3,0,0), mfy1, mfo2], 
["demon_priest", "Demon Priest", "Demon Priests", tf_guarantee_allnoranged, 0,0, fac_demon_worshippers, [itm_cuir_bouilli_sp, itm_demon_hood, itm_black_greaves, itm_blackplatemitty, itm_war_horse9, itm_asmoday_sword, itm_kite_shield_5], 
attrlev(31,18,13,15,42), wpex(390,390,390,150,180,150), strsk(9,6,5,5)|agisk(8,5,5,7,0)|lordsk1(4,0,0,3,2,2,2,3)|lordsk2(0,0,0,1,3,4,1,0), mfy1, mfo2], 
["demon_lord", "Demon Invoker", "Demon Invokers", tf_guarantee_allnoranged, 0,0, fac_demon_worshippers, [itm_spak_coat_of_plates_c, itm_asmoday_helmet2, itm_black_boot_salad_of, itm_blackplatemitty, itm_charger_dark, itm_demonic_sword_1h, itm_asmoday_seel], 
attrlev(39,21,16,21,62), wpex(480,480,480,180,200,180), strsk(10,8,6,6)|agisk(10,7,5,9,0)|lordsk1(5,0,2,4,3,2,3,4)|lordsk2(0,0,0,2,4,4,2,0), mfo1, mfo2], 

#General Ialoch
["unholy_demon_general","Unholy Demon General","Unholy Demon Generals",tf_undead|tf_guarantee_allnoranged|tf_allways_fall_dead,0,0,fac_demon_worshippers, [itm_spak_coat_of_plates_d, itm_demon_helm, itm_black_boot_salad_of, itm_blackplatemitty, itm_horny_charger_black, itm_demon_sword], 
attrlev(90,30,33,33,82), wpex(600,600,600,200,200,600), strsk(10,10,9,9)|agisk(10,9,8,10,8)|lordsk1(8,0,4,4,8,4,4,4)|lordsk2(0,0,0,3,6,4,8,4), undead_face1,undead_face2], 
["demon_death_knight","Demon Death Knight","Demon Death Knights",tf_undead|tf_allways_fall_dead|tf_guarantee_allnoranged,0,0,fac_demon_worshippers, [itm_spak_coat_of_plates_c, itm_helm_horned, itm_black_boot_salad_of, itm_glovesblack, itm_horny_charger_black, itm_spak_iceaxe, itm_asmoday_seel], 
attrlev(68,28,23,24,70), wpex(540,540,540,180,180,500), strsk(10,10,9,8)|agisk(10,9,7,10,8)|lordsk1(7,0,1,4,5,3,4,4)|lordsk2(0,0,0,2,3,4,3,3), undead_face1,undead_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Order of Faith
["faith_disciple","Disciple of Faith","Disciples of Faith",tf_guarantee_archer,0,0,fac_faith, [itm_rathos_surcoat_redyellow, itm_rathos_11thcent_conicalhelm_ry_store, itm_rus_splint_greaves, itm_gloves_lord_l, itm_jack_boromir, itm_norman_shield_4, itm_spak_crsb01, itm_bolts], 
attrlev(17,15,11,10,28), wpex(210,210,210,160,180,160), strsk(4,4,3,4)|agisk(5,3,5,2,0)|lordsk1(0,0,1,2,2,1,2,2)|lordsk2(1,0,1,1,0,2,0,1), mercenary_face_1, mercenary_face_2], 
["faith_defender","Defender of Faith","Defenders of Faith",tf_guarantee_inf,0,0,fac_faith, [itm_early_transitional_ry, itm_crusaderbucket_yellow_1, itm_iron_greaves, itm_wisby_gauntlets_black, itm_lui_battleaxea, itm_norman_shield_4, itm_great_axe_no3], 
attrlev(28,20,14,14,38), wpex(330,330,330,240,260,240), strsk(7,7,5,5)|agisk(7,6,6,4,0)|lordsk1(0,0,3,2,4,1,3,3)|lordsk2(2,1,2,2,1,4,1,1), mercenary_face_1, mercenary_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Maccavian Old Gods
["aethling", "Divine Aethling", "Divine Aethlings", tf_guarantee_inf, 0,0, fac_old_gods, [itm_maximilian_armour_1, itm_barbuta2_black, itm_black_greaves, itm_glovesblack, itm_executer], 
attrlev(35,22,18,18,50), wpex(440,440,400,260,260,260), strsk(10,10,8,8)|agisk(10,6,7,0,0)|lordsk1(3,0,4,1,6,1,2,3)|lordsk2(0,0,0,3,3,3,2,0), nofa1, nofa2], 

#Maccavian New Gods
["crusader", "Holy Crusader", "Holy Crusaders", tf_guarantee_allnoranged, 0,0, fac_new_gods, [itm_4black_armor, itm_crusader_knight_helm_d, itm_crusader_knight_helm_b, itm_black_boot_salad_of, itm_blackplatemitty, itm_mail_mittens, itm_plated_charger9, itm_crusader_sword, itm_shield_10], 
attrlev(30,23,18,18,50), wpex(400,400,370,200,200,200), strsk(9,9,7,7)|agisk(9,9,5,8,0)|lordsk1(1,0,3,1,6,1,2,3)|lordsk2(2,2,2,1,3,3,3,1), mfo1, mfo2], 

# Hakkon Inquisition troops
#["inquisition_warrior", "Inquisition Warrior Priest", "Inquisition Warrior Priests", tf_guarantee_all|tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_horse, 0,0, fac_inquisition, [], 
#def_attrib|level(25)|str_9|agi_12, wp(188), knows_common|knows_spotting_2|knows_pathfinding_2|knows_riding_4|knows_power_strike_5|knows_ironflesh_4, mfy1, mfo2], 
["inquisition_acolyte", "Inquisition Acolyte", "Inquisition Acolytes", tf_guarantee_inf, 0,0, fac_inquisition, [itm_ped_padd_lamellar_narrowd, itm_light_leather_boots, itm_brass_mail_mittens, itm_spiked_staff_no1], 
attrlev(14,11,8,7,13), wpex(160,160,150,80,100,100), strsk(3,3,2,2)|agisk(3,1,3,2,0)|lordsk1(1,0,0,1,1,0,1,1)|lordsk2(0,0,0,0,0,2,0,0), 0x000000000000b00436db6db6db6db64b00000000001db6d80000000000000000, 0x00000001ff00c00636db6db6db6db7b300000000001db6de0000000000000000], 
["inquisition_heretic_seeker", "Inquisition Heretic Seeker", "Inquisition Heretic Seekers", tf_guarantee_allnoranged, 0,0, fac_inquisition, [itm_early_transitional_rust, itm_argossky_helm, itm_boot_average_crusader_b, itm_lamellar_gauntlets, itm_romanhalfcata2, itm_lui_empirewarhammerb, itm_painted_brass_shield], 
attrlev(19,14,10,11,25), wpex(230,230,200,100,140,140), strsk(5,5,4,4)|agisk(5,4,4,5,0)|lordsk1(2,0,1,2,3,1,3,2)|lordsk2(0,0,0,1,1,3,0,0), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 
["hakkon_low_inquisitor", "Hakkon Low Inquisitor", "Hakkon Low Inquisitors", tf_guarantee_allnoranged, 0,0, fac_inquisition, [itm_early_transitional_orange, itm_barbuta2_greekish_grey, itm_mail_chausses_shin_guard, itm_dorn_knight_gant, itm_romanhalfcata, itm_lui_knighthammerempire, itm_hermitage_shield_3], 
attrlev(24,17,13,16,35), wpex(310,310,260,120,190,190), strsk(7,7,6,5)|agisk(7,5,5,6,0)|lordsk1(2,0,1,4,4,1,3,3)|lordsk2(0,0,1,1,2,4,1,0), 0x000000034000b01136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00c01136db6db6db6db7b300000000001db6de0000000000000000], 
["hakkon_inquisitor", "Hakkon Inquisitor", "Hakkon Inquisitors",tf_guarantee_allnoranged, 0,0, fac_inquisition, [itm_dorn_sand_snakes_armor, itm_barbuta2_greekish_bronze, itm_black_greaves, itm_glovesblack, itm_5warhorse_holy, itm_gothic_hammer, itm_new_shield], 
attrlev(30,21,17,24,50), wpex(400,400,330,150,250,250), strsk(9,9,7,6)|agisk(9,7,6,8,0)|lordsk1(3,0,2,6,5,2,4,4)|lordsk2(0,0,2,2,4,4,3,0), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 

#Lord Ceylius the Dishonorable
["masnerian_household_guard","Masnerian Household Guard","Masnerian Household Guards", tf_guarantee_allnoranged,0,0,fac_outlaws, [itm_black_armor, itm_crusaderbucket1, itm_black_greaves, itm_scale_gauntlets, itm_charger_black, itm_luc_iron_morningstar, itm_steel_heater1_dark], 
attrlev(31,21,15,24,60), wpex(430,430,400,200,200,200), strsk(9,9,7,7)|agisk(9,9,4,9,7)|lordsk1(4,0,3,2,5,0,2,3)|lordsk2(0,0,0,2,2,4,2,1), swadian_face_middle_1, swadian_face_older_2], 

#Nox of Zephilli
["perisno_runed_knight", "Perisno Runed Knight", "Perisno Runed Knights", tf_guarantee_allnoranged, 0,0, fac_kingdom_0, [itm_dark_lord_armor2, itm_winged_great_helmet, itm_plate_boots2, itm_glovesblack, itm_spak_charger_plate, itm_luc_winged_mace_2h, itm_shb1], 
attrlev(50,30,27,30,80), wpex(575,575,575,450,450,450), strsk(10,10,9,9)|agisk(10,10,7,10,6)|lordsk1(2,0,8,3,8,2,3,4)|lordsk2(3,2,4,4,4,4,7,3), mfo1, mfo2], 

["bullius_knight", "Glorious Knight of The Great Holy Bull", "Glorious Knights of The Great Holy Bull", tf_guarantee_allnoranged, 0,0, fac_illica, [itm_kuyak_b, itm_kuyak_a, itm_rus_lamellar_b, itm_guard_knight_helm, itm_bronzeshynald, itm_iron_greaves, itm_splinted_greaves_spurs, itm_boot_average_crusader_b, 
itm_beargauntlets, itm_wisby_gauntlets_black, itm_dark_mail_mittens, itm_cow_mod_a, itm_lui_knightaxeonehb, itm_luc_germanic_battle_axe, itm_luc_english_horseman_axe, itm_shield_8], #armor they wear and weapons they use is what Reich soldiers are equipped with - i.e. this is loot from the dead
attrlev(27,20,15,16,40), wpex(400,400,375,330,130,200), strsk(8,8,5,7)|agisk(8,8,6,9,8)|lordsk1(5,3,2,2,5,2,3,4)|lordsk2(0,0,0,0,1,4,1,1), vaegir_face_young_1, vaegir_face_young_2], #stats are identical to those of Illica Falki Knights (it's they in disguise)

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#Red Immortals
["red_immortal_hero","Mactabilus","Mactabilus",tf_hero,0,0,fac_red_immortals, [itm_imperial_armor_body_combined, itm_imperial_helm, itm_imperial_boots_male, itm_glovesblack, itm_jack_anduril, itm_shield_imperial, itm_roman_pilum_1], 
attrlev(70,44,30,40,65), wpex(680,680,680,500,500,680), strsk(10,10,10,10)|agisk(10,10,10,8,8)|lordsk1(4,0,10,5,10,5,6,5)|lordsk2(4,4,6,6,7,6,9,3), 0x0000000bff00625136db6db6db6db75c00000000001db6db0000000000000000], 

["red_immortal","Red Immortal","Red Immortals",tf_guarantee_inf,0,0,fac_red_immortals, [itm_imperial_armor_body_combined, itm_imperial_helm, itm_imperial_boots_male, itm_glovesblack, itm_jack_anduril, itm_sp_shr1, itm_roman_pilum_1], 
attrlev(60,42,28,30,60), wpex(650,650,600,400,400,600), strsk(10,10,10,9)|agisk(10,10,10,7,7)|lordsk1(2,0,8,3,10,4,4,4)|lordsk2(2,2,4,4,3,4,6,2), 0x000000071d00619136db6db6db6db75c00000000001db6db0000000000000000,0x0000000aba00625136db6db6db6db75c00000000001db6db0000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["m10_pmc_i_recruit", "Hired Recruit", "Hired Recruits", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(10,8,7,8,7), wpex(100,100,100,80,80,100), strsk(1,1,1,0)|agisk(1,1,1,0,0)|lordsk1(0,0,0,0,0,0,0,1)|lordsk2(0,0,0,0,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m10_pmc_i_soldier", "Hired Soldier", "Hired Soldiers", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(14,10,9,11,14), wpex(170,170,170,120,120,170), strsk(3,3,3,2)|agisk(3,2,3,0,0)|lordsk1(1,0,0,0,1,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m10_pmc_i_warrior", "Hired Warrior", "Hired Warriors", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(19,13,11,14,25), wpex(240,240,240,160,160,240), strsk(5,5,5,3)|agisk(5,4,4,0,0)|lordsk1(1,0,1,0,3,0,1,2)|lordsk2(0,0,0,0,0,2,0,0), mercenary_face_1, mercenary_face_2], 
["m10_pmc_i_vetwarrior", "Hired Veteran Warrior", "Hired Veteran Warriors", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(24,16,13,17,36), wpex(320,320,320,200,200,320), strsk(7,7,7,4)|agisk(7,5,6,0,0)|lordsk1(2,0,2,0,4,0,2,3)|lordsk2(0,0,0,0,0,3,0,0), mercenary_face_1, mercenary_face_2], 
["m10_pmc_i_footknight", "Hired Foot Knight", "Hired Foot Knights", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(30,20,16,20,50), wpex(400,400,400,250,250,400), strsk(9,9,9,6)|agisk(9,7,8,0,0)|lordsk1(2,0,4,0,6,0,3,4)|lordsk2(0,0,0,0,0,4,1,1), mercenary_face_1, mercenary_face_2], 
["m10_pmc_i_defender", "Hired Defender", "Hired Defenders", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(30,20,16,20,50), wpex(400,400,400,250,250,400), strsk(9,9,9,6)|agisk(9,7,8,0,0)|lordsk1(2,0,4,0,6,0,3,4)|lordsk2(0,0,0,0,0,4,1,1), mercenary_face_1, mercenary_face_2], 
#Cavalry
["m10_pmc_c_rider", "Hired Rider", "Hired Riders", tf_guarantee_all, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(18,13,11,15,25), wpex(230,230,230,160,160,230), strsk(4,4,4,3)|agisk(4,3,3,4,4)|lordsk1(1,0,0,0,3,1,2,2)|lordsk2(0,0,0,0,0,1,0,1), mercenary_face_1, mercenary_face_2], 
["m10_pmc_c_cavalry", "Hired Cavalry", "Hired Cavalry", tf_guarantee_all, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(22,16,13,19,36), wpex(300,300,300,200,200,300), strsk(6,6,6,4)|agisk(6,4,4,6,6)|lordsk1(2,0,1,0,5,1,3,3)|lordsk2(0,0,0,0,0,2,0,1), mercenary_face_1, mercenary_face_2], 
["m10_pmc_c_knight", "Hired Knight", "Hired Knights", tf_guarantee_all, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(28,20,17,24,50), wpex(375,375,375,250,250,375), strsk(8,8,8,6)|agisk(8,6,5,8,8)|lordsk1(2,0,3,0,7,1,4,4)|lordsk2(0,0,0,0,1,3,2,2), mercenary_face_1, mercenary_face_2], 
["m10_pmc_c_horsearcher", "Hired Horse Archer", "Hired Horse Archers", tf_guarantee_all, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(27,21,17,24,50), wpex(360,360,360,360,360,360), strsk(7,8,8,8)|agisk(8,6,5,8,8)|lordsk1(2,0,3,0,7,1,4,4)|lordsk2(0,0,0,0,1,3,2,2), mercenary_face_1, mercenary_face_2], 
#Archers
["m10_pmc_a_archer", "Hired Archer", "Hired Archers", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(13,11,9,11,14), wpex(140,140,140,160,160,140), strsk(2,2,2,3)|agisk(3,2,3,0,0)|lordsk1(1,1,0,0,2,0,1,1)|lordsk2(0,0,0,0,0,1,0,0), mercenary_face_1, mercenary_face_2], 
["m10_pmc_a_vetarcher", "Hired Veteran Archer", "Hired Veteran Archers", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(17,15,11,14,25), wpex(180,180,180,220,220,180), strsk(3,4,3,5)|agisk(4,2,5,0,0)|lordsk1(1,2,0,0,3,0,2,2)|lordsk2(0,0,0,0,0,1,0,1), mercenary_face_1, mercenary_face_2], 
["m10_pmc_a_masterarcher", "Hired Master Archer", "Hired Master Archers", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(21,19,13,18,36), wpex(230,230,230,300,300,230), strsk(5,5,5,7)|agisk(6,3,6,0,0)|lordsk1(1,3,1,0,5,1,3,3)|lordsk2(0,0,0,0,0,2,0,1), mercenary_face_1, mercenary_face_2], 
["m10_pmc_a_sharpshooter", "Hired Sharpshooter", "Hired Sharpshooters", tf_guarantee_archer, 0,0, fac_commoners, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(25,25,16,22,50), wpex(280,280,280,380,380,280), strsk(7,7,6,9)|agisk(8,4,7,0,0)|lordsk1(2,4,2,1,7,2,4,4)|lordsk2(0,0,1,1,0,3,0,2), mercenary_face_1, mercenary_face_2], 


["player_retainers", "Household Guard", "Household Guards", tf_guarantee_all, 0,0, fac_player_supporters_faction, [itm_heraldic_tabard, itm_leather_boots], 
attrlev(32,26,18,18,60), wpex(400,400,400,400,400,400), strsk(10,9,9,9)|agisk(10,8,8,9,9)|lordsk1(3,2,4,2,5,2,4,4)|lordsk2(2,0,2,4,3,4,3,2), mercenary_face_1, mercenary_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
["troops_end","Troops_end","Troops_end",0,0,0,fac_neutral, [itm_velvet], 
attrlev(48,18,13,18,60), wpex(350,350,350,350,350,350), strsk(10,10,10,10)|agisk(9,8,8,8,7)|lordsk1(3,2,4,2,5,2,4,4)|lordsk2(2,0,2,4,3,4,3,2), swadian_face_middle_1, swadian_face_older_2], #STATS are used for Giant household troops

["mrg_ingvar", "Ingvar", "Ingvar", tf_hero, 0,0, fac_commoners, [itm_west_pikeman_armor, itm_dorn_spearbearer_boots, itm_mail_mittens, itm_heroicsword], 
attrlev(30,20,20,20,50), wpex(300,300,300,300,300,300), strsk(8,8,8,8)|agisk(8,8,8,8,8), 0x0000000a31000218281a8d9ac956b94b00000000001ec8910000000000000000], 
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

## SU. Bounty ##
["fugitive","Nervous Man","Nervous Men",tf_guarantee_inf,0,0,fac_commoners, [itm_red_shirt, itm_rough_tunic_mailed, itm_coarse_tunic, itm_tabard, itm_leather_vest, itm_nomad_boots, itm_rus_shoes, itm_fur_hat, itm_leather_cap, itm_sword_medieval_c, itm_throwing_daggers], 
attrlev(14,7,8,5,10), wpex(100,100,100,100,100,100), strsk(2,3,2,2)|agisk(2,0,2,0,0), mercenary_face_1,mercenary_face_2], 
## SU. Bounty ##
["belligerent_drunk","Belligerent Drunk","Belligerent Drunks",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_red_shirt, itm_dethertir_armor_c, itm_coarse_tunic, itm_tabard, itm_leather_vest, itm_ankle_boots_cwe, itm_nomad_boots, itm_rus_shoes, itm_sword_medieval_c, itm_luc_italian_dagger, itm_wooden_stick], 
attrlev(13,6,6,6,10), wpex(90,90,90,90,90,90), strsk(1,3,2,2)|agisk(2,0,1,0,0),bandit_face1, bandit_face2], 
["hired_assassin","Hired Assassin","Hired Assassins",tf_guarantee_archer,0,0,fac_commoners, [itm_red_shirt, itm_coarse_tunic, itm_tabard, itm_leather_vest, itm_ankle_boots_cwe, itm_nomad_boots, itm_rus_shoes, itm_fur_hat, itm_leather_cap, itm_luc_sarranid_dagger, itm_assassin_throwing_daggers, itm_assassin_throwing_daggers], 
attrlev(27,30,21,18,54), wpex(440,440,440,400,400,440), strsk(9,9,10,9)|agisk(10,8,10,7,7), bandit_face1, bandit_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["peasant_rebel_ag","Peasant Rebel","Peasant Rebels",tf_guarantee_armor,0,reserved,fac_neutral, [itm_scythe, itm_knife, itm_military_fork, itm_sickle, itm_rrr_club1, itm_stones, itm_leather_cap, itm_felt_hat, itm_coarse_tunic, itm_pelt_coat, itm_nomad_boots], 
attrlev(9,5,5,5,1), wp(50), strsk(1,1,0,0)|agisk(0,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,1), mercenary_face_1, mercenary_face_2], 

["caravan_master","Caravan Master","Caravan Masters",tf_guarantee_all,0,0,fac_commoners, [itm_taureg_armor, itm_helmet_with_neckguard, itm_civil_rich_boots_a, itm_gloves_lord_l, itm_luc_english_falchion, itm_saddle_horse, itm_saddle_horse, itm_saddle_horse, itm_sumpter_horse], 
attrlev(18,16,18,20,20), wpex(220,220,220,160,160,160), strsk(4,4,3,3)|agisk(5,3,4,6,6)|lordsk1(0,0,0,2,2,4,4,4)|lordsk2(0,0,0,0,4,2,4,8), mercenary_face_1, mercenary_face_2], 

["messenger","Messenger","Messengers",tf_guarantee_armor|tf_guarantee_boots,0,0,fac_commoners, [itm_scythe, itm_knife, itm_military_fork, itm_sickle, itm_rrr_club1, itm_stones, itm_leather_cap, itm_felt_hat, itm_coarse_tunic, itm_pelt_coat, itm_nomad_boots], 
attrlev(9,5,5,5,1), wp(50), strsk(1,1,0,0)|agisk(0,0,1,0,0)|lordsk1(0,0,0,0,0,0,0,1), mercenary_face_1, mercenary_face_2], 

["temporary_minister","Minister","Minister",tf_hero,0,reserved,fac_commoners, [itm_rich_outfit, itm_civil_rich_boots_a], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000001a911044f589eb5e69d76beec00000000001dd7230000000000000000], 
## SU. Adviser
["intel_adviser", "Spymaster", "Spymaster", tf_hero, 0,reserved, fac_neutral, [itm_pilgrim_disguise, itm_rus_shoes], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), mercenary_face_1, mercenary_face_2], 

["troll","Troll","Troll",tf_troll|tf_guarantee_armor,0,0,fac_neutral, [itm_troll_arm, itm_troll_club_1], 
attrlev(250,15,9,5,80), wpex(400,400,400,10,10,300), strsk(15,15,10,0)|agisk(10,5,3,0,0), swadian_face_young_1, swadian_face_young_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["quick_battle_6_player", "{!}quick_battle_6_player", "{!}quick_battle_6_player", tf_hero, 0, 0, fac_player_faction, [itm_taureg_armor, itm_nomad_boots, itm_mail_boots, itm_skullcap, itm_sword_medieval_c, itm_crossbow, itm_bolts, itm_plate_covered_round_shield], knight_attrib_1,wp(130),knight_skills_1, 0x000000000008010b01f041a9249f65fd], 

["tutorial_fighter_1","Novice Fighter","Fighters",tf_hero,0,0,fac_kingdom_2, [itm_rough_spiked_rings, itm_nomad_boots], def_attrib|level(1),wp_melee(10),knows_athletics_1|knows_ironflesh_2|knows_shield_2,0x000000088c1073144252b1929a85569300000000000496a50000000000000000,vaegir_face_older_2], 
["tutorial_fighter_2","Novice Fighter","Fighters",tf_hero,0,0,fac_kingdom_2, [itm_green_tunic, itm_nomad_boots], def_attrib|level(1),wp_melee(10),knows_athletics_1|knows_ironflesh_2|knows_shield_2,0x000000088b08049056ab56566135c46500000000001dda1b0000000000000000,vaegir_face_older_2], 
["tutorial_fighter_3","Regular Fighter","Fighters",tf_hero,0,0,fac_kingdom_2, [itm_green_tunic, itm_nomad_boots], def_attrib|level(9),wp_melee(50),knows_athletics_1|knows_ironflesh_2|knows_shield_2,0x00000008bc00400654914a3b0d0de74d00000000001d584e0000000000000000,vaegir_face_older_2], 
["tutorial_fighter_4","Veteran Fighter","Fighters",tf_hero,0,0,fac_kingdom_2, [itm_rough_tunic_mailed, itm_nomad_boots], def_attrib|level(16),wp_melee(110),knows_athletics_1|knows_ironflesh_3|knows_power_strike_2|knows_shield_2,0x000000089910324a495175324949671800000000001cd8ab0000000000000000,vaegir_face_older_2], 
["tutorial_archer_1","Archer","Archers",tf_guarantee_ranged|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_kingdom_2, [itm_leather_jerkin, itm_leather_vest, itm_nomad_boots, itm_vaegir_spiked_helmet, itm_vaegir_fur_helmet, itm_vaegir_fur_cap, itm_nomad_cap], def_attrib|str_12|level(19),wp_melee(70)|wp_archery(110),knows_ironflesh_1|knows_power_draw_2|knows_athletics_2|knows_power_throw_1,vaegir_face_young_1,vaegir_face_older_2], 
["tutorial_master_archer","Archery Trainer","Archery Trainer",tf_hero,0,0,fac_kingdom_2, [itm_rough_tunic_mailed, itm_nomad_boots], def_attrib|str_12|level(19),wp_melee(70)|wp_archery(110),knows_ironflesh_1|knows_power_draw_2|knows_athletics_2|knows_power_throw_1,0x0000000ea508540642f34d461d2d54a300000000001d5d9a0000000000000000,vaegir_face_older_2], 
["tutorial_rider_1","Rider","{!}Vaegir Knights",tf_mounted|tf_guarantee_boots|tf_guarantee_gloves|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_horse|tf_guarantee_shield,0,0,fac_kingdom_2, [itm_green_tunic, itm_hunter, itm_saddle_horse, itm_leather_gloves], def_attrib|level(24),wp(130),knows_riding_4|knows_shield_2|knows_ironflesh_3|knows_power_strike_2,vaegir_face_middle_1,vaegir_face_older_2], 
["tutorial_rider_2","Horse archer","{!}Khergit Horse Archers",tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_ranged|tf_guarantee_horse,0,0,fac_kingdom_3, [itm_tribal_warrior_outfit, itm_beduin_armor_c, itm_hunter_boots, itm_tab_shield_small_round_a, itm_steppe_horse], def_attrib|level(14),wp(80)|wp_archery(110),knows_riding_5|knows_power_draw_3|knows_ironflesh_1|knows_horse_archery_4|knows_power_throw_1,khergit_face_young_1,khergit_face_older_2], 
["tutorial_master_horseman","Riding Trainer","Riding Trainer",tf_hero,0,0,fac_kingdom_2, [itm_leather_vest, itm_nomad_boots], def_attrib|str_12|level(19),wp_melee(70)|wp_archery(110),knows_ironflesh_1|knows_power_draw_2|knows_athletics_2|knows_power_throw_1,0x0000000ea0084140478a692894ba185500000000001d4af30000000000000000,vaegir_face_older_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#The Jin Empire
# recruit > militia > swordsman > veteran swordsman > elite swordsman
# 													> assassin
# 		                        > light cavalry > shock cavalry
#         > bowman > trained bowman > veteran bowman
#["jin_recruit", "Jin Recruit", "Jin Recruits", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_outlaws, [itm_steppe_cap, itm_fur_coat, itm_light_leather_boots, itm_dagger, itm_wooden_shield, itm_rrr_club1], def_attrib|level(5), wp(70), knows_common|knows_power_strike_1, khergit_face_younger_1, khergit_face_old_2], 
#["jin_militia", "Jin Militia", "Jin Militia", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_shield, 0,0, fac_outlaws, [itm_ao_vai_2, itm_leather_gloves, itm_new_steppe_cap_a, itm_lui_waronehandedaxec, itm_tab_shield_small_round_b, itm_sword_khergit_1], def_attrib|level(11)|str_8, wp(123), knows_common|knows_athletics_2|knows_ironflesh_2|knows_power_strike_3, khergit_face_young_1, khergit_face_older_2], 
#["jin_swordsman", "Jin Swordsman", "Jin Swordsmen", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_shield, 0,0, fac_outlaws, [itm_spear, itm_military_cleaver_b, itm_bastard_sword_b, itm_tab_shield_kite_cav_b, itm_mail_chausses_shin_guard, itm_khergit_war_helmet, itm_new_lamellar_gauntlets, itm_giap_viet3], def_attrib|level(20)|str_12|agi_3, wp(170), knows_common|knows_riding_3|knows_ironflesh_4|knows_power_strike_5|knows_shield_4|knows_athletics_4|knows_power_throw_3, khergit_face_young_1, khergit_face_older_2], 
#["jin_trained_swordsman", "Jin Trained Swordsman", "Jin Trained Swordsmen", tf_randomize_face|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield, 0,0, fac_outlaws, [itm_splinted_greaves_spurs, itm_new_lamellar_gauntlets, itm_giap_viet2_l, itm_throwing_spears, itm_sword_khergit_4, itm_bastard_sword_a_fix, itm_leather_covered_round_shield], def_attrib|level(28)|str_19|agi_9, wp(255), knows_common|knows_spotting_3|knows_tactics_2|knows_athletics_5|knows_shield_5|knows_weapon_master_6|knows_power_strike_6|knows_ironflesh_5|knows_power_throw_5, khergit_face_young_1, khergit_face_older_2], 
#["jin_veteran_swordsman", "Jin Veteran Swordsman", "Jin Veteran Swordsmen", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield, 0,0, fac_outlaws, [], def_attrib|level(40)|str_18|agi_12, wp(300), knows_common|knows_riding_1|knows_shield_4|knows_power_strike_7|knows_ironflesh_7|knows_athletics_7, khergit_face_young_1, khergit_face_older_2], 
#["jin_assassin", "Jin Assassin", "Jin Assassins", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield, 0,0, fac_outlaws, [itm_shadow_mask, itm_shadow_greaves, itm_gondor_bracer_l, itm_shadow_outfit_c, itm_youhou_assassin_sword, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar], def_attrib|level(46)|str_15|agi_22, wp(340), knows_common|knows_riding_1|knows_shield_6|knows_power_strike_7|knows_ironflesh_8|knows_athletics_9, khergit_face_young_1, khergit_face_older_2], 
#["jin_light_cavalry", "Jin Light Cavalry", "Jin Light Cavalry", tf_mounted|tf_guarantee_allnoranged, 0,0, fac_outlaws, [], def_attrib|level(30)|str_14|agi_5, wp(250), knows_common|knows_spotting_3|knows_riding_5|knows_power_strike_5|knows_ironflesh_6, khergit_face_young_1, khergit_face_older_2], 
#["jin_shock_cavalry", "Jin Shock Cavalry", "Jin Shock Cavalry", tf_mounted|tf_guarantee_allnoranged, 0,0, fac_outlaws, [], def_attrib|level(41)|str_17|agi_7|cha_5|int_5, wp(350), knows_riding_6|knows_ironflesh_6|knows_power_strike_8|knows_tracking_5|knows_shield_6, khergit_face_young_1, khergit_face_older_2], 
#["jin_bowman", "Jin Bowman", "Jin Bowmen", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_ranged, 0,0, fac_outlaws, [itm_short_bow, itm_arrows, itm_arrows, itm_shinobi_bite, itm_leather_boots, itm_leather_gloves], def_attrib|level(14), wp(120), knows_common|knows_riding_2|knows_ironflesh_1|knows_power_draw_2, khergit_face_younger_1, khergit_face_old_2], 
#["jin_trained_bowman", "Jin Trained Bowman", "Jin Trained Bowmen", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_ranged, 0,0, fac_outlaws, [], def_attrib|level(27)|str_9, wp(190), knows_common|knows_riding_2|knows_ironflesh_1|knows_athletics_1|knows_power_throw_4|knows_power_draw_5, khergit_face_younger_1, khergit_face_old_2], 
#["jin_veteran_bowman", "Jin Veteran Bowman", "Jin Veteran Bowmen", tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield|tf_guarantee_ranged, 0,0, fac_kingdom_7, [], str_14|agi_10|int_4|cha_4|level(33), wp(240), knows_common|knows_power_draw_5|knows_ironflesh_1|knows_power_strike_1|knows_athletics_2, khergit_face_younger_1, khergit_face_old_2], 
#["jin_messenger","Jin Messenger","Jin Messengers",tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_horse|tf_guarantee_ranged,0,0,fac_outlaws, [itm_sword_khergit_2, itm_leather_jerkin, itm_leather_boots, itm_courser, itm_leather_gloves, itm_short_bow, itm_arrows], str_7|agi_21|int_4|cha_4|level(25),wp(125),knows_common|knows_riding_7|knows_horse_archery_5|knows_power_draw_5|companionscout_skills,khergit_face_young_1,khergit_face_older_2], 
#["jin_deserter","Jin Deserter","Jin Deserters",tf_guarantee_ranged|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_deserters, [itm_arrows, itm_spiked_mace, itm_axe, itm_sword_khergit_1, itm_short_bow, itm_short_bow, itm_hunting_bow, itm_javelin, itm_javelin, itm_steppe_cap, itm_nomad_cap_b, itm_ao_vai_1, itm_steppe_armor, itm_tribal_warrior_outfit, itm_nomad_boots], str_10|agi_5|int_4|cha_4|level(14),wp(80),knows_ironflesh_1|knows_power_draw_1,khergit_face_young_1,khergit_face_older_2], 
#["jin_prison_guard","Prison Guard","Prison Guards", tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield, 0, 0, fac_outlaws, [itm_elite_armor_a, itm_ghulam_helm2, itm_khopesh_1, itm_new_gauntlets_b, itm_mail_boots, itm_scimitar_b, itm_painted_brass_shield, itm_war_darts, itm_war_darts], def_attrib|level(35)|str_21|agi_9, wp(236), knows_riding_5|knows_power_strike_5|knows_ironflesh_5|knows_horse_archery_4|knows_power_throw_5|knows_shield_3|knows_athletics_4, khergit_face_young_1, khergit_face_older_2], 
#["jin_castle_guard","Castle Guard","Castle Guards", tf_randomize_face|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_guarantee_gloves|tf_guarantee_shield, 0, 0, fac_outlaws, [itm_war_darts, itm_war_darts, itm_rough_macle_ringed, itm_sarranid_helmet1_black, itm_new_lamellar_gauntlets, itm_mail_chausses_shin_guard, itm_luc_long_war_spear, itm_luc_heavy_wooden_shield, itm_winged_helm_new, itm_scimitar], def_attrib|level(23)|str_8, wp(187), knows_ironflesh_5|knows_power_strike_3|knows_power_throw_4|knows_athletics_4|knows_shield_3|knows_weapon_master_1, khergit_face_young_1, khergit_face_older_2], 

#######################  SOLDIERS_END ###############

##+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++Walkers begin
["kplayer_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_aketon_green_1, itm_civ_body_m_tabard_1, itm_civ_body_m_leather_vest_2, itm_rough_tunic_spiked, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_black, itm_civ_foot_leather_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), mfy1, mfo2], 
["k00_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_aketon_green_1, itm_civ_body_m_tabard_1, itm_civ_body_m_leather_vest_2, itm_rough_tunic_spiked, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_black, itm_civ_foot_leather_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), mfy1, mfo2], 
["k01_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_heraldic_tabard, itm_taureg_armor, itm_civ_body_m_shirt_rich_1, itm_civ_body_m_tabard_3, itm_civ_body_m_gamb_red, itm_civ_foot_ankle_boots_1, itm_civ_foot_leather_boots_1, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_red], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k02_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_padded_cloth_3, itm_civ_body_m_pino_leather_fur_2, itm_civ_body_m_gamb_brown, itm_civ_body_m_pino_leather_4, itm_civ_head_m_leather_cap_3, itm_civ_head_m_leather_cap_1, itm_civ_foot_rich_boots_black, itm_civ_foot_cavalry_boots_black, itm_civ_foot_plated_boots_1, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), vaegir_face_middle_1, vaegir_face_middle_2], 
["k03_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_arab_robe_2, itm_civ_body_m_arab_armor_1, itm_civ_body_m_arab_vest_3, itm_civ_body_m_arab_robe_7, itm_civ_body_m_arab_robe_6, itm_civ_head_m_full_turban_1, itm_civ_head_m_full_turban_2, itm_civ_head_m_turban_1, itm_civ_head_m_turban_black_3, itm_civ_foot_arab_leather_boots_1, itm_civ_foot_arab_leather_boots_2, itm_civ_foot_arab_leather_boots_black, itm_civ_foot_plated_boots_arab], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), draharan_faces_arab_begin, draharan_faces_arab_end], 
["k04_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_fur_coat_rich_1, itm_civ_body_m_pino_leather_3, itm_civ_body_m_gamb_blue, itm_civ_body_m_rich_fur_1, itm_civ_body_m_fur_coat_1, itm_civ_head_m_leather_cap_3, itm_civ_head_m_leather_cap_4, itm_civ_foot_highlander_boots, itm_civ_foot_furred_boots_1, itm_civ_foot_leather_boots_1, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), nofa1, nofa2], 
["k05_town_walker", "Elf", "Elves", tf_elven_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_arab_bandit_a, itm_civ_body_m_aketon_green_1, itm_civ_body_m_arab_robe_8, itm_bronn_armor, itm_civ_foot_rich_boots_black, itm_civ_foot_rich_boots_red, itm_civ_foot_elven_boots_green], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000000000000136db6db6db6db6db00000000001db6db0000000000000000, 0x000000003f00000636db6db6db6db6db00000000001db6db0000000000000000], 
["k06_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_gamb_striped, itm_civ_body_padded_armor_1, itm_civ_body_padded_armor_7, itm_turk_bandit_c, itm_hakkon_noble_outfit, itm_civ_foot_ankle_boots_1, itm_civ_foot_leather_boots_2, itm_civ_foot_plated_boots_1, itm_civ_foot_cavalry_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
["k07_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_padded_armor_5, itm_civ_body_m_leather_vest_3, itm_civ_body_m_shirt_rich_3, itm_giap_viet4, itm_giap_viet3, itm_civ_foot_ankle_boots_1, itm_civ_foot_ankle_boots_brown, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1, itm_civ_foot_rich_boots_red], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k08_town_walker", "Man", "Men", tf_elven_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_knight_armor_templar_a, itm_knight_armor_templar_a_1, itm_courtly_outfit, itm_padded_jack, itm_civ_foot_plated_boots_2, itm_civ_foot_rich_boots_black, itm_civ_foot_cavalry_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), elintoran_face_young_begin, elintoran_face_young_end], 
["k09_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_fur_vest_1, itm_civ_body_m_ragged_outfit_warm, itm_civ_body_m_rawhide_coat_1, itm_new_rawhide_coat_a, itm_civ_head_m_leather_cap_nord, itm_civ_head_m_leather_cap_nord_1, itm_civ_foot_hide_boots_1, itm_civ_foot_leather_boots_1, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), nofa1, nofa2], 
["k10_town_walker", "Dwarf", "Dwarves", tf_dwarf_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dwarf_civilian_2_red, itm_dwarf_civilian_2_blue, itm_dwarf_civilian_2_green, itm_dwarf_civilian_2_purple, itm_highlander_boots_2_2, itm_boot_average_crusader_b, itm_rus_splint_greaves, itm_mail_boots], #old itm_a_h4, itm_a_h1_1, itm_a_h2, itm_a_h3, itm_dwarf_helm_l, itm_b_h1
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k11_town_walker", "Elf", "Elves", tf_elven_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_ao_vai_2_x, itm_civ_body_m_tabard_4, itm_civ_body_m_shirt_3, itm_armour_vale, itm_civ_foot_furred_boots_1, itm_civ_foot_rich_boots_black], #copy-pasted villagers' equipment
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000002d50005d036db6db6db6db6db00000000001db6db0000000000000000,0x00000002ee0035d736db6db6db6db6db00000000001db6db0000000000000000], #redundant - Geldarin elves do not have a town; though it should be present for the sake of correct order
["k12_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_padded_cloth_1, itm_civ_body_m_gamb_white, itm_civ_body_m_nomad_lam_white, itm_peasant_leather_ls, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1, itm_civ_foot_ankle_boots_brown], #copy-pasted villagers' equipment
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_middle_1, swadian_face_old_2], 
["k13_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_nomad_lam_kuulan, itm_civ_body_m_nomad_lam_brass, itm_civ_body_m_nomad_lam_black, itm_heavy_armor_arabs_d, itm_civ_head_m_fur_hat_2, itm_civ_head_m_fur_hat_3, itm_boot_average_crusader_c, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k14_town_walker", "Giant", "Giants", tf_giant_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_giant_plate_armor_bakhal, itm_giant_archer_armor_bakhal, itm_armor_marauder_recruit_c_01, itm_spiked_bakhal_helmet, itm_giant_helmet_bakhal, itm_giant_warrior_boots, itm_giant_gr_boots_knee_01, itm_giant_grey_boots], 
attrlev(25,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k15_town_walker", "Giant", "Giants", tf_giant_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_giant_guardsman_armor_sut, itm_giant_plate_armor_sut, itm_giant_guard_armor_sut, itm_giant_leather_armor_sut, itm_giant_helmet_karnoth, itm_giant_brown_boots, itm_giant_br_boots_knee_02], 
attrlev(25,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k16_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_woodman_chieftain, itm_leaf_armour, itm_woodman_padded, itm_woodman_scout, itm_aroulo_boots], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), aroulo_face_younger_1, aroulo_face_older_2], 
["k17_town_walker", "Man", "Men", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_shirt_a_got_1, itm_roman_hamata, itm_roman_armor_cent, itm_roman_armor, itm_roman_squamata, itm_roman_armor_white, itm_roman_cent_hamata, itm_roman_greaves_gutter, itm_roman_greaves_greek, itm_gauntlets_arabs_a_l], #old itm_padded_cloth_got_1, itm_shirt_a_got_1, itm_rough_leather_2, itm_rough_leather_6, itm_civ_foot_plated_boots_1, itm_civ_foot_plated_boots_2
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 

##+++++++++++++++++++++++++++++++++
#missing
["k01_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_coarse_tunic_red, itm_civ_body_m_shirt_2, itm_civ_body_m_pino_leather_1, itm_civ_foot_hide_boots_1, itm_civ_foot_leather_boots_1, itm_civ_foot_ankle_boots_brown], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k02_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_coarse_tunic_1, itm_civ_body_m_leather_vest_1, itm_civ_body_m_pino_leather_fur_1, itm_civ_head_m_leather_cap_1, itm_civ_foot_hide_boots_1, itm_civ_foot_leather_boots_1, itm_civ_foot_ankle_boots_brown, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), vaegir_face_middle_1, vaegir_face_middle_2], 
["k03_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_arab_robe_3, itm_civ_body_m_arab_robe_4, itm_civ_body_m_arab_robe_5, itm_civ_body_m_arab_robe_1, itm_civ_head_m_turban_1, itm_civ_head_m_cwe_turban_black_1, itm_civ_head_m_cwe_turban_black_2, itm_civ_foot_arab_leather_boots_1, itm_civ_foot_arab_leather_boots_2, itm_civ_foot_arab_leather_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), draharan_faces_black_begin, draharan_faces_black_end], 
["k04_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_shirt_rich_4, itm_peasant_leather_plate_b, itm_civ_body_m_tabard_2, itm_civ_body_m_leather_jerkin_1, itm_civ_foot_leather_boots_2, itm_civ_foot_leather_boots_1, itm_civ_foot_ankle_boots_brown, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), nofa1, nofa2], 
["k05_village_walker", "Villager", "Villagers", tf_elven_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_shirt_3, itm_civ_body_m_peasant_clothes_1, itm_leather_armor, itm_peasant_lamellar_ls, itm_rough_tunic_spiked, itm_civ_foot_rich_boots_black, itm_civ_foot_leather_boots_1, itm_civ_foot_ankle_boots_1, itm_civ_foot_furred_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000000000000136db6db6db6db6db00000000001db6db0000000000000000, 0x000000003f00000636db6db6db6db6db00000000001db6db0000000000000000], 
["k06_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_shirt_1, itm_civ_body_padded_armor_5, itm_turk_bandit_a, itm_peasant_leather_ls, itm_civ_foot_ankle_boots_1, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000070000b0c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff00c10636db6db6db6db7b300000000001db6de0000000000000000], 
["k07_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_nomad_fur_armor_1, itm_civ_body_m_nomad_lam_l_1, itm_black_steppe_armor, itm_khergit_armor, itm_nomad_armor, itm_civ_foot_ankle_boots_brown, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), zann_face_young_to_middle_begin, zann_face_young_to_middle_end], 
["k08_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_aketon_white_1, itm_civ_body_m_white_shirt_1, itm_civ_body_m_gamb_grey, itm_civ_body_m_tabard_1, itm_civ_foot_ankle_boots_1, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), elintoran_face_young_begin, elintoran_face_young_end], 
["k09_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_leather_vest_2, itm_rough_leather_6, itm_civ_body_m_pino_tunic_1, itm_rough_leather_2, itm_civ_head_m_leather_cap_nord, itm_civ_head_m_leather_cap_nord_1, itm_civ_foot_hide_boots_1, itm_civ_foot_leather_boots_1, itm_leather_gloves], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), nofa1, nofa2], 
["k10_village_walker", "Villager", "Villagers", tf_dwarf_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dwarf_civilian_1_red, itm_dwarf_civilian_1_blue, itm_dwarf_civilian_1_green, itm_dwarf_civilian_1_purple, itm_b_h1, itm_leather_boots_dark, itm_west_rider_boots, itm_splinted_greaves], #old itm_a_h1, itm_civ_body_padded_armor_2, itm_light_leather, itm_novici_hospitaller, itm_civ_foot_highlander_boots, itm_civ_foot_leather_boots_2, itm_b_h1
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), kaikoth_male_faces_begin, kaikoth_male_faces_end], 
["k11_village_walker", "Villager", "Villagers", tf_elven_male|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_ao_vai_2_x, itm_civ_body_m_tabard_4, itm_civ_body_m_shirt_3, itm_armour_vale, itm_civ_foot_furred_boots_1, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000002d50005d036db6db6db6db6db00000000001db6db0000000000000000,0x00000002ee0035d736db6db6db6db6db00000000001db6db0000000000000000], 
["k12_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_padded_cloth_1, itm_civ_body_m_gamb_white, itm_civ_body_m_nomad_lam_white, itm_peasant_leather_ls, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1, itm_civ_foot_ankle_boots_brown], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_middle_1, swadian_face_old_2], 
["k13_village_walker", "Villager", "Villagers", tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_ao_vai_1, itm_civ_body_padded_armor_6, itm_civ_body_m_nomad_vest_1, itm_wei_xiadi_kher_lamellar_vest02, itm_civ_head_m_fur_hat_1, itm_civ_head_m_nomad_cap_1, itm_boot_average_crusader_c, itm_civ_foot_hide_boots_1, itm_civ_foot_nomad_boots_1, itm_civ_foot_ankle_boots_brown], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), kuulan_face_young_to_old_begin, kuulan_face_young_to_old_end], 
["k14_village_walker", "Villager", "Villagers", tf_giant_male|tf_guarantee_armor, 0,0, fac_commoners, [itm_armor_marauder_recruit_c_01, itm_armor_marauder_recruit_a_01, itm_giants_grey_pants, itm_giant_gr_boots_knee_01, itm_giant_grey_boots], 
attrlev(25,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k15_village_walker", "Villager", "Villagers", tf_giant_male|tf_guarantee_armor, 0,0, fac_commoners, [itm_giant_archer_armor_sut_2, itm_giant_archer_armor_sut, itm_armor_marauder_recruit_b_01, itm_giants_brown_pants, itm_giant_brown_boots, itm_giant_br_boots_knee_02], 
attrlev(25,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), swadian_face_younger_1, swadian_face_middle_2], 
["k16_village_walker", "Villager", "Villagers", tf_guarantee_armor, 0,0, fac_commoners, [itm_woodman_tunic, itm_civ_body_m_peasant_fur_1, itm_civ_body_m_rawhide_coat_1, itm_civ_foot_hunter_boots_1, itm_aroulo_boots], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), aroulo_face_younger_1, aroulo_face_older_2], 

##+++++++++++++++++++++++++++++++++
["kplayer_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_green_tunic, itm_civ_body_m_surcoat_3, itm_lady_dress_green, itm_rough_tunic_spiked, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_black, itm_civ_foot_leather_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k00_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_green_tunic, itm_civ_body_m_surcoat_3, itm_lady_dress_green, itm_rough_tunic_spiked, itm_civ_foot_leather_boots_2, itm_civ_foot_rich_boots_black, itm_civ_foot_leather_boots_1], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k01_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_red_dress, itm_lady_dress_ruby, itm_court_dress, itm_civ_foot_rich_boots_red], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k02_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_new_dress_a, itm_new_dress_b, itm_brown_dress, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k03_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_sarranid_lady_dress, itm_sarranid_lady_dress_b, itm_khergit_lady_dress, itm_civ_foot_rich_boots_red, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k04_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_blue_dress, itm_lady_dress_blue, itm_court_dress, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k05_f_town_walker", "Elf", "Elves", tf_elven_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_new_dress_b, itm_lady_dress_green, itm_green_dress, itm_civ_foot_rich_boots_black, itm_civ_foot_rich_boots_red], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k06_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_brown_dress, itm_sarranid_lady_dress_b, itm_new_dress_c, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k07_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [],   #redundant - we don't have Zann-ish female faces and therefore Zann female are exluded; though it should be present for the sake of correct order
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k08_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_lady_dress_blue, itm_lady_dress_ruby, itm_lady_dress_green, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k09_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_fur_coat_rich_1, itm_civ_body_m_ragged_outfit_warm, itm_civ_body_m_fur_coat_1, itm_civ_foot_rich_boots_black, itm_leather_boots_dark], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k10_f_town_walker", "Dwarf", "Dwarves", tf_dwarf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_lady_dress_ruby, itm_civ_body_m_pino_leather_2, itm_civ_body_padded_armor_4, itm_civ_foot_rich_boots_red, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k11_f_town_walker", "Elf", "Elves", tf_elven_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_new_dress_a, itm_ao_vai_2_x, itm_arab_bandit_c, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k12_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dress, itm_civ_body_m_coarse_tunic_1, itm_peasant_dress, itm_civ_foot_leather_boots_2],  
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k13_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_khergit_lady_dress_b, itm_ao_vai_2, itm_civ_body_m_nomad_vest_1, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k14_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), giant_face_female_start, giant_face_female_end], 
["k15_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), giant_face_female_start, giant_face_female_end], 
["k16_f_town_walker", "Woman", "Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_woodman_tunic, itm_woodman_scout, itm_aroulo_boots], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), aroulo_face_woman_younger_1, aroulo_face_woman_older_2], 
#So far the rest are blocked in script_init_town_walkers, and therefore are not needed

##+++++++++++++++++++++++++++++++++
#missing
["k01_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dress, itm_woolen_dress, itm_peasant_dress, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k02_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_peasant_dress, itm_woolen_dress, itm_civ_body_m_gamb_striped, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k03_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_khergit_lady_dress_b, itm_sarranid_common_dress, itm_sarranid_common_dress_b, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k04_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_blue_dress, itm_peasant_dress, itm_woolen_dress, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k05_f_village_walker", "Peasant Woman", "Peasant Women", tf_elven_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_green_dress, itm_lady_dress_green, itm_ao_vai_2_l, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k06_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_light_leather, itm_sarranid_common_dress_b, itm_civ_body_m_pino_leather_6, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k08_f_village_walker", "Peasant Woman", "Peasant Women", tf_elven_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dress, itm_woolen_dress, itm_civ_body_m_padded_cloth_1, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k09_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_gamb_brown, itm_civ_body_m_leather_vest_1, itm_civ_body_m_pino_leather_fur_1, itm_civ_foot_leather_boots_2, itm_leather_boots_dark], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k10_f_village_walker", "Peasant Woman", "Peasant Women", tf_dwarf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_sarranid_common_dress, itm_padded_jack, itm_dress, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k11_f_village_walker", "Peasant Woman", "Peasant Women", tf_elven_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_new_dress_a, itm_ao_vai_2_x, itm_arab_bandit_c, itm_civ_foot_rich_boots_black], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k12_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_dress, itm_civ_body_m_coarse_tunic_1, itm_peasant_dress, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
["k13_f_village_walker", "Peasant Woman", "Peasant Women", tf_female|tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [itm_civ_body_m_arab_vest_1, itm_civ_body_m_arab_vest_2, itm_black_steppe_armor, itm_civ_foot_leather_boots_2], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), woman_face_1, woman_face_2], 
#So far the rest are blocked in script_init_town_walkers, and therefore are not needed
##+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++Walkers end

["tournament_master","{!} spy_walkers_end","{!} spy_walkers_end",tf_hero, 0,0, fac_commoners, [itm_peasant_leather_ls, itm_nomad_boots], def_attrib|level(2),wp(20),knows_common,0x000000000008414401e28f534c8a2d09], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# Ryan BEGIN
["ramun_the_slave_trader","Ramun, the slave trader","Ramun, the slave trader",tf_hero, 0,0, fac_commoners, [itm_leather_jacket, itm_leather_boots], 
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000fd5104594385281c55b8e44eb00000000001d99220000000000000000], 
#["guide","Quick Jimmy","Quick Jimmy",tf_hero, no_scene,0, fac_commoners, [itm_coarse_tunic, itm_hunter_boots], def_attrib|level(2),wp(20),knows_inventory_management_10, 0x00000000000c318301f24e38a36e38e3], 
# Ryan END

["Xerina","Kela the Amazon","Kela",tf_hero|tf_female, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(28,30,14,20,50), wpex(400,400,400,500,200,200), strsk(9,8,6,10)|agisk(10,6,7,4,6),0x00000001ac0820074920561d0b51e6ed00000000001d40ed0000000000000000], 
["Dranton","Clathas","Clathas",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(40,14,10,18,50), wpex(420,420,350,240,300,400), strsk(10,10,10,8)|agisk(9,8,4,5,4),0x000000062b0000536942d2385b6d2d5c00000000001dc7190000000000000000], 
["Kradus","Cyndim the Blademaster","Cyndim",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(32,21,12,20,50), wpex(500,500,400,280,280,300), strsk(10,9,8,7)|agisk(10,7,6,4,0),0x0000000f5b1052c61ce1a9521db1375200000000001ed31b0000000000000000], 
["tourneynpc1","Teli the Wanderer","Teli the Wanderer",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(29,27,14,18,50), wpex(360,360,440,350,480,300), strsk(8,8,8,8)|agisk(9,4,8,8,7),0x00000001bf1055c64b9bcdab19c7b8da00000000001d269a0000000000000000], 
["tourneynpc2","Eylrin the Shieldmaster","Eylrin",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(44,16,11,19,50), wpex(400,400,300,200,200,300), strsk(10,9,7,7)|agisk(8,10,3,2,0),0x00000001a00435d127738f271ab62b2b00000000001d275c0000000000000000], 
["tourneynpc3","Sir Kelras","Kelras",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(38,26,18,26,50), wpex(440,440,440,440,440,440), strsk(9,9,9,9)|agisk(9,9,4,9,6),0x000000003f00034f46cb70e51c121d2a00000000001dc86b0000000000000000], 
["tourneynpc4","Sir Meir","Meir",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(36,22,18,25,50), wpex(420,420,550,300,300,420), strsk(10,10,10,10)|agisk(9,8,2,8,6),0x000000077600100240db6df6febdb76d00000000001db77a0000000000000000], 
["tourneynpc5","Fighter Deterney","Fighter Deterney",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(33,22,11,16,50), wpex(450,450,450,390,390,390), strsk(10,10,9,9)|agisk(10,9,5,2,0),0x00000005b00c405818da8a4d3496bb5a00000000001f46d20000000000000000], 
["tourneynpc6","Master Bladesman Regin","Master Bladesman Regin",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(30,40,13,20,50), wpex(500,500,480,200,200,200), strsk(10,10,8,8)|agisk(10,9,9,2,0),0x0000000d4000609113ad7334dbb5d6dc00000000001ea4b80000000000000000], 
["tourneynpc7","Spearmaster Hale","Spearmaster Hale",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(34,27,13,19,50), wpex(380,380,600,300,300,480), strsk(10,10,8,7)|agisk(10,2,8,2,0),0x00000001a700644e16d469b8d26db6db00000000001db6e30000000000000000], 
["tourneynpc8","Sir Naldlett","Sir Naldlett",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(32,30,18,25,50), wpex(400,400,400,400,400,400), strsk(10,10,10,10)|agisk(10,10,6,10,8),0x000000003200048926725934a38a359300000000001e491b0000000000000000], 
["tourneynpc9","Sir Slicer","Sir Slicer",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(40,33,14,21,50), wpex(480,480,480,240,240,240), strsk(10,10,7,7)|agisk(10,6,9,8,0),0x000000000000424416de31331995171b000000000005b92a0000000000000000], 
["tourneynpc10","Weapons Master Aret","Weapons Master Aret",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(32,24,15,22,50), wpex(460,460,460,460,460,460), strsk(9,9,9,9)|agisk(10,10,5,2,0),0x000000002b1034496ca96aa4ca6e392400000000000dc90b0000000000000000], 
["tourneynpc11","Desert Assassin Ordtom","Desert Assassin Ordtom",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(30,30,16,18,50), wpex(500,500,400,300,300,500), strsk(10,9,8,8)|agisk(10,4,9,4,0),0x000000002f10f0cb4b2b53495a712c9b00000000001ea5e10000000000000000], 
["tourneynpc12","Sir Iodis","Sir Iodis",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(32,16,18,24,50), wpex(600,450,300,200,200,200), strsk(10,10,7,7)|agisk(10,10,5,6,0),0x000000019f08c4443b226dcd2a52aade00000000001db6e30000000000000000], 
["tourneynpc13","Ascomann","Ascomann",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(26,36,22,16,50), wpex(300,300,300,500,500,500), strsk(8,8,10,10)|agisk(10,2,10,10,10),0x0000000c2a0934cf3926d23919c59d9a00000000001dc69c0000000000000000], 
["tourneynpc14","Foreigner Rafklal","Foreigner Rafklal",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(36,18,15,24,50), wpex(400,550,400,200,200,550), strsk(10,10,10,8)|agisk(10,2,7,7,0),0x0000000d72015389370c4d4732b536de00000000001db9280000000000000000], 
["tourneynpc15","Champion Fighter Toba","Champion Fighter Toba",tf_hero, 0,reserved, fac_commoners, [itm_leather_jerkin, itm_leather_boots], 
attrlev(60,12,6,18,50), wpex(400,400,400,300,300,300), strsk(10,10,10,10)|agisk(8,8,4,4,0),0x00000002bd0014d627344ea88d523b9400000000001e29360000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Tutorial
["tutorial_trainer", "Training Ground Master", "Training Ground Master", tf_hero, 0, 0, fac_commoners, [itm_robe, itm_nomad_boots], def_attrib|level(2),wp(20), knows_common, 0x000000000008414401e28f534c8a2d09], 
["tutorial_student_1", "{!}tutorial_student_1", "{!}tutorial_student_1", tf_guarantee_boots|tf_guarantee_armor, 0, 0, fac_neutral, [itm_practice_sword, itm_practice_shield, itm_leather_jerkin, itm_padded_leather, itm_leather_armor, itm_leather_boots, itm_vaegir_fur_cap, itm_nasal_helmet], def_attrib|level(2),wp(20), knows_common,swadian_face_young_1,swadian_face_old_2], 
["tutorial_student_2", "{!}tutorial_student_2", "{!}tutorial_student_2", tf_guarantee_boots|tf_guarantee_armor, 0, 0, fac_neutral, [itm_practice_sword, itm_practice_shield, itm_leather_jerkin, itm_padded_leather, itm_leather_armor, itm_leather_boots, itm_vaegir_fur_cap, itm_nasal_helmet], def_attrib|level(2),wp(20), knows_common,swadian_face_young_1,swadian_face_old_2], 
["tutorial_student_3", "{!}tutorial_student_3", "{!}tutorial_student_3", tf_guarantee_boots|tf_guarantee_armor, 0, 0, fac_neutral, [itm_practice_staff, itm_leather_jerkin, itm_padded_leather, itm_leather_armor, itm_leather_boots, itm_vaegir_fur_helmet, itm_khergit_war_helmet], def_attrib|level(2),wp(20), knows_common,swadian_face_young_1,swadian_face_old_2], 
["tutorial_student_4", "{!}tutorial_student_4", "{!}tutorial_student_4", tf_guarantee_boots|tf_guarantee_armor, 0, 0, fac_neutral, [itm_practice_staff, itm_leather_jerkin, itm_padded_leather, itm_leather_armor, itm_leather_boots, itm_vaegir_fur_helmet, itm_khergit_war_helmet], def_attrib|level(2),wp(20), knows_common,swadian_face_young_1,swadian_face_old_2], 
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Salt Mine
["Galeas", "Galeas", "Galeas", tf_hero, 0, 0, fac_commoners, [itm_leather_jacket, itm_leather_boots], def_attrib|level(5),wp(20), knows_common, 0x00000009780c0092672e6cb96c9498e200000000001e246b0000000000000000], 

#Dhorak Keep
["farmer_from_bandit_village", "Farmer", "Farmers", tf_guarantee_armor, 0, 0, fac_commoners, [], def_attrib|level(4),wp(60), knows_common, mercenary_face_1, mercenary_face_2], 

["trainer_1", "Trainer", "Trainer", tf_hero, scn_training_ground_ranged_melee_1|entry(6), 0, fac_commoners, [itm_leather_jerkin, itm_leather_boots], def_attrib|level(2),wp(20), knows_common, 0x0000000d0d1030c74ae8d661b651c6840000000000000e220000000000000000], 
["trainer_2", "Trainer", "Trainer", tf_hero, scn_training_ground_ranged_melee_2|entry(6), 0, fac_commoners, [itm_nomad_vest, itm_leather_boots], def_attrib|level(2),wp(20), knows_common, 0x0000000e5a04360428ec253846640b5d0000000000000ee80000000000000000], 
["trainer_3", "Trainer", "Trainer", tf_hero, scn_training_ground_ranged_melee_3|entry(6), 0, fac_commoners, [itm_padded_leather, itm_leather_boots], def_attrib|level(2),wp(20), knows_common, 0x0000000e4a0445822ca1a11ab1e9eaea0000000000000f510000000000000000], 
["trainer_4", "Trainer", "Trainer", tf_hero, scn_training_ground_ranged_melee_4|entry(6), 0, fac_commoners, [itm_leather_jerkin, itm_leather_boots], def_attrib|level(2),wp(20), knows_common, 0x0000000e600452c32ef8e5bb92cf1c970000000000000fc20000000000000000], 
["trainer_5", "Trainer", "Trainer", tf_hero, scn_training_ground_ranged_melee_5|entry(6), 0, fac_commoners, [itm_leather_vest, itm_leather_boots], def_attrib|level(2),wp(20), knows_common, 0x0000000e77082000150049a34c42ec960000000000000e080000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# -------- this section implicitly tied together by assumptions coded at  mo_constants    and otherwise influences code --------#
# Ranson Brokers
["ransom_broker_1", "Ransom_Broker", "Ransom_Broker", tf_hero, 0, 0, fac_commoners, [itm_sarranid_leather_armor, itm_leather_boots], def_attrib|level(5),wp(20), knows_common,0x0000000aac00a30a395c3bbbdca9bd7400000000001db3110000000000000000], #+
["ransom_broker_2", "Ransom_Broker", "Ransom_Broker", tf_hero, 0, 0, fac_commoners, [itm_black_lamellar_armor_light, itm_sarranid_boots_black], def_attrib|level(5),wp(20), knows_common,0x00000008ec007396395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_3", "Ransom_Broker", "Ransom_Broker", tf_hero, 0, 0, fac_commoners, [itm_novici_hospitaller, itm_west_rider_boots], def_attrib|level(5),wp(20), knows_common,0x00000006ff005403395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_4", "Ransom_Broker", "Ransom_Broker", tf_hero, 0, 0, fac_commoners, [itm_tabard, itm_west_rider_boots], def_attrib|level(5),wp(20), knows_common,0x00000006ff004446395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_5", "Ransom_Broker", "Ransom_Broker", tf_hero, 0, 0, fac_commoners, [itm_rough_mail_spiked, itm_splinted_leather_greaves], def_attrib|level(5),wp(20), knows_common,0x00000006c00034c9395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_6", "Ransom_Broker", "Ransom_Broker", tf_hero|tf_elven_male, 0, 0, fac_commoners, [itm_rough_mail_coat, itm_lorien_boots], def_attrib|level(5),wp(20), knows_common,0x00000006c0005050395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_7", "Ransom_Broker", "Ransom_Broker", tf_hero|tf_dwarf_male, 0, 0, fac_commoners, [itm_dwarf_civilian_3_c, itm_leather_boots_dark], def_attrib|level(5),wp(20), knows_common,0x00000006e7003081395c3bbbdca8bd7400000000001db3110000000000000000], #+
["ransom_broker_8", "Ransom_Broker", "Ransom_Broker", tf_hero|tf_female, 0, 0, fac_commoners, [itm_haubergeon_brass, itm_sarranid_boots_brass], def_attrib|level(5),wp(20), knows_common,0x00000006d700300376000000000046f000000000000000000000000000000000], #+
["ransom_broker_9", "Ransom_Broker", "Ransom_Broker", tf_hero|tf_female, 0, 0, fac_commoners, [itm_tribal_warrior_outfit, itm_civil_rich_boots_b], def_attrib|level(5),wp(20), knows_common,0x00000006c000001470db6c36d36e152500000000000000000000000000000000], #+
["ransom_broker_10", "Ransom_Broker", "Ransom_Broker", tf_hero|tf_elven_female, 0, 0, fac_commoners, [itm_wei_xiadi_rod_padded_cloth, itm_civil_rich_boots_b], def_attrib|level(5),wp(20), knows_common,0x00000006ff10100406ab41c8d694a6e300000000001e270d0000000000000000], #+

# Tavern traveler.
["tavern_bookseller_1", "Book_Merchant", "Book_Merchant", tf_hero|tf_is_merchant, 0, 0, fac_commoners, [itm_red_gambeson, itm_light_leather_boots, itm_book_tactics, itm_book_persuasion, itm_book_wound_treatment_reference, itm_book_leadership, itm_book_intelligence, itm_book_training_reference, itm_book_surgery_reference], 
def_attrib|level(5),wp(20), knows_common,0x0000000fe5011346395c3bbbdcaa3d7400000000001db3100000000000000000], 
["tavern_bookseller_2", "Book_Merchant", "Book_Merchant", tf_hero|tf_is_merchant, 0, 0, fac_commoners, [itm_ped_padd_lamellar_grey2, itm_light_leather_boots, itm_book_wound_treatment_reference, itm_book_leadership, itm_book_intelligence, itm_book_trade, itm_book_engineering, itm_book_weapon_mastery, itm_book_global_knowledge], 
def_attrib|level(5),wp(20), knows_common,0x0000000fe50125c9395c3bbbdcaa3d7400000000001db3100000000000000000], 

# Tavern minstrel.
["tavern_minstrel_1", "Wandering Minstrel", "Minstrel", tf_hero|tf_randomize_face|tf_guarantee_shield|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_commoners, [itm_leather_jacket, itm_hunter_boots, itm_lute, itm_dedal_lira], def_attrib|level(5),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["tavern_minstrel_2", "Wandering Bard", "Minstrel", tf_hero|tf_randomize_face|tf_guarantee_shield|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_commoners, [itm_tunic_with_green_cape, itm_hunter_boots, itm_lyre, itm_dedal_lira], def_attrib|level(5),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["tavern_minstrel_3", "Wandering Ashik", "Minstrel", tf_hero|tf_randomize_face|tf_guarantee_shield|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_commoners, [itm_beduin_armor_c, itm_hunter_boots, itm_lute, itm_dedal_lira], def_attrib|level(5),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["tavern_minstrel_4", "Wandering Skald", "Minstrel", tf_hero|tf_randomize_face|tf_guarantee_shield|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_commoners, [itm_fur_coat, itm_hunter_boots, itm_lyre, itm_dedal_lutnia], def_attrib|level(5),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["tavern_minstrel_5", "Wandering Troubadour", "Minstrel", tf_hero|tf_randomize_face|tf_guarantee_shield|tf_guarantee_armor|tf_guarantee_boots, 0, 0, fac_commoners, [itm_red_shirt, itm_hunter_boots, itm_lute, itm_dedal_lutnia], def_attrib|level(5),wp(20), knows_common,merchant_face_1,merchant_face_2], 
# idibil brytenwalda cleric, abbot and bishop (quest especial derfel Cadarn, historical character, born 566. Hermit at 636)
["sacerdote_1","Priest Felixius of the New Gods","Felixius",tf_hero, scn_town_1_castle|entry(9), reserved, fac_new_gods, [itm_pilgrim_disguise, itm_rus_shoes], def_attrib|level(5),wp(20),knows_common,0x0000000bf80c45d226a971b31e54c8f400000000001e56990000000000000000], 
["sacerdote_2","Priest Fyurs of the Old Gods","Fyurs",tf_hero, scn_town_1_castle|entry(10), reserved, fac_old_gods, [itm_pilgrim_disguise, itm_rus_shoes], def_attrib|level(5),wp(20),knows_common,0x0000000e821043404864c59b0c92352400000000001d56580000000000000000], 
#dedal = Tavern Animations Mod Begin
["musican_male","Musican","Musican",tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_taureg_armor, itm_blue_hose], def_attrib|level(4),wp(60),knows_common, mfy1, mfo2], 
["musican_female","Musican","Musican",tf_female|tf_guarantee_boots|tf_guarantee_armor,0,0,fac_commoners, [itm_blue_dress, itm_dress, itm_woolen_dress, itm_peasant_dress, itm_blue_hose, itm_blue_hose, itm_wimple_a, itm_wimple_with_veil, itm_female_hood], def_attrib|level(2),wp(40),knows_common,woman_face_1,woman_face_2], 
["musicans_end","_","_",tf_inactive,0,0,0, [], 0,0,0,0], 
# Taver Animations Mod END brokers.

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

########### COMPANIONS BEGIN
# Npc changes by S.U. & Michadr, edited by Silberfalke
["kingdom_heroes_including_player_begin", "kingdom_heroes_including_player_begin", "kingdom_heroes_including_player_begin", tf_hero, 0,reserved, fac_kingdom_1, [], lord_attrib,wp(220),knows_common, 0x000000000010918a01f248377289467d], 

########### GS cannot move anything between ransom broker and here #####
# Dev. Notes:
# Npc (Companion dialouges can be found in mo_strings, search # Companion Dialogues
["npc1","Kierland","Kierland",tf_hero|tf_dwarf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_j_surcoat_comp_4b_dwarf, itm_act_dwarven_archer_helmet_t2, itm_mail_boots, itm_dwarf_hammer_4, itm_dwarf_shield_5a, itm_akheavy_crossbow_1, itm_steel_bolts], 
attrlev(23,12,18,10,10), wpex(125,80,80,60,125,125), strsk(4,3,3,2)|agisk(3,4,5,1,0)|lordsk1(0,0,0,0,0,0,1,5)|lordsk2(4,1,3,1,1,0,0,1), 0x000000097800410636eb89b95bd4366e00000000001db75c0000000000000000], #dwarf healer looking for herb, but he is in debt after travelling to the island 
["npc2","Oliver","Oliver",tf_hero|tf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_corrazina_red, itm_open_salet_coif, itm_dorn_spearbearer_boots, itm_gauntlets_arabs_a_l, itm_1hlongsword, itm_antique1dag, itm_antique_dag_as_sh], 
attrlev(23,23,12,18,22), wpex(250,150,125,250,150,100), strsk(4,7,5,7)|agisk(8,4,6,2,0)|lordsk1(1,0,2,0,2,0,2,3)|lordsk2(0,0,0,0,4,2,2,1), 0x00000002970d05d53a5b9218c46d26d200000000001dc66c0000000000000000], 
["npc3","Puma","Puma",tf_hero|tf_giant_female|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_armour_north_clanman2, itm_splinted_leather_greaves, itm_leather_gloves, itm_boar_spear_of_frederick_iv_of_tyrol, itm_practice_bow_2, itm_spak_bow8_arrow], 
attrlev(29,19,11,8,26), wpex(150,150,220,260,100,160), strsk(7,6,5,8)|agisk(6,2,7,0,0)|lordsk1(2,6,0,3,0,4,4,4)|lordsk2(1,0,1,0,0,1,2,3), 0x00000002af04100914e989d96c962b530000000000f4376a0000000000000000], 
["npc4","Dugwar","Dugwar",tf_hero|tf_giant_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_giant_guardsman_armor_sut_2, itm_giant_noble_helmet, itm_giant_furred_boots_1, itm_giant_gloves_plus, itm_axe_weathered_berserker_a_01, itm_middleaxe_marauder_of_norsca_b_01, itm_sut_warrior_shield], 
attrlev(44,17,9,12,34), wpex(290,290,200,150,50,210), strsk(11,10,7,6)|agisk(7,5,5,0,0)|lordsk1(5,1,1,0,0,0,0,2)|lordsk2(0,0,0,0,0,4,1,0), 0x000000060000420850da2a6d69b159b400000000001d48d50000000000000000], 
["npc5","Eilona","Eilona",tf_hero|tf_elven_female|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_armour_tyrell_rider, itm_eilonas_bow], 
attrlev(16,22,17,13,16), wpex(170,110,140,240,130,90), strsk(1,3,1,5)|agisk(5,2,7,6,6)|lordsk1(0,2,0,5,0,5,5,3)|lordsk2(2,0,1,0,1,0,0,2), 0x00000001a1083202225bd6450b6d80e20000000000f238db0000000000000000], 
["npc6","Lord Rendalion","Rendalion",tf_hero|tf_elven_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_rivend_rohir_armor_1a, itm_rivend_helmet_2a, itm_riv_boots, itm_cwe_king_gloves, itm_blue_warhorse, itm_sabre_ebony, itm_rivend_shield_1], 
attrlev(32,27,25,30,60), wpex(525,500,450,475,250,150), strsk(8,9,6,9)|agisk(10,7,7,9,8)|lordsk1(6,4,2,3,3,4,7,4)|lordsk2(2,0,1,1,6,5,7,4), 0x00000005ea00500548ed4a36dd753b2500000000001cb76a0000000000000000], #former Irdulerain
["npc7","Arin","Arin",tf_hero|tf_female|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_ragged_outfit, itm_ankle_boots, itm_wooden_stick], 
attrlev(7,10,13,15,1), wpex(70,50,50,50,50,60), strsk(0,0,1,0)|agisk(0,0,3,4,0)|lordsk1(0,0,0,0,1,0,2,8)|lordsk2(2,0,2,0,4,0,0,4), 0x000000002800400f77558e46dc754ac100000000000000000000000000000000], 
["npc8","Ling Zhou","Ling Zhou",tf_hero|tf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_dorn_squire_armor, itm_song_helm_kk, itm_west_arbalester_boots, itm_wisby_gauntlets_red, itm_dorn_horse_lamellar_a, itm_luc_hafted_blade_2, itm_heavy_crossbow, itm_bolts], #spirit ship
attrlev(24,28,25,20,35), wpex(240,240,400,200,300,160), strsk(5,6,4,4)|agisk(8,3,3,7,0)|lordsk1(2,0,3,3,6,1,3,5)|lordsk2(1,0,2,1,8,2,8,3), 0x0000000f740955cc585b9a9a1476199800000000001e36ea0000000000000000], 
["npc9","Baznor","Baznor",tf_hero|tf_dwarf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_et_pearl_dwarf, itm_dwarf_helm_o, itm_wp_boots_light, itm_dwarf_glove, itm_white_great_hammer, itm_luc_throwing_hammer, itm_luc_throwing_hammer], 
attrlev(37,14,9,12,35), wpex(300,360,200,100,150,360), strsk(10,9,9,6)|agisk(8,5,6,0,0)|lordsk1(6,0,0,1,0,0,4,3)|lordsk2(0,0,0,2,0,7,1,1), 0x000000077f04a10428d4aea792b158db00000000001cc5630000000000000000], 
["npc10","Eadweard","Eadweard",tf_hero|tf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [(itm_west_guardsman_heavy_2, imod_lordly), (itm_maciejowski_helmet_new5, imod_lordly), (itm_wp_boots_light, imod_lordly), (itm_dorn_squire_gauntles, imod_lordly), (itm_plated_charger7, imod_champion), (itm_sword_val_1, imod_masterwork), (itm_sh_golden, imod_reinforced), (itm_sniper_crossbow, imod_masterwork), (itm_akbolt_b, imod_large_bag)], 
attrlev(36,24,19,20,60), wpex(550,500,500,200,400,200), strsk(10,10,7,7)|agisk(10,9,6,10,0)|lordsk1(0,0,4,8,5,1,3,5)|lordsk2(2,1,2,0,6,4,8,1), 0x0000000b8010340128c595b75a9096db00000000001dc6990000000000000000], 
["npc11","Maruf al-Karim","Maruf al-Karim",tf_hero|tf_male|tf_unmoveable_in_party_window, 0, reserved, fac_commoners, [itm_sarranid_mail_shirt, itm_sarranid_boots_brass, itm_saracin_sword_b, itm_dal_hinduh, itm_new_strong_bow, itm_bronze_arrow], 
attrlev(12,12,12,20,10), wpex(140,80,100,140,70,100), strsk(0,2,2,4)|agisk(3,3,6,5,0)|lordsk1(4,0,0,0,0,0,2,10)|lordsk2(0,0,0,0,8,0,1,6), 0x00000008340134c739543bbbdcb235f400000000001db70c0000000000000000], #kindness+generosity    - ironic

#COMPANIONS END


#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Faction rulers
["kingdom_0_lord","Aracanus","Aracanus",tf_hero, 0, reserved, fac_kingdom_0, [(itm_dark_lord_armor, imod_lordly), (itm_black_helmet, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_twilight_gloves, imod_lordly), itm_plated_charger9, itm_flamberge, itm_knights_mace_no1, itm_sp_shr1, itm_civ_twiligh_armor_2, itm_civ_twilight_boots, itm_civ_twilight_gloves], 
attrlev(38,30,32,30,60), wpex(470,470,400,300,300,250), strsk(10,8,6,8)|agisk(10,8,5,9,6)|lordsk1(0,2,8,3,8,4,4,5)|lordsk2(4,2,4,3,9,7,10,4), 0x000000053a0002146942da385b6d2d5c00000000001db9140000000000000000], 
["kingdom_1_lord", "Field Marshal Lioniasus", "Lioniasus", tf_hero, 0,reserved, fac_kingdom_1, [(itm_early_transitional_blue, imod_lordly), (itm_winged_great_helmet, imod_lordly), (itm_plate_boots, imod_lordly), (itm_plate_mittens, imod_lordly), itm_english_war_horse3, itm_winged_mace_no1, itm_tab_shield_heater_cav_b, itm_civ_early_transitional_blue, itm_civ_foot_ornate_boots_1], 
attrlev(29,24,19,22,50), wpex(450,450,450,400,400,300), strsk(9,8,7,7)|agisk(10,8,6,10,5)|lordsk1(3,5,8,3,6,4,3,3)|lordsk2(2,1,3,6,6,6,7,2), 0x00000004e90824ca28d36e331b7532f300000000001d276a0000000000000000], 
["kingdom_2_lord", "Princess Birgit", "Birgit", tf_female|tf_hero, 0,reserved, fac_kingdom_2, [(itm_gothic_plate_female, imod_lordly), (itm_barbuta2, imod_lordly), (itm_plate_boots, imod_lordly), (itm_plate_mittens, imod_lordly), itm_fire_dragon, itm_bastard_sword_b, itm_steel_shield_kite, itm_heavy_throwing_axes, itm_new_dress_b, itm_civ_foot_rich_boots_black, itm_gondor_bracer_l], 
attrlev(25,30,25,30,50), wpex(370,370,370,300,300,370), strsk(7,8,8,7)|agisk(8,6,7,10,8)|lordsk1(3,3,4,5,5,2,3,6)|lordsk2(5,3,5,4,9,4,7,8), 0x00000000080c000b76db6db6db6da6db00000000000000000000000000000000], 
["kingdom_3_lord", "Vizier Khalil", "Khalil", tf_hero, 0,reserved, fac_kingdom_3, [(itm_sultan_armor, imod_lordly), (itm_brass_veiled_helmet, imod_lordly), (itm_black_greaves, imod_lordly), (itm_brass_mail_mittens, imod_lordly), itm_saracen_horse_sultan, itm_youhou_assassin_sword, itm_saracin_shield_p, itm_civ_body_m_arab_robe_7, itm_civ_foot_plated_boots_arab], 
attrlev(28,27,30,32,60), wpex(540,540,400,480,200,480), strsk(10,9,9,9)|agisk(10,9,4,10,10)|lordsk1(6,5,8,5,7,6,6,8)|lordsk2(7,3,5,5,10,9,10,10), 0x0000000efe0495864934959cdc4ea74b00000000001ee8720000000000000000], #friend
["kingdom_4_lord", "Queen Trisna", "Trisna", tf_female|tf_hero, 0,reserved, fac_kingdom_4, [(itm_coat_of_plates_blue, imod_lordly), (itm_crownedhelm, imod_lordly), (itm_iron_greaves, imod_lordly), itm_plate_mittens, itm_plate_armour_charger2, itm_frostfang, itm_dal_muslimf, itm_got_green_dress1, itm_civ_foot_rich_boots_black], 
attrlev(28,25,27,32,58), wpex(440,440,400,300,200,400), strsk(8,8,8,7)|agisk(9,9,5,9,6)|lordsk1(1,3,4,4,8,3,4,8)|lordsk2(4,3,5,6,9,5,8,6), 0x00000007760c000f77c5681adb4db37200000000000000000000000000000000], #0x00000006760c000f778371b6db6db2f300000000000000000000000000000000
["kingdom_5_lord", "Princess Linthradil", "Linthradil", tf_elven_female|tf_hero, 0,reserved, fac_kingdom_5, [(itm_mirk_armor_1a, imod_lordly), itm_royal_ench, (itm_dorn_knight_boots, imod_lordly), (itm_gondor_bracer_l, imod_lordly), itm_mail_armour_charger1, itm_elvish_sword, itm_dal_muslimf, itm_lonely, itm_blackarrow, itm_green_dress, itm_civ_foot_rich_boots_black], 
attrlev(25,32,30,32,56), wpex(440,440,440,540,200,200), strsk(5,7,6,9)|agisk(9,6,8,9,10)|lordsk1(0,8,2,8,4,8,9,5)|lordsk2(6,3,6,1,9,5,6,6), 0x00000001990400145a121437126d12a00000000000e8d2d00000000000000000], 
["kingdom_6_lord", "Imperial General Hakkon III", "Hakkon III", tf_hero, 0,reserved, fac_kingdom_6, [(itm_amade_bronze_plate_champion, imod_lordly), (itm_imperial_helm, imod_lordly), (itm_bronzeshynald, imod_lordly), (itm_bronzeplatemitten, imod_lordly), itm_charger_bronze, itm_sw_warhammer_steel, itm_sh_golden, itm_civ_hakkon_plate_1, itm_civ_foot_imperial_boots_m], 
attrlev(35,27,30,29,60), wpex(530,530,500,200,350,530), strsk(10,9,9,7)|agisk(10,8,3,10,8)|lordsk1(7,0,10,1,10,2,2,5)|lordsk2(2,1,5,9,6,10,10,0), 0x0000000ab908b50426a22c55554a291500000000001d275a0000000000000000], 
["kingdom_7_lord", "Emperor Zann Mandate of Heaven", "Zann", tf_hero, 0, reserved, fac_kingdom_7, [(itm_dorn_immortal_armor, imod_lordly), (itm_dorn_immortal_helmet, imod_lordly), (itm_black_boot_salad_of, imod_lordly), (itm_kote, imod_lordly), itm_warhorse_sarranid_black, itm_two_handed_katana, itm_roman_shield_velite, itm_taureg_armor, itm_civ_foot_suneate_boots_red], 
attrlev(32,32,26,32,60), wpex(600,600,450,300,200,300), strsk(8,10,8,8)|agisk(10,5,6,8,5)|lordsk1(9,3,8,5,6,5,5,7)|lordsk2(3,1,3,5,10,7,10,8), 0x000000076110939648ef4a3addd63b2500000000001cb76b0000000000000000], 
["kingdom_8_lord", "Marshal Padraigh", "Padraigh", tf_hero, 0, reserved, fac_kingdom_8, [(itm_dark_lord_armor2, imod_lordly), (itm_pigface_new, imod_lordly), (itm_dorn_knight_boots, imod_lordly), (itm_dorn_knight_gant, imod_lordly), itm_plated_charger7, itm_bastard_sword_b, itm_wardens_shield, itm_spak_crsb01, itm_akbolt_b, itm_knight_armor_templar_a_1, itm_civ_foot_mail_boots_1], 
attrlev(36,28,32,34,58), wpex(570,570,500,300,500,300), strsk(10,10,9,9)|agisk(10,9,6,10,6)|lordsk1(4,4,9,3,9,3,5,5)|lordsk2(4,4,6,8,8,9,10,3), 0x00000006a508020a4d547198b4cecb3d00000000001d381b0000000000000000], 
["kingdom_9_lord", "Aethling Hallbjorn", "Hallbjorn", tf_hero, 0, reserved, fac_kingdom_9, [(itm_bers_armor, imod_lordly), (itm_bers_helm_open, imod_lordly), (itm_dorn_spearbearer_boots, imod_lordly), (itm_plate_mittens, imod_lordly), itm_morgenstern_no2, itm_civ_foot_cavalry_boots_black], 
attrlev(48,32,16,32,58), wpex(600,600,600,160,100,320), strsk(10,10,9,9)|agisk(10,4,10,0,0)|lordsk1(10,0,10,6,3,2,3,4)|lordsk2(1,0,3,1,6,8,9,0), 0x0000000cb411931442528bbbdad129d500000000001f62b00000000000000000], 
["kingdom_10_lord", "Drgrimst Harunn", "Harunn", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_west_guardsman_dark_dwarf, imod_lordly), (itm_dwarf_helm_h, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_glovesblack, itm_nord_clan_axe, itm_luc_throwing_hammer, itm_civ_foot_plated_boots_black], 
attrlev(55,27,19,25,58), wpex(480,550,480,220,220,500), strsk(13,13,12,8)|agisk(10,7,8,5,0)|lordsk1(6,0,10,1,7,2,4,7)|lordsk2(0,0,2,7,6,9,8,5), 0x000000093800320804a454bb1cae5eb400000000001e191b0000000000000000], 
["kingdom_11_lord","Sidhethon","Sidhethon",tf_hero|tf_elven_male, 0, reserved, fac_kingdom_11, [(itm_riv_armor_leader, imod_lordly), (itm_rivend_helmet_2a, imod_lordly), (itm_shadow_greaves, imod_lordly), (itm_gondor_bracer_l, imod_lordly), itm_sabre_ebony, itm_ranger_bow, itm_spak_arrow, itm_civ_elven_armor_0, itm_civ_foot_cavalry_boots_black], 
attrlev(34,27,32,30,58), wpex(500,500,500,550,100,100), strsk(10,10,6,10)|agisk(10,4,9,7,8)|lordsk1(4,8,8,6,9,8,9,5)|lordsk2(3,0,4,5,8,8,8,3), 0x000000000000000736db6db6db6db6db00000000001db6db0000000000000000], 
["kingdom_12_lord","Zeladeck","Zeladeck", tf_hero, 0, 0, fac_kingdom_12, [(itm_tarth_armor, imod_lordly), (itm_luc_knight_helm, imod_lordly), (itm_bronzeshynald, imod_lordly), (itm_gauntlets_arabs_b_l, imod_lordly), itm_plated_charger8, itm_skyfall, itm_steel_shield_kite, itm_latticed_flatbow, itm_bronze_arrow, itm_civ_brienne_tarth_armor, itm_civ_foot_cavalry_boots_1], 
attrlev(38,33,20,30,60), wpex(530,530,500,500,200,300), strsk(10,10,9,10)|agisk(10,9,8,10,9)|lordsk1(10,8,7,8,5,7,8,5)|lordsk2(0,0,1,0,7,8,10,2), 0x0000000a3f00358a391b5538dc91369300000000001d291b0000000000000000], 
["kingdom_13_lord", "Boshman Baatur", "Boshman", tf_hero, 0,reserved, fac_kingdom_13, [(itm_zabadai_man_armor, imod_lordly), (itm_helm_tyrk_heavi_b, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_glovesblack, imod_lordly), itm_ak_warhorse_chain_a, itm_luc_knightly_axe, itm_saracin_shield_g, itm_throwing_spears, itm_civ_body_m_nomad_lam_kuulan, itm_civ_foot_rich_boots_black], 
attrlev(42,30,23,34,60), wpex(600,600,500,500,150,500), strsk(10,10,10,10)|agisk(10,7,7,10,10)|lordsk1(8,6,8,6,4,8,8,7)|lordsk2(2,0,4,5,8,8,10,6), 0x000000092610838b48ed4a36dd752b2500000000001cb7500000000000000000], 
["kingdom_14_lord", "Vandr Jornleikr", "Jornleikr", tf_giant_male|tf_hero, 0,reserved, fac_kingdom_14, [(itm_giant_chieftan_armor_bakhal, imod_reinforced), (itm_giant_horned_helmet_bakhal, imod_reinforced), (itm_giant_plated_boots_war, imod_reinforced), (itm_giant_gloves_plus1, imod_reinforced), itm_axe_elite_berserker_a_01, itm_giant_plate_armor_bakhal, itm_giant_warrior_boots], 
attrlev(98,20,12,20,60), wpex(550,550,400,100,100,400), strsk(15,15,14,10)|agisk(10,7,10,0,0)|lordsk1(10,2,10,1,1,0,2,3)|lordsk2(0,0,0,2,6,10,10,0), 0x0000000bab0022c238d68f3d69b1c85d00000000001dda430000000000000000], 
["kingdom_15_lord", "Chieftain Shielkus", "Shielkus", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_15, [(itm_giant_chieftan_armor_sut, imod_reinforced), (itm_giant_horned_helmet_sut, imod_reinforced), itm_giant_plated_boots_sharp, itm_giant_gloves_plus, itm_axe_elite_raider_01, itm_giant_guardsman_armor_sut, itm_giant_br_boots_knee_02], 
attrlev(76,17,19,20,58), wpex(460,480,480,260,140,260), strsk(14,13,10,10)|agisk(10,5,7,6,0)|lordsk1(5,0,8,0,4,0,2,5)|lordsk2(0,0,1,5,8,8,8,2), 0x0000000b400081c7276bc646dcd3092300000000001eb8e30000000000000000], 
["kingdom_16_lord", "Aroulo Pomaahkaa", "Pomaahkaa", tf_hero, 0,reserved, fac_kingdom_16, [(itm_armour_braided, imod_lordly), (itm_aroulo_boots, imod_hardened), itm_gloves_lord_l, itm_woodman_staff, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep, itm_civ_aroulo_armor_1], 
attrlev(45,33,12,26,60), wpex(600,600,640,550,100,640), strsk(10,10,10,10)|agisk(10,3,10,0,0)|lordsk1(5,9,8,9,3,9,8,5)|lordsk2(2,0,2,1,9,8,10,3), 0x0000000c6a0cd00b26ca86c5136156ad00000000001db87a0000000000000000], 
["kingdom_17_lord", "Atanos Paramonos", "Paramonos", tf_hero, 0, reserved, fac_kingdom_17, [(itm_tribune_b_3, imod_lordly), (itm_h_tribune2, imod_lordly), (itm_roman_centurion_boots, imod_lordly), (itm_west_man_at_arms_gl, imod_lordly), itm_plate_armour_charger2, (itm_luc_celtic_sword_cwe, imod_masterwork), itm_steel_shield_kite, itm_roman_pilum_2, itm_roman_pilum_2, itm_civ_foot_plated_boots_2], 
attrlev(37,30,30,32,60), wpex(560,560,450,250,250,560), strsk(10,10,10,7)|agisk(10,9,8,10,10)|lordsk1(4,1,10,3,10,3,7,5)|lordsk2(2,1,3,6,9,9,10,3), 0x00000007b3111004285c95ab597136f500000000001dc4a90000000000000000], #endurance, constancy  #old fc 0x00000007b3111004286395ab597136f500000000001dc4a90000000000000000
["kingdom_ou_lord", "Haderas", "Haderas", tf_hero, 0,reserved, fac_outlaw_union, [(itm_dorn_wiper, imod_lordly), (itm_sugarloaf_b, imod_lordly), (itm_west_pikeman_boots_dark, imod_lordly), (itm_glovesblack, imod_lordly), itm_charger_black, itm_razor_nema, itm_sh_snake], 
attrlev(43,25,26,32,60), wpex(620,600,600,350,550,500), strsk(10,10,10,10)|agisk(10,10,7,10,8)|lordsk1(10,3,10,7,9,3,5,6)|lordsk2(1,0,3,4,9,10,10,3), 0x0000000a7f00f5d149557ab55d921fbc00000000001db7600000000000000000], #0x0000000a7f00f5d149557ab55d921db400000000001db7600000000000000000

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["knight_0_1","Alindel","Alindel",tf_hero, 0, reserved, fac_kingdom_0, [itm_knight_armor_tevton_c_cloak, (itm_open_salet_coif, imod_lordly), itm_dorn_knight_boots, itm_mail_mittens, itm_tribal4, itm_knights_winged_mace_2h, itm_spak_knightsh, itm_padded_cloth, itm_ankle_boots_cwe], 
attrlev(19,13,33,23,45), wpex(250,150,250,80,200,80), strsk(4,4,2,2)|agisk(5,4,4,5,0)|lordsk1(0,0,0,0,1,2,1,5)|lordsk2(10,10,10,0,7,1,5,5), 0x0000000cc101119236db71976b8d293b00000000001dd4da0000000000000000], 
["knight_0_2","Knight Commander Geraint","Geraint",tf_hero, 0, reserved, fac_kingdom_0, [(itm_dark_lord_armor, imod_reinforced), (itm_twilighthelm, imod_reinforced), (itm_west_pikeman_boots_dark, imod_reinforced), itm_twilight_gloves, itm_charger_black, itm_sword_val_3, itm_sh_snake, itm_civ_perisno_lord_armor, itm_leather_boots_dark], 
attrlev(34,22,25,28,58), wpex(520,520,500,200,200,200), strsk(10,10,8,8)|agisk(10,8,3,10,0)|lordsk1(4,0,8,0,8,0,2,4)|lordsk2(0,0,0,4,5,8,8,1), 0x0000000fc109620458acb11ca095984c00000000001da6a90000000000000000], #old man
["knight_0_3","Knight Commander Brynmor","Brynmor",tf_hero, 0, reserved, fac_kingdom_0, [(itm_perisno_heavy_armour, imod_lordly), (itm_bolzanobucket, imod_reinforced), (itm_twilight_boots, imod_lordly), itm_blackplatemitty, itm_twilight_horse, (itm_lui_knighthammer, imod_balanced), itm_tab_shield_heater_cav_b, itm_civ_perisno_heavy_armour, itm_civ_foot_cavalry_boots_black, itm_gondor_bracer_l], 
attrlev(33,25,26,25,55), wpex(480,480,480,250,250,250), strsk(9,10,8,8)|agisk(10,8,4,9,0)|lordsk1(2,1,7,3,6,1,3,6)|lordsk2(0,0,0,3,6,7,6,3), 0x00000008b1118446251b8dd4b45eacab00000000001f44eb0000000000000000], #great hill
["knight_0_4","Knight Commander Bleddyn","Bleddyn",tf_hero, 0, reserved, fac_kingdom_0, [(itm_knight_armor_templar_d_cloak, imod_lordly), (itm_col1_madelnbucket1, imod_reinforced), (itm_twilight_boots, imod_lordly), itm_dark_mail_mittens, itm_5warhorse_holy, (itm_2h_claymore_cwe, imod_balanced), itm_shields_archer_templar_a, itm_spak_crsb01, itm_akbolt_b, itm_civ_twilight_boots], 
attrlev(30,25,23,25,56), wpex(450,450,400,200,450,200), strsk(9,9,8,7)|agisk(9,7,5,8,7)|lordsk1(9,1,8,8,5,2,9,4)|lordsk2(0,0,0,1,8,8,8,2), 0x0000000a791005c54ad58a36dd953efe00000000001cb7730000000000000000], #wolf
["knight_0_5","Knight Commander Cadogan","Cadogan",tf_hero, 0, reserved, fac_kingdom_0, [(itm_j_blacksmith_marinian_armor_d, imod_lordly), itm_crusaderbucket1, (itm_twilight_boots, imod_reinforced), itm_glovesblack, itm_twilight_horse, itm_jack_anduril, itm_sp_newsh, itm_civ_foot_plated_boots_black], 
attrlev(31,24,27,24,56), wpex(475,475,450,220,220,220), strsk(9,9,6,6)|agisk(10,6,3,9,0)|lordsk1(5,0,7,3,6,1,3,4)|lordsk2(0,0,1,4,5,6,7,1), 0x0000000a7a1165112052cbb99a9125d400000000001f62310000000000000000], #glory in battle
["knight_0_6","Knight Commander Ivor","Ivor",tf_hero, 0, reserved, fac_kingdom_0, [(itm_heraldic_surcoat_plated, imod_lordly), (itm_dwarvenforged_helm_1, imod_lordly), (itm_plate_boots, imod_reinforced), itm_gauntlets_arabs_a_l, itm_forest_mount, itm_warblade_greensilver, itm_saracin_shield_h, itm_ebonybow, itm_blackarrow, itm_civ_heraldic_surcoat_heavy, itm_civ_foot_plated_boots_2], 
attrlev(30,28,25,25,50), wpex(430,400,400,480,300,200), strsk(8,9,7,10)|agisk(9,5,5,9,9)|lordsk1(7,8,3,8,3,9,9,6)|lordsk2(2,0,4,1,8,5,4,5), 0x000000025511058a74dc71b66c91aca500000000001ca7630000000000000000], #bow warrior
["knight_0_7","Knight Commander Meredith","Meredith",tf_hero|tf_female, 0, reserved, fac_kingdom_0, [(itm_xenoargh_female_armor_sisters_of_mercy4, imod_reinforced), (itm_barbuta2_black, imod_lordly), itm_twilight_boots, itm_bnw_gauntlets, itm_5warhorse_holy, itm_jack_anduril, itm_shields_archer_templar_a, itm_civ_perisno_nun_armor, itm_civ_twilight_boots], 
attrlev(27,26,32,30,50), wpex(450,400,400,100,200,100), strsk(7,8,6,6)|agisk(9,7,5,9,0)|lordsk1(0,0,2,2,3,1,4,6)|lordsk2(10,6,9,1,9,3,5,6), 0x000000027a10200f7764d9c50b6ca32200000000000000000000000000000000], #great lord; unisex name
["knight_0_8","Knight Commander Roderick","Roderick",tf_hero, 0, reserved, fac_kingdom_0, [(itm_plate_armor3, imod_lordly), (itm_maciejowski_helmet_new5, imod_reinforced), (itm_twilight_boots, imod_lordly), itm_gauntlets_arabs_b_l, itm_wlong22, itm_great_axe_no4, itm_steel_shield_heater, itm_civ_perisno_runed_armor, itm_civ_foot_cavalry_boots_red], 
attrlev(34,20,22,27,56), wpex(500,500,500,150,250,250), strsk(10,10,7,7)|agisk(10,8,2,9,0)|lordsk1(6,0,9,2,5,3,4,4)|lordsk2(0,0,2,7,6,8,9,2), 0x0000000c030802982cce8db4ecada4e500000000001d56a30000000000000000], #fame&power
["knight_0_9","Knight Commander Evan","Evan",tf_hero, 0, reserved, fac_kingdom_0, [(itm_early_transitional_perisnified, imod_lordly), (itm_luc_knight_helm, imod_reinforced), (itm_plate_boots, imod_reinforced), itm_mail_mittens, itm_forest_mount, itm_jack_faramir, itm_steel_shield_herald03, itm_sniper_crossbow, itm_steel_bolts, itm_civ_early_transitional_perisnified, itm_civ_foot_mail_boots_1], 
attrlev(27,23,22,16,46), wpex(370,300,300,150,400,150), strsk(8,8,7,7)|agisk(8,6,6,8,5)|lordsk1(1,3,5,6,5,5,6,4)|lordsk2(5,0,4,6,2,3,2,1), 0x0000000fc01175c5450596369d55b91b00000000001db69b0000000000000000], #
["knight_0_10","Knight Commander Ceinwen","Ceinwen",tf_hero|tf_female, 0, reserved, fac_kingdom_0, [(itm_cuir_bouilli_sil, imod_reinforced), itm_royal_ench, (itm_dorn_knight_boots, imod_reinforced), (itm_cwe_king_gloves, imod_thick), itm_mail_armour_charger1, itm_sarranid_mace_1, itm_spak_knightsh, itm_ivorybow, itm_spak_ar2, itm_civ_cuir_bouilli_silver, itm_civ_foot_ornate_boots_1], 
attrlev(24,25,24,32,45), wpex(350,300,300,400,200,200), strsk(6,7,5,9)|agisk(8,4,4,7,8)|lordsk1(5,4,0,3,1,3,7,9)|lordsk2(3,0,3,0,10,5,3,10), 0x0000000ec010001675834da8968aa6da00000000000000000000000000000000], #lovely & white, fair, blessed
["knight_0_11", "Knight Commander Raunaeril", "Raunaeril", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_0, [itm_perisno_armour_1, itm_elfhelm_gold, itm_twilight_boots, itm_glovesblack, itm_charger_bronze, itm_lorien_sword_hand_and_half, itm_saracin_shield_g, itm_latticed_flatbow, itm_elmwoodquiver_arrow, itm_civ_body_m_surcoat_3, itm_civ_foot_mail_boots_1], 
attrlev(26,27,25,24,48), wpex(380,380,300,400,300,260), strsk(7,8,6,9)|agisk(8,6,6,8,4)|lordsk1(4,6,2,3,3,4,5,5)|lordsk2(3,0,3,2,4,4,4,3), 0x00000004f700200726dd7228d589b48c00000000001ca87d0000000000000000], 
["knight_0_12","Knight Commander Rhys","Rhys",tf_hero, 0, reserved, fac_kingdom_0, [(itm_brigandine_b_heraldic, imod_reinforced), (itm_luc_knight_helm, imod_reinforced), (itm_iron_greaves, imod_reinforced), itm_wisby_gauntlets_black, itm_knight_horse_green, itm_luc_spiked_war_club, itm_saracin_shield_h, itm_assassin_throwing_daggers, itm_assassin_throwing_daggers, itm_mail_with_tunic_green, itm_civ_foot_mail_boots_1], 
attrlev(26,26,18,23,45), wpex(330,330,300,150,200,400), strsk(8,8,10,6)|agisk(7,4,6,6,9)|lordsk1(9,2,4,6,1,4,7,6)|lordsk2(0,0,2,0,8,6,1,8), 0x00000007b70c44092b6674552a54898b00000000001cfa5c0000000000000000], #enthusiasm


#Tolranian Lords
["knight_1_1", "Count Tyricas", "Tyricas", tf_hero, 0, reserved, fac_kingdom_1, [(itm_west_heraldic, imod_reinforced), itm_col1_madelnbucket1, itm_west_pikeman_boots, itm_wisby_gauntlets_red, itm_ak_warhorse_chain_b, itm_sword_val_3, itm_shb2, itm_civ_body_m_surcoat_1, itm_civ_foot_mail_boots_1], 
attrlev(31,20,27,26,58), wpex(535,535,535,400,400,400), strsk(10,10,9,8)|agisk(10,8,4,9,4)|lordsk1(0,3,9,1,4,1,2,5)|lordsk2(4,2,5,5,7,4,8,2), 0x0000000b2810538139716e38e41d34f200000000001dc75b0000000000000000], 
["knight_1_2", "Count Tolranius", "Tolranius", tf_hero, 0, reserved, fac_kingdom_1, [(itm_churburg_13_brass, imod_reinforced), itm_ak_wing_helmet_b, itm_steel_greaves, itm_wisby_gauntlets_red, itm_charger2spak, itm_2hand_swadian_regent, itm_civ_body_m_surcoat_4, itm_civ_foot_mail_boots_1], 
attrlev(33,25,24,27,58), wpex(500,500,500,380,300,300), strsk(10,10,9,9)|agisk(10,8,5,9,5)|lordsk1(3,3,8,2,5,2,2,4)|lordsk2(2,1,4,2,5,7,8,1), 0x00000009f50c35862762b238dc96399200000000001d57340000000000000000], 
["knight_1_3", "Count Enduinius", "Enduinius", tf_hero, 0, reserved, fac_kingdom_1, [(itm_rathos_surcoat_english, imod_lordly), (itm_ak_bascinet_new_b, imod_reinforced), itm_iron_greaves, itm_gondor_bracer_l, itm_english_war_horse4, itm_cinthorc, itm_dal_hinduf, itm_fire_nomad_bow, itm_1steel_arrow, itm_civ_body_m_surcoat_5, itm_civ_foot_plated_boots_2], 
attrlev(30,24,27,26,54), wpex(420,400,400,450,300,300), strsk(9,8,7,8)|agisk(9,6,4,8,8)|lordsk1(4,7,4,6,5,6,7,4)|lordsk2(2,1,2,0,6,5,5,4), 0x0000000ccd0511d3578d52d15d70290400000000001626fa0000000000000000], 
["knight_1_4", "Count Calarius", "Calarius", tf_hero, 0, reserved, fac_kingdom_1, [itm_kingsman_plate, itm_great_helmet, itm_west_man_at_arms_boots, itm_glovesblack, itm_charger, itm_sword_val_2, itm_saracin_shield_r, itm_lance_lev5, itm_taureg_armor, itm_civ_foot_rich_boots_black, itm_gloves_lord_l], 
attrlev(31,18,23,32,52), wpex(450,425,450,300,300,300), strsk(9,10,8,8)|agisk(9,7,2,10,0)|lordsk1(2,4,6,3,7,2,2,6)|lordsk2(2,1,2,3,8,5,7,4), 0x00000007aa0c1054546471ca6c4e472900000000001eb6c40000000000000000], 
["knight_1_5", "Count Marteius", "Marteius", tf_hero, 0, reserved, fac_kingdom_1, [(itm_heraldic_tunic_new, imod_reinforced), itm_ak_great_helmet_a, itm_plate_boots, itm_plate_mittens, itm_charger_black, itm_luc_iron_morningstar, itm_shb2, itm_civ_body_m_pino_leather_2, itm_civ_foot_plated_boots_1], 
attrlev(36,22,23,26,58), wpex(500,500,500,250,250,250), strsk(10,10,7,7)|agisk(10,8,5,9,0)|lordsk1(7,1,7,5,3,4,5,5)|lordsk2(0,0,2,1,6,8,7,1), 0x0000000bf80062961a9c8e156a18c51b00000000001c075a0000000000000000], 
["knight_1_6", "Count Barainius", "Barainius", tf_hero, 0, reserved, fac_kingdom_1, [itm_king_knight_armour, itm_crusaderbucket_orange, itm_west_man_at_arms_boots, itm_hourglass_gauntlets_ornate, itm_ak_charger_plate, itm_luc_morningstar_4, itm_shb1, itm_lance_5, itm_civ_body_m_surcoat_1, itm_civ_foot_cavalry_boots_red, itm_gloves_lord_l], 
attrlev(30,19,26,33,56), wpex(440,440,440,280,280,280), strsk(8,8,7,7)|agisk(8,5,3,9,0)|lordsk1(1,2,3,0,2,0,0,7)|lordsk2(1,0,0,2,8,3,4,5), 0x0000000bc508000736db74c6a39ea8e300000000001db8eb0000000000000000], 
["knight_1_7", "Count Graianius", "Graianius", tf_hero, 0, reserved, fac_kingdom_1, [(itm_early_transitional_heraldic, imod_reinforced), itm_crusaderbucket_purple, itm_iron_greaves, itm_dorn_knight_gant, itm_war_horse5, itm_lui_baronaxeoneh, itm_saracin_shield_s, itm_civ_heraldic_cuir_bouilli, itm_civ_foot_ornate_boots_1, itm_new_leather_gloves], 
attrlev(33,25,22,25,55), wpex(480,480,400,330,330,260), strsk(9,9,8,8)|agisk(10,7,5,9,4)|lordsk1(5,2,5,3,6,3,3,4)|lordsk2(2,0,3,5,5,4,6,0), 0x000000074a001191589dae40948e29b800000000001db7a80000000000000000], 
["knight_1_8", "Count Rylorius", "Rylorius", tf_hero, 0, reserved, fac_kingdom_1, [(itm_early_transitional_blue, imod_reinforced), itm_ak_great_helmet_a, itm_west_pikeman_boots, itm_wisby_gauntlets_red, itm_polish_war_horse2, itm_sword_val_3, itm_shb2, itm_civ_body_m_surcoat_5, itm_civ_foot_rich_boots_red, itm_gloves_lord_l], 
attrlev(27,18,25,28,54), wpex(470,400,400,330,330,330), strsk(8,9,7,7)|agisk(9,8,2,8,0)|lordsk1(3,0,6,1,5,0,0,4)|lordsk2(0,1,1,0,5,7,7,1), 0x0000000bf00865124aabaa431a49274c00000000001ed5240000000000000000], 
#+++++++++++++++++++++++
["knight_1_9", "Viscount Palrana", "Palrana", tf_hero, 0, reserved, fac_kingdom_1, [(itm_rathos_surcoat_english, imod_lordly), itm_ak_wing_helmet_b, itm_iron_greaves, itm_wisby_gauntlets_red, itm_english_war_horse1, itm_morningstar, itm_civ_body_m_gamb_red, itm_civ_foot_cavalry_boots_black], 
attrlev(32,27,18,18,46), wpex(440,440,300,200,200,200), strsk(9,10,8,8)|agisk(8,6,6,7,0)|lordsk1(4,2,6,2,1,2,3,3)|lordsk2(0,0,3,0,3,5,4,1), 0x00000004090805c458739a9a1476199800000000001e36f20000000000000000], 
["knight_1_10", "Count Mirchandus", "Mirchandus", tf_hero, 0, reserved, fac_kingdom_1, [(itm_heraldic_mail_with_surcoat, imod_reinforced), itm_tolrania_kettlehat, itm_civil_rich_boots_a, itm_gauntlets_arabs_a_l, itm_perisno_purebred, itm_swiss_falchion_v2, itm_imperial_bow_2, itm_spak_bow6_arrow, itm_1steel_arrow, itm_civ_body_m_surcoat_4], 
attrlev(27,25,19,20,45), wpex(350,300,180,400,250,200), strsk(7,7,7,8)|agisk(8,3,8,9,9)|lordsk1(5,8,3,7,3,7,8,4)|lordsk2(2,0,2,0,4,7,2,4), 0x000000032a10354648e3b1361d7236cc00000000001dd32a0000000000000000], 
["knight_1_11", "Count Stanmara", "Stanmara", tf_hero, 0, reserved, fac_kingdom_1, [(itm_brigandine_b_heraldic, imod_reinforced), itm_salet_new, itm_mail_boots, itm_gondor_bracer_l, itm_charger, itm_luc_horsemans_hammer, itm_tab_shield_heater_cav_a, itm_sniper_crossbow, itm_akbolt_b, itm_civ_body_m_shirt_rich_1, itm_civ_foot_cavalry_boots_red], 
attrlev(30,24,32,21,46), wpex(360,320,150,300,400,250), strsk(8,9,7,9)|agisk(7,4,4,8,3)|lordsk1(1,2,1,0,6,0,4,7)|lordsk2(1,2,1,9,5,3,2,2), 0x00000008f1102054280d8cb2a24196aa00000000001eb4dc0000000000000000], 
["knight_1_12", "Count Myrinia", "Myrinia", tf_hero, 0, reserved, fac_kingdom_1, [itm_early_transitional_blue, itm_col1_crusaderbucket1, itm_dorn_knight_boots, itm_hourglass_gauntlets_ornate, itm_english_war_horse4, itm_crusader_long_sword_a, itm_shield_11, itm_lance_lev4, itm_civ_body_m_pino_leather_3, itm_civ_foot_leather_boots_2], 
attrlev(28,20,22,18,50), wpex(380,380,380,210,210,210), strsk(9,9,7,7)|agisk(9,8,4,8,0)|lordsk1(0,1,8,2,6,1,2,3)|lordsk2(4,2,5,3,5,4,6,1), 0x0000000a580805442b2c6cc98c8dbaac00000000001d389b0000000000000000], 
#+++++++++++++++++++++++
["knight_1_13", "Viscount Berana", "Berana", tf_hero, 0, reserved, fac_kingdom_1, [(itm_wei_xiadi_swa_surcoat_fancy01, imod_lordly), itm_col1_gotlandbucket, itm_iron_greaves, itm_plate_mittens, itm_polish_war_horse2, itm_lui_knightaxeonehc, itm_norman_shield_1, itm_civ_heraldic_tabard, itm_civ_foot_mail_boots_1], 
attrlev(29,24,17,23,48), wpex(400,400,330,200,250,200), strsk(9,9,7,7)|agisk(9,6,5,8,0)|lordsk1(5,3,5,4,2,2,3,2)|lordsk2(0,0,2,1,3,6,3,0), 0x00000002d110010332d45203954e192200000000001e47630000000000000000], 
["knight_1_14", "Viscount Rafaracus", "Rafaracus", tf_hero, 0, reserved, fac_kingdom_1, [(itm_dethertir_armor_g, imod_lordly), itm_fullfacecoif, itm_west_rider_boots, itm_dark_mail_mittens, itm_danish_greatsword, itm_ebonybow, itm_spak_ar2, itm_civ_body_m_tabard_1, itm_civ_foot_leather_boots_1], 
attrlev(26,30,19,18,42), wpex(260,300,100,360,210,100), strsk(7,7,7,9)|agisk(7,2,9,5,7)|lordsk1(6,8,4,6,2,8,8,2)|lordsk2(1,0,3,0,4,3,5,2), 0x000000022210000532d45203954e192200000000001e47630000000000000000], 
["knight_1_15", "Viscount Regal", "Regal", tf_hero, 0, reserved, fac_kingdom_1, [(itm_mail_with_surcoat, imod_reinforced), (itm_ak_bascinet_new_a, imod_reinforced), itm_iron_greaves, itm_gondor_bracer_l, itm_war_horse1, itm_winged_mace_no1, itm_norman_shield_1, itm_lonely, itm_spak_bow8_arrow, itm_civ_body_m_surcoat_6, itm_civ_foot_plated_boots_1], 
attrlev(23,21,22,20,35), wpex(280,250,200,300,200,200), strsk(6,6,6,7)|agisk(7,5,4,7,7)|lordsk1(3,6,3,4,4,6,6,4)|lordsk2(5,4,6,5,4,3,4,4), 0x00000003550910c94895654c9b660c5d00000000001e34530000000000000000], 
["knight_1_16", "Viscount Dyrlian", "Dyrlian", tf_hero, 0, reserved, fac_kingdom_1, [(itm_wei_xiadi_swa_surcoat_fancy01, imod_reinforced), itm_ak_great_helmet_a, itm_dorn_knight_boots, itm_plate_mittens, itm_steel_greaves, itm_ak_warhorse_chain_b, itm_claymore_no1_v3, itm_saracin_shield_r, itm_lance_lev4, itm_civ_body_m_gamb_red, itm_civ_foot_rich_boots_red], 
attrlev(27,22,22,21,44), wpex(330,330,330,200,100,100), strsk(7,7,6,6)|agisk(8,5,5,7,0)|lordsk1(3,2,4,2,3,2,3,4)|lordsk2(2,0,2,1,5,4,4,8), 0x00000001e109155157a1ba3ad456c8cb00000000001e345a0000000000000000], 
["knight_1_17", "Count Ryinia", "Ryinia", tf_hero, 0, reserved, fac_kingdom_1, [(itm_rathos_surcoat_english, imod_lordly), itm_col1_gotlandbucket, itm_west_pikeman_boots, itm_wisby_gauntlets_red, itm_english_war_horse4, itm_2hand_swadian_regent, itm_taureg_armor, itm_civ_foot_rich_boots_red], 
attrlev(30,24,23,25,50), wpex(370,420,370,300,300,300), strsk(8,9,8,8)|agisk(9,6,5,8,0)|lordsk1(3,0,5,2,4,1,2,4)|lordsk2(0,0,0,2,5,6,5,0), 0x00000007ac0c2008251b8f3b5389a32300000000001dc75b0000000000000000], 
["knight_1_18", "Count Kantar", "Kantar", tf_hero, 0, reserved, fac_kingdom_1, [(itm_early_transitional_heraldic, imod_reinforced), itm_col1_madelnbucket1, itm_west_pikeman_boots, itm_hourglass_gauntlets_ornate, itm_charger_black, itm_crusader_long_sword_a, itm_tab_shield_heater_cav_b, itm_heroicsword, itm_civ_body_m_pino_leather_1, itm_civ_foot_leather_boots_2], 
attrlev(32,24,22,20,50), wpex(440,440,380,200,200,200), strsk(10,10,7,7)|agisk(9,7,6,8,0)|lordsk1(5,2,8,2,5,2,2,4)|lordsk2(1,0,3,0,5,6,7,0), 0x00000005701024913da6b3e4d455bb2c00000000001dc85a0000000000000000], 
["knight_1_19", "Count Dynspis", "Dynspis", tf_hero, 0, reserved, fac_kingdom_1, [(itm_wei_xiadi_swa_surcoat_v, imod_lordly), (itm_open_salet_coif, imod_reinforced), itm_iron_greaves, itm_gauntlets_arabs_b_l, itm_war_horse1, itm_luc_morningstar_4, itm_tab_shield_kite_d, itm_fire_war_bow, itm_spak_bow8_arrow, itm_civ_body_m_shirt_rich_1, itm_civ_foot_rich_boots_black], 
attrlev(27,19,20,22,46), wpex(350,300,275,350,140,140), strsk(8,7,7,8)|agisk(8,5,4,7,4)|lordsk1(3,5,4,4,3,4,5,4)|lordsk2(2,0,2,3,5,4,5,4), 0x00000004550015843d9b6d4a92ada93300000000001d45180000000000000000], 
["knight_1_20", "Viscount Meravian", "Meravian", tf_hero, 0, reserved, fac_kingdom_1, [(itm_corrazina_red, imod_reinforced), itm_ak_great_helmet_a, itm_steel_greaves, itm_wisby_gauntlets_red, itm_english_war_horse1, itm_sword_val_1, itm_shb1, itm_lance_3, itm_civ_body_m_surcoat_6, itm_civ_foot_mail_boots_1], 
attrlev(29,24,25,26,50), wpex(465,465,500,270,270,270), strsk(9,9,8,8)|agisk(10,7,5,8,0)|lordsk1(2,2,7,1,4,2,3,5)|lordsk2(3,1,4,4,6,5,6,2), 0x00000000310855cf4a9b32b4ac6a48bc00000000001d34db0000000000000000], 


#Reich Lords
["knight_2_1", "Baron Hermann", "Hermann", tf_hero, 0, reserved, fac_kingdom_2, [itm_knight_of_the_wall_plate, itm_madelnbucket1, itm_black_boot_salad_of, itm_dark_mail_mittens, itm_wyvern, itm_luc_knightly_axe_b, itm_steel_shield_kite, itm_lance_1, itm_heavy_throwing_axes, itm_civ_body_m_surcoat_2, itm_civ_foot_cavalry_boots_black], 
attrlev(34,25,24,29,58), wpex(580,500,600,350,350,550), strsk(10,10,10,9)|agisk(10,9,5,10,9)|lordsk1(5,2,8,2,6,2,1,4)|lordsk2(2,1,2,4,5,7,8,0), 0x0000000ad80011c33d9b6d4a92ada53500000000001d47180000000000000000], 
["knight_2_2","High Dragon Priestess Khivachis","High Dragon Priestess Khivachis",tf_female|tf_hero,0,0,fac_kingdom_2, [(itm_knights_armor, imod_reinforced), (itm_guard_knight_helm_1, imod_lordly), (itm_knights_boot, imod_reinforced), itm_hourglass_gauntlets, itm_fire_dragon, itm_luc_germanic_battle_axe, itm_round_dragon_shield, itm_lance_lev5], 
attrlev(32,32,25,30,55), wpex(460,460,500,240,240,460), strsk(10,9,9,7)|agisk(10,6,4,10,8)|lordsk1(3,2,5,5,6,5,5,7)|lordsk2(0,0,2,2,7,4,8,4), 0x00000007d600401673da71375b54b6dd00000000000000000000000000000000], 
["knight_2_3", "Baron Fridl", "Fridl", tf_hero, 0, reserved, fac_kingdom_2, [(itm_heraldic_tunic_new, imod_reinforced), itm_gotlandbucket, itm_shynbaulds, itm_wisby_gauntlets_black, itm_plated_charger4, itm_luc_horsemans_axe, itm_steel_shield_heater, itm_civ_body_m_pino_leather_4, itm_civ_foot_leather_boots_2], 
attrlev(32,21,22,24,54), wpex(480,400,400,180,180,300), strsk(10,10,8,8)|agisk(9,7,7,8,5)|lordsk1(2,0,6,1,6,2,4,5)|lordsk2(3,1,3,2,5,4,5,3), 0x0000000b2b0031c56942d2385badcd5b00000000001e37130000000000000000], 
["knight_2_4", "Baron Richard", "Richard", tf_hero, 0, reserved, fac_kingdom_2, [itm_narf_gothic_plate_black, (itm_barbuta2_black, imod_reinforced), itm_black_boot_salad_of, itm_blackplatemitty, itm_plated_charger9, itm_luc_serrated_sword_v2, itm_rohirrim_throwing_axe, itm_civ_body_m_padded_cloth_3, itm_civ_foot_rich_boots_black], 
attrlev(28,22,24,25,52), wpex(350,400,350,200,200,400), strsk(8,8,8,7)|agisk(8,5,4,9,8)|lordsk1(7,0,4,6,6,3,5,4)|lordsk2(2,2,2,4,8,7,7,6), 0x0000000c3a0832c748f272540d8ab65900000000001d34e60000000000000000], 
["knight_2_5", "Graf Volkhard", "Volkhard", tf_hero, 0, reserved, fac_kingdom_2, [itm_marmont_armor, itm_munitionshelm1, itm_black_boot_salad_of, itm_scale_gauntlets, itm_northerner_horse_black, itm_reich_sword, itm_plate_covered_round_shield, itm_spak_crsb01, itm_akbolt_b, itm_civ_heraldic_tabard, itm_civ_foot_furred_boots_1], 
attrlev(26,25,23,18,50), wpex(370,250,250,400,400,300), strsk(7,7,7,7)|agisk(8,5,7,7,7)|lordsk1(5,7,2,8,4,9,9,5)|lordsk2(3,0,3,3,4,4,3,4), 0x000000084d0000035d76bb5f55bad9ad00000000001dd8ec0000000000000000], 
["knight_2_6", "Herzog Oskar", "Oskar", tf_hero, 0, reserved, fac_kingdom_2, [(itm_narf_gothic_plate_black, imod_reinforced), (itm_madelnbucket1, imod_reinforced), itm_black_boot_salad_of, itm_blackplatemitty, itm_black_fire_dragon, itm_luc_winged_mace_2h, itm_saracin_shield_t, itm_lance_lev6, itm_rohirrim_throwing_axe, itm_civ_body_m_coat_of_plates_black, itm_civ_foot_plated_boots_black], 
attrlev(62,34,34,44,60), wpex(650,650,650,400,400,650), strsk(10,10,10,9)|agisk(10,10,7,10,10)|lordsk1(5,6,10,7,10,4,6,7)|lordsk2(7,4,5,1,10,8,10,4), 0x0000000c7f01020638d479551296330a00000000001da92c0000000000000000], 
["knight_2_7", "Baron Hendrik", "Hendrik", tf_hero, 0, reserved, fac_kingdom_2, [itm_knights_armor, itm_maciejowski_helmet5b, itm_knights_boot, itm_dorn_knight_gant, itm_plated_charger5, itm_luc_iron_hand_axe_g, itm_dec_steel_shield, itm_lance_1, itm_civ_kuyak_a, itm_civ_foot_plated_boots_2, itm_gloves_lord_l], 
attrlev(27,18,26,30,58), wpex(470,400,470,300,300,380), strsk(9,9,8,8)|agisk(10,9,3,10,6)|lordsk1(0,2,4,0,5,2,4,6)|lordsk2(4,1,3,3,6,5,6,6), 0x0000000c04100153335ba9390b2d277500000000001d89120000000000000000], 
["knight_2_8", "Baron Vlan", "Vlan", tf_hero, 0, reserved, fac_kingdom_2, [itm_plated_armor1, itm_new_helm1, itm_plate_boots, itm_dorn_knight_gant, itm_plate_charger_brown, itm_luc_germanic_battle_axe, itm_steel_shield_heater, itm_lance_lev6, itm_civ_body_m_fur_coat_rich_1, itm_civ_foot_rich_boots_black], #bought his horse from Sut 
attrlev(30,20,18,22,52), wpex(380,360,380,100,150,200), strsk(8,9,6,6)|agisk(8,8,4,9,0)|lordsk1(6,2,3,0,3,1,1,5)|lordsk2(0,0,1,3,7,5,4,4), 0x0000000c33046581234e8da2cdd248db00000000001f569c0000000000000000], 
#+++++++++++++++++++++++
["knight_2_9", "Baron Mleza", "Mleza", tf_hero, 0, reserved, fac_kingdom_2, [itm_knight_of_the_wall_plate, itm_weimarhelm, itm_black_boot_salad_of, itm_blackplatemitty, itm_plated_charger5, itm_luc_knightly_axe_two_handed, itm_civ_body_m_pino_leather_fur_1, itm_civ_foot_leather_boots_1], 
attrlev(35,26,20,18,55), wpex(480,480,400,200,200,400), strsk(10,10,9,8)|agisk(10,7,6,9,6)|lordsk1(5,2,8,0,1,2,2,3)|lordsk2(1,0,3,2,4,6,6,0), 0x000000086c0451d4136469c4d9b159ad00000000001e28f10000000000000000], 
["knight_2_10", "Graf Waldemar", "Waldemar", tf_hero, 0, reserved, fac_kingdom_2, [itm_armour_gothic, itm_guard_knight_helm, itm_plate_boots, itm_gauntlets, itm_wyvern, itm_varangian_war_axe_no1, itm_sp_shr1, itm_rohirrim_throwing_axe, itm_black_tribal_outfit, itm_civ_foot_highlander_boots], 
attrlev(32,25,22,24,50), wpex(430,430,400,100,100,450), strsk(9,10,10,7)|agisk(9,7,8,9,8)|lordsk1(1,0,6,2,3,2,2,4)|lordsk2(0,0,2,0,4,5,5,1), 0x00000007ee01021166b76edd5cd5eb6e00000000001f691e0000000000000000], 
["knight_2_11", "Baron Gereon", "Gereon", tf_hero, 0, reserved, fac_kingdom_2, [(itm_dorn_wiper, imod_lordly), (itm_maciejowski_helmet5b_black, imod_lordly), (itm_twilight_boots, imod_reinforced), itm_glovesblack, itm_dreaded_wolf, itm_giant_cleaver, itm_sh_snake, itm_civ_heraldic_surcoat_heavy, itm_civ_foot_plated_boots_black], #former Kumipa
attrlev(64,30,40,34,60), wpex(650,650,600,600,600,600), strsk(10,10,10,10)|agisk(10,9,6,10,9)|lordsk1(5,10,9,10,9,9,9,5)|lordsk2(6,1,5,4,5,8,8,2), 0x0000000fff0031c63b0a6e4994ae272a00000000001db4e80000000000000000], 
["knight_2_12", "Baron Reinhold", "Reinhold", tf_hero, 0, reserved, fac_kingdom_2, [itm_narf_gothic_plate_black, itm_flemish_armet_larger_and_black, itm_black_greaves, itm_dark_mail_mittens, itm_plated_charger5, itm_sword_val_2, itm_round_dragon_shield, itm_lance_lev6, itm_civ_early_transitional_white, itm_civ_foot_ornate_boots_1], 
attrlev(28,25,25,28,52), wpex(400,330,600,120,120,120), strsk(8,8,6,6)|agisk(9,6,4,10,0)|lordsk1(0,0,5,0,6,0,2,7)|lordsk2(2,0,4,5,9,5,5,6), 0x000000052d040517350cddd5215494a000000000001ed6f40000000000000000], 
#+++++++++++++++++++++++
["knight_2_13", "Graf Theobald", "Theobald", tf_hero, 0, reserved, fac_kingdom_2, [(itm_early_transitional_black, imod_reinforced), itm_maciejowski_helmet5b_black, itm_black_boot_salad_of, itm_glovesblack, itm_whg2, itm_bastard_sword_b, itm_sh_snake, itm_civ_early_transitional_black, itm_civ_foot_plated_boots_black], 
attrlev(28,19,17,17,46), wpex(360,360,200,200,200,200), strsk(8,8,6,6)|agisk(9,6,4,8,0)|lordsk1(9,3,3,6,4,2,5,5)|lordsk2(0,0,2,2,4,7,3,1), 0x00000000ff042595396456c4d249251400000000001da6fa0000000000000000], 
["knight_2_14", "Baron Hanns", "Hanns", tf_hero, 0, reserved, fac_kingdom_2, [itm_knights_armor, itm_maciejowski_helmet_new4, itm_knights_boot, itm_dorn_knight_gant, itm_plated_charger4, itm_luc_iron_hand_axe_h, itm_dal_muslimf, itm_great_lance, itm_civ_kuyak_b, itm_civ_foot_plated_boots_1], 
attrlev(29,25,24,24,44), wpex(390,370,390,240,240,240), strsk(8,8,7,7)|agisk(9,7,7,9,4)|lordsk1(0,2,5,3,5,3,5,5)|lordsk2(5,4,5,4,5,5,5,4), 0x00000001c500000539233512e287391d00000000001db7200000000000000000], 
["knight_2_15", "Graf Arnulf", "Arnulf ", tf_hero, 0, reserved, fac_kingdom_2, [(itm_rus_lamellar_b, imod_reinforced), itm_frenchpepperpot2, itm_black_greaves, itm_gauntlets_arabs_b_l, itm_dorn_horse_lamellar_c, itm_luc_battleaxeb, itm_luc_cavalry_shield_z, itm_latticed_flatbow, itm_gromitearrow, itm_civ_body_m_pino_leather_5, itm_civ_foot_plated_boots_1], 
attrlev(27,26,22,24,45), wpex(320,200,80,400,310,130), strsk(7,7,6,9)|agisk(8,4,7,7,4)|lordsk1(4,9,3,6,2,7,8,5)|lordsk2(2,0,2,3,5,3,4,7), 0x00000001e80104553b6bb36de5d6eb7400000000001dd72c0000000000000000], 
["knight_2_16", "Baron Otfried", "Otfried", tf_hero, 0, reserved, fac_kingdom_2, [itm_bronzeplate, itm_maciejowski_helmet5b_bronze, itm_bronzeshynald, itm_bronzeplatemitten, itm_plated_charger8, itm_reich_sword, itm_tab_shield_small_round_c, itm_lance_2, itm_civ_body_m_fur_coat_1, itm_civ_foot_leather_boots_2], 
attrlev(28,22,23,25,45), wpex(350,350,380,200,200,290), strsk(8,8,7,6)|agisk(8,7,4,8,0)|lordsk1(3,0,4,0,4,0,1,5)|lordsk2(1,1,1,5,6,4,4,5), 0x0000000306041089471bd2e93375b52c00000000001dd5220000000000000000], 
["knight_2_17", "Graf Kurt", "Kurt", tf_hero, 0, reserved, fac_kingdom_2, [(itm_bnw_armour2, imod_lordly), itm_guard_knight_helm_1, itm_dorn_knight_boots, itm_gauntlets, itm_hospitaller_charger, itm_claymore_no1_v3, itm_saracin_shield_r, itm_civ_body_m_surcoat_7, itm_civ_foot_plated_boots_2, itm_gondor_bracer_l], 
attrlev(24,21,19,25,34), wpex(300,280,280,140,140,140), strsk(6,6,5,5)|agisk(7,5,5,8,0)|lordsk1(1,2,2,0,6,1,1,4)|lordsk2(3,2,2,6,6,3,3,4), 0x00000005eb0d0387374bd19addcea4ab00000000001e32cc0000000000000000], 
["knight_2_18", "Graf Willibald", "Willibald", tf_hero, 0, reserved, fac_kingdom_2, [itm_coat_of_plates_steel, itm_gotlandbucket, itm_dorn_spearbearer_boots, itm_hourglass_gauntlets, itm_hospitaller_charger, itm_sarranid_two_handed_axe_b, itm_steel_shield, itm_rohirrim_throwing_axe, itm_civ_body_m_tabard_2, itm_civ_foot_cavalry_boots_black], 
attrlev(28,22,20,26,42), wpex(380,380,350,160,160,380), strsk(9,9,9,8)|agisk(9,6,5,8,9)|lordsk1(4,0,5,1,3,0,2,4)|lordsk2(0,0,0,3,4,5,6,1), 0x000000037f0001023d9b6d4a92adaae400000000001ec0dc0000000000000000], 
["knight_2_19", "Baron Ralf", "Ralf", tf_hero, 0, reserved, fac_kingdom_2, [itm_xenoargh_metal_leather01, itm_pepperpothelm1, itm_bronzeshynald, itm_dorn_knight_gant, itm_plated_charger8, itm_luc_knightly_axe_one_handed_b, itm_steel_shield_herald01, itm_civ_heraldic_surcoat, itm_civ_foot_plated_boots_1], 
attrlev(35,27,25,22,50), wpex(460,460,460,300,300,460), strsk(9,10,9,8)|agisk(10,8,5,9,0)|lordsk1(4,4,7,2,5,2,3,5)|lordsk2(2,0,3,3,4,6,6,2), 0x00000003730050863b0a764994ae272d00000000001db4e10000000000000000], 
["knight_2_20", "Graf Ludger", "Ludger", tf_hero, 0, reserved, fac_kingdom_2, [itm_pilgrim_disguise_ludger, itm_saddle_horse, itm_jan_zizkas_mace, itm_butchering_knife, itm_assassin_throwing_daggers], 
attrlev(58,42,16,34,48), wpex(600,100,100,100,100,500), strsk(10,10,10,9)|agisk(10,0,10,6,9)|lordsk1(5,0,2,9,0,2,8,5)|lordsk2(8,0,0,0,10,8,8,4), 0x00000006680821d33684a6991b74b69d00000000001e47690000000000000000], 


#Draharan Lords
["knight_3_1", "Emir Fahim", "Fahim", tf_hero, 0, reserved, fac_kingdom_3, [(itm_tyrk_armor_heavi_c, imod_lordly), itm_helm_tyrk_heavi_c, itm_plate_boots, itm_gauntlets_arabs_b_l, itm_war_horse7, itm_khopesh_1, itm_saracin_shield_g, itm_khergit_bow, itm_blackarrow, itm_civ_body_m_arab_robe_7, itm_civ_foot_arab_leather_boots_2, itm_cwe_king_gloves], 
attrlev(28,28,25,28,58), wpex(440,440,300,500,160,440), strsk(8,8,9,9)|agisk(10,6,6,9,10)|lordsk1(2,9,3,7,4,8,8,8)|lordsk2(7,4,6,1,7,5,6,9), 0x0000000d7e00a10554b246b7094dcf9c00000000001e31e70000000000000000], #intelligent, scholar
["knight_3_2", "Emir Harith", "Harith", tf_hero, 0, reserved, fac_kingdom_3, [(itm_wei_xiadi_lamellar_armor02, imod_lordly), (itm_helm_saracin_j, imod_lordly), (itm_dorn_sand_snakes_boots, imod_reinforced), itm_brass_lamellar_gauntlets, itm_bedyin_camel_a, itm_scimitar_b, itm_dal_hinduh, itm_khergit_bow, itm_khergit_arrows, itm_civ_body_m_nomad_lam_brown, itm_civ_foot_arab_leather_boots_2], 
attrlev(27,30,22,25,55), wpex(460,400,400,500,200,500), strsk(8,8,9,9)|agisk(10,5,6,10,10)|lordsk1(9,9,4,9,4,7,8,7)|lordsk2(4,2,4,3,7,7,5,6), 0x0000000cfc04a589492bb334ad71aaa200000000001e052a0000000000000000], #plowman, cultivator
["knight_3_3", "Emir Jabbar", "Jabbar", tf_hero, 0, reserved, fac_kingdom_3, [(itm_sarranid_royal_armor, imod_reinforced), (itm_brass_veiled_helmet, imod_lordly), (itm_dorn_sand_snakes_boots, imod_reinforced), itm_brass_scale_gauntlets, itm_saracen_horse_sultan, itm_luc_sarranid_falchion_m2, itm_dal_hinduh, itm_throwing_spears, itm_throwing_spears, itm_civ_body_m_arab_vest_3, itm_civ_foot_arab_boots_1], 
attrlev(27,27,26,30,58), wpex(480,480,450,400,220,480), strsk(10,8,9,8)|agisk(10,7,5,10,10)|lordsk1(5,5,9,3,7,4,4,6)|lordsk2(3,2,4,5,8,8,9,5), 0x0000000ebf00b3543b0a6e4994ae272a00000000001db4e10000000000000000], #powerful
["knight_3_4", "Emir Najib", "Najib", tf_hero, 0, reserved, fac_kingdom_3, [(itm_heavy_armor_arabs_b, imod_lordly), (itm_helm_tyrk_heavi_c, imod_reinforced), (itm_mail_boots_brass, imod_lordly), itm_hourglass_gauntlets_ornate, itm_saracin_hard_horses_c, (itm_khopesh_1, imod_masterwork), itm_lance_5, itm_saracin_shield_g, itm_civ_body_m_arab_robe_6, itm_civ_foot_arab_leather_boots_2], 
attrlev(26,28,23,26,54), wpex(400,400,400,300,100,300), strsk(8,8,8,8)|agisk(9,5,5,9,8)|lordsk1(6,4,4,5,4,6,6,6)|lordsk2(3,3,4,1,8,7,5,9), 0x0000000c3508d504391b5ac72a96ab6c00000000001e37230000000000000000], #noble, intelligent
["knight_3_5", "Emir Shahnaz", "Shahnaz", tf_hero, 0, reserved, fac_kingdom_3, [(itm_heraldic_surcoat_plated, imod_reinforced), (itm_vaegir_war_helmet, imod_reinforced), itm_black_greaves, itm_dorn_knight_gant, itm_khergit_war_horse, itm_hooksword_spak, itm_tab_shield_small_round_c, itm_throwing_spears, itm_civ_body_m_noble_1, itm_civ_foot_arab_leather_boots_black], 
attrlev(30,28,16,22,55), wpex(500,500,300,300,300,500), strsk(9,10,10,9)|agisk(10,8,4,9,9)|lordsk1(10,4,7,8,2,7,8,6)|lordsk2(2,0,2,3,5,9,6,4), 0x0000000bfe00a2854b377b4964b69b6500000000001de96c0000000000000000], #pride of the king
["knight_3_6", "Emir Barakat", "Barakat", tf_hero, 0, reserved, fac_kingdom_3, [(itm_mamluke_mail, imod_lordly), (itm_facecovermail_turban_black, imod_lordly), (itm_shadow_greaves, imod_lordly), itm_glovesblack, itm_war_horse7, itm_saracin_sword_d, itm_saracin_shield_t, itm_throwing_spears, itm_throwing_spears, itm_civ_body_m_arab_vest_1, itm_civ_foot_arab_leather_boots_2], 
attrlev(30,30,27,26,58), wpex(360,360,400,500,300,500), strsk(7,7,9,9)|agisk(9,2,2,10,10)|lordsk1(6,8,6,3,4,3,8,10)|lordsk2(4,2,4,1,8,5,6,7), 0x0000000cf601301254b3cab7094dc31a00000000001d372f0000000000000000], #blessing
["knight_3_7", "Emir Karam","Karam", tf_hero, 0, reserved, fac_kingdom_3, [itm_sarranid_royal_armor, (itm_sarranid_royal_helmet, imod_lordly), (itm_mail_boots_brass, imod_reinforced), itm_brass_mail_mittens, itm_warhorse_sarranid_brass, itm_saracin_sword_a, itm_brass_shield1, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar, itm_sarranid_cavalry_robe, itm_civ_foot_ankle_boots_1], 
attrlev(28,29,22,22,52), wpex(420,400,400,400,200,420), strsk(9,9,9,8)|agisk(9,6,6,9,9)|lordsk1(1,4,5,2,5,4,4,5)|lordsk2(7,3,5,3,6,5,5,9), 0x0000000c3a00a5ca44be2d14d37cc6dc00000000001ed6df0000000000000000], #generosity
["knight_3_8", "Emir Sharif", "Sharif", tf_hero, 0, reserved, fac_kingdom_3, [(itm_tyrk_armor_heavi_c, imod_reinforced), itm_crusaderbucket1, itm_plate_boots, itm_gauntlets, itm_warhorse_sarranid, itm_khopesh_1, itm_saracin_shield_p, itm_civ_body_m_arab_armor_1, itm_civ_foot_cavalry_boots_1], 
attrlev(30,32,21,27,56), wpex(500,500,500,300,100,300), strsk(10,10,8,8)|agisk(10,8,7,10,6)|lordsk1(3,1,8,1,6,2,2,5)|lordsk2(2,1,2,0,7,8,8,3), 0x0000000d3c0120c45af4af2b1c8d996400000000001db71d0000000000000000], #eminent, virtuous
#+++++++++++++++++++++++
["knight_3_9", "Sahib Mahir","Mahir", tf_hero, 0, reserved, fac_kingdom_3, [(itm_wei_xiadi_samurai_armor02, imod_reinforced), (itm_sarranid_iron_helmet, imod_lordly), itm_dorn_spearbearer_boots, itm_dark_mail_mittens, itm_war_horse7, itm_scimitar_b, itm_dal_muslime, itm_akwar_bow, itm_spak_ar2, itm_civ_heraldic_tabard, itm_civ_foot_arab_leather_boots_2], 
attrlev(25,24,28,20,46), wpex(350,350,350,400,300,300), strsk(8,8,7,8)|agisk(8,5,6,7,3)|lordsk1(2,4,3,2,5,3,5,7)|lordsk2(4,4,4,9,6,4,4,7), 0x00000008bf04a4c421a30ea68b54971500000000001e54db0000000000000000], #skilled
["knight_3_10", "Emir Ihab","Ihab", tf_hero, 0, reserved, fac_kingdom_3, [itm_sarranid_royal_armor, itm_mamluk_helm, itm_dorn_sand_snakes_boots, itm_gauntlets_arabs_b_l, itm_saracin_hard_horses_d, itm_warblade_darkwoodgold, itm_brass_shield, itm_civ_body_m_arab_robe_6, itm_civ_foot_cavalry_boots_1], 
attrlev(22,24,23,30,47), wpex(280,280,200,200,100,100), strsk(5,6,5,5)|agisk(6,3,4,7,0)|lordsk1(6,1,0,0,0,3,3,10)|lordsk2(2,0,0,1,10,2,4,10), 0x000000057d10a558355a4ec74b1dba2e00000000001eb6dc0000000000000000], #gift
["knight_3_11", "Emir Grasullah", "Grasullah", tf_hero, 0, reserved, fac_kingdom_3, [(itm_dorn_assasin_armor, imod_lordly), (itm_asmoday_helmet2, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_twilight_gloves, imod_lordly), (itm_twilight_horse, imod_heavy), itm_jack_anduril, itm_asmoday_seel, itm_sword_val_3, itm_civ_dorn_assasin_armor, itm_civ_foot_plated_boots_black], 
attrlev(52,48,40,36,60), wpex(660,660,660,660,660,660), strsk(10,10,10,10)|agisk(10,10,10,10,10)|lordsk1(5,5,10,10,10,10,10,6)|lordsk2(8,5,8,4,10,10,10,6), 0x00000008f4004611395c9bbbdcb1cdf400000000001db70c0000000000000000], #before beard 0x00000008f4004591395c9bbbdcb1cdf400000000001db70c0000000000000000
["knight_3_12", "Emir Faris", "Faris", tf_hero, 0, reserved, fac_kingdom_3, [itm_tyrk_armor_heavi_c, (itm_vaegir_war_helmet, imod_reinforced), itm_dorn_knight_boots, itm_hourglass_gauntlets_ornate, itm_warhorse, itm_saracin_sword_a, itm_dal_muslime, itm_civ_body_m_arab_vest_2, itm_civ_foot_cavalry_boots_1], 
attrlev(29,30,19,21,50), wpex(430,430,430,250,100,250), strsk(9,9,8,8)|agisk(9,7,7,9,6)|lordsk1(5,2,5,2,6,2,4,6)|lordsk2(2,0,3,1,5,7,6,4), 0x000000063a00a0ca5b33d3c9258d356b00000000001db76d0000000000000000], #knight
#+++++++++++++++++++++++
["knight_3_13", "Sahib Hasan","Hasan", tf_hero, 0, reserved, fac_kingdom_3, [itm_early_transitional_heraldic, itm_helm_saracin_j, itm_iron_greaves, itm_gauntlets_arabs_a_l, itm_tribal2, itm_luc_sarranid_falchion_m2, itm_tab_shield_small_round_c, itm_imperial_bow, itm_spak_ar2, itm_wei_xiadi_swa_tabard, itm_civ_foot_arab_leather_boots_2], 
attrlev(24,26,18,29,42), wpex(340,340,300,400,200,200), strsk(6,7,6,7)|agisk(7,4,7,7,8)|lordsk1(0,6,2,4,2,5,6,5)|lordsk2(3,0,2,1,8,4,4,7), 0x000000017e0121115acb9e9956f5c0dd00000000001db7450000000000000000], #handsome
["knight_3_14", "Sahib Nadir", "Nadir", tf_hero, 0, reserved, fac_kingdom_3, [(itm_sarranid_elite_armor, imod_reinforced), itm_sarranid_veiled_helmet, itm_rus_splint_greaves, itm_brass_lamellar_gauntlets, itm_saracin_hard_horses_c, itm_sword_khergit_4, itm_dal_hindud, itm_war_darts, itm_civ_body_m_arab_vest_1, itm_civ_foot_plated_boots_1], 
attrlev(26,25,20,20,44), wpex(370,370,300,300,100,370), strsk(7,8,8,7)|agisk(8,5,7,8,8)|lordsk1(4,1,5,3,4,3,4,5)|lordsk2(2,0,2,1,4,6,5,4), 0x000000033f0ca3915723cca96a7dc52400000000001db7640000000000000000], #rare
["knight_3_15", "Sahib Samir", "Samir", tf_hero, 0, reserved, fac_kingdom_3, [itm_wei_xiadi_lamellar_armor02, itm_brass_veiled_helmet, itm_shadow_greaves, itm_brass_scale_gauntlets, itm_saracen_horse_sultan, itm_saracin_sword_d, itm_painted_brass_shield5, itm_khergit_bow, itm_bronze_arrow, itm_civ_body_m_arab_robe_8, itm_civ_foot_ankle_boots_1], 
attrlev(24,29,21,23,45), wpex(340,340,300,380,100,300), strsk(7,7,8,8)|agisk(8,4,8,8,9)|lordsk1(4,9,3,7,4,8,8,7)|lordsk2(3,0,2,2,6,3,4,8), 0x000000073901858b394baedb5e51b6df00000000001db6ec0000000000000000], #companion in evening talk
["knight_3_16", "Sahib Khalid","Khalid", tf_hero, 0, reserved, fac_kingdom_3, [itm_brass_mamluke_mail, (itm_sarranid_royal_helmet, imod_lordly), itm_dorn_sand_snakes_boots, itm_gauntlets_arabs_b_l, itm_warhorse_brass, itm_saracin_sword_a, itm_dal_hinduh, itm_khergit_bow, itm_bronze_arrow, itm_civ_body_m_arab_vest_3, itm_civ_foot_plated_boots_arab], 
attrlev(21,24,17,23,36), wpex(270,270,270,300,140,300), strsk(5,6,6,7)|agisk(6,3,5,7,8)|lordsk1(6,6,0,4,1,5,6,5)|lordsk2(1,0,0,1,5,4,4,4), 0x00000001ba00d389694ad2385bad2d5c00000000001db7200000000000000000], #eternal, old 0x00000000370cd38916db69d8a0cd34bc00000000001c96d20000000000000000
["knight_3_17", "Sahib Zulfaqar", "Zulfaqar", tf_hero, 0, reserved, fac_kingdom_3, [(itm_elite_armor_a, imod_lordly), itm_vaegir_war_helmet, itm_black_greaves, itm_new_lamellar_gauntlets, itm_tiger, itm_scimitar_b, itm_dal_hinduk, itm_war_darts, itm_civ_body_m_arab_vest_2, itm_civ_foot_plated_boots_arab], 
attrlev(28,26,20,19,48), wpex(380,380,380,350,130,450), strsk(9,8,8,7)|agisk(8,6,8,8,9)|lordsk1(5,1,5,6,4,6,5,6)|lordsk2(0,0,2,1,5,6,5,6), 0x000000013c0934c6472652b6e68dc4d500000000001e42590000000000000000], #cleaver of the spine
["knight_3_18", "Sahib Rahim", "Rahim", tf_hero, 0, reserved, fac_kingdom_3, [itm_heavy_armor_arabs_b, itm_sarranid_iron_helmet, itm_khergit_leather_boots, itm_gondor_bracer_l, itm_luc_sarranid_dagger, itm_war_scythe_no1, itm_khergit_bow, itm_khergit_arrows, itm_civ_body_m_arab_robe_5, itm_civ_foot_ankle_boots_1], 
attrlev(16,19,29,18,30), wpex(220,150,250,250,80,120), strsk(7,4,3,5)|agisk(5,0,9,4,0)|lordsk1(0,1,0,0,0,6,4,8)|lordsk2(10,8,9,4,6,0,2,7), 0x000000003700d5c650db72bb5b7236df00000000001db6e30000000000000000], #kind, compassionate
["knight_3_19", "Sahib Munir","Munir", tf_hero, 0, reserved, fac_kingdom_3, [itm_youhou_assassin_armor, itm_youhou_assassin_hood, itm_gondor_bracer_l, itm_sarranid_boots_black, itm_youhou_assassin_sword, itm_assassin_throwing_daggers, itm_civ_body_m_nomad_lam_brass, itm_civ_foot_arab_leather_boots_black], 
attrlev(26,28,20,17,46), wpex(400,400,400,300,300,400), strsk(8,8,9,8)|agisk(9,7,9,6,6)|lordsk1(3,4,7,6,6,4,5,5)|lordsk2(3,3,3,2,5,5,3,5), 0x00000000f700d0c528ddb1531272152300000000001d66d90000000000000000], #bright, shining
["knight_3_20", "Sahib Sayyid","Sayyid", tf_hero, 0, reserved, fac_kingdom_3, [(itm_armor_medium_tyrk_d, imod_lordly), itm_mamluk_helm, (itm_saracin_hard_boot_b, imod_lordly), itm_gauntlets_arabs_a_l, itm_saracin_hard_horses_d, itm_luc_sarranid_falchion_m2, itm_dal_hinduh, itm_throwing_spears, itm_throwing_spears, itm_civ_body_m_nomad_lam_brown, itm_civ_foot_rich_boots_black], 
attrlev(28,24,19,25,48), wpex(390,390,390,300,100,400), strsk(9,9,9,8)|agisk(8,7,7,8,9)|lordsk1(4,2,4,2,4,2,3,4)|lordsk2(2,0,2,0,4,6,6,3), 0x000000013b0530d124dd91e459f5949300000000001de7220000000000000000], #lord, master


#Maccavian Lords
["knight_4_1", "Lord Licinius", "Licinius", tf_hero, 0, reserved, fac_kingdom_4, [(itm_huscarl_armour, imod_lordly), itm_pigface_new, itm_steel_greaves, itm_gauntlets, itm_northerner_horse_hunter, itm_luc_knightly_axe_one_handed_b, itm_tab_shield_small_round_c, itm_hurlbat_2, itm_civ_body_m_rich_fur_1, itm_civ_foot_plated_boots_1], 
attrlev(33,24,23,28,58), wpex(500,500,400,180,180,500), strsk(10,10,9,9)|agisk(10,8,6,7,8)|lordsk1(8,2,8,5,7,4,5,6)|lordsk2(0,0,1,4,7,9,8,1), 0x0000000c05002254340eb1d91159392d00000000001eb75a0000000000000000], 
["knight_4_2", "Lord Jormungand", "Jormundgand", tf_hero, 0, reserved, fac_kingdom_4, [ itm_milanese_armour, (itm_crusader_hard_helm_a, imod_lordly), itm_plate_boots, itm_plate_mittens, itm_wlong22, itm_sword_valirian_a, itm_steel_shield, itm_fur_coat_2, itm_civ_foot_rich_boots_black], 
attrlev(32,24,25,28,58), wpex(520,520,480,100,100,300), strsk(10,10,8,8)|agisk(10,8,5,8,0)|lordsk1(2,0,8,2,8,3,4,6)|lordsk2(2,0,2,5,9,7,9,5), 0x0000000ac308225124e26d4a6295965a00000000001da3e40000000000000000], 
["knight_4_3", "Lord Olaf", "Olaf", tf_hero, 0, reserved, fac_kingdom_4, [itm_blacky_platey_salad, itm_crusaderbucket1, itm_black_boot_salad_of, itm_blackplatemitty, itm_northerner_horse_black, itm_luc_knightly_axe_two_handed, itm_saracin_shield_t, itm_hurlbat_2, itm_civ_body_m_coat_of_plates_black, itm_civ_foot_mail_boots_1], 
attrlev(35,26,21,30,58), wpex(540,540,400,150,150,550), strsk(10,10,9,9)|agisk(10,9,6,8,9)|lordsk1(6,0,9,4,8,1,3,4)|lordsk2(0,0,4,7,6,9,9,0), 0x0000000c03040289245a314b744b30a400000000001eb2a90000000000000000], 
["knight_4_4", "Lord Gerlad", "Gerlad", tf_hero, 0, reserved, fac_kingdom_4, [(itm_heraldic_tunic_new, imod_lordly), (itm_maciejowski_helmet_new3, imod_lordly), itm_plate_boots, itm_wisby_gauntlets_black, itm_plate_armour_charger2, itm_lui_battleaxea, itm_tab_shield_round_d, itm_civ_body_m_surcoat_8, itm_civ_foot_mail_boots_1], 
attrlev(30,19,26,27,58), wpex(480,480,400,200,200,400), strsk(9,9,7,7)|agisk(10,8,2,9,3)|lordsk1(1,0,6,1,7,1,1,5)|lordsk2(1,0,2,5,7,6,7,4), 0x0000000feb0122813b6bb36de5d6cb7400000000001dd72c0000000000000000], 
["knight_4_5", "Lord Ragnor", "Ragnor", tf_hero, 0, reserved, fac_kingdom_4, [(itm_kn_arm_leather4, imod_lordly), (itm_crusader_hard_helm_d, imod_reinforced), itm_black_boot_salad_of, itm_twilight_gloves, itm_armor_wolf_black, itm_luc_baronaxeoneh, itm_shield_heater_c, itm_new_sniper_crossbow, itm_akbolt_b, itm_civ_noble_maccavian_armor_2, itm_civ_foot_rich_boots_black], 
attrlev(30,28,26,28,56), wpex(450,300,300,200,400,200), strsk(9,9,8,8)|agisk(10,6,6,9,10)|lordsk1(6,8,3,8,4,7,6,6)|lordsk2(2,0,2,1,9,7,8,6), 0x00000008ea08630546dc8e59422d350a00000000001e55350000000000000000], 
["knight_4_6", "Lord Fenris", "Fenris", tf_hero, 0, reserved, fac_kingdom_4, [ (itm_west_pikeman_armor, imod_reinforced), (itm_pigface_klappvisor, imod_reinforced), itm_west_pikeman_boots, itm_gauntlets, itm_plated_charger2, itm_sword_valirian_a, itm_steel_shield_kite, itm_hurlbat_2, itm_civ_body_m_coat_of_plates_blue, itm_civ_foot_mail_boots_1], 
attrlev(33,26,24,27,56), wpex(480,480,480,300,300,480), strsk(10,10,10,9)|agisk(10,8,7,8,9)|lordsk1(5,1,8,2,7,2,3,4)|lordsk2(2,1,3,7,7,8,7,3), 0x0000000af00012c439233512e29b3f2600000000001db7220000000000000000], 
["knight_4_7", "Lord Falcus", "Falcus", tf_hero, 0, reserved, fac_kingdom_4, [ itm_milanese_armour, (itm_luc_knight_helm, imod_reinforced), itm_steel_greaves, itm_hourglass_gauntlets_ornate, itm_armor_wolf_white, itm_luc_knightly_axe_one_handed, itm_steel_shield_herald03, itm_civ_heraldic_surcoat, itm_civ_foot_plated_boots_2], 
attrlev(32,25,26,25,58), wpex(450,450,400,160,160,160), strsk(9,9,7,7)|agisk(9,7,6,9,0)|lordsk1(9,2,5,8,6,6,4,5)|lordsk2(2,0,2,1,7,9,6,2), 0x00000007ed0002873d9b6d4a92ada53500000000001cc3180000000000000000], 
["knight_4_8", "Lord Singvar", "Singvar", tf_hero, 0, reserved, fac_kingdom_4, [(itm_plate_armor1, imod_lordly), (itm_black_helmet, imod_lordly), (itm_black_greaves, imod_lordly), itm_blackplatemitty, itm_charger_black, itm_crusader_long_sword_c, itm_sp_newsh, itm_hurlbat_2, itm_civ_noble_maccavian_armor_1, itm_civ_foot_cavalry_boots_black, itm_cwe_king_gloves], 
attrlev(30,20,27,30,58), wpex(500,500,440,200,200,500), strsk(8,9,9,7)|agisk(10,8,2,10,10)|lordsk1(8,0,8,6,7,2,3,6)|lordsk2(1,0,2,5,9,8,9,1), 0x0000000fc00061c53b026e4994ae272a00000000001db4e90000000000000000], 
#+++++++++++++++++++++++
["knight_4_9", "Lord Tytus Rex", "Tytus Rex", tf_hero, 0, reserved, fac_kingdom_4, [itm_armor_baratheon, itm_helm_baratheon, itm_boots_baratheon, itm_dorn_knight_gant, itm_plated_charger9, itm_bastard_sword_b, itm_tab_shield_heater_cav_b, itm_riverlands_freylight, itm_civ_foot_plated_boots_black], 
attrlev(33,27,25,22,56), wpex(470,470,450,300,300,300), strsk(9,9,7,7)|agisk(10,8,7,9,6)|lordsk1(4,0,7,3,8,2,3,5)|lordsk2(3,1,4,5,5,7,6,4), 0x00000007ad05059156da5758892cc4e400000000001e42ec0000000000000000], 
["knight_4_10", "Lord Benunius", "Benunius", tf_hero, 0, reserved, fac_kingdom_4, [(itm_wei_xiadi_swa_surcoat_fancy03, imod_lordly), (itm_crusader_hard_helm_ord, imod_lordly), itm_west_pikeman_boots, itm_plate_mittens, itm_plated_charger2, itm_lui_kjergitaxe, itm_tab_shield_kite_d, itm_hurlbat_2, itm_hurlbat_2, itm_civ_heraldic_mail_with_tabard, itm_civ_foot_plated_boots_1], 
attrlev(30,24,23,26,52), wpex(440,400,400,200,200,480), strsk(9,9,7,7)|agisk(9,7,5,9,9)|lordsk1(3,0,5,2,5,3,3,6)|lordsk2(4,3,4,6,8,7,7,6), 0x000000074300030f3d9b6d4a92ada53500000000001cc7180000000000000000], 
["knight_4_11", "Lord Logarson", "Logarson", tf_hero, 0, reserved, fac_kingdom_4, [ itm_brigandine_b_heraldic, itm_rathos_12thcent_faceplate, itm_steel_greaves, itm_wisby_gauntlets_black, itm_armor_wolf_white, itm_luc_war_axe_2, itm_steel_shield_heater, itm_civ_body_m_tabard_4, itm_civ_foot_cavalry_boots_black], 
attrlev(29,22,19,20,46), wpex(450,350,350,100,100,100), strsk(9,10,7,7)|agisk(9,7,7,8,0)|lordsk1(5,0,6,3,3,5,3,4)|lordsk2(0,0,3,2,4,8,7,1), 0x0000000526100005471d52e69c7a3b5b00000000001dc9550000000000000000], 
["knight_4_12", "Lord Aeric", "Aeric", tf_hero, 0, reserved, fac_kingdom_4, [(itm_huscarl_armour, imod_lordly), itm_maciejowski_helmet5b, itm_splinted_greaves_spurs, itm_beargauntlets, itm_executer,  itm_civ_huscarl_armour, itm_civ_foot_plated_boots_1], 
attrlev(42,26,18,24,54), wpex(400,500,500,100,100,300), strsk(10,10,8,8)|agisk(10,3,8,4,0)|lordsk1(8,0,9,2,2,4,5,5)|lordsk2(1,0,2,1,2,8,8,0), 0x000000064000059824936cc51cb5bb2500000000001dd4d80000000000000000], 
#+++++++++++++++++++++++
["knight_4_13", "Lord Faarn", "Faarn", tf_hero, 0, reserved, fac_kingdom_4, [itm_marmont_armor, itm_crusader_knight_helm_d, itm_black_greaves, itm_scale_gauntlets, itm_dk_armour_charger, itm_frostfang, itm_sp_newsh, itm_hurlbat_2, itm_civ_body_m_surcoat_8, itm_civ_foot_plated_boots_2], 
attrlev(31,25,24,26,50), wpex(380,380,350,200,200,400), strsk(7,8,8,7)|agisk(8,6,5,8,8)|lordsk1(4,0,4,3,5,3,4,5)|lordsk2(3,1,3,5,7,7,6,4), 0x000000065a0d058f45238e38da96326600000000001e34e30000000000000000], 
["knight_4_14", "Lord Segrefied", "Segrefied", tf_hero, 0, reserved, fac_kingdom_4, [ itm_maximilian_armour_1, itm_black_helmet, itm_black_greaves, itm_glovesblack, itm_northerner_horse, itm_luc_maciejowski_axe, itm_saracin_shield_t, itm_hurlbat_2, itm_civ_body_m_coat_of_plates_blue, itm_civ_foot_plated_boots_2], 
attrlev(31,24,20,25,48), wpex(400,400,360,120,120,400), strsk(10,9,9,7)|agisk(9,6,6,7,8)|lordsk1(6,0,7,2,4,2,3,4)|lordsk2(0,0,3,3,4,7,7,0), 0x00000004c500030a2cb6aa36ea50a69d00000000001dc55c0000000000000000], 
["knight_4_15", "Lord Finnur", "Finnur", tf_hero, 0, reserved, fac_kingdom_4, [(itm_armour_temeria, imod_lordly), itm_barbuta1, itm_west_pikeman_boots, itm_gondor_bracer_l, itm_northerner_horse, itm_lui_knightaxeonehe, itm_plate_covered_round_shield, itm_crossbow_axe, itm_axe_a, itm_civ_body_m_gamb_blue, itm_civ_foot_plated_boots_1], 
attrlev(28,25,25,23,46), wpex(350,350,350,180,350,200), strsk(8,7,6,7)|agisk(8,4,7,8,7)|lordsk1(5,4,4,6,5,7,8,6)|lordsk2(3,1,3,6,6,5,4,6), 0x00000002e60831941715d1aa8242350000000000001e46630000000000000000], 
["knight_4_16", "Lord Bergur", "Bergur", tf_hero, 0, reserved, fac_kingdom_4, [(itm_armor_35, imod_reinforced), itm_crusader_knight_helm_d, itm_black_greaves, itm_scale_gauntlets, itm_armor_wolf_black, itm_rohirrim_long_hafted_axe, itm_steel_shield, itm_civ_body_m_pino_leather_fur_2, itm_civ_foot_plated_boots_1], 
attrlev(30,24,20,21,45), wpex(370,330,330,130,130,200), strsk(8,8,7,6)|agisk(8,5,5,9,0)|lordsk1(6,2,5,8,5,7,8,5)|lordsk2(1,1,3,2,7,8,5,1), 0x000000034500124239233512e287391d00000000001db7200000000000000000], 
["knight_4_17", "Lord Marayirr", "Marayirr", tf_hero, 0, reserved, fac_kingdom_4, [ (itm_kn_arm_leather4, imod_reinforced), itm_munitionshelm1, itm_black_greaves, itm_glovesblack, itm_dk_armour_charger, itm_axe_crusader_1, itm_tab_shield_kite_cav_b, itm_hurlbat_2, itm_civ_body_m_shirt_rich_4, itm_civ_foot_rich_boots_black], 
attrlev(29,24,19,20,45), wpex(380,320,320,140,140,380), strsk(8,8,9,7)|agisk(8,6,6,8,9)|lordsk1(6,0,6,1,4,2,3,5)|lordsk2(1,0,2,4,4,6,3,3), 0x000000076f0412036d232a2324b5b81400000000001e55630000000000000000], 
["knight_4_18", "Lord Svend", "Svend", tf_hero, 0, reserved, fac_kingdom_4, [(itm_wei_xiadi_surcoat_rhodok02, imod_lordly), itm_barbuta1, itm_splinted_greaves_spurs, itm_mail_mittens, itm_luc_polish_bardiche, itm_lonely, itm_1steel_arrow, itm_1steel_arrow, itm_civ_foot_plated_boots_2], 
attrlev(25,25,23,25,40), wpex(300,300,300,350,200,200), strsk(8,7,7,8)|agisk(8,4,8,5,0)|lordsk1(2,7,3,6,4,6,7,5)|lordsk2(3,0,3,3,4,5,3,5), 0x000000002d0915c5673332a6a94d34da00000000001da9250000000000000000], 
["knight_4_19", "Lord Surdun", "Surdun", tf_hero, 0, reserved, fac_kingdom_4, [itm_early_transitional_heraldic, itm_west_pikeman_helmet, itm_iron_greaves, itm_wisby_gauntlets_black, itm_armor_wolf_black, itm_lui_knightaxetwoha, itm_tab_shield_small_round_b, itm_bow_a, itm_axe_a, itm_civ_body_m_surcoat_2, itm_civ_foot_plated_boots_2], 
attrlev(30,24,24,26,45), wpex(370,370,300,160,300,160), strsk(8,8,7,7)|agisk(8,6,5,8,0)|lordsk1(5,3,5,7,5,6,7,5)|lordsk2(0,0,2,3,7,9,3,5), 0x00000003851025c468e4af44e9a598db00000000001db4b20000000000000000], 
["knight_4_20", "Lord Hinrik", "Hinrik", tf_hero, 0, reserved, fac_kingdom_4, [(itm_kn_arm_leather4, imod_reinforced), itm_crusader_hard_helm_a, itm_steel_greaves, itm_glovesblack, itm_northerner_horse_white, itm_luc_axe_knight_z, itm_tab_shield_kite_cav_b, itm_bow_a, itm_axe_a, itm_civ_noble_maccavian_armor_1, itm_civ_foot_plated_boots_2], 
attrlev(31,23,25,24,46), wpex(400,350,350,200,350,200), strsk(9,9,7,7)|agisk(9,7,6,8,0)|lordsk1(3,0,3,1,5,1,5,6)|lordsk2(3,1,3,7,5,5,5,6), 0x00000004ae0001d16742da385b6d295c00000000001e391b0000000000000000], #duplicating just in case, 0x00000004ae0001d16942d2385b6d2d5c00000000001e39190000000000000000, also Clathas/trp_dranton has similar code


#Elintoran Lords
["knight_5_1", "Archduke Albondiel", "Albondiel", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_elf_armor, imod_lordly), (itm_elfhelm, imod_lordly), itm_shadow_greaves, itm_gondor_bracer_l, itm_scimitar_brightwood, itm_redwoodbow, itm_simpletreequiver_arrow, itm_spak_bow6_arrow, itm_civ_foot_rich_boots_black], 
attrlev(32,35,36,28,60), wpex(570,570,550,620,220,220), strsk(9,10,8,10)|agisk(10,5,10,7,8)|lordsk1(4,10,8,9,7,10,10,5)|lordsk2(3,2,4,5,8,9,10,2), 0x0000000b3c00000436de7626cb8e350c00000000001d269b0000000000000000], 
["knight_5_2", "Archduke Eldaernth", "Eldaernth", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_rivend_rohir_armor_1b, imod_lordly), (itm_dorn_knight_helmet, imod_lordly), itm_twilight_boots, itm_new_gauntlets_b, itm_elvarie_spirit_horse, itm_sabre_elmwood, itm_lorien_round_shield, itm_elmwoodbow, itm_lonely_ar, itm_arab_bandit_a, itm_civ_foot_cavalry_boots_black], 
attrlev(30,32,31,28,58), wpex(550,550,550,550,200,200), strsk(9,10,8,10)|agisk(10,7,7,10,10)|lordsk1(6,9,3,7,4,8,9,6)|lordsk2(5,5,5,2,8,7,8,4), 0x0000000b33004005295e7628cdaa34cc00000000001ca6bb0000000000000000], #before replacement 0x0000000b33004005295e7628cdaa34ce00000000001ca6bb0000000000000000
["knight_5_3", "Archduke Ilyndrathil", "Ilyndrathil", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_lorien_royal, imod_lordly), (itm_rivend_helmet_1c, imod_lordly), itm_twilight_boots, itm_gondor_bracer_l, itm_elvarie_spirit_horse, itm_lorien_sword_a, itm_lorien_round_shield, itm_ebonybow, itm_lonely_ar, itm_civ_body_m_aketon_green_1, itm_civ_foot_rich_boots_black, itm_cwe_king_gloves], 
attrlev(28,30,38,32,58), wpex(500,500,480,480,200,200), strsk(9,8,7,9)|agisk(10,6,6,9,10)|lordsk1(0,6,2,6,2,6,6,7)|lordsk2(8,6,7,1,9,5,7,8), 0x0000000b800030062953b628cdaa348e00000000001ca68d0000000000000000], 
["knight_5_4", "Archduke Lagoruthon", "Lagoruthon", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_lorien_royal, imod_lordly), itm_royal_ench, itm_twilight_boots, itm_new_gauntlets_b, itm_twilight_horse, itm_lorien_sword_hand_and_half, itm_saracin_shield_y, itm_ebonybow, itm_blackarrow, itm_civ_body_m_tabard_2, itm_civ_foot_rich_boots_black], 
attrlev(32,32,32,25,58), wpex(580,580,550,600,240,240), strsk(9,10,7,10)|agisk(10,8,7,10,10)|lordsk1(8,8,6,9,4,7,8,7)|lordsk2(2,0,2,4,8,8,8,2), 0x00000009fc00505032742c96e37134da00000000001da6720000000000000000], #before replacement 0x00000006bc004050327438976375c39a00000000001ca66a0000000000000000
["knight_5_5", "Archduke Berlaeduil", "Berlaeduil", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_mirk_armor_1a, imod_lordly), itm_royal_ench, (itm_plate_boots2, imod_lordly), itm_plate_mittens, itm_plated_charger7, itm_sabre_ebony, itm_dec_steel_shield, itm_light_mail_and_plate, itm_civ_foot_cavalry_boots_red], 
attrlev(31,30,36,32,60), wpex(600,600,540,420,180,180), strsk(8,9,6,7)|agisk(10,8,5,10,4)|lordsk1(0,2,8,3,7,4,4,6)|lordsk2(4,2,4,3,10,7,9,3), 0x0000000ec0001008295c7228cdaa348e00000000001ca6a40000000000000000], 
["knight_5_6", "Archduke Bregedon", "Bregedon", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_twiligh_armor, imod_lordly), itm_royal_ench, itm_twilight_boots, itm_twilight_gloves, itm_twilight_horse, itm_elvish_sword, itm_saracin_shield_r, itm_ebonybow, itm_blackarrow, itm_civ_twiligh_armor, itm_civ_foot_plated_boots_black], 
attrlev(25,25,35,31,56), wpex(400,400,300,400,250,250), strsk(6,7,5,9)|agisk(8,7,4,9,9)|lordsk1(7,8,1,3,4,8,6,10)|lordsk2(4,2,3,2,10,7,5,10), 0x0000000acb0000833acb56a553b0182c00000000001e67110000000000000000], 
["knight_5_7", "Archduke Methenor", "Methenor", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_mirk_armor_1b, imod_reinforced), (itm_elfhelm_gold, imod_lordly), itm_twilight_boots, itm_plate_mittens, itm_twilight_horse, itm_sword_val_1, itm_saracin_shield_h, itm_arab_bandit_a, itm_civ_foot_rich_boots_black], 
attrlev(34,34,30,29,58), wpex(620,620,580,420,200,200), strsk(10,10,8,9)|agisk(10,9,8,10,6)|lordsk1(4,1,9,7,8,6,7,4)|lordsk2(2,2,5,4,6,9,9,1), 0x000000058c006047592450bb5a95c62400000000001f132d0000000000000000], 
["knight_5_8", "Archduke Valthaauuionnon", "Valthaauuionnon", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_rivendellrewardarmour, imod_lordly), (itm_rivend_helmet_1c, imod_lordly), itm_twilight_boots, itm_brass_scale_gauntlets, itm_elvarie_spirit_horse, itm_warblade_ivorygold, itm_saracin_shield_y, itm_ranger_bow, itm_simpletreequiver_arrow, itm_civ_elven_armor_1, itm_civ_foot_cavalry_boots_black], 
attrlev(32,32,40,27,60), wpex(560,560,560,600,140,200), strsk(9,9,7,10)|agisk(10,8,4,9,10)|lordsk1(5,7,7,9,6,6,8,6)|lordsk2(4,3,3,4,8,10,7,2), 0x0000000ec000300f295c76288d4aa48e00000000001ca67b0000000000000000], 
#+++++++++++++++++++++++
["knight_5_9", "Archduke Merisirduil", "Merisirduil", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [itm_rivend_rohir_armor_1b, itm_rivend_helmet_2b, itm_twilight_boots, itm_glovesblack, itm_elvarie_spirit_horse, itm_lorien_sword_a, itm_lorien_round_shield, itm_redwoodbow, itm_lonely_ar, itm_civ_elven_armor_2, itm_civ_foot_plated_boots_black], 
attrlev(30,32,33,30,58), wpex(510,510,510,550,160,160), strsk(7,9,7,9)|agisk(10,7,7,9,10)|lordsk1(3,6,5,5,5,5,6,6)|lordsk2(4,2,4,4,9,5,7,5), 0x00000008c700618f379f6db6cd69b6db00000000001cd6e30000000000000000], 
["knight_5_10", "Duke Faenefindon", "Faenefindon", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_lorien_armor_d, imod_reinforced), itm_rivend_helmet_2b, itm_dorn_knight_boots, itm_hourglass_gauntlets_ornate, itm_mail_armour_charger1, itm_sabre_hithlain, itm_dal_muslimf, itm_ebonybow, itm_whiteleatherquiver_arrow, itm_civ_elven_armor_3, itm_civ_foot_ornate_boots_1], 
attrlev(28,28,30,26,54), wpex(450,450,450,450,230,230), strsk(8,8,6,9)|agisk(9,7,8,8,10)|lordsk1(3,8,4,5,4,5,6,5)|lordsk2(4,2,3,1,6,5,5,1), 0x00000005d80060ca549b4d729a6caad500000000001da4dc0000000000000000], 
["knight_5_11", "Archduke Zaos", "Zaos", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_lorien_royal, imod_reinforced), (itm_rivend_helmet_2b, imod_reinforced), itm_mirk_boots_1, itm_brass_scale_gauntlets, itm_wood_elven_blade, itm_guizugong, itm_lonely_ar, itm_ivorygoldquiver_arrow, itm_courtly_outfit, itm_civ_foot_elven_boots_green], 
attrlev(29,34,31,27,56), wpex(475,475,450,500,300,210), strsk(7,7,6,9)|agisk(10,3,9,6,8)|lordsk1(3,9,6,8,5,8,9,6)|lordsk2(5,2,4,3,8,5,6,3), 0x0000000a4c00304b16df7a28d785349d00000000001ca6ad0000000000000000], 
["knight_5_12", "Duke Tharlaithion", "Tharlaithion", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_mirk_armor_2, imod_lordly), itm_royal_ench, itm_dorn_spearbearer_boots, itm_gondor_bracer_l, itm_ranger_blade, itm_ranger_bow, itm_whiteleatherquiver_arrow, itm_civ_elven_armor_4, itm_civ_foot_rich_boots_black], 
attrlev(27,32,30,26,54), wpex(430,400,400,460,200,200), strsk(8,7,6,10)|agisk(9,3,9,4,6)|lordsk1(4,9,3,10,3,10,10,4)|lordsk2(4,0,4,1,4,4,3,5), 0x000000088800604656db79a8dc2eaaeb00000000001e22d30000000000000000], 
#+++++++++++++++++++++++
["knight_5_13","Duchess Silivethiel","Duchess Silivethiel",tf_elven_female|tf_hero, 0, reserved, fac_kingdom_5, [(itm_j_knight_surcoat_01_with_mantle, imod_reinforced), itm_rivend_helmet_2b, itm_rivend_boots_1b, itm_gondor_bracer_l, itm_elvarie_spirit_horse, itm_warblade_ivorygold, itm_lorien_round_shield, itm_elmwoodbow, itm_ivorygoldquiver_arrow, itm_arab_bandit_a, itm_civil_rich_boots_b], 
attrlev(25,27,23,25,42), wpex(370,370,300,400,220,220), strsk(5,7,5,8)|agisk(8,7,6,7,8)|lordsk1(0,5,8,3,2,6,6,3)|lordsk2(3,0,6,0,4,2,6,2), 0x000000000410004514509110917138aa0000000000e932d40000000000000000], 
["knight_5_14", "Duke Otaerhyn", "Otaerhyn", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_lorien_armor_d, imod_lordly), itm_dorn_knight_helmet_a, itm_mirk_boots_1, itm_gondor_bracer_l, itm_elvarie_spirit_horse, itm_luc_strange_blade, itm_saracin_shield_k, itm_elmwoodbow, itm_simpletreequiver_arrow, itm_civ_heraldic_mail_with_tabard, itm_civ_foot_cavalry_boots_black], 
attrlev(26,29,24,22,46), wpex(420,420,400,420,230,200), strsk(8,8,7,8)|agisk(9,5,5,8,9)|lordsk1(8,6,4,8,4,6,7,6)|lordsk2(1,0,3,1,3,8,3,0), 0x0000000437006045479f6eb74d69b6db00000000001cd6f30000000000000000], 
["knight_5_15", "Duke Gwedagelnen", "Gwedagelnen", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [itm_early_transitional_pearl, itm_royal_ench, itm_dorn_knight_boots, itm_bnw_gauntlets, itm_plated_charger7, itm_warblade_black02, itm_dal_muslimf, itm_civ_early_transitional_pearl, itm_civ_foot_ornate_boots_1], 
attrlev(27,27,29,26,46), wpex(440,440,400,400,220,220), strsk(8,8,7,8)|agisk(9,7,6,8,4)|lordsk1(0,0,5,2,4,3,3,5)|lordsk2(4,1,4,1,6,5,5,4), 0x0000000500000005275c7628cd89a48e00000000001ca6650000000000000000], 
["knight_5_16", "Duke Faeranduil", "Faeranduil", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_rivend_rohir_armor_1b, imod_reinforced), (itm_rivend_helmet_1c, imod_reinforced), itm_dorn_knight_boots, itm_glovesblack, itm_winged_sword, itm_civ_elven_armor_2, itm_civ_foot_ornate_boots_1], 
attrlev(35,30,25,29,50), wpex(480,520,480,360,180,180), strsk(9,10,7,8)|agisk(10,5,9,5,0)|lordsk1(3,0,8,2,6,4,3,3)|lordsk2(2,0,4,2,5,7,7,2), 0x00000000c000600e275c7628cd8a348e00000000001ca6650000000000000000], 
["knight_5_17", "Duke Galasmaedhen", "Galasmaedhen", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [itm_elf_armor, itm_elfhelm, itm_leather_boots_dark, itm_gondor_bracer_l, itm_lorien_sword_b, itm_lonely, itm_spak_bow6_arrow, itm_spak_bow6_arrow, itm_civ_foot_rich_boots_red], 
attrlev(24,26,27,25,42), wpex(330,300,300,360,160,160), strsk(5,7,5,7)|agisk(7,2,6,4,5)|lordsk1(3,6,3,4,4,5,5,3)|lordsk2(2,0,3,1,4,3,3,4), 0x00000004b2002001379a6db6cd6896db00000000001cd6db0000000000000000], 
["knight_5_18", "Duke Laireronian", "Laireronian", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_armour_tyrell_rider, imod_reinforced), (itm_elfhelm_grey, imod_lordly), itm_mirk_boots_1, itm_gondor_bracer_l, itm_forest_mount, itm_warblade_greensilver, itm_saracin_shield_h, itm_civ_elven_armor_5, itm_civ_foot_elven_boots_green], 
attrlev(27,30,29,29,48), wpex(470,470,400,400,215,215), strsk(8,8,6,7)|agisk(9,7,7,9,4)|lordsk1(2,1,6,3,5,4,4,5)|lordsk2(3,1,3,2,7,5,5,5), 0x0000000287003008379f6db6cd8996db00000000001cd6e50000000000000000], 
["knight_5_19", "Duke Throthradien", "Throthradien", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [itm_armour_tyrell_rider, itm_royal_ench, itm_bronzeshynald, itm_gondor_bracer_l, itm_dorn_horse_lamellar_b, itm_luc_bronze_mace, itm_saracin_shield_g, itm_latticed_flatbow, itm_elmwoodquiver_arrow, itm_civ_elven_armor_5, itm_civ_foot_plated_boots_black], 
attrlev(28,27,27,24,48), wpex(430,430,400,430,230,230), strsk(8,8,6,9)|agisk(9,6,6,8,6)|lordsk1(5,4,4,7,5,5,6,6)|lordsk2(1,0,3,1,5,9,5,7), 0x00000003f6005049275c7628cd8a348e00000000001ca6620000000000000000], #before replacement 0x00000003f6005049275c7628cd8a348e00000000001ca6650000000000000000
["knight_5_20", "Duke Naraglad", "Naraglad", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_5, [(itm_j_knight_surcoat_02_with_mantle, imod_reinforced), itm_elfhelm_gold, itm_dorn_knight_boots, itm_gondor_bracer_l, itm_horse_tyrk_e, itm_sabre_val_1, itm_rivend_shield_2a, itm_elmwoodbow, itm_spak_bow6_arrow, itm_civ_elven_armor_7, itm_civ_foot_rich_boots_black], 
attrlev(27,28,29,25,48), wpex(400,400,400,400,400,400), strsk(7,8,6,8)|agisk(8,6,4,8,9)|lordsk1(6,6,5,4,4,6,6,7)|lordsk2(4,1,3,4,8,6,4,7), 0x00000003e7002010384a953a51ada6ee00000000001c97620000000000000000], 


#Hakkon Lords
["knight_6_1", "Hakkon Diodorus", "Diodorus", tf_hero, 0, reserved, fac_kingdom_6, [(itm_amade_bronze_plate_champion, imod_lordly), (itm_corintiah_helmet_steel, imod_reinforced), (itm_bronzeshynald, imod_lordly), itm_plate_mittens, itm_romanhalfcata, itm_imperial_cavalry_sword1h, itm_sh_golden, itm_nowe_jarid, itm_civ_body_m_gamb_striped, itm_civ_foot_plated_boots_1], 
attrlev(32,27,24,25,56), wpex(520,520,450,200,200,520), strsk(10,9,10,8)|agisk(10,8,4,8,10)|lordsk1(6,0,9,1,9,2,2,4)|lordsk2(1,1,3,5,5,9,9,1), 0x00000008ab0020846942d2385b6d2d5900000000001db7190000000000000000], #old Albafar    #
["knight_6_2", "Hakkon Thales", "Thales", tf_hero, 0, reserved, fac_kingdom_6, [(itm_west_guardsman, imod_reinforced), (itm_barbuta2_greekish_black, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_scale_gauntlets, itm_wlong22, itm_lui_empirewarhammerb, itm_saracin_shield_r, itm_hakkon_noble_outfit, itm_civ_foot_cavalry_boots_red], 
attrlev(30,26,26,27,52), wpex(460,460,450,200,300,300), strsk(9,9,8,7)|agisk(9,8,4,8,4)|lordsk1(2,0,6,1,7,2,3,6)|lordsk2(3,1,4,6,7,7,6,4), 0x0000000b770925d448cb74b92b8dab1d00000000001dd71e0000000000000000], #old Saif'Al'Din    #to blossom
["knight_6_3", "Hakkon Amirmoez", "Amirmoez", tf_hero, 0, reserved, fac_kingdom_6, [(itm_gotkn_rom_br_pl_1, imod_lordly), itm_corintiah_helmet_dark, itm_plate_boots, itm_bronzeplatemitten, itm_charger1, itm_lui_knighthammer, itm_sh_golden, itm_nowe_jarid, itm_civ_body_padded_armor_7, itm_civ_foot_cavalry_boots_1], 
attrlev(32,26,25,25,58), wpex(500,500,480,200,400,550), strsk(9,9,10,7)|agisk(10,8,5,9,10)|lordsk1(5,0,8,3,7,1,3,6)|lordsk2(1,1,3,5,8,8,7,3), 0x000000096f10b4d137146da96491a6b300000000001db6a90000000000000000], #
["knight_6_4", "Hakkon Leonidas", "Leonidas", tf_hero, 0, reserved, fac_kingdom_6, [(itm_gotkn_rom_br_pl_2, imod_lordly), (itm_corintiah_helmet_hakleg, imod_lordly), (itm_black_boot_salad_of, imod_lordly), (itm_dorn_sand_snakes_gauntles, imod_lordly), itm_luc_celtic_sword, itm_goplon8, itm_nowe_jarid, itm_roman_pilum_1, itm_civ_hakkon_plate_2, itm_civ_foot_imperial_boots_m], 
attrlev(35,27,24,28,58), wpex(550,500,500,100,180,600), strsk(10,10,10,8)|agisk(10,10,8,4,4)|lordsk1(5,0,10,3,10,4,5,5)|lordsk2(2,0,4,4,5,10,10,0), 0x0000000bfd085298050caa4b285be51a00000000001d13010000000000000000], #old Shakur    #lion
["knight_6_5", "Hakkon Theocritus", "Theocritus", tf_hero, 0, reserved, fac_kingdom_6, [(itm_dorn_sand_snakes_armor, imod_lordly), (itm_imperial_helm, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_blackplatemitty, itm_romanhalfcata, itm_luc_hammer_spike, itm_shield_7, itm_civ_foot_cavalry_boots_1], 
attrlev(29,24,25,27,54), wpex(440,440,400,120,200,260), strsk(8,8,7,6)|agisk(9,6,4,9,0)|lordsk1(9,0,6,7,5,4,8,6)|lordsk2(2,0,2,6,9,9,6,2), 0x000000096208b584330371aae175bb9900000000001e14110000000000000000], #old Qasim    #judge of god
["knight_6_6", "Hakkon Valerius", "Valerius", tf_hero, 0, reserved, fac_kingdom_6, [(itm_early_transitional_gold, imod_lordly), (itm_crete_helm_gold, imod_reinforced), (itm_dorn_knight_boots, imod_lordly), itm_gauntlets_arabs_b_l, itm_charger_bronze, itm_jack_faramir, itm_sh_golden, itm_nowe_jarid, itm_civ_foot_ornate_boots_1, itm_cwe_king_gloves], 
attrlev(33,30,24,26,56), wpex(500,450,450,140,200,500), strsk(9,9,9,7)|agisk(10,8,6,9,10)|lordsk1(8,0,7,2,7,1,2,6)|lordsk2(0,0,0,5,8,9,8,1), 0x0000000b6c00b5c64723294889b1291200000000001e57610000000000000000], #old Abujamal    #to be strong
["knight_6_7", "Hakkon Demetrios", "Demetrios", tf_hero, 0, reserved, fac_kingdom_6, [(itm_churburg_13_mail, imod_reinforced), (itm_corintiah_helmet_dark, imod_lordly), (itm_steel_greaves, imod_lordly), itm_hourglass_gauntlets_ornate, itm_charger1, itm_lui_empirewarhammerb, itm_shield_7, itm_sniper_crossbow, itm_akbolt_a, itm_wei_xiadi_swa_tabard, itm_civ_foot_plated_boots_black], 
attrlev(34,24,27,29,58), wpex(480,480,450,200,500,400), strsk(9,9,8,8)|agisk(10,7,7,8,4)|lordsk1(3,0,8,4,9,4,6,6)|lordsk2(3,3,3,8,8,7,9,4), 0x0000000cb210c5c520528bbbda9125d500000000001f62300000000000000000], #old Sal'Abal
["knight_6_8", "Hakkon Julius", "Julius", tf_hero, 0, reserved, fac_kingdom_6, [(itm_tarth_armor, imod_reinforced), (itm_barbuta1_black, imod_lordly), itm_black_greaves, itm_brass_lamellar_gauntlets, itm_3lamellar_charger, itm_saracin_sword_c, itm_tab_shield_kite_cav_b, itm_sniper_crossbow, itm_akbolt_a, itm_civ_body_padded_armor_1, itm_civ_foot_cavalry_boots_1], 
attrlev(27,24,29,27,52), wpex(380,300,300,200,450,200), strsk(7,8,7,7)|agisk(8,6,6,8,7)|lordsk1(6,5,5,5,6,5,6,7)|lordsk2(4,4,4,9,10,5,5,7), 0x0000000bc609238438b36b44da8cc72500000000001e56db0000000000000000], #old Sala'Al'Dur
#old +++++++++++++++++++++++
["knight_6_9", "Hakkon Maximus", "Maximus", tf_hero, 0, reserved, fac_kingdom_6, [(itm_west_guardsman, imod_lordly), (itm_barbuta2_greekish_purple, imod_reinforced), (itm_black_boot_salad_of, imod_lordly), itm_glovesblack, itm_2imperial_warhorse, itm_imperial_cavalry_sword1h, itm_saracin_shield_c, itm_roman_pilum_1, itm_civ_body_padded_armor_4, itm_civ_foot_plated_boots_black], 
attrlev(33,26,22,24,55), wpex(530,530,500,200,280,530), strsk(9,10,10,8)|agisk(10,8,6,10,10)|lordsk1(5,0,10,0,8,1,3,4)|lordsk2(1,1,4,2,5,8,8,0), 0x000000086901034648dc4aba9d64a79c00000000001cb5b10000000000000000], #old Al'Fahkri    #greatest
["knight_6_10", "Hakkon Alexios", "Alexios", tf_hero, 0, reserved, fac_kingdom_6, [(itm_amade_steel_plate, imod_lordly), (itm_crete_helm, imod_lordly), (itm_dorn_knight_boots, imod_lordly), itm_hourglass_gauntlets_ornate, itm_plated_charger6, itm_claymore_no1_v3, itm_new_shield, itm_lance_lev5, itm_civ_body_m_gamb_brown, itm_civ_foot_plated_boots_1], 
attrlev(31,25,26,25,50), wpex(430,430,400,180,180,260), strsk(8,8,6,6)|agisk(8,6,5,8,0)|lordsk1(3,0,7,2,7,2,3,5)|lordsk2(4,3,4,6,7,7,6,3), 0x000000073b0441056ce99256b4ad4b3300000000001d392c0000000000000000], #old Mu'Tamid    #helper, defender
["knight_6_11", "High Inquisitor Esarion", "High Inquisitor Esarion", tf_hero, 0,0, fac_kingdom_6, [(itm_dorn_sand_snakes_armor, imod_lordly), (itm_corinthian_helm_a, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_glovesblack, itm_charger1, itm_lui_knighthammerempire, itm_saracin_shield_p, itm_roman_pilum_1, itm_roman_pilum_1], 
attrlev(35,28,30,32,60), wpex(520,520,500,200,330,520), strsk(10,10,10,8)|agisk(10,10,7,10,10)|lordsk1(5,0,8,7,8,4,6,6)|lordsk2(0,0,2,4,8,7,8,4), 0x0000000a6800300536db6db6db6db6db00000000001db6db0000000000000000], 
["knight_6_12", "Hakkon Martialis", "Martialis", tf_hero, 0, reserved, fac_kingdom_6, [(itm_gotkn_rom_br_pl_4, imod_lordly), (itm_barbuta2_greekish_grey, imod_lordly), (itm_shynbaulds, imod_lordly), itm_hourglass_gauntlets, itm_charger1, itm_lui_manhunter_polehammer, itm_shield_7, itm_lance_2, itm_hakkon_noble_outfit, itm_civ_foot_cavalry_boots_black], 
attrlev(30,25,20,24,48), wpex(420,420,450,150,200,330), strsk(9,8,6,6)|agisk(8,6,4,8,0)|lordsk1(5,0,7,2,6,1,3,5)|lordsk2(3,0,3,5,5,7,7,1), 0x00000009f0102046635b74ba547197a400000000001e46d10000000000000000], #old Qadir
#old +++++++++++++++++++++++
["knight_6_13", "Hakkon Tacitus", "Tacitus", tf_hero, 0, reserved, fac_kingdom_6, [(itm_early_transitional_rust, imod_reinforced), (itm_crete_helm_br, imod_lordly), itm_boot_average_crusader_b, itm_brass_mail_mittens, itm_luc_english_polehammer, itm_sniper_crossbow, itm_steel_bolts, itm_civ_body_padded_armor_7, itm_civ_foot_leather_boots_2], 
attrlev(28,25,23,22,46), wpex(360,360,400,150,400,250), strsk(7,8,5,5)|agisk(7,4,8,4,0)|lordsk1(4,0,5,4,8,4,7,5)|lordsk2(2,2,4,7,6,7,5,4), 0x00000003711035825b73ad4ad975bb5200000000001db6eb0000000000000000], #old Iqbal   #silent, mute
["knight_6_14", "Hakkon Sergius", "Sergius", tf_hero, 0, reserved, fac_kingdom_6, [(itm_a_roman_chain, imod_lordly), (itm_corintiah_helmet, imod_lordly), itm_mail_boots_brass, itm_brass_scale_gauntlets, itm_roman_gladius_3, itm_sh_golden, itm_nowe_jarid, itm_nowe_jarid, itm_civ_foot_ankle_boots_1, itm_cwe_king_gloves], 
attrlev(30,26,21,24,45), wpex(400,400,400,300,300,400), strsk(8,9,9,7)|agisk(8,7,9,4,4)|lordsk1(6,0,7,1,7,3,3,5)|lordsk2(4,2,6,2,5,7,6,4), 0x000000028e0c05c63a5b921ac22db8e200000000001cca530000000000000000], #old Al'Farsid
["knight_6_15", "Hakkon Antonius", "Antonius", tf_hero, 0, reserved, fac_kingdom_6, [(itm_early_transitional_orange, imod_reinforced), (itm_crete_helm, imod_reinforced), itm_west_pikeman_boots, itm_hourglass_gauntlets, itm_romanhalfcata2, itm_claymore_no1_v3, itm_new_shield, itm_nowe_jarid, itm_civ_body_m_pino_leather_6, itm_civ_foot_leather_boots_2], 
attrlev(28,26,25,25,44), wpex(350,350,300,150,150,350), strsk(7,7,8,6)|agisk(7,5,5,8,8)|lordsk1(6,0,5,4,4,4,3,6)|lordsk2(3,3,3,6,8,6,4,7), 0x00000002660d2389369a6938ccd5b95400000000001f25220000000000000000], #old Albaf
["knight_6_16", "Hakkon Herodes", "Herodes", tf_hero, 0, reserved, fac_kingdom_6, [itm_bronze_plate, (itm_barbuta2_greekish_grey, imod_reinforced), (itm_steel_greaves, imod_lordly), itm_bronze_gauntlet, itm_romanhalfcata2, itm_imperial_cavalry_sword1h, itm_shield_7, itm_lance, itm_civ_body_m_gamb_brown, itm_civ_foot_cavalry_boots_1], 
attrlev(31,25,20,23,48), wpex(420,420,450,160,200,200), strsk(8,8,7,6)|agisk(8,6,6,8,0)|lordsk1(6,0,8,0,2,0,1,4)|lordsk2(0,0,1,2,4,7,7,0), 0x00000004770834140a01f1c5eb91caf400000000001f12da0000000000000000], #old Nur'Ad'Din   #hero
["knight_6_17", "Hakkon Severus", "Severus", tf_hero, 0, reserved, fac_kingdom_6, [itm_marmont_armor, (itm_barbuta2_black, imod_reinforced), itm_black_greaves, itm_dark_mail_mittens, itm_5warhorse_holy, itm_sword_val_4, itm_shield_7, itm_civ_body_m_padded_cloth_3, itm_civ_foot_cavalry_boots_black], 
attrlev(29,24,28,18,45), wpex(370,350,350,300,300,300), strsk(7,7,6,6)|agisk(7,5,4,7,0)|lordsk1(7,0,4,2,5,2,3,6)|lordsk2(5,5,5,6,5,5,3,3), 0x000000047810c00f48ef4a36dd753b2500000000001cb7700000000000000000], #old Bur'Aled    #stern
["knight_6_18", "Hakkon Ambrosios", "Ambrosios", tf_hero, 0, reserved, fac_kingdom_6, [(itm_wei_xiadi_cataphract_armor, imod_lordly), (itm_corintiah_helmet_steel, imod_reinforced), (itm_imperial_boots_male, imod_lordly), itm_scale_gauntlets, itm_2imperial_warhorse, itm_lui_empirewarhammerb, itm_hermitage_shield_1, itm_spak_crsb01, itm_akbolt_b, itm_civ_body_padded_armor_4, itm_civ_foot_rich_boots_black], 
attrlev(31,25,19,22,46), wpex(400,400,350,200,350,300), strsk(9,8,6,6)|agisk(8,7,6,8,4)|lordsk1(5,0,6,6,5,6,7,5)|lordsk2(2,1,3,2,3,6,6,4), 0x000000027f11310a70dc75b66c91aca500000000001c27530000000000000000], #old Abd'al'Karim    #immortal
["knight_6_19", "Hakkon Herminius", "Herminius", tf_hero, 0, reserved, fac_kingdom_6, [itm_bronze_plate, (itm_winged_helm_new, imod_lordly), itm_bronze_greaves, itm_bronze_gauntlet, itm_falcon_horse, itm_luc_bronze_mace, itm_shield_7, itm_civ_body_m_tabard_3, itm_civ_foot_ankle_boots_1], 
attrlev(25,30,23,25,40), wpex(330,300,300,150,150,150), strsk(6,7,5,5)|agisk(7,4,10,10,9)|lordsk1(1,0,1,3,0,10,5,3)|lordsk2(3,0,2,1,4,2,3,7), 0x00000002c01125d148ef4a36ddd53b2500000000001cb74b0000000000000000], #old Al'Hashem
["knight_6_20", "Hakkon Nikandros", "Nikandros", tf_hero, 0, reserved, fac_kingdom_6, [itm_dorn_sand_snakes_armor, (itm_barbuta2_greekish_bronze, imod_reinforced), (itm_dorn_spearbearer_boots, imod_lordly), itm_dorn_knight_gant, itm_halfcata, itm_lui_knighthammerempire, itm_dec_steel_shield, itm_roman_pilum_1, itm_civ_body_padded_armor_5, itm_civ_foot_plated_boots_1], 
attrlev(30,22,17,19,44), wpex(380,380,360,150,150,400), strsk(9,8,9,7)|agisk(8,7,6,7,8)|lordsk1(8,0,6,2,4,1,3,5)|lordsk2(0,0,4,4,4,8,5,1), 0x00000002f1011495281a8d9ac956b94b00000000001e48910000000000000000], #old Al'Ghazzawy    #victory of a man


#Zann Lords
["knight_7_1", "General Tokugawa", "Tokugawa", tf_hero, 0, reserved, fac_kingdom_7, [(itm_redyoroi, imod_lordly), (itm_helm_tyrk_a_market, imod_lordly), itm_redsuneate, itm_redkote, itm_mongol_heavy_sword, itm_civ_redyoroi, itm_civ_foot_suneate_boots_red], 
attrlev(33,29,23,28,58), wpex(550,550,440,200,80,200), strsk(10,10,7,7)|agisk(10,3,8,3,0)|lordsk1(9,0,9,2,7,1,3,4)|lordsk2(0,0,3,1,5,8,8,1), 0x0000000c3f0090cb359eb2b76495d56a00000000001eb6a10000000000000000], 
["knight_7_2", "General Sung Wo", "Sung Wo", tf_hero, 0, reserved, fac_kingdom_7, [(itm_ghulam_heavy_cavalryman_3, imod_lordly), itm_dorn_immortal_helmet, itm_steel_greaves, itm_dark_mail_mittens, itm_warhorse_sarranid, itm_samurai_sword, itm_plate_covered_round_shield, itm_civ_body_m_aketon_white_1, itm_civ_foot_nomad_boots_1], 
attrlev(29,27,25,26,56), wpex(480,480,440,250,100,250), strsk(8,9,7,7)|agisk(9,5,5,8,4)|lordsk1(8,0,3,6,2,6,6,6)|lordsk2(1,0,2,3,8,6,5,4), 0x00000002f1009503281a8d9ac9b6b54b00000000001ec8ad0000000000000000], 
["knight_7_3", "General Qin Min", "Qin Min", tf_hero, 0, reserved, fac_kingdom_7, [(itm_heavy_lamellar_armor, imod_lordly), itm_dorn_immortal_helmet, (itm_black_greaves, imod_lordly), itm_gauntlets, itm_warhorse_sarranid, itm_luc_hafted_blade_2, itm_shinobi_bite_throw, itm_civ_foot_rich_boots_black], 
attrlev(27,31,27,26,56), wpex(400,400,520,220,100,520), strsk(7,9,9,7)|agisk(9,0,4,9,10)|lordsk1(6,2,5,3,4,2,5,7)|lordsk2(5,3,5,6,9,6,5,7), 0x0000000dbf0093d216de3b375c89477200000000001eb65c0000000000000000], 
["knight_7_4", "General Hiero ", "Hiero", tf_hero, 0, reserved, fac_kingdom_7, [(itm_yoroi, imod_reinforced), (itm_kabuto, imod_lordly), itm_shadow_greaves, itm_kote, itm_two_handed_katana, itm_civ_body_m_nomad_lam_black, itm_civ_foot_rich_boots_black], 
attrlev(30,24,20,25,50), wpex(450,450,350,160,80,280), strsk(9,8,6,6)|agisk(9,3,8,3,0)|lordsk1(2,0,6,1,4,1,3,4)|lordsk2(2,0,3,2,4,7,5,1), 0x00000006f200900416de7ab75c69b56200000000001eb68b0000000000000000], 
["knight_7_5", "General Chinghis", "Chinghis", tf_hero, 0, reserved, fac_kingdom_7, [(itm_dorn_immortal_armor, imod_lordly), (itm_kabuto, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_kote, itm_warhorse_sarranid, itm_luc_hafted_blade_2, itm_giap_viet3, itm_civ_foot_ankle_boots_brown], 
attrlev(33,30,21,30,58), wpex(500,500,550,160,70,300), strsk(10,10,7,7)|agisk(10,4,6,9,0)|lordsk1(7,0,9,2,8,1,4,4)|lordsk2(1,0,3,6,7,9,9,2), 0x0000000bbc0091ca16de7ab75c69356a00000000001eb6b70000000000000000], 
["knight_7_6", "General Yuan", "Yuan", tf_hero, 0, reserved, fac_kingdom_7, [(itm_ghulam_heavy_cavalryman_3, imod_lordly), (itm_helm_tyrk_a_market, imod_lordly), itm_splinted_leather_greaves, itm_gondor_bracer_l, itm_halfj1, itm_bogmir_yumi_striped, itm_samurai_arrow_a, itm_samurai_arrow_a, itm_giap_viet4, itm_civ_foot_suneate_boots_black], 
attrlev(26,28,26,25,55), wpex(380,380,450,520,180,180), strsk(7,8,7,10)|agisk(10,2,7,4,6)|lordsk1(3,8,5,5,4,4,8,6)|lordsk2(4,1,3,7,8,6,6,4), 0x0000000a2e00910666b76edd5cd1ab6e00000000001de9130000000000000000], 
["knight_7_7", "General Atila", "Atila", tf_hero, 0, reserved, fac_kingdom_7, [(itm_dorn_immortal_armor, imod_lordly), (itm_asmoday_helmet2, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_scale_gauntlets, itm_warhorse_sarranid_black, itm_mongol_heavy_sword, itm_sh_snake, itm_arabian_armor_b, itm_civ_foot_rich_boots_black], 
attrlev(35,26,20,25,58), wpex(520,520,450,220,100,300), strsk(10,10,8,7)|agisk(10,8,6,8,0)|lordsk1(10,0,9,4,7,1,3,6)|lordsk2(1,0,1,5,9,10,9,0), 0x0000000a7d1095c5286395ab593136f500000000001dc4b00000000000000000], 
["knight_7_8","General Onishi","Onishi", tf_hero,0,0,fac_kingdom_7, [(itm_redyoroi, imod_lordly), (itm_redkabuto, imod_lordly), (itm_redkote, imod_reinforced), (itm_redsuneate, imod_reinforced), itm_two_handed_katana, itm_longest_bow_2, itm_samurai_arrow_a, itm_samurai_arrow_a, itm_civ_giap_viet1_d, itm_civ_foot_suneate_boots_red], 
attrlev(32,29,20,25,58), wpex(450,500,450,500,200,400), strsk(10,10,9,10)|agisk(10,7,9,5,8)|lordsk1(6,8,8,5,7,7,8,6)|lordsk2(2,1,3,9,6,6,7,6), 0x000000000e00959236db6db6db6db6db00000000001db6db0000000000000000], 
["knight_7_9", "General Yachamoci ", "Yachamoci", tf_hero, 0, reserved, fac_kingdom_7, [(itm_yoroi, imod_lordly), (itm_kabuto, imod_lordly), (itm_suneate, imod_lordly), itm_kote, itm_mongol_heavy_sword, itm_civ_blackyoroi, itm_civ_foot_suneate_boots_black], 
attrlev(42,28,21,30,56), wpex(465,465,465,300,200,400), strsk(10,10,9,9)|agisk(9,8,9,6,0)|lordsk1(6,1,7,3,5,3,4,4)|lordsk2(0,0,3,5,4,9,7,5), 0x000000067d0090c3281a899ac956b94b00000000001dc8910000000000000000], 


#Realm of the Falcon Lords 
["knight_8_1", "Eorl Lucarion", "Lucarion", tf_hero, 0, reserved, fac_kingdom_8, [(itm_west_guardsman_heavy_2, imod_reinforced), (itm_pigface_new, imod_lordly), (itm_wp_boots_light, imod_lordly), itm_plate_mittens, itm_wlong24, itm_luc_flanged_mace_iron, itm_gondor_shield_b, itm_lance_1, itm_civ_fountain_guard_armor, itm_civ_foot_ornate_boots_1], 
attrlev(33,24,36,32,58), wpex(520,520,550,300,300,300), strsk(10,10,8,8)|agisk(10,9,4,10,4)|lordsk1(0,2,7,2,7,2,3,6)|lordsk2(8,7,8,5,9,6,8,7), 0x00000008db0d000529538d9b632e296400000000001d96c90000000000000000], 
["knight_8_2","Lady Kathryn","Kathryn",tf_hero|tf_female,0,reserved, fac_kingdom_8, [(itm_early_transitional_pearl, imod_reinforced), (itm_luc_knight_helm, imod_reinforced), (itm_dorn_knight_boots, imod_reinforced), itm_falconian_warhorse, itm_cwe_king_gloves, itm_luc_spiked_mace_5p, itm_steel_shield_kite, itm_guizugong, itm_yinjian, itm_new_dress_f, itm_civ_foot_rich_boots_black], 
attrlev(24,28,26,30,48), wpex(360,360,300,400,400,300), strsk(7,7,6,8)|agisk(8,7,6,9,9)|lordsk1(0,7,3,5,6,7,7,6)|lordsk2(8,7,8,3,7,4,4,8), 0x000000067d00300b759bb226a652c57500000000000000000000000000000000], 
["knight_8_3", "Eorl Diendarion", "Diendarion", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_8, [(itm_armor_master_order_tevton, imod_lordly), (itm_winged_helmet, imod_lordly), (itm_plate_boots2, imod_lordly), itm_gondor_bracer_l, itm_falcon_horse, itm_sabre_whiteleather, itm_dal_hindub, itm_guizugong, itm_yinjian, itm_knight_armor_templar_a, itm_civ_foot_mail_boots_1], 
attrlev(30,30,40,34,58), wpex(540,540,500,630,300,300), strsk(9,8,7,10)|agisk(10,8,5,10,10)|lordsk1(1,10,9,10,8,10,10,6)|lordsk2(7,4,6,2,10,8,10,7), 0x0000000fea00000556da5758892cc4e400000000001e42ec0000000000000000], 
["knight_8_4", "Eorl Filotabien", "Filotabien", tf_elven_male|tf_hero, 0, reserved, fac_kingdom_8, [(itm_citadel_guard_armor, imod_reinforced), (itm_fountain_guard_helmet_mask, imod_lordly), (itm_twilight_boots, imod_lordly), itm_gondor_bracer_l, itm_twilight_horse, itm_courtblades_ebony, itm_gondor_shield_d, itm_ranger_bow, itm_blackarrow, itm_courtly_outfit, itm_civ_foot_ankle_boots_1], 
attrlev(32,32,31,30,56), wpex(500,450,450,500,300,300), strsk(9,9,7,10)|agisk(10,8,8,10,10)|lordsk1(1,9,6,8,6,8,10,6)|lordsk2(5,4,5,4,8,8,8,7), 0x0000000d4900200570dc75b66c91aca500000000001ca7530000000000000000], 
["knight_8_5", "Eorl Dracarion", "Dracarion", tf_hero, 0, reserved, fac_kingdom_8, [(itm_maximilian_armou_silver, imod_reinforced), (itm_citadel_guard_helmet, imod_lordly), (itm_plate_boots2, imod_lordly), itm_plate_mittens, itm_plated_charger7, itm_sw_pear_mace_steel, itm_gondor_shield_c, itm_civ_early_transitional_pearl, itm_civ_foot_mail_boots_1], 
attrlev(33,25,32,30,56), wpex(530,530,530,350,350,350), strsk(10,10,8,8)|agisk(10,9,4,10,0)|lordsk1(2,0,8,2,8,1,2,5)|lordsk2(3,2,5,8,7,9,8,3), 0x000000080500209835134e575149bb2300000000001da6ab0000000000000000], 


#Valahir Lords
["knight_9_1", "Aethling Ragir", "Ragir", tf_hero, 0,reserved, fac_kingdom_9, [(itm_dejawolf_vikingbyrnie, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), (itm_splinted_leather_greaves, imod_lordly), (itm_glovesblack, imod_lordly), itm_lui_baronaxeoneh, itm_tab_shield_round_d, itm_imperial_bow, itm_scull_arrow, itm_civ_body_m_leather_vest_1, itm_civ_foot_plated_boots_1], 
attrlev(32,24,20,26,54), wpex(450,380,380,450,200,400), strsk(10,9,9,10)|agisk(9,8,7,2,0)|lordsk1(3,8,8,8,3,9,8,5)|lordsk2(2,0,2,1,7,8,7,6), 0x00000006f210520623dd715b0d6e445e00000000001db9040000000000000000], 
["knight_9_2", "Aethling Kunthr", "Kunthr", tf_hero, 0, reserved, fac_kingdom_9, [(itm_brig_plate_black, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), (itm_west_pikeman_boots, imod_lordly), (itm_plate_mittens, imod_lordly), itm_ak_warhorse_chain_c, itm_luc_spiked_war_club, itm_ad_viking_shield_round_14, itm_civ_body_m_fur_vest_1, itm_civ_foot_plated_boots_1], 
attrlev(33,23,19,28,56), wpex(460,460,460,120,120,240), strsk(10,10,9,8)|agisk(9,8,4,8,4)|lordsk1(9,0,7,4,5,3,3,7)|lordsk2(0,0,2,3,8,10,6,6), 0x00000009c80863531cac36bc8b6e2a8800000000001de55d0000000000000000], 
["knight_9_3", "Aethling Guntar", "Guntar", tf_hero, 0, reserved, fac_kingdom_9, [(itm_maximilian_armour_1, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), (itm_dorn_spearbearer_boots, imod_lordly), (itm_blackplatemitty, imod_lordly), itm_luc_great_long_axe, itm_civ_body_m_pino_leather_fur_2, itm_civ_foot_leather_boots_1], 
attrlev(37,28,18,30,55), wpex(500,500,500,250,250,250), strsk(10,10,8,8)|agisk(10,6,8,2,0)|lordsk1(8,0,9,3,6,2,3,4)|lordsk2(1,0,3,2,7,10,9,1), 0x0000000b720c42c93a5b921ac22db8e200000000001cca5b0000000000000000], 
["knight_9_4","Aethling Uldin","Uldin", tf_hero, 0,reserved, fac_kingdom_9, [(itm_kuyak_b, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), (itm_splinted_greaves, imod_lordly), (itm_beargauntlets, imod_lordly), itm_long_axe_c_alt, itm_throwing_spears, itm_throwing_spears, itm_tribal_warrior_outfit, itm_boot_average_crusader_c], 
attrlev(32,17,12,20,40), wpex(300,400,200,200,100,300), strsk(9,10,10,8)|agisk(8,2,7,1,0)|lordsk1(8,2,5,1,1,3,4,2)|lordsk2(0,0,3,0,1,6,4,1), 0x000000026701031138ca75b75b563b6500000000001d37150000000000000000], 
["knight_9_5", "Aethling Onund", "Onund", tf_hero, 0, reserved, fac_kingdom_9, [(itm_plate_armor, imod_lordly), (itm_dejawolf_valgarde_helm, imod_lordly), (itm_plate_boots, imod_lordly), itm_dorn_knight_gant, itm_ak_warhorse_chain_c, itm_great_axe, itm_ad_viking_shield_round_12, itm_heavy_throwing_axes, itm_civ_huscarl_armour_dark, itm_civ_foot_plated_boots_2], 
attrlev(34,25,21,26,55), wpex(500,500,450,220,130,500), strsk(10,9,10,7)|agisk(10,7,5,7,9)|lordsk1(8,0,8,2,3,2,3,5)|lordsk2(0,0,2,7,8,8,8,0), 0x00000004ef00558539233512e284b91d00000000001db7200000000000000000], 
["knight_9_6", "Aethling Sigmundr", "Sigmundr", tf_hero, 0, reserved, fac_kingdom_9, [(itm_plate_etched, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), itm_splinted_leather_greaves, itm_gauntlets_arabs_a_l, itm_varangian_axe, itm_imperial_bow_1, itm_1steel_arrow, itm_1steel_arrow, itm_civ_body_m_fur_coat_1, itm_civ_foot_leather_boots_2], 
attrlev(33,21,22,28,58), wpex(480,500,480,500,200,350), strsk(9,9,8,10)|agisk(10,4,4,0,0)|lordsk1(4,7,8,5,4,5,5,6)|lordsk2(3,0,3,3,9,8,9,4), 0x0000000b8400020024936cc51cb5bb2500000000001dd4d90000000000000000], 
["knight_9_7", "Aethling Svafar", "Svafar", tf_hero, 0, reserved, fac_kingdom_9, [(itm_huscarl_armour_dark, imod_lordly), (itm_dejawolf_valgarde_helm, imod_lordly), itm_splinted_leather_greaves, itm_dorn_knight_gant, itm_taleworlds_doubleaxe, itm_throwing_spears, itm_civ_body_m_gamb_grey, itm_civ_foot_rich_boots_black], 
attrlev(39,22,16,29,58), wpex(510,550,510,180,100,550), strsk(10,10,10,8)|agisk(10,4,7,0,0)|lordsk1(10,0,9,2,1,1,3,5)|lordsk2(0,0,2,0,5,10,8,0), 0x0000000cb90052d139233512e287391d00000000001db7200000000000000000], 
["knight_9_8", "Aethling Thorbjorn", "Thorbjorn", tf_hero, 0, reserved, fac_kingdom_9, [(itm_banded_armor_common, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), itm_splinted_leather_greaves, itm_dorn_knight_gant, itm_viking_sword_a, itm_tab_shield_round_e, itm_heavy_throwing_axes, itm_civ_body_m_pino_leather_fur_1, itm_civ_foot_leather_boots_2], 
attrlev(28,23,25,23,48), wpex(430,400,400,200,160,450), strsk(8,8,9,6)|agisk(8,8,6,5,0)|lordsk1(5,0,4,5,6,4,4,6)|lordsk2(5,2,5,7,6,6,5,5), 0x00000008740041452cb6aa36ea50a6e500000000001dc55c0000000000000000], 
["knight_9_9", "Aethling Gudrodar", "Gudrodar", tf_hero, 0, reserved, fac_kingdom_9, [(itm_plate_armor, imod_lordly), (itm_nordic_warlord_helmet, imod_lordly), itm_plate_boots, itm_dorn_knight_gant, itm_tamed_black_wolf, itm_gothic_battle_axe_no1, itm_tab_shield_round_d, itm_civ_body_m_rawhide_coat_1, itm_civ_foot_plated_boots_1], 
attrlev(34,20,17,26,52), wpex(480,480,450,160,100,360), strsk(10,10,8,7)|agisk(9,9,6,8,0)|lordsk1(6,0,8,5,3,5,4,4)|lordsk2(0,0,2,1,6,8,8,1), 0x00000007ab00524a281a8d9ac956b94b00000000001ec8910000000000000000], 
["knight_9_10", "Aethling Siguard", "Siguard", tf_hero, 0, reserved, fac_kingdom_9, [itm_maximilian_armour, (itm_2kettle_hat_new, imod_reinforced), itm_iron_greaves, itm_plate_mittens, itm_luc_knightly_axe_one_handed_b, itm_ad_viking_shield_round_14, itm_rohirrim_throwing_axe, itm_civ_caped_byrnie, itm_civ_foot_plated_boots_1], 
attrlev(35,23,19,27,50), wpex(460,460,400,170,100,500), strsk(9,9,9,7)|agisk(9,8,5,3,0)|lordsk1(6,0,8,2,5,2,2,4)|lordsk2(0,0,1,2,5,7,5,1), 0x00000001d801024639233512e286391d00000000001db7240000000000000000], 


#The Kaikoth Confederation Lords
["knight_10_1", "Drgrimst Durzad", "Durzad", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_dwarven_scalemail, imod_lordly), (itm_dwarf_helm_h, imod_lordly), (itm_west_pikeman_boots, imod_lordly), itm_glovesblack, itm_arhar_armor_2, itm_dwarf_er_th_axe_1, itm_civ_kaikoth_armor_4, itm_civ_foot_west_pikeman_boots], 
attrlev(50,22,21,25,56), wpex(500,500,450,250,300,300), strsk(11,12,10,8)|agisk(10,7,6,9,0)|lordsk1(7,0,8,2,6,2,4,9)|lordsk2(0,0,0,9,6,9,6,8), 0x0000000aff0091cb39518a19226f652400000000001da93c0000000000000000], 
["knight_10_2", "Drgrimst Morrund", "Morrund", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_dwarf_armor_9a, imod_lordly), (itm_dwarf_helm_o, imod_lordly), (itm_dorn_knight_boots, imod_lordly), itm_gauntlets_arabs_b_l, itm_arhar_armor_2, itm_sword_val_3, itm_dwarf_shield_c, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt, itm_civ_kaikoth_armor_2, itm_civ_foot_ornate_boots_1], 
attrlev(43,23,26,28,55), wpex(440,440,400,300,440,300), strsk(10,10,8,8)|agisk(9,7,4,9,9)|lordsk1(5,4,4,5,5,4,6,10)|lordsk2(0,0,1,3,10,7,5,10), 0x0000000aaa0022c30ae492185de2d92200000000001c40ad0000000000000000], 
["knight_10_3","Dama Ramayana","Ramayana",tf_hero|tf_dwarf_female,0,reserved,fac_kingdom_10, [(itm_j_surcoat_orn_13a, imod_lordly), (itm_barbuta1, imod_lordly), (itm_mail_boots, imod_lordly), (itm_gauntlets_arabs_a_l, imod_lordly), itm_dwarf_sword_green, itm_dwarf_shield_4c, itm_dwarf_horn_bow, itm_1steel_arrow, itm_civ_byrnie_a_new, itm_leather_boots_dark], 
attrlev(30,30,21,20,46), wpex(350,250,250,400,350,250), strsk(7,8,7,9)|agisk(8,6,5,5,6)|lordsk1(3,5,3,5,4,4,7,8)|lordsk2(2,0,3,2,7,5,3,8), 0x00000001b1101086321d654cadb0bb4c00000000001ee8990000000000000000], 
["knight_10_4", "Drgrimst Gomur", "Gomur", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_dwarf_armor_5_a, imod_lordly), (itm_inf_t4, imod_lordly), (itm_west_pikeman_boots, imod_lordly), itm_dorn_knight_gant, itm_arhar_armor_2, itm_dwarf_war_mattok_1, itm_dwarf_shield_c, itm_heavy_throwing_axes, itm_civ_foot_west_pikeman_boots], 
attrlev(48,22,20,26,56), wpex(500,500,500,240,240,500), strsk(11,11,9,7)|agisk(10,8,5,10,9)|lordsk1(8,0,7,1,4,1,2,8)|lordsk2(0,0,0,6,7,8,7,8), 0x0000000bbf0050ca06eca9655ab24ed300000000001ea6a90000000000000000], 
["knight_10_5", "Drgrimst Sargoll", "Sargoll", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_dwarf_armor_9a, imod_lordly), (itm_dwarf_helm_n, imod_lordly), (itm_plate_boots2, imod_lordly), itm_dwarf_glove, itm_arhar_armor_2, (itm_dwarf_axe_3, imod_masterwork), itm_dwarf_ih_shield_1c, itm_sniper_crossbow, itm_akbolt_b, itm_dwarf_civilian_2_red, itm_rus_cav_boots], 
attrlev(43,27,24,26,58), wpex(460,460,400,330,460,250), strsk(10,10,8,8)|agisk(9,5,5,9,6)|lordsk1(4,7,6,8,5,8,9,8)|lordsk2(0,0,0,5,9,10,6,9), 0x0000000a5604d14b465d8958ea74a6ec00000000001d52660000000000000000], 
["knight_10_6", "Drgrimst Calrak", "Calrak", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [(itm_dwarf_scalemail, imod_reinforced), (itm_dwarf_helm_f, imod_reinforced), (itm_west_pikeman_boots, imod_reinforced), (itm_mail_mittens, imod_reinforced), itm_arhar_1, (itm_dwarf_pickaxe, imod_masterwork), itm_dwarf_shield_i, itm_luc_throwing_hammer, itm_luc_throwing_hammer, itm_dwarf_armor_4_c, itm_civ_foot_mail_boots_1], 
attrlev(47,20,18,27,54), wpex(420,420,420,200,200,420), strsk(11,13,11,8)|agisk(8,5,7,6,8)|lordsk1(2,0,4,0,2,3,7,10)|lordsk2(0,0,0,9,7,5,6,9), 0x00000008b300310d27ac8aa999fca6fc00000000001dd6950000000000000000], 
["knight_10_7", "Drgrimst Vohgold", "Vohgold", tf_hero|tf_dwarf_male, 0, reserved, fac_kingdom_10, [itm_dwarf_armor_9b, (itm_dwarf_helm_f, imod_lordly), (itm_steel_greaves, imod_lordly), itm_gauntlets_arabs_b_l, itm_arhar_armor_2, itm_sungodaxe, itm_dwarf_shield_4c, itm_lance_lev5, itm_civ_kaikoth_armor_2, itm_civ_foot_mail_boots_1], 
attrlev(44,19,30,32,58), wpex(450,450,450,330,330,400), strsk(10,10,7,7)|agisk(9,8,2,10,4)|lordsk1(1,0,7,2,6,3,3,10)|lordsk2(3,0,3,10,9,6,9,10), 0x0000000fff00404c3add55d2dab4ad2200000000001e254b0000000000000000], 
["knight_10_8","Dama Jala","Jala",tf_hero|tf_dwarf_female,0,reserved, fac_kingdom_10, [itm_west_guardsman_dark, (itm_bolzanobucket, imod_lordly), (itm_west_pikeman_boots_dark, imod_lordly), itm_dark_mail_mittens, itm_arhar_armor_2, itm_dwarf_war_mattok_1, itm_dwarf_ih_shield_1c, itm_civ_mail_black, itm_civ_foot_rich_boots_black], 
attrlev(34,26,28,18,50), wpex(400,400,300,100,300,350), strsk(8,10,9,7)|agisk(9,7,3,8,7)|lordsk1(6,0,6,2,5,1,3,7)|lordsk2(0,0,1,5,5,9,4,6), 0x0000000cff10518f321d654c6db0bb6d00000000001ee8a80000000000000000],


#Geldarin Lords
["knight_11_1", "Geldarin Lord Oroe", "Oroe", tf_hero|tf_elven_male, 0, reserved, fac_kingdom_11, [(itm_riv_armor_leader, imod_lordly), itm_royal_ench, itm_twilight_boots, itm_hourglass_gauntlets_ornate, itm_blue_warhorse, itm_sabre_ebony, itm_saracin_shield_d, itm_arab_bandit_c, itm_lorien_boots], 
attrlev(32,25,34,29,56), wpex(520,480,480,450,150,150), strsk(10,10,8,9)|agisk(10,7,7,9,10)|lordsk1(6,9,6,10,5,9,9,5)|lordsk2(5,3,5,4,8,8,8,2), 0x00000002a40060021b54759a5c5a4ba100000000001da8a40000000000000000], 
["knight_11_2", "Geldarin Lady Tamaris", "Tamaris", tf_elven_female|tf_hero, 0,0, fac_kingdom_11, [(itm_rivend_rohir_armor_1a, imod_reinforced), itm_royal_ench, (itm_riv_boots, imod_reinforced), (itm_gondor_bracer_l, imod_reinforced), itm_twilight_horse, itm_sabre_val_1, itm_rivend_shield_1, itm_ebonybow, itm_blackarrow, itm_green_dress, itm_lorien_boots], 
attrlev(28,30,25,27,54), wpex(450,450,400,500,200,180), strsk(8,9,7,10)|agisk(10,5,6,8,10)|lordsk1(5,8,4,9,4,7,8,5)|lordsk2(5,3,4,1,10,4,8,6), 0x00000001b40800091888ec34e2add72a0000000000e1a9610000000000000000], 
["knight_11_3","Geldarin Lord Kalrind","Kalrind",tf_elven_male|tf_hero, 0, 0, fac_kingdom_11, [(itm_rivendellrewardarmour, imod_lordly), itm_royal_ench, (itm_riv_boots, imod_lordly), (itm_gondor_bracer_l, imod_reinforced), itm_blue_warhorse, itm_elvish_sword, itm_saracin_shield_d, itm_skywoodbow, itm_blackarrow, itm_civ_elven_armor_6], 
attrlev(35,30,24,28,58), wpex(500,500,500,500,150,150), strsk(10,10,7,10)|agisk(10,9,6,9,9)|lordsk1(10,8,8,9,5,7,8,4)|lordsk2(2,0,4,1,5,9,7,1), 0x0000000c3f00204134db6db6db6db6db00000000001db6eb0000000000000000], 


#Cretasan Lords
["knight_12_1", "Knyaz Kafak", "Kafak", tf_hero, 0, reserved, fac_kingdom_12, [(itm_early_transitional_pearl, imod_reinforced), (itm_cretas_full_helm, imod_lordly), itm_plate_boots2, itm_bnw_gauntlets, itm_wlong22, itm_sarranid_mace_1, itm_dal_muslimf, itm_waorstaffb, itm_civ_body_m_nomad_lam_white, itm_civ_foot_cavalry_boots_1], 
attrlev(29,22,26,25,50), wpex(420,350,450,250,250,250), strsk(8,8,7,7)|agisk(9,6,6,8,5)|lordsk1(3,0,6,4,6,4,4,6)|lordsk2(4,4,4,6,7,7,6,6), 0x00000007040125454b9b754a92adace400000000001ec0e30000000000000000], 
["knight_12_2","Nodah","Nodah",tf_hero, 0, reserved, fac_kingdom_12, [(itm_armor_19, imod_lordly), itm_crusader_hard_helm_d, (itm_iron_greaves_a, imod_lordly), (itm_scale_gauntlets, imod_lordly), itm_golden_deer, itm_german_horsemans_axe_no1, itm_saracin_shield_g, itm_hangong, itm_spak_bow6_arrow, itm_civ_foot_plated_boots_2], 
attrlev(27,23,17,17,44), wpex(420,420,400,420,150,200), strsk(8,9,6,9)|agisk(9,7,6,9,9)|lordsk1(7,7,4,6,3,6,7,4)|lordsk2(2,0,2,0,4,5,4,4), 0x000000003b0020c546da6db6dbadd0dc00000000001db6cb0000000000000000], 
["knight_12_3", "Knyaz Bullius", "Bullius", tf_hero, 0, reserved, fac_kingdom_12, [(itm_tarth_armor, imod_reinforced), (itm_guard_knight_helm, imod_lordly), itm_bronzeshynald, itm_lamellar_gauntlets, itm_cow_mod_a, itm_greathammer_no1, itm_shield_8, itm_civ_body_m_coarse_tunic_1], 
attrlev(29,33,22,24,55), wpex(460,400,400,500,150,250), strsk(9,9,8,10)|agisk(9,7,6,10,10)|lordsk1(7,8,4,7,4,7,8,5)|lordsk2(2,0,3,0,10,7,7,6), 0x000000061c10308e70dc75b66c91aca500000000001c27530000000000000000], 


#Kuu-lan Lords
["knight_13_1", "Atabek Aksakal", "Aksakal", tf_hero, 0, reserved, fac_kingdom_13, [(itm_khergit_guard_armor, imod_lordly), (itm_helm_tyrk_heavi_b, imod_lordly), (itm_bronzeshynald, imod_lordly), itm_brass_scale_gauntlets, itm_warhorse_sarranid_brass, itm_warblade_ivorygold, itm_dal_muslimj, itm_imperial_bow, itm_blackarrow, itm_civ_foot_hide_boots_1, itm_cwe_king_gloves], 
attrlev(30,26,28,32,58), wpex(480,400,400,480,150,400), strsk(7,8,7,9)|agisk(9,6,2,10,10)|lordsk1(4,8,4,7,4,8,6,8)|lordsk2(5,2,5,5,10,7,8,9), 0x0000000fc000834056dd65a8dc2eaaeb00000000001e22d30000000000000000], 
["knight_13_2", "Atabek Karasakal", "Karasakal", tf_hero, 0, reserved, fac_kingdom_13, [(itm_vaegir_elite_armor, imod_lordly), (itm_helm_tyrk_heavi_b, imod_lordly), (itm_steel_greaves, imod_lordly), itm_hourglass_gauntlets_ornate, itm_ak_warhorse_chain_a, itm_luc_sarranid_falchion, itm_dal_hinduh, itm_heavy_lance, itm_civ_body_padded_armor_6, itm_civ_foot_leather_boots_2], 
attrlev(31,30,19,26,56), wpex(450,500,500,340,100,340), strsk(9,10,9,9)|agisk(9,6,5,10,6)|lordsk1(7,3,7,5,5,6,7,6)|lordsk2(1,0,2,5,8,8,8,4), 0x000000073400810a395c2fb69ca92df400000000001db7190000000000000000], 
["knight_13_3", "Akin Bey", "Akin", tf_hero, 0, reserved, fac_kingdom_13, [(itm_wei_xiadi_sarranid_mamluk_armor, imod_reinforced), (itm_helm_tyrk_heavi_b, imod_reinforced), (itm_shadow_greaves, imod_lordly), itm_gondor_bracer_l, itm_hospitaller_knight_horse_a, itm_scimitar_b, itm_leather_covered_round_shield, itm_tulgan_bow_kuulan, itm_blackarrow, itm_civ_foot_rich_boots_black], 
attrlev(24,28,16,21,46), wpex(340,300,300,380,110,280), strsk(6,6,5,8)|agisk(7,4,5,8,9)|lordsk1(9,7,3,7,1,7,7,4)|lordsk2(0,0,1,1,5,6,4,4), 0x00000005c000800635233512e246251c00000000001db6a20000000000000000], 
["knight_13_4","Kengesh Oglan","Kengesh",tf_hero, 0, reserved, fac_kingdom_13, [(itm_khergit_elite_armor, imod_lordly), itm_helm_tyrk_heavi_b, (itm_boot_average_crusader_b, imod_lordly), (itm_gauntlets_arabs_a_l, imod_lordly), itm_horse5, itm_sword_khergit_1, itm_dal_muslimj, itm_hangong, itm_elmwoodquiver_arrow, itm_ao_vai_1, itm_leather_boots_dark], 
attrlev(23,27,18,20,45), wpex(300,200,200,400,80,350), strsk(5,6,6,8)|agisk(7,5,7,9,8)|lordsk1(2,7,2,6,1,7,7,4)|lordsk2(3,0,2,1,5,3,4,6), 0x000000003608800867132aa6a94da51900000000001da90a0000000000000000], 


#Bakhal Lords
["knight_14_1", "Ofugr Skirn", "Skirn", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_14, [(itm_elite_marauder_armor2, imod_reinforced), (itm_bakhal_guard_helmet, imod_reinforced), itm_giant_leather_boots, itm_giant_gloves_plus1, itm_crowbill_marauder_01, itm_bakhal_elite_shield, itm_giant_archer_armor_bakhal, itm_giant_gr_boots_knee_01], 
attrlev(78,19,12,14,58), wpex(500,500,400,200,100,200), strsk(14,14,11,10)|agisk(10,8,9,0,0)|lordsk1(9,0,9,1,2,0,1,3)|lordsk2(0,0,0,2,3,10,8,0), 0x0000000afd0472c96591e936eccaeaad00000000001e9a030000000000000000], 
["knight_14_2", "Ofugr Lokidon", "Lokidon", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_14, [(itm_armor_elite_berserker_a_01, imod_reinforced), (itm_giant_honor_helmet, imod_reinforced), itm_giant_warrior_boots, itm_giant_greatsword, itm_skeleton_archer_bow, itm_scull_arrow, itm_scull_arrow, itm_armor_marauder_recruit_c_01, itm_giant_grey_boots], 
attrlev(54,25,14,12,54), wpex(400,400,400,400,120,120), strsk(13,13,10,13)|agisk(9,3,10,0,0)|lordsk1(9,6,4,5,1,5,6,4)|lordsk2(0,0,0,0,4,8,3,3), 0x000000093a04124138d68db754ba42cb00000000001e59d30000000000000000], 
["knight_14_3", "Ofugr Vanigos", "Vanigos", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_14, [(itm_giant_warrior_armor_bakhal, imod_reinforced), (itm_giant_horned_skull_helmet_bakhal, imod_reinforced), itm_giant_warrior_boots, itm_giant_gloves_plus1, itm_axe_weathered_berserker_b_01, itm_armor_marauder_recruit_a_01, itm_giant_gr_boots_knee_01], 
attrlev(83,20,13,16,58), wpex(520,520,500,160,80,220), strsk(15,12,9,9)|agisk(10,5,10,0,0)|lordsk1(10,0,8,5,1,1,3,4)|lordsk2(0,0,0,0,6,10,7,0), 0x0000000a7408330417d38a2943adb95200000000001eb7160000000000000000], 


#Sut Lords
["knight_15_1", "Chieftain Fegros", "Fegros", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_15, [(itm_giant_guardsman_armor_sut, imod_reinforced), (itm_giant_noble_helmet, imod_reinforced), (itm_giant_plated_boots_war, imod_reinforced), (itm_giant_gloves_plus, imod_lordly), itm_sut_slasher_02, itm_sut_elite_shield, itm_skeleton_archer_bow, itm_bronze_arrow, itm_giant_brown_boots], 
attrlev(52,22,15,17,50), wpex(375,375,350,375,100,280), strsk(10,10,9,10)|agisk(8,7,9,5,0)|lordsk1(5,6,5,6,2,5,5,4)|lordsk2(0,0,0,1,3,6,4,3), 0x00000004480040c736db6db6db6db6db00000000001db6db0000000000000000], 
["knight_15_2", "Chieftain Trenoz", "Trenoz", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_15, [(itm_giant_guardsman_armor_sut_2, imod_reinforced), (itm_giant_bers_helmet, imod_reinforced), (itm_giant_plated_boots_sharp, imod_reinforced), itm_giant_gloves_plus, itm_horny_charger_plate, itm_giant_axe_01, itm_sut_elite_shield, itm_civ_sut_armor_1, itm_giant_brown_boots], 
attrlev(73,21,15,16,58), wpex(470,470,380,120,120,240), strsk(14,14,10,10)|agisk(10,7,9,9,0)|lordsk1(9,0,9,3,2,0,3,4)|lordsk2(0,0,0,4,8,10,8,1), 0x0000000aff0040836764ca7d2d92289200000000001dd0de0000000000000000], 
["knight_15_3", "Chieftain Grolok", "Grolok", tf_giant_male|tf_hero, 0, reserved, fac_kingdom_15, [(itm_giant_guardsman_armor_sut_2, imod_reinforced), (itm_giant_warlord_helmet, imod_reinforced), itm_giant_furred_boots_1, itm_giant_gloves_plus, itm_axe_berserker_a_01, itm_luc_throwing_hammer, itm_giant_guard_armor_sut, itm_giant_brown_boots], 
attrlev(68,19,16,16,56), wpex(440,440,360,180,120,440), strsk(13,13,13,10)|agisk(10,6,10,5,0)|lordsk1(9,0,7,3,3,0,3,4)|lordsk2(0,0,0,0,5,10,6,3), 0x0000000a7f00604836db6db6db6db75c00000000001db6db0000000000000000], 


#Aroulo Lords
["knight_16_1", "Chief Ahomana", "Ahomana", tf_hero, 0, reserved, fac_kingdom_16, [(itm_armour_braided, imod_lordly), itm_ranger_helmet_tld, (itm_aroulo_boots, imod_hardened), itm_stonemaul_aroulo, itm_aroulo_throwing_wep, itm_rawhide_coat], 
attrlev(49,27,9,25,58), wpex(550,640,550,200,50,550), strsk(10,10,10,9)|agisk(10,0,10,0,0)|lordsk1(5,2,10,4,2,4,5,4)|lordsk2(0,0,2,0,5,9,9,0), 0x0000000c4008d01046e566c92b69a2de00000000001dbb2a0000000000000000], 
["knight_16_2", "Chief Qochata", "Qochata", tf_hero, 0, reserved, fac_kingdom_16, [(itm_leaf_armour, imod_lordly), (itm_aroulo_boots, imod_hardened), itm_gloves_lord_l, itm_woodman_staff, itm_strong_bow, itm_blackarrow, itm_blackarrow], #old itm_jack_sting
attrlev(34,34,10,22,56), wpex(560,400,400,600,100,400), strsk(9,9,8,10)|agisk(10,0,10,0,0)|lordsk1(6,10,4,9,0,9,10,6)|lordsk2(1,0,1,0,7,6,6,5), 0x00000009c508d0076b9d3b1524b6312300000000001ed8620000000000000000], 
["knight_16_3", "Chief Hahkethomemah", "Hahkethomemah", tf_hero, 0, reserved, fac_kingdom_16, [(itm_armour_braided, imod_lordly), itm_leather_warrior_cap, (itm_aroulo_boots, imod_hardened), itm_gloves_lord_l, itm_bamboo_spear, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep, itm_civ_body_m_fur_vest_1], 
attrlev(35,25,19,30,58), wpex(480,480,550,400,80,600), strsk(9,9,10,8)|agisk(10,0,7,0,0)|lordsk1(3,2,1,5,2,5,4,6)|lordsk2(5,3,5,2,10,5,9,4), 0x0000000fb400d000395c3bbbdcaa4df400000000001db7240000000000000000], 
["knight_16_4", "Chief Togquos", "Togquos", tf_hero, 0, reserved, fac_kingdom_16, [(itm_woodman_chieftain, imod_lordly), (itm_aroulo_boots, imod_hardened), itm_gloves_lord_l, itm_woodman_staff, (itm_gondor_bow, imod_bent), itm_aroulo_arrows], 
attrlev(38,28,11,24,56), wpex(450,400,500,550,110,200), strsk(10,10,8,10)|agisk(10,0,9,1,0)|lordsk1(7,8,5,10,1,7,8,5)|lordsk2(0,0,0,1,8,8,6,6), 0x0000000bef10f00819aa66c95930d4db00000000001e3add0000000000000000], 
["knight_16_5", "Ratu Dohate", "Dohate", tf_hero, 0, reserved, fac_kingdom_16, [(itm_woodman_padded, imod_lordly), itm_aroulo_boots, itm_woodman_staff, itm_hide_covered_round_shield, itm_strong_bow, itm_aroulo_arrows], #old itm_luc_waronehandedaxec
attrlev(32,27,9,17,35), wpex(400,200,400,440,60,300), strsk(7,8,7,8)|agisk(8,3,9,0,0)|lordsk1(3,6,1,7,0,6,7,4)|lordsk2(1,0,0,0,3,5,2,2), 0x000000047510d00546a251dadc8e45ab00000000001e951c0000000000000000], 
["knight_16_6", "Ratu Bagwunagijik", "Bagwunagijik", tf_hero, 0, reserved, fac_kingdom_16, [(itm_bnw_armour2, imod_battered), (itm_h_tribune_bronze_feathered, imod_battered), (itm_riv_boots, imod_battered), (itm_beargauntlets, imod_battered), (itm_epieu_de_guerre_no1, imod_bent), (itm_luc_morningstar_4, imod_chipped), itm_woodman_scout], 
attrlev(38,26,15,19,44), wpex(500,500,500,150,50,150), strsk(10,10,8,8)|agisk(10,1,8,2,0)|lordsk1(9,0,3,2,0,1,4,6)|lordsk2(0,0,0,0,1,6,3,8), 0x00000008cf0cd5ca28cc511cac86ad5600000000001f56530000000000000000], #his weird equipment is supposed to be loot from those unfortunate who were foolish enough to venture into Aroulian territory

#TTL Lords
["knight_17_1", "Legatus Tertius", "Tertius", tf_hero, 0,reserved, fac_kingdom_17, [(itm_gotkn_rom_br_pl_8, imod_reinforced), (itm_roman_helm_preator_dark, imod_lordly), (itm_roman_centurion_boots, imod_lordly), (itm_west_man_at_arms_gl, imod_reinforced), itm_5warhorse_holy, itm_bb_spathion_lotr_1, itm_saracin_shield_l, itm_civ_foot_imperial_boots_m], 
attrlev(35,26,25,26,57), wpex(525,450,450,300,200,400), strsk(10,10,9,7)|agisk(10,10,7,9,7)|lordsk1(5,0,10,5,10,5,7,5)|lordsk2(4,1,6,6,7,9,9,3), 0x000000083f05901124d59a291b91c72300000000001e46a90000000000000000], #third
["knight_17_2", "Legatus Octavius", "Octavius", tf_hero, 0,reserved, fac_kingdom_17, [(itm_west_swordsman, imod_reinforced), (itm_h_tribune4, imod_lordly), (itm_imperial_boots_male, imod_lordly), (itm_west_arbalester_gl, imod_lordly), itm_twilight_horse_got, itm_an_warhammer, itm_roman_shield_cav, itm_spak_crsb01, itm_akbolt_b, itm_civ_foot_imperial_boots_m], 
attrlev(27,24,20,21,50), wpex(400,350,350,250,300,250), strsk(8,7,6,6)|agisk(9,7,7,8,7)|lordsk1(4,4,5,8,5,6,6,5)|lordsk2(2,0,3,3,5,10,5,6), 0x000000045f0105c53acb56a553b0182c00000000001e67110000000000000000], #eight
["knight_17_3", "Legatus Sextus", "Sextus", tf_hero, 0,reserved, fac_kingdom_17, [(itm_a_roman_chain_5, imod_lordly), (itm_h_tribune2, imod_lordly), (itm_roman_centurion_boots, imod_reinforced), (itm_gauntlets_arabs_b_l, imod_lordly), itm_2lamellar_charger, itm_luc_celtic_sword_cwe, itm_saracin_shield_y, itm_civ_foot_cavalry_boots_1, itm_gloves_lord_l], 
attrlev(32,25,26,26,56), wpex(500,460,460,260,160,400), strsk(10,9,8,6)|agisk(10,8,6,10,7)|lordsk1(4,0,8,2,8,2,3,5)|lordsk2(4,1,5,8,7,7,8,4), 0x000000073f096014275491c6ed9539d900000000001fc5620000000000000000], #sixth


#Mercenary Lords
["knight_merc_1","Captain Kara","Kara",tf_female|tf_hero, 0, reserved, fac_commoners, [itm_xenoargh_new_female_armor04, (itm_barbuta1, imod_lordly), (itm_black_greaves, imod_reinforced), itm_gauntlets_arabs_b_l, itm_plated_charger6, itm_cinthorc, itm_tab_shield_kite_cav_b, itm_spak_crsb02, itm_akbolt_b, itm_light_mail_and_plate, itm_civil_rich_boots_a], 
attrlev(20,24,24,26,42), wpex(280,200,200,250,300,100), strsk(5,6,5,5)|agisk(6,4,4,8,8)|lordsk1(2,5,1,2,3,2,3,7)|lordsk2(5,0,3,4,6,2,3,6), 0x000000016f08000b77a431170bcd26e500000000000000000000000000000000], 
["knight_merc_2","Captain Marcus","Marcus",tf_male|tf_hero, 0, reserved, fac_commoners, [(itm_4black_armor, imod_lordly), itm_sugarloaf_a, itm_black_boot_salad_of, itm_bnw_gauntlets, itm_5warhorse_holy, (itm_crusader_sword, imod_masterwork), itm_shield_10, itm_bow_a, itm_axe_a, itm_riverlands_freylight, itm_west_rider_boots], 
attrlev(30,21,22,24,56), wpex(440,400,400,150,300,180), strsk(9,9,5,6)|agisk(9,7,4,9,0)|lordsk1(1,2,9,1,7,1,2,3)|lordsk2(2,2,3,2,5,4,9,3), 0x00000004b500258f36d48ab65388971b00000000001d24d90000000000000000], 
["knight_merc_3","Captain Fazl","Fazl",tf_hero, 0, reserved, fac_commoners, [itm_aqs_merchant_outf, (itm_dorn_sand_snakes_helm, imod_lordly), (itm_khergit_guard_boots, imod_lordly), itm_gauntlets_arabs_b_l, itm_spakhorse_03, (itm_2scimitar_darkwood, imod_masterwork), itm_tulgan_bow_kuulan, itm_elmwoodquiver_arrow, itm_surcoat_bur_02d, itm_civ_foot_arab_leather_boots_2], 
attrlev(18,20,18,28,35), wpex(240,240,150,280,100,150), strsk(4,5,4,5)|agisk(5,1,4,6,6)|lordsk1(4,3,0,2,0,4,4,10)|lordsk2(1,0,1,0,9,1,1,10), 0x000000023f00d4ca36db6db65b75b69c00000000001d48db0000000000000000], 
["knight_merc_4","Captain Tylen","Tylen",tf_hero, 0, reserved, fac_commoners, [(itm_churburg_13_brass, imod_reinforced), (itm_crusader_knight_helm_c, imod_reinforced), (itm_steel_greaves, imod_reinforced), (itm_hourglass_gauntlets_ornate, imod_reinforced), itm_barded_armour_charger2, (itm_sword_val_2, imod_masterwork), itm_shield_11, itm_lance_3, itm_wei_xiadi_swa_tabard, itm_civ_foot_rich_boots_black], 
attrlev(27,20,18,22,50), wpex(380,350,400,120,120,100), strsk(8,8,6,6)|agisk(8,6,3,8,0)|lordsk1(6,1,7,2,4,0,3,3)|lordsk2(1,0,2,2,5,6,6,1), 0x00000003c40005c436db729adb69b6dc00000000001d370b0000000000000000], 
["knight_merc_5","Captain Alastair","Alastair",tf_hero, 0, reserved, fac_commoners, [(itm_west_man_at_arms_armor, imod_reinforced), (itm_great_helmet, imod_reinforced), (itm_west_pikeman_boots, imod_reinforced), (itm_dorn_knight_gant, imod_reinforced), itm_charger_black, itm_bastard_sword_b, itm_shb1, itm_civ_freelmar_armor, itm_civ_foot_west_pikeman_boots], 
attrlev(36,23,19,28,60), wpex(540,540,500,350,350,350), strsk(10,10,8,7)|agisk(10,9,5,10,0)|lordsk1(5,0,10,1,8,2,4,4)|lordsk2(0,0,3,4,4,8,9,3), 0x0000000a351183d14ad59636ddb5cefe00000000001cb76a0000000000000000], 
["knight_merc_6","Captain Haidar","Haidar",tf_hero, 0, reserved, fac_commoners, [(itm_brigandine_b_heraldic, imod_reinforced), (itm_crusaderbucket1, imod_reinforced), itm_plate_boots, itm_mail_mittens, itm_dorn_horse_lamellar_a, itm_luc_iron_morningstar, itm_tab_shield_heater_cav_b, itm_heavy_crossbow, itm_steel_bolts, itm_civ_heraldic_brigandine_b, itm_civ_foot_mail_boots_1], 
attrlev(30,20,16,20,52), wpex(420,420,250,200,400,400), strsk(10,10,9,8)|agisk(9,5,5,7,4)|lordsk1(7,5,7,6,3,3,5,4)|lordsk2(1,0,2,1,3,8,5,3), 0x000000073f0133893c5bbd4912cdaafe00000000001ec0d90000000000000000], #lion
["knight_merc_7","Captain Jemma","Jemma",tf_female|tf_hero, 0, reserved, fac_commoners, [(itm_perisnofemalearmor, imod_lordly), (itm_flemish_armet, imod_lordly), (itm_plate_boots, imod_reinforced), itm_gauntlets, itm_wlong4, itm_flamberg, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt, itm_van_helsing_crossbow_bolt, itm_civ_body_m_surcoat_7, itm_civ_foot_mail_boots_1], 
attrlev(26,33,24,33,52), wpex(430,430,350,250,380,200), strsk(8,8,7,7)|agisk(9,4,5,8,10)|lordsk1(7,2,5,6,5,2,7,5)|lordsk2(1,0,3,0,8,7,6,6), 0x000000060e08101676e3b312ec6d05a300000000000000000000000000000000], #gem
["knight_merc_8","Captain Harold","Harold",tf_hero, 0, reserved, fac_commoners, [(itm_armor_master_order_hospitaller, imod_lordly), (itm_crusaderbucket_blue, imod_lordly), (itm_plate_boots2, imod_reinforced), itm_plate_mittens, itm_wlong2, itm_luc_hammer_spike, itm_steel_shield_heater, itm_civ_foot_ornate_boots_1], 
attrlev(32,18,24,32,60), wpex(560,560,560,300,300,300), strsk(10,9,7,7)|agisk(10,10,3,10,0)|lordsk1(4,0,9,8,8,3,3,4)|lordsk2(3,2,3,3,7,9,9,4), 0x0000000fc009100f3accd1b4ec6d9b2300000000001d56a20000000000000000], #army & power, leader, ruler
["knight_merc_9","Shi Jin","Shi Jin",tf_hero, 0, reserved, fac_commoners, [(itm_dorn_squire_armor, imod_reinforced), (itm_kevin_song_helm_b, imod_lordly), (itm_west_man_at_arms_boots, imod_reinforced), itm_gauntlets_arabs_b_l, itm_song_charger_b, itm_viper_sword, itm_saracin_shield_r, itm_civ_songgeneral_b, itm_civ_foot_cavalry_boots_black], 
attrlev(27,27,23,20,56), wpex(380,350,330,250,100,100), strsk(6,8,6,7)|agisk(8,4,6,8,4)|lordsk1(2,1,5,2,7,4,4,4)|lordsk2(1,1,2,6,3,4,5,2), 0x000000003f0155ca2396ad249b51b2d400000000001db4e90000000000000000], 
#Mactabilius! - as merc for 3rd legion only?

#Outlaw Union Lords
["knight_ou_1","Ulfhednar","Ulfhednar", tf_hero, 0, 0, fac_outlaw_union, [(itm_bear_warrior, imod_lordly), (itm_2kettle_hat_new, imod_reinforced), (itm_splinted_leather_greaves, imod_reinforced), (itm_beargauntlets, imod_reinforced), itm_giant_club, itm_luc_throwing_hammer, itm_luc_throwing_hammer], 
attrlev(66,28,11,24,60), wpex(500,600,500,150,150,500), strsk(10,10,10,8)|agisk(10,7,10,0,0)|lordsk1(10,3,7,5,4,4,3,5)|lordsk2(0,0,0,3,4,9,8,1), 0x00000008800102985b5b7029e3459ebe00000000001da4e00000000000000000], 
["knight_ou_2","Nibor Hood","Nibor Hood", tf_hero, 0, 0, fac_outlaw_union, [(itm_peasant_leather_ring_ls, imod_lordly), (itm_stark_hood, imod_hardened), itm_stark_hanter_boots, (itm_leather_gloves, imod_hardened), itm_jack_boromir, itm_ranger_bow, itm_blackarrow, itm_blackarrow], 
attrlev(26,40,15,22,54), wpex(380,380,380,600,400,200), strsk(8,8,5,10)|agisk(10,4,10,3,10)|lordsk1(9,10,5,8,7,9,9,4)|lordsk2(2,1,3,3,5,5,6,3), 0x00000004ae00418336db6db6db55a6db00000000001db6db0000000000000000], 
["knight_ou_3","Envassarel","Envassarel", tf_hero|tf_elven_male, 0, 0, fac_outlaw_union, [(itm_mirk_armor_1c, imod_lordly), (itm_sugarloaf_b, imod_hardened), (itm_rivend_boots_1c, imod_lordly), (itm_dorn_assasin_gant, imod_lordly), itm_5warhorse_holy, itm_an_sword01b, itm_rivend_shield_2b], 
attrlev(38,35,32,30,60), wpex(620,620,620,600,400,500), strsk(10,10,9,10)|agisk(10,10,9,10,10)|lordsk1(4,5,10,9,10,8,10,6)|lordsk2(4,1,4,3,8,7,8,5), 0x0000000c3f00300914db79b6db8dbb6a00000000001db6ec0000000000000000], 
["knight_ou_4","Fianora","Fianora", tf_hero|tf_elven_female, 0, 0, fac_outlaw_union, [(itm_rivend_rohir_armor_1d, imod_lordly), itm_royal_ench, (itm_rivend_boots_1c, imod_lordly), (itm_dorn_assasin_gant, imod_lordly), itm_5warhorse_holy, itm_elvish_sword, itm_rivend_shield_2b, itm_ebonybow, itm_blackarrow], 
attrlev(29,37,30,33,60), wpex(530,530,530,600,400,400), strsk(8,10,8,10)|agisk(10,8,10,10,10)|lordsk1(5,8,8,10,10,9,10,7)|lordsk2(4,1,4,4,10,8,7,8), 0x00000007ff08221540db344909c9c9ab0000000000eaa6e80000000000000000], #0x0000000cff08021540db364889c9c92c0000000000eaa6e80000000000000000
["knight_ou_5","Kangras One-Eyed","Kangras One-Eyed", tf_hero|tf_giant_male, 0, 0, fac_outlaw_union, [(itm_armor_elite_marauder_of_norsca_c_02, imod_reinforced), (itm_giant_horned_skull_helmet_bakhal, imod_reinforced), itm_giant_plated_boots_war, itm_giant_gloves_plus, itm_axe_elite_raider_01], 
attrlev(77,18,13,16,58), wpex(450,500,450,200,120,410), strsk(13,14,11,9)|agisk(10,5,7,0,0)|lordsk1(10,2,9,1,2,0,4,3)|lordsk2(0,0,0,1,3,8,5,0), 0x0000000cc008620040db344909c9c9ab00000000001ea6e80000000000000000], 
["knight_ou_6","Dworill Goldbeard","Dworill Goldbeard", tf_hero|tf_dwarf_male, 0, 0, fac_outlaw_union, [itm_dwarf_armor_10, itm_dwarf_ih_helm_3, itm_wp_boots_light, itm_dwarf_glove_2, itm_mail_armour_charger1, itm_sungodaxe, itm_dwarf_ih_shield_1c], 
attrlev(37,17,25,32,50), wpex(350,290,290,200,300,300), strsk(9,9,8,6)|agisk(8,9,2,7,0)|lordsk1(2,0,0,0,2,0,8,10)|lordsk2(2,0,2,5,10,4,6,10), 0x0000000cc000c30b40e6544919d2c9ab00000000001dd6ec0000000000000000], 
["knight_ou_7","Big Ax","Big Ax", tf_hero|tf_dwarf_male, 0, 0, fac_outlaw_union, [(itm_brienne_armor_dwarf, imod_lordly), (itm_dwarf_ih_helm_2, imod_lordly), (itm_west_pikeman_boots_dark, imod_reinforced), (itm_glovesblack, imod_reinforced), itm_nord_clan_axe], 
attrlev(49,21,15,12,58), wpex(500,550,450,200,350,500), strsk(13,13,11,7)|agisk(10,5,7,0,0)|lordsk1(9,0,7,3,4,2,5,6)|lordsk2(0,0,0,4,3,10,5,0), 0x0000000cff00a08112e6944919d2c9ab00000000001dd6ec0000000000000000], 
["knight_ou_8","Morana","Morana", tf_hero|tf_giant_female, 0, 0, fac_outlaw_union, [(itm_medusa_armor, imod_lordly), (itm_barbuta_horny, imod_lordly), (itm_west_man_at_arms_boots, imod_reinforced), (itm_scale_gauntlets_b, imod_reinforced), itm_plate_charger_brown, itm_sut_slasher_02, itm_bakhal_leather_shield], 
attrlev(47,20,19,24,58), wpex(430,430,350,200,200,300), strsk(8,10,8,6)|agisk(9,5,5,9,0)|lordsk1(5,3,7,7,3,3,4,5)|lordsk2(0,0,5,0,6,7,7,4), 0x0000000ff904701742eb6ebb2d973f650000000000f01ae30000000000000000], #goddess of winter and death
["knight_ou_9","Avitus Rex","Avitus Rex", tf_hero, 0, 0, fac_outlaw_union, [(itm_armour_vargo, imod_reinforced), (itm_helmet_cof_1, imod_lordly), (itm_west_pikeman_boots_dark, imod_reinforced), (itm_dorn_assasin_gant, imod_reinforced), itm_charger_black, itm_pappen2, itm_sh_snake, itm_crossbow_axe, itm_steel_bolts], 
attrlev(34,24,23,21,58), wpex(450,400,400,250,400,300), strsk(9,10,8,8)|agisk(10,7,5,9,0)|lordsk1(9,0,8,5,7,3,5,5)|lordsk2(0,0,2,4,4,9,7,2), 0x00000007fe05930656dc9758892cc6e400000000001e44e90000000000000000], #ancestral
["knight_ou_10","Kaito","Kaito", tf_hero, 0, 0, fac_outlaw_union, [(itm_domaru, imod_lordly), (itm_mosoru_song_qibing, imod_lordly), (itm_dorn_spearbearer_boots, imod_lordly), (itm_dorn_assasin_gant, imod_reinforced), itm_saracin_hard_horses_a, itm_ninjato], 
attrlev(29,26,19,25,55), wpex(480,500,400,400,200,400), strsk(9,9,8,8)|agisk(10,4,3,10,9)|lordsk1(7,3,7,4,5,4,5,5)|lordsk2(2,0,2,3,5,7,6,4), 0x0000000cb000800a5d256924df32275b00000000001e16a40000000000000000], #sea+fly
["knight_ou_11","Dmitriy","Dmitriy", tf_hero, 0, 0, fac_outlaw_union, [itm_dorn_wiper, (itm_west_man_at_arms_closed, imod_reinforced), (itm_west_pikeman_boots_dark, imod_reinforced), (itm_dorn_squire_gauntles, imod_reinforced), itm_whg2, itm_faradon_largeclub, itm_gothic_hammer, itm_steel_heater1_dark], 
attrlev(38,20,17,17,56), wpex(450,500,300,150,300,150), strsk(10,10,9,7)|agisk(10,5,6,6,0)|lordsk1(6,1,5,2,4,0,3,4)|lordsk2(0,0,0,3,2,7,5,1), 0x00000007b30064114b165e366b95bd6200000000001db6ed0000000000000000], #zemledelets
["knight_ou_12","Israa","Israa", tf_hero|tf_female, 0, 0, fac_outlaw_union, [(itm_youhou_assassin_armor_red, imod_lordly), itm_noble_ench, (itm_dorn_spearbearer_boots, imod_lordly), (itm_dorn_assasin_gant, imod_reinforced), itm_perisno_purebred, itm_youhou_assassin_sword, itm_saracin_shield_t, (itm_spak_crsb02, imod_masterwork), itm_akbolt_b], 
attrlev(26,34,26,29,55), wpex(500,500,500,400,500,400), strsk(8,9,9,9)|agisk(10,8,9,9,9)|lordsk1(4,4,9,7,9,4,8,5)|lordsk2(3,2,6,4,8,8,5,6), 0x00000001a70c500f759da4a48d8aa32800000000000000000000000000000000], #travel at night
["knight_ou_13","Dragan","Dragan", tf_hero, 0, 0, fac_outlaw_union, [(itm_early_transitional_black, imod_lordly), (itm_sugarloaf_b, imod_reinforced), (itm_west_pikeman_boots_dark, imod_lordly), (itm_blackplatemitty, imod_reinforced), itm_dreaded_wolf, itm_stark_axe, itm_saracin_shield_t], 
attrlev(45,28,25,27,58), wpex(520,520,500,300,300,350), strsk(10,10,8,8)|agisk(10,8,7,10,7)|lordsk1(8,6,9,8,7,6,6,5)|lordsk2(1,0,3,5,5,8,8,1), 0x0000000b3f00428f4b16be36ebd63d6200000000001db6f20000000000000000], #precious - Serbian, Croatian, Slovene, Macedonian, Bulgarian name, nothing to do with dragons
["knight_ou_14","Kimiko","Kimiko", tf_hero|tf_female, 0, 0, fac_outlaw_union, [(itm_j_surcoat_bur_01c, imod_lordly), (itm_dorn_sand_snakes_helm_b, imod_lordly), itm_west_man_at_arms_boots, (itm_gauntlets_arabs_b_l, imod_reinforced), itm_saracin_hard_horses_a, itm_two_handed_katana, itm_saracin_shield_r, itm_imperial_bow_2, itm_spak_bow6_arrow], 
attrlev(24,27,17,20,46), wpex(360,360,330,400,150,280), strsk(5,7,5,7)|agisk(8,5,6,9,9)|lordsk1(3,6,4,4,3,4,6,5)|lordsk2(3,0,1,0,4,3,3,5), 0x000000037c0c00197889ae269a4a179b00000000000000000000000000000000], #valuable/beautiful/noble
["knight_ou_15","Emhiara","Emhiara", tf_hero|tf_giant_female, 0, 0, fac_outlaw_union, [(itm_armour_north_clanman2, imod_lordly), (itm_barbuta_horny, imod_hardened), (itm_bear_boots, imod_hardened), (itm_beargauntlets, imod_hardened), itm_runico_axe_d, itm_dwarf_horn_bow, itm_scull_arrow, itm_scull_arrow], 
attrlev(42,25,14,14,45), wpex(280,350,300,350,180,300), strsk(10,10,9,10)|agisk(8,3,8,0,0)|lordsk1(5,7,3,5,1,6,5,5)|lordsk2(2,0,2,0,2,4,4,4), 0x000000057300300756fa76cb7573e6d00000000000f4552b0000000000000000], 
["knight_ou_16","Yeong-Cheol","Yeong-Cheol", tf_hero, 0, 0, fac_outlaw_union, [(itm_dorn_spearbearer_armor, imod_lordly), (itm_vaegir_war_helmet, imod_lordly), (itm_west_man_at_arms_boots, imod_reinforced), (itm_scale_gauntlets_b, imod_reinforced), itm_dorn_horse_lamellar_a, itm_luc_strange_blade, itm_dec_steel_shield, itm_akwar_bow, itm_scull_arrow], 
attrlev(25,20,23,23,50), wpex(390,350,350,460,300,300), strsk(7,7,7,9)|agisk(9,5,4,8,6)|lordsk1(6,5,5,4,7,3,6,6)|lordsk2(0,0,2,4,8,7,5,5), 0x0000000a3f04750c4265925784ae3b2400000000001d989c0000000000000000], #eternal
["knight_ou_17","Jordana","Jordana", tf_hero|tf_dwarf_female, 0, 0, fac_outlaw_union, [(itm_early_transitional_pearl, imod_lordly), (itm_salet_new, imod_lordly), (itm_wp_boots_light, imod_hardened), (itm_scale_gauntlets_b, imod_hardened), itm_mail_armour_charger1, itm_knights_warhammer_no1, itm_dwarf_shield_6c, itm_van_helsing_crossbow_01, itm_van_helsing_crossbow_bolt], 
attrlev(29,27,20,28,55), wpex(350,250,250,250,450,230), strsk(7,8,6,6)|agisk(9,5,4,7,8)|lordsk1(8,3,1,5,6,1,6,7)|lordsk2(0,0,0,2,9,7,6,8), 0x00000001b20c7058247c86d76426d95d00000000001e9c500000000000000000], 
["knight_ou_18","Derek","Derek", tf_hero, 0, 0, fac_outlaw_union, [(itm_black_armor, imod_lordly), (itm_munitionshelm1, imod_lordly), (itm_west_pikeman_boots_dark, imod_reinforced), (itm_scale_gauntlets, imod_reinforced), itm_unholy_trident, itm_kite_shield_5, itm_sniper_crossbow, itm_steel_bolts], 
attrlev(31,27,17,25,54), wpex(340,340,500,200,380,280), strsk(9,10,7,7)|agisk(10,4,9,0,0)|lordsk1(5,0,7,0,10,2,5,4)|lordsk2(0,0,2,2,3,5,8,2), 0x00000000350d95c54d73f8e922d0b2a300000000001e46650000000000000000], #
["knight_ou_19","Lachlan","Lachlan", tf_hero, 0, 0, fac_outlaw_union, [(itm_a_h3, imod_lordly), (itm_barbuta1_black, imod_reinforced), itm_highlander_boots_2_2, (itm_beargauntlets, imod_reinforced), (itm_2h_claymore, imod_masterwork)], 
attrlev(36,24,13,24,54), wpex(480,550,480,230,230,230), strsk(10,10,7,7)|agisk(10,5,9,0,0)|lordsk1(8,2,8,2,2,2,4,4)|lordsk2(0,0,1,0,3,7,6,0), 0x0000000c7401028318d25038e172293300000000001e34aa0000000000000000], #
["knight_ou_20","Waqar","Waqar", tf_hero, 0, 0, fac_outlaw_union, [(itm_j_surcoat_ssm_01d, imod_lordly), (itm_saracin_turban_c_eaqarab, imod_lordly), (itm_dorn_sand_snakes_boots, imod_lordly), (itm_dorn_squire_gauntles, imod_lordly), itm_saracen_horse_sultan, itm_luc_sarranid_falchion_m3, itm_brass_shield, itm_hangong, itm_song_arrows], 
attrlev(29,31,28,28,58), wpex(490,450,450,500,260,360), strsk(10,9,8,10)|agisk(10,8,7,10,10)|lordsk1(5,5,8,5,5,4,8,6)|lordsk2(4,2,6,3,8,7,7,6), 0x0000000a3810a347234b59b53579cd3d00000000001d392a0000000000000000], #majesty, dignity
["knight_ou_21","Duke","Duke", tf_hero, 0, 0, fac_outlaw_union, [(itm_black_marshal_armor, imod_reinforced), (itm_greatbascinet1, imod_reinforced), (itm_black_boot_salad_of, imod_lordly), (itm_hourglass_gauntlets_ornate, imod_lordly), itm_plated_charger9, itm_an_axe01, itm_saracin_shield_t, itm_hurlbat_2], 
attrlev(35,23,24,25,60), wpex(520,500,500,330,330,330), strsk(10,10,10,8)|agisk(10,9,5,10,8)|lordsk1(8,1,9,3,7,3,5,5)|lordsk2(0,0,3,5,8,7,9,4), 0x000000077d01644f36ddb5b75b8dbd7400000000001db6e20000000000000000], #




#rihoran; riobher; braden; dairaden, kairaden, fairaden, kairathos, kilraden


#Isis - good merc; Vlad; Bryce, Laszlo, Gayelord, Bradley, Dominique, Morgan, Eamon, Mangus, Hudsona, Iskandar

#Kellardan, Kellanhir empire, Gellanhir/Gellasar/Gellarhan Gachnerian, seineral, (e)styon

##Dellarhan Empire/Federation (dellarh?!)

#corrupted cog

#(itm_saracin_hard_boot_b, imod_lordly)


# ["knight_0_1","Alindel","Alindel",tf_hero, 0, reserved, fac_player_supporters_faction, [itm_knight_armor_tevton_c_cloak, (itm_open_salet_coif, imod_lordly), itm_dorn_knight_boots, itm_mail_mittens, itm_tribal4, itm_knights_winged_mace_2h, itm_spak_knightsh, itm_padded_cloth, itm_ankle_boots_cwe], 
# attrlev(19,13,33,23,45), wpex(250,150,250,80,200,80), strsk(4,4,2,2)|agisk(5,4,4,5,0)|lordsk1(0,0,0,0,1,2,1,5)|lordsk2(10,10,10,0,7,1,5,5), 0x0000000cc101119236db71976b8d293b00000000001dd4da0000000000000000], 
# ["knight_0_2","Knight Geraint","Geraint",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_dark_lord_armor, imod_reinforced), (itm_twilighthelm, imod_reinforced), (itm_west_pikeman_boots_dark, imod_reinforced), itm_twilight_gloves, itm_charger_black, itm_sword_val_3, itm_sh_snake, itm_civ_perisno_lord_armor, itm_leather_boots_dark], 
# attrlev(34,22,25,28,58), wpex(520,520,500,200,200,200), strsk(10,10,8,8)|agisk(10,8,3,10,0)|lordsk1(4,0,8,0,8,0,2,4)|lordsk2(0,0,0,4,5,8,8,1), 0x0000000fe209620458acb11ca095984c00000000001da6a90000000000000000], #old man
# ["knight_0_3","Knight Brynmor","Brynmor",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_perisno_heavy_armour, imod_lordly), (itm_bolzanobucket, imod_reinforced), (itm_twilight_boots, imod_lordly), itm_blackplatemitty, itm_twilight_horse, (itm_lui_knighthammer, imod_balanced), itm_tab_shield_heater_cav_b, itm_civ_perisno_heavy_armour, itm_civ_foot_cavalry_boots_black, itm_gondor_bracer_l], 
# attrlev(33,25,26,25,55), wpex(480,480,480,250,250,250), strsk(9,10,8,8)|agisk(10,8,4,9,0)|lordsk1(2,1,7,3,6,1,3,6)|lordsk2(0,0,0,3,6,7,6,3), 0x00000008b1118446251b8dd4b45eacab00000000001f44eb0000000000000000], #great hill
# ["knight_0_4","Knight Bleddyn","Bleddyn",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_knight_armor_templar_d_cloak, imod_lordly), (itm_col1_madelnbucket1, imod_reinforced), (itm_twilight_boots, imod_lordly), itm_dark_mail_mittens, itm_5warhorse_holy, (itm_2h_claymore_cwe, imod_balanced), itm_shields_archer_templar_a, itm_spak_crsb01, itm_akbolt_b, itm_civ_twilight_boots], 
# attrlev(30,25,23,25,56), wpex(450,450,400,200,450,200), strsk(9,9,8,7)|agisk(9,7,5,8,7)|lordsk1(9,1,8,8,5,2,9,4)|lordsk2(0,0,0,1,8,8,8,2), 0x0000000a791005c54ad58a36dd953efe00000000001cb7730000000000000000], #wolf
# ["knight_0_5","Knight Cadogan","Cadogan",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_j_blacksmith_marinian_armor_d, imod_lordly), itm_crusaderbucket1, (itm_twilight_boots, imod_reinforced), itm_glovesblack, itm_twilight_horse, itm_jack_anduril, itm_sp_newsh, itm_civ_foot_plated_boots_black], 
# attrlev(31,24,27,24,56), wpex(475,475,450,220,220,220), strsk(9,9,6,6)|agisk(10,6,3,9,0)|lordsk1(5,0,7,3,6,1,3,4)|lordsk2(0,0,1,4,5,6,7,1), 0x0000000a7a1165112052cbb99a9125d400000000001f62310000000000000000], #glory in battle
# ["knight_0_6","Knight Ivor","Ivor",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_heraldic_surcoat_plated, imod_lordly), (itm_dwarvenforged_helm_1, imod_lordly), (itm_plate_boots, imod_reinforced), itm_gauntlets_arabs_a_l, itm_forest_mount, itm_warblade_greensilver, itm_saracin_shield_h, itm_ebonybow, itm_blackarrow, itm_civ_heraldic_surcoat_heavy, itm_civ_foot_plated_boots_2], 
# attrlev(30,28,25,25,50), wpex(430,400,400,480,300,200), strsk(8,9,7,10)|agisk(9,5,5,9,9)|lordsk1(7,8,3,8,3,9,9,6)|lordsk2(2,0,4,1,8,5,4,5), 0x000000025511058a74dc71b66c91aca500000000001ca7630000000000000000], #bow warrior
# ["knight_0_7","Knight Meredith","Meredith",tf_hero|tf_female, 0, reserved, fac_player_supporters_faction, [(itm_xenoargh_female_armor_sisters_of_mercy4, imod_reinforced), (itm_barbuta2_black, imod_lordly), itm_twilight_boots, itm_bnw_gauntlets, itm_5warhorse_holy, itm_jack_anduril, itm_shields_archer_templar_a, itm_civ_perisno_nun_armor, itm_civ_twilight_boots], 
# attrlev(27,26,32,30,50), wpex(450,400,400,100,200,100), strsk(7,8,6,6)|agisk(9,7,5,9,0)|lordsk1(0,0,2,2,3,1,4,6)|lordsk2(10,6,9,1,9,3,5,6), 0x000000027a10200f7764d9c50b6ca32200000000000000000000000000000000], #great lord; unisex name

# ["knight_6_19", "Hakkon Herminius", "Herminius", tf_hero, 0, reserved, fac_kingdom_6, [itm_bronze_plate, (itm_winged_helm_new, imod_lordly), itm_bronze_greaves, itm_bronze_gauntlet, itm_falcon_horse, itm_luc_bronze_mace, itm_shield_7, itm_civ_body_m_tabard_3, itm_civ_foot_ankle_boots_1], 
# attrlev(25,30,23,25,40), wpex(330,300,300,150,150,150), strsk(6,7,5,5)|agisk(7,4,10,10,9)|lordsk1(1,0,1,3,0,10,5,3)|lordsk2(3,0,2,1,4,2,3,7), 0x00000007001125d148ef4a36ddd53b2500000000001cb74b0000000000000000], #old Al'Hashem
# ["knight_4_18", "Lord Svend", "Svend", tf_hero, 0, reserved, fac_kingdom_4, [(itm_wei_xiadi_surcoat_rhodok02, imod_lordly), itm_barbuta1, itm_splinted_greaves_spurs, itm_mail_mittens, itm_luc_polish_bardiche, itm_lonely, itm_1steel_arrow, itm_1steel_arrow, itm_civ_foot_plated_boots_2], 
# attrlev(25,25,23,25,40), wpex(300,300,300,350,200,200), strsk(8,7,7,8)|agisk(8,4,8,5,0)|lordsk1(2,7,3,6,4,6,7,5)|lordsk2(3,0,3,3,4,5,3,5), 0x000000002d0915c5673332a6a94d34da00000000001da9250000000000000000], 






#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["knight_1_1_wife","Lady Serena","Serena",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_commoners, 
[itm_lady_dress_ruby, itm_turret_hat_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000004ef10000d435551b75c92e6b30000000000f0b85b0000000000000000], #female giant's default face

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#Royal family members
#Tolranian ladies - eight mothers, eight daughters, four sisters
["kingdom_1_lady_1","Lady Anna","Anna",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000055910200107632d675a92b92d00000000001e45620000000000000000], 
["kingdom_1_lady_2","Lady Nelda","Nelda",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054f08100232636aa90d6e194b00000000001e43130000000000000000], 
["kingdom_1_lady_3","Lady Bela","Bela",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000018f0410064854c742db74b52200000000001d448b0000000000000000], 
["kingdom_1_lady_4","Lady Elina","Elina",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000204201229b131e90d6a8ae400000000001e28dd0000000000000000], 
["kingdom_1_lady_5","Lady Constanis","Constanis",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000055910201607632d675a92b92d00000000001e45620000000000000000], 
["kingdom_1_lady_6","Lady Vera","Vera",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000d08200c1693b142ca6a271a00000000001db6920000000000000000], 
["kingdom_1_lady_7","Lady Auberina","Auberina",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000001900000c42ac4e76d5d0d35300000000001e26a40000000000000000], 
["kingdom_1_lady_8","Lady Tibal","Tibal",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000001900000542ac4e76d5d0d35300000000001e26a40000000000000000], 
["kingdom_1_lady_9","Lady Magar","Magar",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c70c20032aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_1_lady_10","Lady Thedosa","Thedosa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003a00200e46a129464baaa6db00000000001de7a00000000000000000], 
["kingdom_1_lady_11","Lady Melisar","Melisar",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003c080011531e8932e432bb5a000000000008db6a0000000000000000], 
["kingdom_1_lady_12","Lady Irena","Irena",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003f04101248d245d6526d456b00000000001e3b350000000000000000], 
["kingdom_1_lady_13","Lady Philenna","Philenna",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003a00200e46a129464baaa6db00000000001de7a00000000000000000], 
["kingdom_1_lady_14","Lady Sonadel","Sonadel",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003a0c300f358a56d51c8e399400000000000944dc0000000000000000], 
["kingdom_1_lady_15","Lady Boadila","Boadila",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003b08000f531e8932e432bb5a000000000008db6a0000000000000000], 
["kingdom_1_lady_16","Lady Elys","Elys",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003b08000d531e8932e432bb5a000000000008db6a0000000000000000], 
["kingdom_1_lady_17","Lady Johana","Johana",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000446e4b4c2cc5234d200000000001ea3120000000000000000], 
["kingdom_1_lady_18","Lady Bernatys","Bernatys",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000000083010465800000901161200000000001e38cc0000000000000000], 
["kingdom_1_lady_19","Lady Enricata","Enricata",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610001264d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_1_lady_20","Lady Gaeta","Gaeta",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_1, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058210000964d3693664f0c54b00000000001d332d0000000000000000], 

#Reich des Drachen Ladies
["kingdom_2_lady_1","Frau Adelheid","Adelheid",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000007c010100c588caf17142ab93d00000000001ddfa40000000000000000], 
["kingdom_2_lady_2","Frau Katharina","Katharina",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c00c20032aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_2_lady_3","Frau Mathilde","Mathilde",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000007080004782a6cc4ecae4d1e00000000001eb6e30000000000000000], 
["kingdom_2_lady_4","Frau Monika","Monika",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054008200638db99d89eccbd3500000000001ec91d0000000000000000], 
["kingdom_2_lady_5","Frau Franziska","Franziska",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000007c0101011588caf17142ab93d00000000001ddfa40000000000000000], 
["kingdom_2_lady_6","Frau Heidi","Heidi",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c00c20142aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_2_lady_7","Frau Tanja","Tanja",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000007080004782a6cc4ecae4d1e00000000001eb6e30000000000000000], 
["kingdom_2_lady_8","Frau Ingrid","Ingrid",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054008200e38db99d89eccbd3500000000001ec91d0000000000000000], 
["kingdom_2_lady_9","Frau Yvette","Yvette",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000007c0101012588caf17142ab93d00000000001ddfa40000000000000000], 
["kingdom_2_lady_10","Frau Ursula","Ursula",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c00c200d2aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_2_lady_11","Frau Jasmin","Jasmin",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000007080004782a6cc4ecae4d1e00000000001eb6e30000000000000000], 
["kingdom_2_lady_12","Frau Olga","Olga",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054008200f38db99d89eccbd3500000000001ec91d0000000000000000], 
["kingdom_2_lady_13","Frau Isolde","Isolde",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000007c0101010588caf17142ab93d00000000001ddfa40000000000000000], 
["kingdom_2_lady_14","Frau Traude","Traude",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c00c200c2aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_2_lady_15","Frau Wilma","Wilma",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000007080004782a6cc4ecae4d1e00000000001eb6e30000000000000000], 
["kingdom_2_lady_16","Frau Ida","Ida",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [ itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054008201638db99d89eccbd3500000000001ec91d0000000000000000], 
["kingdom_2_lady_17","Frau Gitte","Gitte",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000007c0101002588caf17142ab93d00000000001ddfa40000000000000000], 
["kingdom_2_lady_18","Frau Rosalin","Rosalin",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000008c00c20052aa5ae36b4259b9300000000001da6a50000000000000000], 
["kingdom_2_lady_19","Frau Erika","Erika",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000007080004782a6cc4ecae4d1e00000000001eb6e30000000000000000], 
["kingdom_2_lady_20","Frau Ludwiga","Ludwiga",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_2, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054008200638db99d89eccbd3500000000001ec91d0000000000000000], 

#Draharan Ladies
["kingdom_3_lady_1","Lady Borge","Borge",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_1], 
["kingdom_3_lady_2","Lady Tuan","Tuan",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000250030062f604b804aa6a2c100000000001d5cff0000000000000000], 
["kingdom_3_lady_3","Lady Mahraz","Mahraz",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_red_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_2], 
["kingdom_3_lady_4","Lady Ayasu","Ayasu",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_red_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000019400300c37226c34cb89a2c300000000001db6e70000000000000000], 
["kingdom_3_lady_5","Lady Ravin","Ravin",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000056e082002471c91c8aa2a130b00000000001d48a40000000000000000], 
["kingdom_3_lady_6","Lady Ruha","Ruha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003f00300c5f606b0261aea2c200000000001ddc9f0000000000000000], 
["kingdom_3_lady_7","Lady Chedina","Chedina",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000320c30023ce23a145a8f27a300000000001ea6dc0000000000000000], 
["kingdom_3_lady_8","Lady Kefra","Kefra",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000320c30023ce23a145a8f27a300000000001ea6dc0000000000000000], 
["kingdom_3_lady_9","Lady Nirvaz","Nirvaz",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000001940c3012019c925165d1129b00000000001d13240000000000000000], 
["kingdom_3_lady_10","Lady Dulua","Dulua",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x0000000194003003372271b0d3a9a2c300000000001d16d70000000000000000], 
["kingdom_3_lady_11","Lady Selik","Selik",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000019b083005389591941379b8d100000000001e63150000000000000000], 
["kingdom_3_lady_12","Lady Thalatha","Thalatha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000002500200e2f604b004a82a2c100000000001d5c870000000000000000], 
["kingdom_3_lady_13","Lady Yasreen","Yasreen",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000056e082015471c91c8aa2a130b00000000001d48a40000000000000000], 
["kingdom_3_lady_14","Lady Nadha","Nadha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_1], 
["kingdom_3_lady_15","Lady Zenur","Zenur",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_2], 
["kingdom_3_lady_16","Lady Arjis","Arjis",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000250030062f604b004a82a2c100000000001d5cef0000000000000000], 
["kingdom_3_lady_17","Lady Atjahan", "Atjahan",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000001a700300265cb6db15d6db6da00000000001f82180000000000000000], 
["kingdom_3_lady_18","Lady Qutala","Qutala",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000001500300137e06db2618aa2c300000000001dd86f0000000000000000], 
["kingdom_3_lady_19","Lady Hindal","Hindal",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000320c30113ce23a145a8f27a300000000001ea6dc0000000000000000], 
["kingdom_3_lady_20","Lady Mechet","Mechet",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000001bf00300c39246de0d3b1a2c100000000001d16a70000000000000000], 
["kingdom_3_lady_21","Lady Lulua","Lulua",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000019400300e372271b0d3a9a2c300000000001d16d70000000000000000], 

#Maccavian Ladies
["kingdom_4_lady_1","Lady Jadeth","Jadeth",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100003274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_4_lady_2","Lady Miar","Miar",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610000664d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_4_lady_3","Lady Dria","Dria",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000569a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_4_lady_4","Lady Glunde","Glunde",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000000000f1564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_4_lady_5","Lady Loeka","Loeka",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100003274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_4_lady_6","Lady Bryn","Bryn",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610001164d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_4_lady_7","Lady Eir","Eir",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_4_lady_8","Lady Thera","Thera",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000000011564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_4_lady_9","Lady Hild","Hild",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100003274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_4_lady_10","Lady Endegrid","Endegrid",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610000d64d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_4_lady_11","Lady Herjasa","Herjasa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_4_lady_12","Lady Svipul","Svipul",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000000121564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_4_lady_13","Lady Ingunn","Ingunn",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b10000e274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_4_lady_14","Lady Kaeteli","Kaeteli",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610000f64d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_4_lady_15","Lady Eilif","Eilif",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_4_lady_16","Lady Gudrun","Gudrun",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000000000c1564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_4_lady_17","Lady Bergit","Bergit",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100003274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_4_lady_18","Lady Aesa","Aesa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610001164d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_4_lady_19","Lady Alfrun","Alfrun",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_4_lady_20","Lady Afrid","Afrid",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_4, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000000021564d196e2aa279400000000001dc4ed0000000000000000], 

# Elintoran ladies
["kingdom_5_lady_1","Lady Esyaviel","Esyaviel",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_2","Lady Saidethima","Saidethima",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_3","Lady Anesthoneth","Anesthoneth",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_4","Lady Filglerthalasa","Filglerthalasa",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_5","Lady Aranwen","Aranwen",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_6","Lady Jhaumrithe","Jhaumrithe",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_7","Lady Veluthil","Veluthil",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_8","Lady Namyriitha","Namyriitha",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_9","Lady Essaerae","Essaerae",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_10","Lady Minurauniel","Minurauniel",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_11","Lady Renuraiwen","Renuraiwen",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_12","Lady Daerhilleryn","Daerhilleryn",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_13","Lady Bronmariiel","Bronmariiel",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_14","Lady Almethya","Almethya",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_15","Lady Daumeltithria","Daumeltithria",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_16","Lady Galeddolliel","Galeddolliel",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_17","Lady Gweyr","Gweyr",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_18","Lady Yalanilue","Yalanilue",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2,elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_19","Lady Enauraiiel","Enauraiiel",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_20","Lady Tareswen","Tareswen",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2,elintoran_face_female_start, elintoran_face_female_end], 
["kingdom_5_lady_21","Lady Myriitha","Myriitha",tf_hero|tf_elven_female|tf_randomize_face|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, elintoran_face_female_start, elintoran_face_female_end], 
#["kingdom_5_lady_22","Lady Tessaerae","Tessaerae",tf_hero|tf_elven_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000018000000a2f278e04c48ba4c600000000001c361f0000000000000000], 
#["kingdom_5_lady_23","Lady Auriel","Auriel",tf_hero|tf_elven_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_5, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000006800000052bafad06c48aa4c700000000001c36170000000000000000], 

#Hakkon Ladies
["kingdom_6_lady_1","Lady Rayma","Rayma",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000055910200107632d675a92b92d00000000001e45620000000000000000], 
["kingdom_6_lady_2","Lady Thanaikha","Thanaikha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054f08100232636aa90d6e194b00000000001e43130000000000000000], 
["kingdom_6_lady_3","Lady Sulaha","Sulaha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000018f0410064854c742db74b52200000000001d448b0000000000000000], 
["kingdom_6_lady_4","Lady Shatha","Shatha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000204201229b131e90d6a8ae400000000001e28dd0000000000000000], 
["kingdom_6_lady_5","Lady Bawthan","Bawthan",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_6","Lady Mahayl","Mahayl",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000d08200e1693b142ca6a271a00000000001db6920000000000000000], 
["kingdom_6_lady_7","Lady Isna","Isna",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_8","Lady Siyafan","Siyafan",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000001900000542ac4e76d5d0d35300000000001e26a40000000000000000], 
["kingdom_6_lady_9","Lady Ifar","Ifar",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_10","Lady Yasmin","Yasmin",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003a00200d46a129464baaa6db00000000001de7a00000000000000000], 
["kingdom_6_lady_11","Lady Dula","Dula",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_12","Lady Ruwa","Ruwa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003f04101148d245d6526d456b00000000001e3b350000000000000000], 
["kingdom_6_lady_13","Lady Luqa","Luqa",tf_hero|tf_randomize_face|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_14","Lady Zandina","Zandina",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003a0c3015358a56d51c8e399400000000000944dc0000000000000000], 
["kingdom_6_lady_15","Lady Lulya","Lulya",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1, swadian_woman_face_2], 
["kingdom_6_lady_16","Lady Zahara","Zahara",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003b080008531e8932e432bb5a000000000008db6a0000000000000000], 
["kingdom_6_lady_17","Lady Safiya","Safiya",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000446e4b4c2cc5234d200000000001ea3120000000000000000], 
["kingdom_6_lady_18","Lady Khalisa","Khalisa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000008300c465800000901161200000000001e38cc0000000000000000], 
["kingdom_6_lady_19","Lady Janab","Janab",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress_b, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_1], 
["kingdom_6_lady_20","Lady Sur","Sur",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_6, [itm_sarranid_lady_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, swadian_woman_face_2], 

# Realm of the Falcon Ladies
["kingdom_8_lady_1","Lady Ayaris","Ayaris",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000000000b3cde6db6dd89b6e500000000001e371b0000000000000000], 
["kingdom_8_lady_2","Lady Mayandra","Mayandra",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000068a0c300c375ba4b56c69d66d00000000001cd9140000000000000000], 
["kingdom_8_lady_3","Lady Gwendana","Gwendana",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000037c10300f559d6636d48ec4b300000000001da9220000000000000000], 
["kingdom_8_lady_4","Lady Eirendra","Eirendra",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000006a308000128e1cdd6938e36ab00000000001d3ccc0000000000000000], 
["kingdom_8_lady_5","Lady Wievyanda","Wievyanda",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000002100300b6adc84992575449a00000000001cbb660000000000000000], 
["kingdom_8_lady_6","Lady Samarisia","Samarisia",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000108000f52a9689d6b6dc6ec00000000001ab31b0000000000000000], 
["kingdom_8_lady_8","Lady Esther","Esther",tf_hero|tf_elven_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000108000f52a9689d6b6dc6ec00000000001ab31b0000000000000000], 
["kingdom_8_lady_9","Lady Dierdra","Dierdra",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_8, [itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000006a308000128e1cdd6938e36ab00000000001d3ccc0000000000000000], 

#Valahir Ladies
["kingdom_9_lady_1","Lady Otkatla","Otkatla",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100003274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_9_lady_2","Lady Anni","Anni",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610000664d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_9_lady_3","Lady Rjupa","Rjupa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_9_lady_4","Lady Ingrior","Ingrior",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000000021564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_9_lady_5","Lady Hallgeror","Hallgeror",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b10000e274d65d2d239eb1300000000001d49080000000000000000], 
["kingdom_9_lady_6","Lady Bergljot","Bergljot",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000058610000564d3693664f0c54b00000000001d332d0000000000000000], 
["kingdom_9_lady_7","Lady Myrgjol","Myrgjol",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000c000469a4d5cda4b1349c00000000001cd6600000000000000000], 
["kingdom_9_lady_8","Lady Ela","Ela",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_peasant_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000000000141564d196e2aa279400000000001dc4ed0000000000000000], 
["kingdom_9_lady_9","Lady Pernilla","Pernilla",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_9, [itm_court_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000054b100015274d65d2d239eb1300000000001d49080000000000000000], 

# Kaikoth
["kingdom_10_lady_1","Lady Khabarova","Khabarova",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000000000b3cde6db6dd89b6e500000000001e371b0000000000000000], 
["kingdom_10_lady_2","Lady Chayandra","Chayandra",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000068a0c300c375ba4b56c69d66d00000000001cd9140000000000000000], 
["kingdom_10_lady_3","Lady Khendana","Khendana",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000037c10300f559d6636d48ec4b300000000001da9220000000000000000], 
["kingdom_10_lady_4","Lady Mirendra","Mirendra",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000006a308000128e1cdd6938e36ab00000000001d3ccc0000000000000000], 
["kingdom_10_lady_6","Lady Helena","Helena",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000108000f52a9689d6b6dc6ec00000000001ab31b0000000000000000], 
["kingdom_10_lady_8","Lady Kiri","Kiri",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000002100300a6adc84992575449a00000000001cbb660000000000000000], 
["kingdom_10_lady_9","Lady Lora","Lora",tf_hero|tf_dwarf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_10, [ itm_lady_dress_ruby, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000108000f52a9689d6b6dc6ec00000000001ab31b0000000000000000], 

#Zann - commented by leo: (1) speaking modding-wise, we can't create female asian faces with what we have, (2) speaking game-wise, Zann lords invade alone, they didn't take their ladies with them.
# ["kingdom_zann_lady_1","Lady Selpa","Selpa",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000019b083005389591941379b8d100000000001e63150000000000000000], 
# ["kingdom_zann_lady_2","Lady Zhelana","Zhelana",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000002500200e2f604b004a82a2c100000000001d5c870000000000000000], 
# ["kingdom_zann_lady_3","Lady Maurii","Maurii",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000056e082002471c91c8aa2a130b00000000001d48a40000000000000000], 
# ["kingdom_zann_lady_4","Lady Zazha","Zazha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_1], 
# ["kingdom_zann_lady_5","Lady Jamur","Jamur",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_2], 
# ["kingdom_zann_lady_6","Lady Thoris","Thoris",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000250030062f604b004a82a2c100000000001d5cef0000000000000000], 
# ["kingdom_zann_lady_7","Lady Amana", "Amana",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000001a700300265cb6db15d6db6da00000000001f82180000000000000000], 
# ["kingdom_zann_lady_8","Lady Malaj","Malaj",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_red_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, khergit_woman_face_2], 
# ["kingdom_zann_lady_9","Lady Ayaku","Ayaku",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_7, [itm_red_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000019400300c37226c34cb89a2c300000000001db6e70000000000000000], 
#["kingdom_zann_lady_10","Lady Rajin","Rajin",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000056e082002471c91c8aa2a130b00000000001d48a40000000000000000], 
#["kingdom_zann_lady_11","Lady Luha","Luha",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_green_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000003f00300c5f606b0261aea2c200000000001ddc9f0000000000000000], 
#["kingdom_zann_lady_12","Lady Ketina","Ketina",tf_hero|tf_female|tf_unmoveable_in_party_window,0,reserved,fac_kingdom_3, [itm_brown_dress, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x00000000320c30023ce23a145a8f27a300000000001ea6dc0000000000000000], 

#  ["kingdom_11_lord_daughter","kingdom_11_lord_daughter","kingdom_11_lord_daughter",tf_hero|tf_female,0,reserved,fac_kingdom_10, [ itm_lady_dress_blue, itm_turret_hat_blue, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000008300701c08d34a450ce43], 
#  ["kingdom_13_lord_daughter","kingdom_13_lord_daughter","kingdom_13_lord_daughter",tf_hero|tf_female,0,reserved,fac_kingdom_10, [ itm_lady_dress_green, itm_turret_hat_green, itm_leather_boots], def_attrib|level(2),wp(50),knows_common|knows_riding_2, 0x000000000008000401db10a45b41d6d8], 
["grandmaster_tresan","{!} kingdom_ladies_end","{!} kingdom_ladies_end",tf_guarantee_gloves|tf_hero|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_helmet|tf_mounted|tf_guarantee_horse,0,0,fac_eagle_brotherhood, [], attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000005c004014436db6db6db6db6db00000000001db69a0000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Unique Spawn + Quest NPCs
["nox_of_zephilli", "Nox of Zephilli", "Nox of Zephilli", tf_hero|tf_guarantee_allnoranged, 0,0, fac_outlaws, [itm_dark_lord_armor2, itm_crown_helm, itm_twilight_boots, itm_glovesblack, itm_spak_charger_plate, itm_luc_morningstar_3, itm_sp_shr1], 
attrlev(90,35,30,50,85), wpex(650,650,650,550,550,550), strsk(10,10,10,10)|agisk(10,10,8,10,8)|lordsk1(7,0,6,4,8,3,4,6)|lordsk2(3,3,5,8,7,9,8,3), 0x00000003f9082594684b4db6d86d273300000000001db4aa0000000000000000], 
["lord_ceylius","Lord Ceylius the Dishonorable","Lord Ceylius the Dishonorable", tf_guarantee_allnoranged|tf_hero,0,0,fac_outlaws, [itm_black_armor, itm_sugarloaf_a, itm_black_greaves, itm_scale_gauntlets, itm_charger, itm_luc_iron_morningstar, itm_steel_shield_heater], 
attrlev(27,15,18,36,55), wpex(300,300,300,150,150,150), strsk(7,7,5,5)|agisk(7,5,2,8,0)|lordsk1(8,0,1,0,2,0,2,5)|lordsk2(0,0,0,3,10,5,7,6), 0x000000019908344f556984b56072a4a5000000000016337e0000000000000000], 
["general_ialoch","Marshal Ialoch the Fiend","General Ialoch the Fiend",tf_hero|tf_guarantee_allnoranged,0,0,fac_demon_worshippers, [itm_spak_coat_of_plates_d, itm_sugarloaf_b, itm_black_boot_salad_of, itm_blackplatemitty, itm_horny_charger_black, itm_demonic_sword_1h, itm_asmoday_seel], 
attrlev(160,34,40,40,85), wpex(660,660,660,400,400,400), strsk(10,10,10,10)|agisk(10,10,10,10,10)|lordsk1(10,0,9,8,9,7,8,4)|lordsk2(5,5,5,7,7,8,10,7), 0x00000006ff00458f36db6db6db6db6db00000000001db6db0000000000000000], 
["quick_battle_troop_1","King Rafklazan","King Rafklazan", tf_no_capture_alive|tf_guarantee_all|tf_hero,0,0,fac_foreigners, [itm_sarranid_royal_armor, itm_col2_madelnbucket2, itm_bronzeshynald, itm_gauntlets_arabs_b_l, itm_charger_bronze, itm_nisaynian_legacy, itm_luc_throwing_scimitar, itm_luc_throwing_scimitar], 
attrlev(48,38,26,42,60), wpex(550,550,500,400,200,550), strsk(10,10,10,9)|agisk(10,7,4,10,9)|lordsk1(6,4,5,4,6,4,4,6)|lordsk2(2,0,3,2,8,7,10,7), 0x00000004b504b1074522923969ccbcde00000000001e43700000000000000000], 
["quick_battle_troop_14","Atanos Octiem","Atanos Octiem", tf_mounted|tf_no_capture_alive|tf_hero|tf_guarantee_all,0,0,fac_first_legion, [itm_roman_catafract_heavy_2, itm_roman_helm_preator, itm_roman_centurion_boots, itm_hourglass_gauntlets_ornate, itm_2lamellar_charger, itm_luc_celtic_sword, itm_roman_shield_cav, itm_roman_pilum_2, itm_roman_pilum_2], 
attrlev(48,36,20,28,60), wpex(580,580,500,300,300,600), strsk(10,10,10,9)|agisk(10,10,10,10,10)|lordsk1(4,3,10,4,10,3,5,5)|lordsk2(0,0,4,7,7,8,8,4), 0x000000003500c011369c6e36ca4db6d200000000001dc7200000000000000000], 

["heroes_end", "{!}heroes end", "{!}heroes end", tf_hero, 0,reserved, fac_neutral, [itm_saddle_horse, itm_leather_jacket, itm_nomad_boots], def_attrib|level(2),wp(20),knows_common, 0x000000000008318101f390c515555594], #stores custom titles as its names

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Seneschals
["town_0_seneschal", "{!}Town 0 Seneschal", "{!}Town 0 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000c218501ef4f5d2ccb0026], 
["town_1_seneschal", "{!}Town 1 Seneschal", "{!}Town 1 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000c218501ef4f5d2ccb0026], 
["town_2_seneschal", "{!}Town 2 Seneschal", "{!}Town 2 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000c03cc01cc34a9a467fdfd], 
["town_3_seneschal", "{!}Town 3 Seneschal", "{!}Town 3 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000c500e01dbb2115a55f3cd], 
["town_4_seneschal", "{!}Town 4 Seneschal", "{!}Town 4 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000008035201e6eebaf3f3eb2b], 
["town_5_seneschal", "{!}Town 5 Seneschal", "{!}Town 5 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000000249101e7898999ac54c6], 
["town_6_seneschal", "{!}Town 6 Seneschal", "{!}Town 6 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000010360b01cef8b57553d34e], 
["town_7_seneschal", "{!}Town 7 Seneschal", "{!}Town7 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000000018101f9487aa831dce4], 
["town_8_seneschal", "{!}Town 8 Seneschal", "{!}Town 8 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000004715201ea236c60a2bcae], 
["town_9_seneschal", "{!}Town 9 Seneschal", "{!}Town 9 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000440c601e1cd45cfb38550], 
["town_10_seneschal", "{!}Town 10 Seneschal", "{!}Town 10 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000010230c01ef41badb50465e], 
["town_11_seneschal", "{!}Town 11 Seneschal", "{!}Town 11 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000008061301fb89acfb95332f], 
["town_12_seneschal", "{!}Town 12 Seneschal", "{!}Town 12 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x00000000000c13ce01dc4723ab936c82], 
["town_13_seneschal", "{!}Town 13 Seneschal", "{!}Town 13 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000008548e01d952a9b25d6d5a], 
["town_14_seneschal", "{!}Town 14 Seneschal", "{!}Town 14 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000004728b01c293c694944b05], 
["town_15_seneschal", "{!}Town 15 Seneschal", "{!}Town 15 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000004728b01c293c694944b05], 
["town_16_seneschal", "{!}Town 16 Seneschal", "{!}Town 16 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000004728b01c293c694944b05], 
["town_17_seneschal", "{!}Town 17 Seneschal", "{!}Town 17 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [ ], def_attrib|level(2),wp(20),knows_common, 0x000000000004728b01c293c694944b05], 


["castle_1_seneschal", "{!}Castle 1 Seneschal", "{!}Castle 1 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000010360b01cef8b57553d34e], 
["castle_2_seneschal", "{!}Castle 2 Seneschal", "{!}Castle 2 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000008061301fb89acfb95332f], 
["castle_3_seneschal", "{!}Castle 3 Seneschal", "{!}Castle 3 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000008548e01d952a9b25d6d5a], 
["castle_4_seneschal", "{!}Castle 4 Seneschal", "{!}Castle 4 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000004715201ea236c60a2bcae], 
["castle_5_seneschal", "{!}Castle 5 Seneschal", "{!}Castle 5 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c500e01dbb2115a55f3cd], 
["castle_6_seneschal", "{!}Castle 6 Seneschal", "{!}Castle 6 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c03cc01cc34a9a467fdfd], 
["castle_7_seneschal", "{!}Castle 7 Seneschal", "{!}Castle 7 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c13ce01dc4723ab936c82], 
["castle_8_seneschal", "{!}Castle 8 Seneschal", "{!}Castle 8 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c218501ef4f5d2ccb0026], 
["castle_9_seneschal", "{!}Castle 9 Seneschal", "{!}Castle 9 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000008035201e6eebaf3f3eb2b], 
["castle_10_seneschal", "{!}Castle 10 Seneschal", "{!}Castle 10 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000440c601e1cd45cfb38550], 
["castle_11_seneschal", "{!}Castle 11 Seneschal", "{!}Castle 11 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000440c601e1cd45cfb38550], 
["castle_12_seneschal", "{!}Castle 2 Seneschal", "{!}Castle 2 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000008061301fb89acfb95332f], 
["castle_13_seneschal", "{!}Castle 3 Seneschal", "{!}Castle 3 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000008548e01d952a9b25d6d5a], 
["castle_14_seneschal", "{!}Castle 4 Seneschal", "{!}Castle 4 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x000000000004715201ea236c60a2bcae], 
["castle_15_seneschal", "{!}Castle 5 Seneschal", "{!}Castle 5 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c500e01dbb2115a55f3cd], 
["castle_16_seneschal", "{!}Castle 6 Seneschal", "{!}Castle 6 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c03cc01cc34a9a467fdfd], 
["castle_17_seneschal", "{!}Castle 6 Seneschal", "{!}Castle 6 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c03cc01cc34a9a467fdfd], 
["castle_18_seneschal", "{!}Castle 6 Seneschal", "{!}Castle 6 Seneschal", tf_hero|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(2),wp(20),knows_common, 0x00000000000c03cc01cc34a9a467fdfd], 

#Arena Masters
["town_0_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_0_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_1_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_1_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_2_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_2_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_3_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_3_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_4_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_4_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_5_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_elven_male|tf_randomize_face, scn_town_5_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_6_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_6_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_7_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_7_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_8_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_8_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_9_arena_master", "Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_9_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_10_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_dwarf_male|tf_randomize_face, scn_town_10_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_11_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_elven_male|tf_randomize_face, scn_town_11_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_12_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_12_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_13_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_13_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mosoru_face_1, mosoru_face_2], 
["town_14_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_giant_male|tf_randomize_face, scn_town_14_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_15_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_giant_male|tf_randomize_face, scn_town_15_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mfo1, mfo2], 
["town_16_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_16_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, aroulo_face_younger_1, aroulo_face_older_2], 
["town_17_arena_master","Tournament Master","{!}Tournament Master",tf_hero|tf_randomize_face, scn_town_17_arena|entry(52),reserved, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, 0x00000007000100c436db6db6db6db64b00000000001db6d90000000000000000, 0x00000009ff01210636db6db6db6db7b300000000001db6de0000000000000000], 


["town_0_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_1_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_2_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_3_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_4_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_5_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_6_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_7_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_8_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_9_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_10_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_11_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_12_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_13_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_14_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_15_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_16_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_17_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|tf_female|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_1_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_2_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_3_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_4_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_5_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_6_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_7_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_8_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_9_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_10_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_11_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_12_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_13_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_14_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_15_armorer","Armorer", "{!}Armorer", tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_16_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_17_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_18_armorer","Armorer", "{!}Armorer", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 

# Weapon merchants
["town_0_weaponsmith","Weaponsmith", "{!}Weaponsmith", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_1_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_2_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_3_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_4_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_5_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_6_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_7_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_8_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_9_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_10_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_11_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_12_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_13_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_14_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_15_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_16_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["town_17_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_1_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_2_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_3_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_4_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_5_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_6_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_7_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_8_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_9_weaponsmith", "Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_10_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_11_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_12_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_13_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_14_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_15_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_elven_male|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_16_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_17_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 
["townsle_18_weaponsmith","Weaponsmith","{!}Weaponsmith",tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2], 

#Tavern keepers
["town_0_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_0_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_1_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_1_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_2_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_2_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_3_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_3_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, woman_face_1, woman_face_2], 
["town_4_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_4_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_5_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_elven_male|tf_hero|tf_randomize_face, scn_town_5_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_6_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_female, scn_town_6_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, woman_face_1, woman_face_2], 
["town_7_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_7_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mosoru_face_1, mosoru_face_2], 
["town_8_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_8_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_9_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_female, scn_town_9_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, woman_face_1, woman_face_2], 
["town_10_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_dwarf_male, scn_town_10_tavern|entry(9),0, fac_commoners, [], attrlev(30,16,16,12,10), wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_11_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_elven_male|tf_randomize_face|tf_female, scn_town_11_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_12_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face, scn_town_12_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_13_tavernkeeper", "Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_female, scn_town_13_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, mosoru_face_1, mosoru_face_2], 
["town_14_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_giant_male|tf_randomize_face, scn_town_14_tavern|entry(9),0, fac_commoners, [], attrlev(30,16,16,12,10), wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_15_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_giant_male, scn_town_15_tavern|entry(9),0, fac_commoners, [], attrlev(30,16,16,12,10), wp(20),knows_common, mercenary_face_1, mercenary_face_2], 
["town_16_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_female, scn_town_16_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, aroulo_face_woman_younger_1, aroulo_face_woman_older_2], 
["town_17_tavernkeeper","Tavern_Keeper","{!}Tavern_Keeper",tf_hero|tf_randomize_face|tf_female, scn_town_17_tavern|entry(9),0, fac_commoners, [], def_attrib|level(2),wp(20),knows_common, 0x000000034000001136db6db6db6db64b00000000001db6d80000000000000000, 0x000000087f00301136db6db6db6db7b300000000001db6de0000000000000000], 


#Goods Merchants
["town_0_merchant","Carak", "{!}Merchant", tf_hero|tf_randomize_face|          tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_1_merchant", "Finn_Bohun","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_2_merchant", "Meepo","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_3_merchant", "Rose_Corbon","{!}Merchant",tf_elven_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_4_merchant", "Stanley_Percival","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_5_merchant", "Leik_Zantor","{!}Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_6_merchant", "Emelina_Denvorn","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_7_merchant", "Nuno_Middleton","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_8_merchant", "Mortimer_Dalyngridge","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_9_merchant", "Thomas_Aragone","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_10_merchant","Ademetos_Temay","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_11_merchant","Cratinus_Andrade","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_12_merchant","Jessica_Deherty","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_13_merchant","Mary_Voisin","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_14_merchant","Vladik_Felius","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_15_merchant","Manton_Corviser","{!}Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_16_merchant","Muriel_Bealcrest","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_17_merchant","Camilla_Sharptongue","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_1_merchant", "Finn_Bohun","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_2_merchant", "Meepo","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_3_merchant", "Rose_Corbon","{!}Merchant",tf_elven_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_4_merchant", "Stanley_Percival","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_5_merchant", "Leik_Zantor","{!}Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_6_merchant", "Emelina_Denvorn","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_7_merchant", "Nuno_Middleton","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_8_merchant", "Mortimer_Dalyngridge","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_9_merchant", "Thomas_Aragone","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_10_merchant","Ademetos_Temay","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_11_merchant","Cratinus_Andrade","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_12_merchant","Jessica_Deherty","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_13_merchant","Mary_Voisin","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_14_merchant","Vladik_Felius","{!}Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_15_merchant","Manton_Corviser","{!}Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_16_merchant","Muriel_Bealcrest","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_17_merchant","Muriel_Bealcrest","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_18_merchant","Muriel_Bealcrest","{!}Merchant",tf_female|tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 

# Horse Merchants
["town_0_horse_merchant","Sarah_Arrowway", "{!}Town 0 Horse Merchant", tf_hero|tf_randomize_face|tf_female|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20),knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_1_horse_merchant", "Jill_Westwick", "{!}Town 1 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_2_horse_merchant", "Richard_Awbrey", "{!}Town 2 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_3_horse_merchant", "Drew_Barentyn", "{!}Town 3 Horse Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_4_horse_merchant", "Johann_Battaile", "{!}Town 4 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_5_horse_merchant", "Alicia_Fyncham", "{!}Town 5 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_elven_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_6_horse_merchant", "Everard_Flete", "{!}Town 6 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_7_horse_merchant", "John_Herdewyk", "{!}Town 7 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_8_horse_merchant", "William_Newport", "{!}Town 8 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_9_horse_merchant", "Rubert_Twygg", "{!}Town 9 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_10_horse_merchant", "Alice_Tymperley", "{!}Town 10 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_11_horse_merchant", "Francis_Abyndon", "{!}Town 11 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_12_horse_merchant", "Nicholas_Alwyn", "{!}Town 12 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_13_horse_merchant", "Artyom_Fusik", "{!}Town 13 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_14_horse_merchant", "Margaret_Bamme", "{!}Town 14 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["town_15_horse_merchant", "Martin_Boleyn", "{!}Town 15 Horse Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_16_horse_merchant", "Henry_Bryce", "{!}Town 16 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["town_17_horse_merchant", "Calvus", "{!}Town 16 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_1_horse_merchant", "Jill_Westwick", "{!}townsle 1 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(2),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_2_horse_merchant", "Richard_Awbrey", "{!}townsle 2 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_3_horse_merchant", "Drew_Barentyn", "{!}townsle 3 Horse Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_4_horse_merchant", "Johann_Battaile", "{!}townsle 4 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_5_horse_merchant", "Alicia_Fyncham", "{!}townsle 5 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_elven_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_6_horse_merchant", "Everard_Flete", "{!}townsle 6 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_7_horse_merchant", "John_Herdewyk", "{!}townsle 7 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_8_horse_merchant", "William_Newport", "{!}townsle 8 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_9_horse_merchant", "Rubert_Twygg", "{!}townsle 9 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_10_horse_merchant", "Alice_Tymperley", "{!}townsle 10 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_11_horse_merchant", "Francis_Abyndon", "{!}townsle 11 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_12_horse_merchant", "Nicholas_Alwyn", "{!}townsle 12 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_13_horse_merchant", "Artyom_Fusik", "{!}townsle 13 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_14_horse_merchant", "Margaret_Bamme", "{!}townsle 14 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant|tf_female, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, woman_face_1, woman_face_2], 
["townsle_15_horse_merchant", "Martin_Boleyn", "{!}townsle 15 Horse Merchant", tf_hero|tf_elven_male|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_16_horse_merchant", "Henry_Bryce", "{!}townsle 16 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_17_horse_merchant", "Henry_Bryce", "{!}townsle 16 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 
["townsle_18_horse_merchant", "Henry_Bryce", "{!}townsle 16 Horse Merchant", tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners, [], def_attrib|level(5),wp(20), knows_inventory_management_10, merchant_face_1, merchant_face_2], 

#Town Mayors
["town_0_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_fur_coat_2, itm_civ_foot_plated_boots_1, itm_cwe_king_gloves], #Maccan
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009ee045205446eaf58d146471d00000000001f34f50000000000000000], #cooopy

["town_1_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_fur_coat_2, itm_civ_foot_plated_boots_1, itm_cwe_king_gloves], #Maccan
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009ee045205446eaf58d146471d00000000001f34f50000000000000000], 
["town_2_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_gamb_blue, itm_civ_foot_plated_boots_1, itm_leather_gloves], #Forde
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009c10440424d2bca2c5d6e2aca00000000001d3a920000000000000000], 
["town_3_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_elven_male, 0, 0, fac_neutral, [itm_arab_bandit_a, itm_boot_average_crusader_c], #Lille
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009e600600252ed4ab4ca0996dc00000000001d56cc0000000000000000], 
["town_4_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_gamb_red, itm_civ_foot_cavalry_boots_black], #Leuven
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009d90c0512296eb164ee5948da00000000001d66930000000000000000], 
["town_5_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_elven_male, 0, 0, fac_neutral, [itm_lorien_armor_e, itm_boot_average_crusader_c], #Forniron
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000f59000001296eb164ee5948da00000000001d66930000000000000000], 
["town_6_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_rich_outfit, itm_civ_foot_plated_boots_2], #Lesbere
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000091200158657a1564d34baa74b00000000001da9130000000000000000], 
["town_7_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_rich_outfit, itm_boot_average_crusader_c], #Vinica
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000009330003cf0d6394b8897658d400000000001da7200000000000000000], 
["town_8_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_rich_fur_1, itm_civ_foot_plated_boots_1, itm_cwe_king_gloves], #Murdenholl
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000093c1044445ed652490867366300000000001de51c0000000000000000], 
["town_9_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_kuyak_b, itm_civ_foot_rich_boots_black, itm_leather_gloves], #Voldeberg
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x000000082f04318733197106a16d479a00000000001e57260000000000000000], 
["town_10_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_arab_vest_3, itm_civ_foot_arab_leather_boots_2], #Khul Vara
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000bae04a0cf33197106a16d479a00000000001e57260000000000000000], 
["town_11_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_kuyak_a, itm_boot_average_crusader_c, itm_leather_gloves], #Freising
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000bb30c65c545448e591cdb374c00000000001dcadc0000000000000000], 
["town_12_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_fur_coat_1, itm_civ_foot_rich_boots_black, itm_cwe_king_gloves], #Arendal
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000c830d025245448e591cdb374c00000000001dcadc0000000000000000], 
["town_13_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_pino_leather_fur_2, itm_boot_average_crusader_c, itm_leather_gloves], #Reichberg
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000cb00523d446d18d39025548e200000000001e469b0000000000000000], 
["town_14_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_padded_armor_4, itm_civ_foot_plated_boots_1], #Krain
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000ca20924d849666ec764ccccbe00000000000b33590000000000000000], 
["town_15_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_elven_male, 0, 0, fac_neutral, [itm_lorien_armor_c, itm_civ_foot_elven_boots_green], #Elsinore
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000c8100000349666ec764ccccbe00000000001f33590000000000000000], 
["town_16_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_surcoat_5, itm_civ_foot_plated_boots_1], #Galwe
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000a8700101449666ec764ccccbe00000000001f33590000000000000000], 
["town_17_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_arab_robe_7, itm_civ_head_m_cwe_turban_black_1, itm_civ_foot_arab_leather_boots_2], #Uliastai
attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d3f00a5c949666ec764ccccbe00000000001f33590000000000000000], 
# ["town_18_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_nomad_lam_brown, itm_civ_foot_arab_leather_boots_black], #Bulgan
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d0f0930c6474ba6bb114ea11c00000000001d97250000000000000000], 
# ["town_19_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_hakkon_noble_outfit, itm_civ_foot_rich_boots_red], #Amarna
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d2d052111275e6aa0b331376600000000001d28920000000000000000], 
# ["town_20_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_giant_male, 0, 0, fac_neutral, [itm_giant_champion_armor_bakhal, itm_giant_warrior_boots], #Vellinaz
# attrlev(30,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d2d042205275e6aa0b331376600000000001d28920000000000000000], 
# ["town_21_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_giant_male, 0, 0, fac_neutral, [itm_armor_weathered_marauder_of_norsca_b_01, itm_giant_br_boots_knee_02], #Sut
# attrlev(30,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d3f04404c275e6aa0b331376600000000001d28920000000000000000], 
# ["town_22_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_gamb_brown, itm_boot_average_crusader_c], #Arish
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d2c10c584235c9149612ebb5300000000001e69230000000000000000], 
# ["town_23_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_fur_vest_1, itm_civ_foot_rich_boots_black, itm_leather_gloves], #Grund
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d2c10430a235c9149612ebb5300000000001e69230000000000000000], 
# ["town_24_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_pino_leather_4, itm_civ_foot_rich_boots_black, itm_leather_gloves], #Grozny
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d2e0c628544a284ca95a9baa600000000001d27ab0000000000000000], 
# ["town_25_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_armor_master_order_templar, itm_boot_average_crusader_c], #Fountain Hall
# attrlev(30,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000d250845912a4ab6232c55ac5c00000000001f36cd0000000000000000], 
# ["town_26_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_dwarf_male, 0, 0, fac_neutral, [itm_dwarf_armor_8_a, itm_dorn_knight_boots], #Karnoth                               old itm_a_h3, itm_boot_average_crusader_c
# attrlev(30,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x00000007ff00a2cb4264b6b95ea9f56200000000001dd4e90000000000000000], #old 0x0000000a420051431a63aa469231985b00000000001e6a5c0000000000000000
# ["town_27_mayor", "Guild_Master", "{!}Guild_Master", tf_hero|tf_dwarf_male, 0, 0, fac_neutral, [itm_dwarf_civilian_2_purple, itm_splinted_greaves], #Dwallnor                          old itm_a_h1_1, itm_civ_foot_rich_boots_black
# attrlev(30,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000bab04208208e46d3712a5b6de00000000001e2a9b0000000000000000], #old 0x0000000a7f00304728606dc6e58a491a00000000001cd7120000000000000000
# ["town_28_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_aroulo_armor_1, itm_aroulo_boots], #Qaletaqa
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000a7300d5c64b5445badb8cdb2900000000001ed6920000000000000000], 
# ["town_29_mayor", "Guild_Master", "{!}Guild_Master", tf_hero, 0, 0, fac_neutral, [itm_civ_body_m_nomad_lam_kuulan, itm_civ_foot_plated_boots_2], #Tumatarhun
# attrlev(18,16,16,12,10), wpex(100,100,100,100,100,100), strsk(4,4,4,4)|agisk(4,4,4,4,4), 0x0000000a7f0081084b5445badb8cdb2900000000001e16920000000000000000], 

["tavern_traveler_1", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_giap_viet4, itm_civil_rich_boots_b], def_attrib|level(5),wp(20), knows_common,0x000000071001110a395c3bbbdcaa3d7400000000001db3110000000000000000], 
["tavern_traveler_2", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_heavy_armor_arabs_f, itm_splinted_greaves], def_attrib|level(5),wp(20), knows_common,0x00000007100141c1395c3bbbdca81d7400000000001db3110000000000000000], 
["tavern_traveler_3", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_black_tribal_outfit, itm_splinted_greaves], def_attrib|level(5),wp(20), knows_common,0x0000000800001344395c3bbbdca82d7400000000001db3110000000000000000], 
["tavern_traveler_4", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_banded_armor, itm_splinted_greaves], def_attrib|level(5),wp(20), knows_common,0x000000002a006409395c3bbbdca82d7400000000001db3110000000000000000], 
["tavern_traveler_5", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_khergit_elite_armor, itm_boot_average_crusader_b], def_attrib|level(5),wp(20), knows_common,0x0000000fea008113395c3bbbdca82d7400000000001db3110000000000000000], 
["tavern_traveler_6", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_knight_armor_hospitaller_c_cloak, itm_dorn_spearbearer_boots], def_attrib|level(5),wp(20), knows_common,0x0000000a3800c207395c3bbbdca9ad7600000000001db5100000000000000000], 
["tavern_traveler_7", "Traveller", "Traveller", tf_hero|tf_female, 0, 0, fac_commoners, [itm_brigandine_red, itm_light_leather_boots], def_attrib|level(5),wp(20), knows_common, 0x000000003f0000067554286724f6c31600000000000000000000000000000000], 
["tavern_traveler_8", "Traveller", "Traveller", tf_hero|tf_female, 0, 0, fac_commoners, [itm_ped_padd_lamellar_whitel, itm_light_leather_boots], def_attrib|level(5),wp(20), knows_common,0x0000000a0e00000a36db6db6db6db6db00000000000000000000000000000000], 
["tavern_traveler_9", "Traveller", "Traveller", tf_hero|tf_elven_male, 0, 0, fac_commoners, [itm_lorien_armor_d, itm_civil_rich_boots_b], def_attrib|level(5),wp(20), knows_common,0x0000000a3400201064662a291495a72400000000001e136e0000000000000000], 
["tavern_traveler_10", "Traveller", "Traveller", tf_hero, 0, 0, fac_commoners, [itm_leather_vest, itm_leather_boots], def_attrib|level(5),wp(20), knows_common,0x00000005f200c012395c3bbbdcaa3d7400000000001db3110000000000000000], 


#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Village Elders
["village_1_elder", "Rob_Kazzian", "{!}village_1_elder", tf_hero|tf_randomize_face|tf_is_merchant, 0,0, fac_commoners, [], def_attrib|level(2),wp(20), knows_inventory_management_10, mfo1, mfo2], 

#Place extra merchants before this point
["merchants_end", "merchants_end", "merchants_end", tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20), knows_inventory_management_10,0], 


#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# Chests
["zendar_chest","{!}Zendar Chest","{!}Zendar Chest",tf_hero|tf_inactive, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_common,0], 
["tutorial_chest_1","{!}Melee Weapons Chest","{!}Melee Weapons Chest",tf_hero|tf_inactive, 0,reserved, fac_neutral, [itm_tutorial_sword, itm_tutorial_axe, itm_tutorial_spear, itm_tutorial_club, itm_tutorial_battle_axe], def_attrib|level(18),wp(60),knows_common, 0], 
["tutorial_chest_2","{!}Ranged Weapons Chest","{!}Ranged Weapons Chest",tf_hero|tf_inactive, 0,reserved, fac_neutral, [itm_tutorial_short_bow, itm_tutorial_arrows, itm_tutorial_crossbow, itm_tutorial_bolts, itm_tutorial_throwing_daggers], def_attrib|level(18),wp(60),knows_common, 0], 
["treasure","Treasure","Treasure",tf_hero|tf_is_merchant|tf_inactive, 0,reserved, fac_neutral, [itm_dwarf_helm_n, itm_strange_great_sword, itm_bread, itm_smoked_fish], def_attrib|level(18),wp(60),knows_common, 0], 
# 0.8 third legion begin
["legion_chest_1","{!}Unusual Chest","{!}Unusual Chest",tf_hero|tf_inactive, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_common, 0], 
# 0.8 third legion end
#cwr finishing shrine of grazir
["grazir_chest","{!}Chest","{!}Chest",tf_hero|tf_inactive, 0,reserved, fac_neutral, [itm_demon_hood], def_attrib|level(18),wp(60),knows_common, 0], 
#cwr finishing shrine of grazir
["household_possessions","{!}household_possessions","{!}household_possessions",tf_hero|tf_inactive|tf_is_merchant, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_inventory_management_10, 0], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# These are used as arrays in the scripts.
#####################################
# ARRAYs  
["key_config","Key Config","Key Configs",tf_hero,0,0,fac_commoners, [], def_attrib|str_14,0,knows_common|knows_power_draw_2,0], 
#####################################  

["temp_array_a","{!}temp_array_a","{!}temp_array_a",tf_hero|tf_inactive, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_common, 0], 
["temp_array_b","{!}temp_array_b","{!}temp_array_b",tf_hero|tf_inactive, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_common, 0], 
["temp_array_c","{!}temp_array_c","{!}temp_array_c",tf_hero|tf_inactive, 0,reserved, fac_neutral, [], def_attrib|level(18),wp(60),knows_common, 0], 

["stack_selection_amounts","{!}stack_selection_amounts","{!}stack_selection_amounts",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 
["stack_selection_ids","{!}stack_selection_ids","{!}stack_selection_ids",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 

["notification_menu_types","{!}notification_menu_types","{!}notification_menu_types",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 
["notification_menu_var1","{!}notification_menu_var1","{!}notification_menu_var1",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 
["notification_menu_var2","{!}notification_menu_var2","{!}notification_menu_var2",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 

["banner_background_color_array","{!}banner_background_color_array","{!}banner_background_color_array",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 

["multiplayer_data","{!}multiplayer_data","{!}multiplayer_data",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib,0,knows_common,0], 

# TPE 1.3 Additions  Silverstag but used in combat enhancement presentation
["tpe_presobj", "{!}Local Merchant","{!}Local Merchant",0,0,0, fac_commoners,																																												[																																																																																																								], def_attrib|level(5),wp(40),knows_inventory_management_10, 0], 
# Why: To remove needing so many global variables to track presentation objects.

##  ["black_khergit_guard","Black Khergit Guard","Black Khergit Guard",tf_mounted|tf_guarantee_ranged|tf_guarantee_shield|tf_guarantee_boots|tf_guarantee_helmet|tf_guarantee_armor|tf_guarantee_horse,0,0,fac_black_khergits,
##   [itm_arrows, itm_nomad_sabre, itm_scimitar, itm_winged_mace, itm_lance, itm_khergit_bow, itm_guard_knight_helm_1, itm_khergit_leather_boots, itm_heraldic_cuir_bouilli, itm_nomad_shield, itm_steppe_horse, itm_northerner_horse], 
##   def_attrib|level(28),wp(140),knows_riding_6|knows_ironflesh_4|knows_horse_archery_6|knows_power_draw_6,khergit_face1, khergit_face2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Multiplayer AI Troops
#["multiplayer_end", "{!}multiplayer_end", "{!}multiplayer_end", 0, 0, 0, fac_kingdom_5, [], 0, 0, 0, 0, 0], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#Player history array
["log_array_entry_type", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_entry_time", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_actor", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_center_object", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_center_object_lord", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_center_object_faction", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_troop_object", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_troop_object_faction", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 
["log_array_faction_object", "{!}Local Merchant","{!}Local Merchant",tf_guarantee_boots|tf_guarantee_armor, 0,0, fac_commoners, [], def_attrib|level(5),wp(40),knows_power_strike_1, merchant_face_1, merchant_face_2], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["looter_leader","Robber","Robbers",tf_hero,0,0,fac_outlaws, [itm_lui_waronehandedaxec, itm_rrr_club1, itm_butchering_knife, itm_falchion, itm_rawhide_coat, itm_stones, itm_peasant_leather_ls, itm_rough_tunic_mailed, itm_woolen_cap, itm_woolen_cap, itm_nomad_boots, itm_rus_shoes], 
def_attrib|level(4),wp(20),knows_common,0x00000001b80032473ac49738206626b200000000001da7660000000000000000,bandit_face2], 

["bandit_leaders_end","bandit_leaders_end","bandit_leaders_end",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 

["relative_of_merchant", "Merchant's Brother", "{!}Prominent",tf_hero,0,0,fac_kingdom_2, [itm_rough_tunic_mailed, itm_nomad_boots], def_attrib|level(1),wp_melee(10),knows_athletics_1|knows_ironflesh_2|knows_shield_2,0x00000000320410022d2595495491afa400000000001d9ae30000000000000000,mercenary_face_2], 

["relative_of_merchants_end","relative_of_merchants_end","relative_of_merchants_end",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
#-#-#-#Hunting Mod begin Michadr (v.0.7)#-#-#-#
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
["deer","Deer","Deer",0,0,0,fac_neutral, [], def_attrib|level(0),wp(60),0,swadian_face_younger_1, swadian_face_younger_1], 
["boar","Boar","Boar",0,0,0,fac_neutral, [], def_attrib|level(0),wp(80),0,swadian_face_younger_1, swadian_face_younger_1], 
["wolf","Wolf","Wolf",0,0,0,fac_neutral, [], def_attrib|level(0),wp(80),0,swadian_face_younger_1, swadian_face_younger_1], 
["coat","Goat","Goat",0,0,0,fac_neutral, [], def_attrib|level(0),wp(60),0,swadian_face_younger_1, swadian_face_younger_1], 
["coat_b","Goat","Goat",0,0,0,fac_neutral, [], def_attrib|level(0),wp(60),0,swadian_face_younger_1, swadian_face_younger_1], 
["wilddonkey","Wild Donkey","Wild Donkey",0,0,0,fac_neutral, [], def_attrib|level(0),wp(60),0,swadian_face_younger_1, swadian_face_younger_1], 
#["rino","Rhino","Rhino",0,0,0,fac_neutral, [], def_attrib|level(0),wp(90),0,swadian_face_younger_1, swadian_face_younger_1], 
#["rino2","Black Rhino","Black Rhino",0,0,0,fac_neutral, [], def_attrib|level(0),wp(90),0,swadian_face_younger_1, swadian_face_younger_1], 
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
#-#-#-#Hunting Mod end#-#-#-#
#-#-#-#-#-#-#-#-#-#-#-#-#-#

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#advistors begin
##diplomacy begin
["dplmc_chamberlain","Chamberlain Aubrey de Vere", "Chamberlains",tf_hero|tf_male,0,0,fac_commoners, [itm_tabard, itm_leather_boots], def_attrib|level(10), wp(40),knows_inventory_management_10,0x000000002c0420c9268a8d14cd65a8e400000000000db69a0000000000000000], 

["dplmc_constable","Constable Miles de Gloucester","Constables",tf_hero|tf_male,0,0,fac_commoners, [itm_dplmc_coat_of_plates_red_constable, itm_mail_boots], knight_attrib_4,wp_melee(200),knows_common|knows_shield_3|knows_ironflesh_3|knows_power_strike_4|knows_athletics_4,0x00000000220c008a4b416da8eb6ac6da00000000000d39640000000000000000], 

["dplmc_chancellor","Chancellor Herfast","Chancellors",tf_hero|tf_male,0,0,fac_commoners, [itm_nobleman_outfit, itm_leather_boots], def_attrib|level(10), wp(40),knows_inventory_management_10, 0x00000008a50d020f4ded2a25eb4dab2400000000001d26f10000000000000000], 

["dplmc_messenger","Messenger","Messengers",tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_horse|tf_guarantee_ranged,0,0,fac_neutral, [itm_sword_medieval_a, itm_leather_jerkin, itm_leather_boots, itm_courser, itm_leather_gloves, itm_light_crossbow, itm_bolts], def_attrib|agi_21|int_30|cha_21|level(25),wp(130),knows_common|knows_riding_7|knows_horse_archery_5|knows_leadership_7, mfy1, mfy2], 

["dplmc_scout","Scout","Scouts",tf_mounted|tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_horse|tf_guarantee_ranged,0,0,fac_neutral, [itm_sword_medieval_c_small, itm_leather_jerkin, itm_leather_boots, itm_courser, itm_leather_gloves, itm_light_crossbow, itm_steel_bolts], def_attrib|agi_21|int_30|cha_21|level(25),wp(130),knows_common|knows_riding_7|knows_horse_archery_5|knows_leadership_7, mfy1, mfo2], 

["perisno_marshal","Perisno High Marshal","High Marshal",tf_hero, 0, reserved, fac_player_supporters_faction, [itm_civ_twiligh_armor, itm_civ_foot_cavalry_boots_black, itm_gondor_bracer_l, itm_cinthorc], 
attrlev(46,34,28,30,60), wpex(430,430,430,430,430,430), strsk(10,10,9,9)|agisk(10,10,6,10,7)|lordsk1(1,0,4,2,8,2,4,4)|lordsk2(3,3,3,4,3,4,7,3), 0x00000007b90412c929668f389a81db1900000000001ea31b0000000000000000], 

# ["dog","Wolf","Wolves",tf_hero|tf_undead|tf_guarantee_all,0,0,fac_commoners, [itm_dog_companion_horse, itm_dog_bite], #Viking Conquest stuff
# attrlev(20,18,5,10,15), wpex(0,0,300,0,0,0), knows_ironflesh_8|knows_riding_7, 0, 0],

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

["freel_marshal","Freelancer Marshal","Freelancer Marshal",tf_hero|tf_no_capture_alive, scn_conversation_scene|entry(1),reserved, fac_freelancer_guild, [itm_west_man_at_arms_armor, itm_ak_wing_helmet_b, itm_black_boot_salad_of, itm_plate_mittens, itm_charger2spak, itm_luc_spiked_mace_5p, itm_sp_shr1], 
attrlev(50,27,22,38,70), wpex(600,600,600,500,500,500), strsk(10,10,9,9)|agisk(10,10,7,10,7)|lordsk1(4,0,10,3,9,3,5,5)|lordsk2(2,0,5,6,7,7,9,6), 0x0000000d7001000436db6db6db6db6db00000000001db6db0000000000000000], 
["bakur", "Bakur the Giant", "Bakur the Giant", tf_giant_male|tf_guarantee_inf|tf_hero, 0, 0, fac_neutral, [itm_armor_elite_marauder_of_norsca_c_02, itm_giant_horned_helmet_bakhal, itm_giant_leather_boots, itm_giant_gloves_plus1, itm_axe_elite_raider_01, itm_throwing_spears], 
attrlev(65,22,8,15,62), wpex(460,460,380,250,200,460), strsk(14,13,12,10)|agisk(9,6,10,0,0)|lordsk1(4,0,4,2,2,0,3,3)|lordsk2(0,0,0,2,0,4,5,0), 0x000000093a04124138d68db754ba42cb00000000001e59d30000000000000000],

["remus","Remus","Remus",tf_hero, 0, reserved, fac_wolf_knights, [itm_churburg_13_mail, itm_hounskull, itm_shynbaulds, itm_hourglass_gauntlets_ornate, itm_luc_english_polehammer], 
attrlev(30,21,15,18,50), wpex(450,450,450,180,180,180), strsk(9,9,7,7)|agisk(9,7,7,8,0)|lordsk1(0,0,7,4,5,3,4,4)|lordsk2(1,1,3,3,4,4,6,4), 0x000000065610424846ac8a106d2aacd400000000001d1b9b0000000000000000], 



["kingdom_0_real_lord","Aracanus","Aracanus",tf_hero, 0, reserved, fac_player_supporters_faction, [(itm_dark_lord_armor, imod_lordly), (itm_black_helmet, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_twilight_gloves, imod_lordly), itm_plated_charger9, itm_flamberge, itm_knights_mace_no1, itm_sp_shr1], 
attrlev(38,30,32,30,60), wpex(470,470,400,300,300,250), strsk(10,8,6,8)|agisk(10,8,5,9,6)|lordsk1(0,2,8,3,8,4,4,5)|lordsk2(4,2,4,3,9,7,8,4), 0x000000053a0002146942da385b6d2d5c00000000001db9140000000000000000], 
["kingdom_1_real_lord", "King Torlian", "Torlian", tf_hero, 0,reserved, fac_kingdom_1, [(itm_kingsman_plate, imod_lordly), (itm_winged_great_helmet, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_hourglass_gauntlets_ornate, itm_ak_charger_plate, itm_luc_morningstar_new, itm_saracin_shield_c, itm_rich_outfit, itm_civil_rich_boots_a], 
attrlev(38,23,28,38,60), wpex(580,580,580,300,300,250), strsk(10,10,8,8)|agisk(10,9,3,10,4)|lordsk1(4,4,10,3,9,2,3,6)|lordsk2(2,2,2,5,10,8,10,5), 0x0000000999040194375a6dacd26db6db00000000001eb69a0000000000000000], 
["kingdom_2_real_lord", "Kaiser Otto IV", "Otto IV", tf_hero, 0,reserved, fac_kingdom_2, [(itm_armour_gothic, imod_lordly), (itm_madelnbucket1, imod_lordly), (itm_black_boot_salad_of, imod_lordly), itm_glovesblack, itm_wyvern, itm_great_axe_no4, itm_round_dragon_shield2, itm_civ_body_m_fur_coat_rich_1, itm_civ_foot_furred_boots_1], 
attrlev(33,25,29,34,60), wpex(530,530,530,300,300,400), strsk(9,9,9,8)|agisk(10,8,2,10,8)|lordsk1(7,3,7,4,9,2,3,5)|lordsk2(3,3,3,7,10,8,9,5), 0x00000009d0042095248b65b49a6ea2eb00000000001d97330000000000000000], 
["kingdom_3_real_lord", "Sultan Yusuf al-Salah", "Yusuf al-Salah", tf_hero, 0,reserved, fac_kingdom_3, [(itm_sultan_armor, imod_lordly), itm_royal_ench, (itm_dorn_sand_snakes_boots, imod_lordly), (itm_gauntlets_arabs_b_l, imod_lordly), itm_warhorse_sarranid_brass, itm_warblade_darkwoodgold, itm_saracin_shield_y, itm_civ_sultan_armor, itm_civ_foot_plated_boots_arab, itm_cwe_king_gloves], 
attrlev(30,32,22,28,60), wpex(480,480,400,480,200,480), strsk(9,9,9,9)|agisk(10,7,7,9,9)|lordsk1(8,9,5,6,5,8,9,8)|lordsk2(5,2,5,3,9,8,8,10), 0x0000000659049349488965b49a6ec2eb00000000001ca75c0000000000000000], 
["kingdom_4_real_lord", "Agathor Krex", "Krex", tf_hero, 0,reserved, fac_kingdom_4, [(itm_milanese_armour, imod_lordly), (itm_pigface_klappvisor, imod_lordly), (itm_steel_greaves, imod_lordly), (itm_hourglass_gauntlets, imod_lordly), itm_plated_charger2, itm_german_horsemans_axe_no1, itm_saracin_shield_s, itm_hurlbat_2, itm_civ_body_m_noble_1, itm_civ_foot_ankle_boots_brown], 
attrlev(38,29,26,33,60), wpex(550,550,400,200,250,600), strsk(10,10,10,9)|agisk(10,9,6,10,9)|lordsk1(7,1,8,3,7,5,5,5)|lordsk2(2,2,3,8,10,9,10,3), 0x0000000960001285431a94371b50b76300000000001dd8e20000000000000000], 
["kingdom_5_real_lord", "Queen Arwen", "Arwen", tf_elven_female|tf_hero, 0,reserved, fac_kingdom_5, [(itm_mirk_armor_1b, imod_lordly), itm_royal_ench, (itm_mirk_boots_1, imod_lordly), (itm_twilight_gloves, imod_lordly), itm_twilight_horse, itm_warblade_greensilver, itm_sp_shr1, itm_ranger_bow, itm_blackarrow, itm_new_dress_b, itm_civ_foot_cavalry_boots_black], 
attrlev(32,38,36,40,60), wpex(550,550,550,620,300,300), strsk(9,9,8,10)|agisk(10,8,8,10,10)|lordsk1(5,9,5,8,8,10,10,8)|lordsk2(7,5,7,3,10,7,10,8), 0x000000092c1010132a91c8b899b1c2f30000000000e916710000000000000000], 
["kingdom_6_real_lord", "Emperor Hakkon II", "Hakkon II", tf_hero, 0,reserved, fac_kingdom_6, [(itm_west_guardsman, imod_lordly), (itm_barbuta2_greekish_purple, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_glovesblack, imod_lordly), itm_plated_charger9, itm_jack_anduril, itm_shield_7, itm_throwing_spears, itm_civ_west_guardsman, itm_civ_foot_imperial_boots_m], 
attrlev(36,30,28,35,60), wpex(560,560,500,200,400,600), strsk(10,10,10,9)|agisk(10,9,6,10,10)|lordsk1(6,1,10,2,10,3,3,5)|lordsk2(2,2,4,9,10,10,10,3), 0x000000074804024836db6cb71bd2392b00000000001db50b0000000000000000], 
["kingdom_7_real_lord", "Emperor Zann Mandate of Heaven", "Zann", tf_hero, 0, reserved, fac_kingdom_7, [(itm_dorn_immortal_armor, imod_lordly), (itm_dorn_immortal_helmet, imod_lordly), (itm_black_boot_salad_of, imod_lordly), (itm_kote, imod_lordly), itm_warhorse_sarranid_black, itm_two_handed_katana, itm_roman_shield_velite, itm_taureg_armor, itm_civ_foot_suneate_boots_red], 
attrlev(32,32,26,32,60), wpex(600,600,450,300,200,300), strsk(8,10,8,8)|agisk(10,5,6,8,5)|lordsk1(9,3,8,5,6,5,5,7)|lordsk2(3,1,3,5,10,7,10,8), 0x000000076110939648ef4a3addd63b2500000000001cb76b0000000000000000], 
["kingdom_8_real_lord", "Field Marshal Gunnar", "Gunnar", tf_hero, 0,0, fac_kingdom_8, [(itm_dark_lord_armor2, imod_lordly), (itm_winged_helmet, imod_lordly), (itm_west_pikeman_boots, imod_lordly), (itm_dorn_knight_gant, imod_lordly), itm_spak_charger_plate, itm_sword_val_3, itm_gondor_shield_c, itm_civ_twiligh_armor_silver, itm_civ_foot_ornate_boots_1], 
attrlev(44,32,35,44,60), wpex(620,620,600,500,500,500), strsk(10,10,10,10)|agisk(10,9,5,10,8)|lordsk1(4,5,10,5,10,5,7,7)|lordsk2(6,5,8,9,10,10,10,4), 0x00000006340180116942d2385bb93d5c00000000001e37190000000000000000], 
["kingdom_9_real_lord", "King Ingveld", "Ingveld", tf_hero, 0,reserved, fac_kingdom_9, [(itm_plate_armor, imod_lordly), (itm_maciejowski_helmet5b, imod_lordly), (itm_plate_boots, imod_lordly), (itm_dorn_knight_gant, imod_lordly), itm_ak_warhorse_chain_c, itm_luc_maciejowski_axe, itm_heavy_throwing_axes, itm_fur_coat_2, itm_civ_foot_plated_boots_1], 
attrlev(48,25,22,32,60), wpex(600,600,500,400,250,600), strsk(10,10,10,9)|agisk(10,8,5,8,10)|lordsk1(10,3,10,5,7,4,6,5)|lordsk2(2,0,2,4,9,10,10,1), 0x0000000a730182cf3acb56a553b0182c00000000001e67110000000000000000], 
["kingdom_10_real_lord", "King Bergnar", "Bergnar", tf_hero|tf_dwarf_male, 0,reserved, fac_kingdom_10, [itm_dwarf_armor_10, (itm_dwarf_helm_j, imod_lordly), (itm_west_pikeman_boots, imod_lordly), itm_dwarf_glove, itm_arhar_armor_2, itm_sungodaxe, itm_dwarf_ih_shield_1c, itm_luc_throwing_hammer, itm_civ_kaikoth_armor_3, itm_civ_foot_ornate_boots_1], 
attrlev(54,22,26,36,60), wpex(580,580,500,350,350,600), strsk(12,12,11,10)|agisk(10,9,4,10,10)|lordsk1(2,5,10,4,8,3,4,10)|lordsk2(0,0,0,10,10,9,10,10), 0x00000009b900710b2cdf6bb4a856558c00000000001de32c0000000000000000], 
["kingdom_11_real_lord", "Geldarin King Rhinio", "Rhinio", tf_hero|tf_elven_male, 0,reserved, fac_kingdom_11, [(itm_rivendellrewardarmour, imod_lordly), itm_royal_ench, (itm_riv_boots, imod_lordly), (itm_cwe_king_gloves, imod_lordly), itm_warblade_bluesilver, itm_ranger_bow, itm_spak_arrow, itm_spak_arrow, itm_civ_elven_armor_0], 
attrlev(37,37,40,38,60), wpex(620,550,550,620,200,330), strsk(10,10,8,10)|agisk(10,6,10,8,10)|lordsk1(7,10,10,9,8,10,10,8)|lordsk2(9,6,9,3,10,9,10,3), 0x0000000bbd00000b12e251b6a474976400000000001ed3240000000000000000], 
["kingdom_12_real_lord", "King Aolas", "Aolas", tf_hero, 0,reserved, fac_kingdom_12, [(itm_plate_armor3, imod_lordly), (itm_crown_helm, imod_lordly), (itm_dorn_knight_boots, imod_lordly), itm_plate_mittens, itm_charger_steel, itm_sword_val_3, itm_steel_shield_kite, itm_courtly_outfit, itm_civ_foot_hide_boots_1], 
attrlev(34,22,30,32,60), wpex(520,520,500,350,350,350), strsk(10,9,8,8)|agisk(10,8,2,9,0)|lordsk1(3,2,8,2,9,2,2,8)|lordsk2(6,6,6,8,10,8,10,8), 0x0000000a4111020448ef4a36ddd53b2500000000001cb74b0000000000000000], 
["kingdom_13_real_lord", "Boshman Baatur", "Boshman", tf_hero, 0,reserved, fac_kingdom_13, [(itm_zabadai_man_armor, imod_lordly), (itm_helm_tyrk_heavi_b, imod_lordly), (itm_twilight_boots, imod_lordly), (itm_glovesblack, imod_lordly), itm_ak_warhorse_chain_a, itm_luc_knightly_axe, itm_saracin_shield_g, itm_throwing_spears, itm_civ_body_m_nomad_lam_kuulan, itm_civ_foot_rich_boots_black], 
attrlev(42,30,23,34,60), wpex(600,600,500,500,150,500), strsk(10,10,10,10)|agisk(10,7,7,10,10)|lordsk1(8,6,8,6,4,8,8,7)|lordsk2(2,0,4,5,8,8,10,6), 0x000000092610838b48ed4a36dd752b2500000000001cb7500000000000000000], 
["kingdom_14_real_lord", "Vandr Jornleikr", "Jornleikr", tf_giant_male|tf_hero, 0,reserved, fac_kingdom_14, [(itm_giant_chieftan_armor_bakhal, imod_reinforced), (itm_giant_horned_helmet_bakhal, imod_reinforced), (itm_giant_plated_boots_war, imod_reinforced), (itm_giant_gloves_plus1, imod_reinforced), itm_axe_elite_berserker_a_01, itm_giant_plate_armor_bakhal, itm_giant_warrior_boots], 
attrlev(98,20,12,20,60), wpex(550,550,400,100,100,400), strsk(15,15,14,10)|agisk(10,7,10,0,0)|lordsk1(10,2,10,1,1,0,2,3)|lordsk2(0,0,0,2,6,10,10,0), 0x0000000bab0022c238d68f3d69b1c85d00000000001dda430000000000000000], 
["kingdom_15_real_lord", "Grand Chieftain Azhar", "Azhar", tf_giant_male|tf_hero, 0,reserved, fac_kingdom_15, [(itm_giant_chieftan_armor_sut, imod_reinforced), (itm_giant_warlord_helmet, imod_reinforced), (itm_giant_plated_boots_war, imod_reinforced), (itm_giant_gloves_plus, imod_reinforced), itm_horny_charger_plate, itm_sut_one_handed_war_axe, itm_sut_elite_shield, itm_giant_leather_armor_sut, itm_giant_br_boots_knee_02], 
attrlev(81,21,15,24,60), wpex(520,520,520,230,100,200), strsk(15,15,13,13)|agisk(10,9,8,9,0)|lordsk1(9,3,10,2,3,0,2,4)|lordsk2(0,0,0,4,6,10,10,1), 0x0000000cd200010b693369b6e3751a6300000000001e39230000000000000000], 
["kingdom_16_real_lord", "Aroulo Pomaahkaa", "Pomaahkaa", tf_hero, 0,reserved, fac_kingdom_16, [(itm_armour_braided, imod_lordly), (itm_aroulo_boots, imod_hardened), itm_gloves_lord_l, itm_woodman_staff, itm_aroulo_throwing_wep, itm_aroulo_throwing_wep, itm_civ_aroulo_armor_1], 
attrlev(45,33,12,26,60), wpex(600,600,640,550,100,640), strsk(10,10,10,10)|agisk(10,3,10,0,0)|lordsk1(5,9,8,9,3,9,8,5)|lordsk2(2,0,2,1,9,8,10,3), 0x0000000c6a0cd00b26ca86c5136156ad00000000001db87a0000000000000000], 
["kingdom_17_real_lord", "Atanos Paramonos", "Paramonos", tf_hero, 0, reserved, fac_kingdom_17, [(itm_tribune_b_3, imod_lordly), (itm_h_tribune2, imod_lordly), (itm_roman_centurion_boots, imod_lordly), (itm_west_man_at_arms_gl, imod_lordly), itm_plate_armour_charger2, (itm_luc_celtic_sword_cwe, imod_masterwork), itm_steel_shield_kite, itm_roman_pilum_2, itm_roman_pilum_2, itm_civ_foot_plated_boots_2], 
attrlev(37,30,30,32,60), wpex(560,560,450,250,250,560), strsk(10,10,10,7)|agisk(10,9,8,10,10)|lordsk1(4,1,10,3,10,3,7,5)|lordsk2(2,1,3,6,9,9,10,3), 0x00000007b3111004285c95ab597136f500000000001dc4a90000000000000000],

["salt_mine_merchant","Barezan","Barezan", tf_hero|tf_is_merchant, 0,0, fac_commoners, [itm_pilgrim_disguise, itm_light_leather_boots], def_attrib|level(2),wp(20),knows_inventory_management_10, 0x0000000fe50085d3395c3bbbdca9ad7400000000001db3100000000000000000], 

#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# SU. Entertainment Guild 0.7. ALPHA STAGE
["entertainment_guildsman_1", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #fire_arrows
["entertainment_guildsman_2", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #x_coordinate
["entertainment_guildsman_3", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #y_coordinate
["entertainment_guildsman_4", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #z_coordinate
["entertainment_guildsman_5", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #x_velocity
["entertainment_guildsman_6", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #y_velocity
["entertainment_guildsman_7", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], #z_velocity
["entertainment_guildsman_8", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["entertainment_guildsman_10", "Entertainment Guildsman", "Entertainment Guildsmen", tf_hero|tf_randomize_face, 0, 0, fac_commoners, [itm_leather_boots, itm_tabard], def_attrib|level(10),wp(20), knows_common,merchant_face_1,merchant_face_2], 
["entertainment_guildsman_end","_","_",tf_inactive,0,0,0, [], 0,0,0,0], 
# SU. Entertainment Guild 0.7. ALPHA STAGE


["inventory_backup","Inventory","Inventory",tf_hero|tf_inactive,0,reserved,fac_neutral, [], def_attrib|level(18),wp(60),knows_inventory_management_10,0], 

["treasure_2","Treasure","Treasure",tf_hero|tf_is_merchant|tf_inactive, 0,reserved, fac_neutral, [itm_warhammer], def_attrib|level(18),wp(60),knows_common, 0], 

############## PERISNO DEFINITIONS END #########

### list system 
["list_01","-","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], # cf_select_random_walled_center_with_faction needs this
["list_02","-","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], # as would sea trader kit when calling create_kingdom_party_if_below_limit
["list_03","-","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
### list

#HORSE ARCHERS TROOPS SHOULD BE THE LAST ONES IN A ROW
#pos20-pos34 are used for these divisions!
["pl_infantry","pl_inf_shields","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_archers","pl_archers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_cavalry","pl_cavalry","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_horsearchers","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_d5","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_d6","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_d7","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_d8","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["pl_d9","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
#
["t1_infantry","t1_inf_shields","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], #enemies
["t1_archers","t1_archers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_cavalry","t1_cavalry","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_horsearchers","t1_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_d5","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_d6","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_d7","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_d8","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_d9","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
#
["t2_infantry","t2_inf_shields","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], #allies
["t2_archers","t2_archers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_cavalry","t2_cavalry","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_horsearchers","t2_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_d5","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_d6","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_d7","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_d8","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_d9","pl_horsearchers","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["misspot_cache_troops_end","-","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 


["pl_inf_sh ock","pl_inf_shock","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t1_inf_sh ock","t1_inf_shock","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
["t2_inf_sh ock","t2_inf_shock","-",tf_hero, 0,0, fac_commoners, [], def_attrib|level(2),wp(20),knows_inventory_management_10,0], 
]


##TROOP TREES
#Major Factions

#Tolrania
upgrade2(troops,"k01_tol_footman","k01_tol_trainedfootman","k01_tol_bowman")
upgrade(troops,"k01_tol_trainedfootman","k01_tol_vetfootman")
upgrade2(troops,"k01_tol_vetfootman","k01_tol_hacker","k01_tol_kingsguard")
upgrade(troops,"k01_tol_hacker","k01_tol_masterhacker")
upgrade(troops,"k01_tol_bowman","k01_tol_longbowman")
upgrade(troops,"k01_tol_longbowman","k01_tol_vetlongbowman")
upgrade2(troops,"k01_tol_vetlongbowman","k01_tol_archer","k01_tol_headhunter")
upgrade(troops,"k01_tol_kingsguard","k01_tol_kingsman")
upgrade(troops,"k01_tol_recruit","k01_tol_footman")
upgrade(troops,"k01_tol_n_crownsquire","k01_tol_n_crownknight")

upgrade(troops,"k01_tol_enduinius_longbowman", "k01_tol_enduinius_vetlongbowman") 
upgrade(troops,"k01_tol_enduinius_vetlongbowman","k01_tol_archer") #Enduinius never trains headhunters, only foot archers

#Reich des Drachen
upgrade2(troops,"k02_rei_krieger","k02_rei_fussoldat","k02_rei_bogenschutze")
upgrade2(troops,"k02_rei_fussoldat","k02_rei_landsknecht","k02_rei_reiter")
upgrade(troops,"k02_rei_bogenschutze","k02_rei_scharfschutze")
upgrade(troops,"k02_rei_scharfschutze","k02_rei_elitescharfschutze")
upgrade(troops,"k02_rei_elitescharfschutze","k02_rei_kaiserlichecharfschutze")
upgrade(troops,"k02_rei_landsknecht","k02_rei_speerkampfer")
upgrade(troops,"k02_rei_speerkampfer","k02_rei_elitespeerkampfer")
upgrade(troops,"k02_rei_reiter","k02_rei_kavallerie")
upgrade(troops,"k02_rei_kavallerie","k02_rei_dragoner")
upgrade(troops,"k02_rei_recruit","k02_rei_krieger")

upgrade(troops,"k02_rei_fridl_krieger","k02_rei_fridl_fussoldat")
upgrade(troops,"k02_rei_fridl_fussoldat","k02_rei_landsknecht")
#Drahara
upgrade2(troops,"k03_dra_spearman","k03_dra_vetspearman","k03_dra_desertbowman")
upgrade(troops,"k03_dra_vetspearman","k03_dra_desertwarrior")
upgrade2(troops,"k03_dra_desertwarrior","k03_dra_lightrider","k03_dra_shadowwarrior")
upgrade(troops,"k03_dra_lightrider","k03_dra_warrider")
upgrade(troops,"k03_dra_desertarcher","k03_dra_windarcher")
upgrade(troops,"k03_dra_desertbowman","k03_dra_desertarcher")
upgrade(troops,"k03_dra_shadowwarrior","k03_dra_desertassassin")
upgrade(troops,"k03_dra_tribesman","k03_dra_spearman")
upgrade(troops,"k03_dra_m_shadowguard","k03_dra_m_duskguard")

#Maccavia
upgrade2(troops,"k04_mac_axeman","k04_mac_footman","k04_mac_crossbowman")
upgrade(troops,"k04_mac_crossbowman","k04_mac_heavycrossbowman")
upgrade2(troops,"k04_mac_heavycrossbowman","k04_mac_mtdmarksman","k04_mac_marksman")
upgrade(troops,"k04_mac_footman","k04_mac_swordsman")
upgrade2(troops,"k04_mac_swordsman","k04_mac_swordsmaster","k04_mac_spearman")
upgrade(troops,"k04_mac_spearman","k04_mac_halberdier")
upgrade(troops,"k04_mac_marksman","k04_mac_heavymarksman")
upgrade(troops,"k04_mac_swordsmaster","k04_mac_northguard")
upgrade(troops,"k04_mac_freeman","k04_mac_axeman")

#Elintoran nation
upgrade(troops,"k05_eli_hunter","k05_eli_scout")
upgrade(troops,"k05_eli_scout","k05_eli_bowman")
upgrade2(troops,"k05_eli_bowman","k05_eli_rider","k05_eli_archer")
upgrade(troops,"k05_eli_rider","k05_eli_sunriserider")
upgrade(troops,"k05_eli_sunriserider","k05_eli_knight")
upgrade(troops,"k05_eli_archer","k05_eli_ranger")
upgrade(troops,"k05_eli_ranger","k05_eli_crimsonranger")

#Hakkon Empire
upgrade2(troops,"k06_hak_militia","k06_hak_spearman","k06_hak_footman")
upgrade2(troops,"k06_hak_footman","k06_hak_heavyfootman","k06_hak_crossbowman")
upgrade(troops,"k06_hak_crossbowman","k06_hak_sharpshooter")
upgrade(troops,"k06_hak_heavyfootman","k06_hak_legionnaire")
upgrade2(troops,"k06_hak_spearman","k06_hak_lancer","k06_hak_vetspearman")
upgrade(troops,"k06_hak_vetspearman","k06_hak_impspearman")
upgrade(troops,"k06_hak_lancer","k06_hak_implancer")
upgrade(troops,"k06_hak_loyalrecruit","k06_hak_militia")

#Valahir Clan
upgrade(troops,"k09_val_thrall", "k09_val_landi")
upgrade2(troops,"k09_val_landi", "k09_val_drengr","k09_val_bogisveinn")
upgrade(troops,"k09_val_drengr", "k09_val_harddrengr")
upgrade(troops,"k09_val_harddrengr", "k09_val_seggr")
upgrade2(troops,"k09_val_seggr", "k09_val_huscarl","k09_val_hersir")
upgrade(troops,"k09_val_huscarl", "k09_val_vassargl")
upgrade(troops,"k09_val_hersir", "k09_val_hiligord")
upgrade(troops,"k09_val_bogisveinn", "k09_val_bogirre")
upgrade(troops,"k09_val_bogirre", "k09_val_heavybogirre")
upgrade(troops,"k09_val_heavybogirre", "k09_val_ullr")

#Cretas
upgrade(troops,"k12_cre_rabble","k12_cre_levy")
upgrade2(troops,"k12_cre_levy","k12_cre_vigil","k12_cre_huntsman")
upgrade2(troops,"k12_cre_vigil","k12_cre_defender","k12_cre_warden")
upgrade(troops,"k12_cre_huntsman","k12_cre_skilledhuntsman")
upgrade(troops,"k12_cre_skilledhuntsman","k12_cre_horsehunter")
upgrade(troops,"k12_cre_defender","k12_cre_custodian")
upgrade(troops,"k12_cre_custodian","k12_cre_eidolon")
upgrade2(troops,"k12_cre_warden","k12_cre_cavalry","k12_cre_ironclad")
upgrade(troops,"k12_cre_cavalry","k12_cre_eidolonknight")

#Realm of the Falcon
upgrade2(troops,"k08_fal_cav01","k08_fal_cav02","k08_fal_cavar02")
upgrade(troops,"k08_fal_cav02","k08_fal_cav03")
upgrade(troops,"k08_fal_cavar02","k08_fal_cavar03")
#
upgrade(troops,"k08_fal_inf01","k08_fal_inf02")
upgrade(troops,"k08_fal_inf02","k08_fal_inf03")
#
upgrade(troops,"k08_fal_arch01","k08_fal_arch02")
upgrade(troops,"k08_fal_arch02","k08_fal_arch03")

#Kaikoth Confederation
upgrade(troops,"k10_kai_miner","k10_kai_clansman")
upgrade2(troops,"k10_kai_clansman","k10_kai_footman","k10_kai_highlandcrossbowman")
upgrade2(troops,"k10_kai_footman","k10_kai_halberdier","k10_kai_warrior")
upgrade(troops,"k10_kai_halberdier","k10_kai_elite_halberdier")
upgrade2(troops,"k10_kai_warrior","k10_kai_mountainwarrior","k10_kai_elitescout")
upgrade2(troops,"k10_kai_mountainwarrior","k10_kai_mountainkeeper","k10_kai_ironguardsman")
upgrade(troops,"k10_kai_seeker","k10_kai_highseeker")
upgrade(troops,"k10_kai_highlandcrossbowman","k10_kai_seeker")
upgrade(troops,"k10_kai_n_ironfist","k10_kai_n_vanguard")
upgrade(troops,"k10_kai_harunn_warrior","k10_kai_mountainwarrior")
upgrade(troops,"k10_kai_n_master_miner","k10_kai_n_foreman")

#Geldarin Elves
upgrade(troops,"k11_gel_recruit","k11_gel_woodbowman")
upgrade(troops,"k11_gel_woodbowman","k11_gel_woodarcher")
upgrade2(troops,"k11_gel_woodarcher","k11_gel_sergeant","k11_gel_bordersentinel")
upgrade2(troops,"k11_gel_sergeant","k11_gel_ranger","k11_gel_blademaster")
upgrade2(troops,"k11_gel_ranger","k11_gel_forestwarden","k11_gel_footknight")
upgrade(troops,"k11_gel_n_noble","k11_gel_n_duke")

#Bakhal
upgrade2(troops,"k14_bak_villager","k14_bak_huntsman","k14_bak_footman")
upgrade(troops,"k14_bak_footman","k14_bak_soldier")
upgrade(troops,"k14_bak_soldier","k14_bak_warrior")
upgrade(troops,"k14_bak_warrior","k14_bak_seasonedwarrior")
upgrade(troops,"k14_bak_seasonedwarrior","k14_bak_champion")
upgrade(troops,"k14_bak_huntsman","k14_bak_archer")
upgrade(troops,"k14_bak_archer","k14_bak_skullshooter")
upgrade(troops,"k14_bak_hslave1","k14_bak_hslave2")

#Sut
upgrade(troops,"k15_sut_giant","k15_sut_clansman")
upgrade2(troops,"k15_sut_clansman","k15_sut_huntsman","k15_sut_fighter")
upgrade(troops,"k15_sut_huntsman","k15_sut_bowman")
upgrade(troops,"k15_sut_fighter","k15_sut_warrior")
upgrade2(troops,"k15_sut_warrior","k15_sut_chiefsguard","k15_sut_berserker")
upgrade(troops,"k15_sut_n_raider","k15_sut_n_chieftan")

#Aroulo
upgrade(troops,"k16_aro_unproven","k16_aro_tribesman")
upgrade(troops,"k16_aro_tribesman","k16_aro_woodsman")
upgrade2(troops,"k16_aro_woodsman","k16_aro_hurler","k16_aro_bowman")
upgrade(troops,"k16_aro_bowman","k16_aro_bowmaster")
upgrade2(troops,"k16_aro_hurler","k16_aro_fighter","k16_aro_provenhurler")
upgrade(troops,"k16_aro_fighter","k16_aro_warrior")
upgrade(troops,"k16_aro_warrior","k16_aro_provenwarrior")
upgrade(troops,"k16_aro_provenhurler","k16_aro_masterhurler")

#Kuu-lan
upgrade2(troops,"k13_kuu_nomad","k13_kuu_anshi","k13_kuu_eren")
upgrade(troops,"k13_kuu_anshi","k13_kuu_sadak")
upgrade(troops,"k13_kuu_sadak","k13_kuu_atkish")
upgrade(troops,"k13_kuu_atkish","k13_kuu_mergen")
upgrade(troops,"k13_kuu_mergen","k13_kuu_kara_mergen")
upgrade(troops,"k13_kuu_eren","k13_kuu_yasak")
upgrade(troops,"k13_kuu_yasak","k13_kuu_aldaspan")
upgrade2(troops,"k13_kuu_aldaspan","k13_kuu_lankes","k13_kuu_ulan")
upgrade(troops,"k13_kuu_ulan","k13_kuu_baatur")

#TTL
upgrade2(troops,"k17_ttl_compinfantry","k17_ttl_compsoldier","k17_ttl_compcavalry")
upgrade(troops,"k17_ttl_compcavalry","k17_ttl_compcavalryplus")
upgrade2(troops,"k17_ttl_compsoldier","k17_ttl_legionary","k17_ttl_comparcher")
upgrade(troops,"k17_ttl_comparcher","k17_ttl_sagittarius")
upgrade(troops,"k17_ttl_legionary","k17_ttl_legionaryveteranus")
upgrade2(troops,"k17_ttl_legionaryveteranus","k17_ttl_legionaryimperialis","k17_ttl_praetorian")

#The Zann Dynasty (Michadr Edited For 0.72)
upgrade(troops,"k07_zan_peasant","k07_zan_militia")
upgrade2(troops,"k07_zan_militia","k07_zan_swordsman","k07_zan_bowman")
upgrade(troops,"k07_zan_swordsman","k07_zan_trainedswordsman")
upgrade(troops,"k07_zan_bowman","k07_zan_trainedbowman")
upgrade2(troops,"k07_zan_trainedbowman","k07_zan_vetbowman","k07_zan_mtdarcher")
upgrade(troops,"k07_zan_vetbowman", "k07_zan_longbowman")
upgrade(troops,"k07_zan_mtdarcher", "k07_zan_swifthunter")
upgrade(troops,"k07_zan_swifthunter", "k07_zan_heavyrider")
upgrade(troops,"k07_zan_trainedswordsman", "k07_zan_vetswordsman")
upgrade(troops,"k07_zan_vetswordsman", "k07_zan_spearman")
upgrade(troops,"k07_zan_spearman","k07_zan_spearmaster")

#Perisno (Player Faction)
upgrade(troops,"k00_per_recruit","k00_per_militia")
upgrade2(troops,"k00_per_militia","k00_per_footman","k00_per_bowman")
upgrade(troops,"k00_per_bowman","k00_per_archer")
upgrade(troops,"k00_per_archer","k00_per_runearcher")
upgrade(troops,"k00_per_runearcher","k00_per_darkarcher")
upgrade(troops,"k00_per_footman","k00_per_manatarms")
upgrade2(troops,"k00_per_manatarms","k00_per_cavalry","k00_per_warrior")
upgrade2(troops,"k00_per_warrior","k00_per_champion","k00_per_guardsman")
upgrade(troops,"k00_per_cavalry","k00_per_darkcavalry") 
upgrade(troops,"k00_per_n_eclipseknight","k00_per_n_totaleclipseknight") 
#Perisno 1st Female Trooptree
upgrade(troops,"k00_per_f_recruit","k00_per_f_maiden")
upgrade(troops,"k00_per_f_maiden","k00_per_f_rider")
upgrade(troops,"k00_per_f_rider","k00_per_f_ranger")
upgrade(troops,"k00_per_f_ranger","k00_per_f_champion")

#Perisno Pilgrims
upgrade(troops,"k00_per_pm_pilgrim", "k00_per_pm_monk")
upgrade(troops,"k00_per_pm_monk", "k00_per_pm_cleric")
upgrade2(troops,"k00_per_pm_cleric", "k00_per_pm_crusader", "k00_per_pm_priest")
upgrade(troops,"k00_per_pm_crusader","k00_per_pm_zealot")
upgrade(troops,"k00_per_pm_priest", "k00_per_pm_holychampion")
#Female Perisno Pilgrims
upgrade(troops,"k00_per_pf_initiate", "k00_per_pf_novice")
upgrade(troops,"k00_per_pf_novice", "k00_per_pf_nunfoot")
upgrade(troops,"k00_per_pf_nunfoot", "k00_per_pf_nuncavalry")
upgrade(troops,"k00_per_pf_nuncavalry","k00_per_pf_priestess")
#
upgrade(troops,"k00_per_pm_good_pilgrim", "k00_per_pm_good_monk")
upgrade(troops,"k00_per_pm_good_monk", "k00_per_pm_good_cleric")
upgrade(troops,"k00_per_pm_good_cleric", "k00_per_pm_priest")
upgrade(troops,"k00_per_pm_bad_pilgrim", "k00_per_pm_bad_monk")
upgrade(troops,"k00_per_pm_bad_monk", "k00_per_pm_bad_cleric")
upgrade(troops,"k00_per_pm_bad_cleric", "k00_per_pm_crusader")

#Noble Recruitment
upgrade2(troops,"k00_per_n_squire", "k00_per_n_rangerknight","k00_per_n_greatknight")
upgrade2(troops,"k04_mac_n_squire", "k04_mac_n_blackknight","k04_mac_n_steelknight")
upgrade(troops,"k06_hak_n_cavalry", "k06_hak_n_impknight")
upgrade2(troops,"k06_hak_n_cavalry", "k06_hak_n_impknight","k06_hak_n_impcavalry")
upgrade(troops,"k02_rei_n_knappe", "k02_rei_n_drachenritter")
upgrade(troops,"k05_eli_n_hisentinel", "k05_eli_n_hiwarden")
upgrade(troops,"k09_val_n_thegn", "k09_val_n_jarl")
upgrade(troops,"k09_val_n_jarl", "k09_val_n_asbjarl")
upgrade2(troops,"k03_dra_n_dunerider", "k03_dra_n_royalrider","k03_dra_n_duneguardian")
upgrade(troops,"k08_fal_n_cav01","k08_fal_n_cav02")
upgrade2(troops,"k01_tol_n_squire", "k01_tol_n_knight","k01_tol_n_footknight")
#upgrade(troops,"k01_tol_n_knight","k01_tol_n_champion")
upgrade(troops,"k13_kuu_n_alaman","k13_kuu_n_ataman")
upgrade(troops,"k16_aro_n_strongone","k16_aro_n_beastslayer")
upgrade(troops,"k17_ttl_n_optio","k17_ttl_n_kalero")
upgrade(troops,"k17_ttl_n_kalero","k17_ttl_n_visavo")


#Minor Factions and Spawns
#Mercenaries (Changed and completed by Silberfalke)
#Cavalry
upgrade(troops,"townsman","m01_mem_c_cavalryman")
upgrade2(troops,"m01_mem_c_cavalryman","m01_mem_c_caravanguard","m01_mem_a_skirmisher")
upgrade2(troops,"m01_mem_c_caravanguard","m01_mem_i_swordsman","m01_mem_c_shockcavalry")
upgrade(troops,"m01_mem_c_shockcavalry","m01_mem_c_cavalry")
upgrade(troops,"m01_mem_c_cavalry","m01_mem_c_lancer")
#Infantry
upgrade(troops,"m01_mem_i_swordsman","m01_mem_i_sellsword")
upgrade(troops,"m01_mem_i_sellsword","m01_mem_i_impknight")
#Crossbows
upgrade(troops,"m01_mem_a_skirmisher","m01_mem_a_crossbowman")
upgrade(troops,"m01_mem_a_crossbowman","m01_mem_a_vetcrossbowman")
upgrade(troops,"m01_mem_a_vetcrossbowman","m01_mem_a_sniper")

#Female Mercenaries
upgrade2(troops,"m02_mef_2_refugee","m02_mef_2_archer","k00_per_pf_initiate")
upgrade(troops,"m02_mef_2_archer","m02_mef_2_tracker")
upgrade(troops,"m02_mef_2_tracker","m02_mef_2_huntress")
upgrade(troops,"m02_mef_2_huntress","m02_mef_2_masterhuntress")
upgrade(troops,"m02_mef_2_masterhuntress","m02_mef_2_stalker")

#Perisno 2nd Female Trooptree
upgrade2(troops,"m02_mef_1_peasantwoman","m02_mef_1_campdefender","k00_per_f_recruit")
upgrade2(troops,"m02_mef_1_campdefender","m02_mef_1_femmefatale","m02_mef_1_scout")
upgrade(troops,"m02_mef_1_scout","m02_mef_1_markswoman")
upgrade(troops,"m02_mef_1_markswoman","m02_mef_1_sharpshooter")
upgrade2(troops,"m02_mef_1_femmefatale","m02_mef_1_vixenrider", "m02_mef_1_swordsister")
upgrade2(troops,"m02_mef_1_swordsister", "m02_mef_1_swordmaiden", "m02_mef_1_viragocav")
upgrade2(troops,"m02_mef_1_swordmaiden", "m02_mef_1_assassin", "m02_mef_1_footknight")
upgrade2(troops,"m02_mef_1_viragocav", "m02_mef_1_viragoheroine", "m02_mef_1_maidenofwar")

#Manhunter(Glory Seeking Man) Changed and completed by Silberfalke
upgrade2(troops,"farmer", "m03_gsm_gloryseekingman","k00_per_recruit")
upgrade2(troops,"m03_gsm_gloryseekingman","m03_gsm_volunteer","m03_gsm_villageguard")
upgrade(troops,"m03_gsm_volunteer","m03_gsm_bountyscout")
upgrade(troops,"m03_gsm_bountyscout","m03_gsm_bountyhunter")
upgrade2(troops,"m03_gsm_bountyhunter","m03_gsm_elitebountyhunter","m03_gsm_inspector")
upgrade2(troops,"m03_gsm_inspector","m03_gsm_captain","m03_gsm_sheriff")
#Manhunter Infantry
upgrade(troops,"m03_gsm_villageguard","m03_gsm_cityguard")
upgrade(troops,"m03_gsm_cityguard","m03_gsm_sergeant")
upgrade(troops,"m03_gsm_sergeant","m03_gsm_inspector")

#Freelancers
upgrade2(troops,"m04_frg_i_recruit", "m04_frg_i_soldier", "m04_frg_a_archer")
upgrade2(troops,"m04_frg_i_soldier", "m04_frg_i_infantry", "m04_frg_c_rider")
upgrade(troops,"m04_frg_i_infantry", "m04_frg_i_swordsmaster")
upgrade(troops,"m04_frg_i_swordsmaster", "m04_frg_i_dismknight")
#freelancer knights
upgrade(troops,"m04_frg_c_rider", "m04_frg_c_squire")
upgrade(troops,"m04_frg_c_squire", "m04_frg_c_knight")
upgrade(troops,"m04_frg_c_knight", "m04_frg_c_marshal")
#freelancer archers
upgrade(troops,"m04_frg_a_archer", "m04_frg_a_vetarcher")
upgrade(troops,"m04_frg_a_vetarcher", "m04_frg_a_masterarcher")
upgrade(troops,"m04_frg_a_masterarcher", "m04_frg_a_sharpshooter")

#Player's mercs
upgrade2(troops,"m10_pmc_i_recruit", "m10_pmc_i_soldier", "m10_pmc_a_archer")
upgrade2(troops,"m10_pmc_i_soldier", "m10_pmc_i_warrior", "m10_pmc_c_rider")
upgrade(troops,"m10_pmc_i_warrior", "m10_pmc_i_vetwarrior")
upgrade2(troops,"m10_pmc_i_vetwarrior", "m10_pmc_i_footknight", "m10_pmc_i_defender")
#
upgrade(troops,"m10_pmc_c_rider", "m10_pmc_c_cavalry")
upgrade2(troops,"m10_pmc_c_cavalry", "m10_pmc_c_knight", "m10_pmc_c_horsearcher")
#
upgrade(troops,"m10_pmc_a_archer", "m10_pmc_a_vetarcher")
upgrade(troops,"m10_pmc_a_vetarcher", "m10_pmc_a_masterarcher")
upgrade(troops,"m10_pmc_a_masterarcher", "m10_pmc_a_sharpshooter")

# Perisno Pioneers
upgrade(troops,"settler","pioneer")
upgrade(troops,"pioneer","pioneer_adventurer")

upgrade(troops,"jin_guardsman","jin_impguardsman")

#Foreign Invaders
upgrade(troops,"foreign_invader","foreign_warlord")

#Slave Rebels /Silberfalke-slave 2nd upgrade path added
upgrade2(troops,"slave_male", "trained_slave","m03_gsm_gloryseekingman")
upgrade(troops,"trained_slave", "veteran_slave")
upgrade(troops,"veteran_slave", "gladiator")
#Desouk
upgrade2(troops,"desouk_female_slave", "m02_mef_1_campdefender","m02_mef_2_archer")

#Volheere Raiders
upgrade2(troops,"volheere_raider", "strong_volheere_raider","sea_archer")
upgrade(troops,"strong_volheere_raider", "sea_barbarian")

#Illica Falki
upgrade(troops,"illica_hunter", "illica_rider")
upgrade2(troops,"illica_rider", "illica_knight", "illica_ranger")

#Silberfalke Advanced Bandits
upgrade(troops,"ou_looter","ou_bandit")
upgrade(troops,"ou_bandit","ou_wandering_criminal")
upgrade(troops,"ou_wandering_criminal","ou_brigand")
upgrade(troops,"ou_brigand","ou_marauder")
upgrade(troops,"ou_marauder","ou_vanquisher")
upgrade(troops,"ou_vanquisher","ou_knight_of_doom")
#
upgrade(troops,"ou_dwarf","ou_dwarfaxeman")
upgrade(troops,"ou_dwarfaxeman","ou_dwarfinfantry")
upgrade(troops,"ou_dwarfinfantry","ou_dwarfaxemaster")
upgrade(troops,"ou_dwarfaxemaster","ou_dwarfwhatever")
#
upgrade(troops,"ou_redinitiate","ou_scarletsnake")
upgrade(troops,"ou_scarletsnake","ou_redsnake")
upgrade(troops,"ou_redsnake","ou_maroonsnake")
upgrade(troops,"ou_maroonsnake","ou_maroonviper")


#Saccar Raiders
upgrade(troops,"saccar_raider","saccar_chieftain")
#Sandwalkers
upgrade(troops,"desert_bandit","sandstalker")
#Escaped Prisoners new tree connections
upgrade(troops,"mountain_bandit","war_prisoner")
upgrade2(troops,"war_prisoner","m03_gsm_bountyhunter","m01_mem_c_cavalry")

#Mosoru (Michadr)
upgrade(troops,"mosoru_rider","mosoru_battle_rider")
upgrade(troops,"mosoru_battle_rider","mosoru_war_rider")
upgrade(troops,"mosoru_war_rider","mosoru_warlord")
upgrade(troops,"mosoru_maiden_rider","mosoru_maiden_cavalry")

#Wolf Knights
upgrade(troops,"wolf_page", "wolf_squire")
upgrade(troops,"wolf_squire", "wolf_knight")
upgrade(troops,"wolf_knight", "wolf_elder")

#Imperial Scouts
upgrade(troops,"imperial_scout", "seasoned_imperial_scout")

#Eagle Knights
upgrade(troops,"eagle_retainer","eagle_knight")
upgrade(troops,"eagle_knight","eagle_lord")

#Demon Worshippers
upgrade(troops,"demon_worshipper","demon_priest")
upgrade(troops,"demon_priest","demon_lord")

#Order of Faith (completed by Silberfalke)
upgrade(troops,"faith_disciple", "faith_defender")

#Hakkon Inquisition
upgrade(troops,"inquisition_acolyte", "hakkon_low_inquisitor")
upgrade(troops,"hakkon_low_inquisitor", "hakkon_inquisitor")

# modmerger_start version=201 type=2
try:
	component_name = "troops"
	var_set = { "troops" : troops }
	from modmerger import modmerge
	modmerge(var_set)
except:
	raise
# modmerger_end
